/*  
 *  - - - - - - - - - - - - - 
 *   g a l _ d a y s 2 c a l  
 *  - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine converts the day of the year, days, to Gregorian 
 *     year, month, day, and fraction of a day.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     year                i        Year 
 *     days                d        Days of the year and fraction of day  
 * 
 *  Returned:
 *  
 *     *iy                 i        Year  
 *     *im                 i        Month  
 *     *id                 i        Day  
 *     *fd                 d        Fraction of day  
 *  
 *  Notes:
 *
 *  1) In early eras the conversion is from the "Proleptic Gregorian  
 *     Calendar";  no account is taken of the date(s) of adoption of  
 *     the Gregorian Calendar, nor is the AD/BC numbering convention  
 *     observed.  
 *
 *  This revision:
 *  
 *     2008 April 6   
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_days2cal.h"
#include <math.h>
  
void  
gal_days2cal  
 (  
    int year,  
    double days,  
    int *iy,  
    int *im,  
    int *id,  
    double *fd  
 ) 
 
{

  int MTAB[] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 } ;

  int i, inttemp, dayofyr;

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  if ( year % 100 == 0 && year % 400 != 0 ) {  
    MTAB[1] = 28 ;  
  }  
  else if ( year % 4 == 0 ) {  
    MTAB[1] = 29 ;  
  }  
  else {  
    MTAB[1] = 28 ;  
  }
  dayofyr = ( int ) floor ( days ) ;
  
/* 
 * Find month and day of month 
 */

  i = 0 ;
  inttemp = 0 ;
  while ( dayofyr > inttemp + MTAB[i] && i < 11 ) {
    inttemp += MTAB[i] ;
    i++ ;
  }
  *iy = year ;
  *im = i + 1 ;
  *id = dayofyr - inttemp ;
  *fd = days - dayofyr ;
  
/*  
 * Finished.  
 */  
 
 }
 
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
