/*  
 *  - - - - - - - - - - - -
 *   g a l _ u t c 2 u t 1  
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine converts a UTC jd date to a UT1 jd date.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     utc1                d        UTC date part 1 ( see Note 1 )
 *     utc2                d        UTC date part 2 ( see Note 1 )
 *     dut1                d        UT1 - UTC ( seconds )  
 *  
 *  Returned:
 *  
 *     *ut1                d        UT1 date part 1 ( see Note 1 )  
 *     *ut2                d        UT1 date part 2 ( see Note 1 ) 
 *  
 *  Notes:
 *
 *  1) The Julian Date is apportioned in any convenient way between  
 *     the arguments tai1 and tai2.  For example, JD=2450123.7 could  
 *     be expressed in any of these ways, among others:  
 *  
 *              utc1         utc2  
 *  
 *         2450123.7          0.0   (JD method)  
 *         2451545.0      -1421.3   (J2000 method)  
 *         2400000.5      50123.2   (MJD method)  
 *         2450123.5          0.2   (date & time method)  
 *  
 *  This revision:
 *  
 *     2008 April 13  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_utc2ut1.h"
#include "gal_const.h"
  
void 
gal_utc2ut1  
 (  
    double utc1,
    double utc2,
    double dut1,
    double *ut1a,
    double *ut1b
 ) 
 
{
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  *ut1a = utc1 ;
  *ut1b = utc2 + dut1 / GAL_D2S ;
   
/*  
 * Finished.  
 */  
 
}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
