/*  
 *  - - - - - - - - - - - - - - - - - - - - - - 
 *   g a l _ t p r e c n u t - ( m a i n . c )  
 *  - - - - - - - - - - - - - - - - - - - - - - 
 *  
 *  This program is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This program runs the test suite for the precnut sub-library
 *  
 *  Status: 
 *  
 *     Library test program  
 *  
 *  Returned:  
 *  
 *     gal_tprecnut     i           0 is returned if all the tests pass, 
 *                                  1 is returned if any of the tests fail
 *  
 *  Called:  
 *  
 *     gal_test_start               Initialize and start the test run
 *     gal_test_stop                Stop the test run and output the statistics
 *     gal_bi00_test                gal_bi00 test routine
 *     gal_bp00_test                gal_bp00 test routine  
 *     gal_bp06_test                gal_bp06 test routine  
 *     gal_bpn2xy_test              gal_bp2xy test routine  
 *     gal_c2i00a_test              gal_c2i00a test routine  
 *     gal_c2i00b_test              gal_c2i00b test routine  
 *     gal_c2i06a_test              gal_c2i06a test routine  
 *     gal_c2ibpn_test              gal_c2ibpn test routine  
 *     gal_c2ixy_test               gal_c2ixy test routine  
 *     gal_c2ixys_test              gal_c2ixys test routine  
 *     gal_c2t00a_test              gal_c2t00a test routine  
 *     gal_c2t00b_test              gal_c2t00b test routine  
 *     gal_c2t06a_test              gal_c2t06a test routine  
 *     gal_c2tcio_test              gal_c2tcio test routine  
 *     gal_c2teqx_test              gal_c2teqx test routine  
 *     gal_c2tpe_test               gal_c2tpe test routine  
 *     gal_c2txy_test               gal_c2txy test routine  
 *     gal_eo06a_test               gal_eo06a test routine  
 *     gal_eors_test                gal_eors test routine  
 *     gal_fad03_test               gal_fad03 test routine  
 *     gal_fae03_test               gal_fae03 test routine  
 *     gal_faf03_test               gal_faf03 test routine  
 *     gal_faju03_test              gal_faju03 test routine  
 *     gal_fal03_test               gal_fal03 test routine  
 *     gal_falp03_test              gal_falp03 test routine  
 *     gal_fama03_test              gal_fama03 test routine  
 *     gal_fame03_test              gal_fame03 test routine  
 *     gal_fane03_test              gal_fane03 test routine  
 *     gal_faom03_test              gal_faom03 test routine  
 *     gal_fapa03_test              gal_fapa03 test routine  
 *     gal_fasa03_test              gal_fasa03 test routine  
 *     gal_faur03_test              gal_faur03 test routine  
 *     gal_fave03_test              gal_fave03 test routine  
 *     gal_fw2m_test                gal_fw2m test routine  
 *     gal_fw2xy_test               gal_fw2xy test routine  
 *     gal_num00a_test              gal_num00a test routine  
 *     gal_num00b_test              gal_num00b test routine  
 *     gal_num06a_test              gal_num06a test routine  
 *     gal_numat_test               gal_numat test routine  
 *     gal_nut00a_test              gal_nut00a test routine  
 *     gal_nut00b_test              gal_nut00b test routine  
 *     gal_nut06a_test              gal_nut06a test routine  
 *     gal_nut80_test               gal_nut80 test routine  
 *     gal_nutm80_test              gal_nutm80 test routine  
 *     gal_obl06_test               gal_onl06 test routine  
 *     gal_obl80_test               gal_obl80 test routine  
 *     gal_p06e_test                gal_p06e test routine  
 *     gal_pb06_test                gal_pb06 test routine  
 *     gal_pfw06_test               gal_pfw06 test routine  
 *     gal_pmat00_test              gal_pmat00 test routine  
 *     gal_pmat06_test              gal_pmat06 test routine  
 *     gal_pmat76_test              gal_pmat76 test routine  
 *     gal_pn00_test                gal_pn00 test routine  
 *     gal_pn00a_test               gal_pn00a test routine  
 *     gal_pn00b_test               gal_pn00b test routine  
 *     gal_pn06_test                gal_pn06 test routine  
 *     gal_pn06a_test               gal_pn06a test routine  
 *     gal_pnm00a_test              gal_pnm00a test routine  
 *     gal_pnm00b_test              gal_pnm00b test routine  
 *     gal_pnm06a_test              gal_pnm06a test routine  
 *     gal_pnm80_test               gal_pnm80 test routine  
 *     gal_pom00_test               gal_pom00 test routine  
 *     gal_pr00_test                gal_pr00 test routine  
 *     gal_prec76_test              gal_prec76 test routine  
 *     gal_s00_test                 gal_s00 test routine  
 *     gal_s00a_test                gal_s00a test routine  
 *     gal_s00b_test                gal_s00b test routine  
 *     gal_s06_test                 gal_s06 test routine  
 *     gal_s06a_test                gal_s06a test routine  
 *     gal_sp00_test                gal_sp00 test routine  
 *     gal_xy06_test                gal_xy06 test routine  
 *     gal_xys00a_test              gal_xys00a test routine  
 *     gal_xys00b_test              gal_xys00b test routine  
 *     gal_xys06a_test              gal_xys06a test routine
 *  
 *  This revision:  
 * 
 *     2008 March 15 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_test_common.h"
#include "gal_test.h"
#include "gal_bi00_test.h"
#include "gal_bp00_test.h"  
#include "gal_bp06_test.h"  
#include "gal_bpn2xy_test.h"  
#include "gal_c2i00a_test.h"  
#include "gal_c2i00b_test.h"  
#include "gal_c2i06a_test.h" 
#include "gal_c2ibpn_test.h"  
#include "gal_c2ixy_test.h"  
#include "gal_c2ixys_test.h"  
#include "gal_c2t00a_test.h"  
#include "gal_c2t00b_test.h"  
#include "gal_c2t06a_test.h"  
#include "gal_c2tcio_test.h"  
#include "gal_c2teqx_test.h"  
#include "gal_c2tpe_test.h"  
#include "gal_c2txy_test.h"  
#include "gal_eo06a_test.h"  
#include "gal_eors_test.h"  
#include "gal_fad03_test.h"  
#include "gal_fae03_test.h"  
#include "gal_faf03_test.h"  
#include "gal_faju03_test.h"  
#include "gal_fal03_test.h" 
#include "gal_falp03_test.h"  
#include "gal_fama03_test.h"  
#include "gal_fame03_test.h"  
#include "gal_fane03_test.h"  
#include "gal_faom03_test.h"  
#include "gal_fapa03_test.h"  
#include "gal_fasa03_test.h"  
#include "gal_faur03_test.h" 
#include "gal_fave03_test.h"  
#include "gal_fw2m_test.h"  
#include "gal_fw2xy_test.h"  
#include "gal_num00a_test.h"  
#include "gal_num00b_test.h"  
#include "gal_num06a_test.h"  
#include "gal_numat_test.h"  
#include "gal_nut00a_test.h"  
#include "gal_nut00b_test.h"  
#include "gal_nut06a_test.h"  
#include "gal_nut80_test.h"  
#include "gal_nutm80_test.h"  
#include "gal_obl06_test.h"  
#include "gal_obl80_test.h"  
#include "gal_p06e_test.h"  
#include "gal_pb06_test.h"  
#include "gal_pfw06_test.h"  
#include "gal_pmat00_test.h"  
#include "gal_pmat06_test.h"  
#include "gal_pmat76_test.h"  
#include "gal_pn00_test.h"  
#include "gal_pn00a_test.h"  
#include "gal_pn00b_test.h"  
#include "gal_pn06_test.h"  
#include "gal_pn06a_test.h" 
#include "gal_pnm00a_test.h"  
#include "gal_pnm00b_test.h"  
#include "gal_pnm06a_test.h"  
#include "gal_pnm80_test.h"  
#include "gal_pom00_test.h"  
#include "gal_pr00_test.h"  
#include "gal_prec76_test.h"  
#include "gal_s00_test.h"  
#include "gal_s00a_test.h"  
#include "gal_s00b_test.h"  
#include "gal_s06_test.h"  
#include "gal_s06a_test.h"  
#include "gal_sp00_test.h"  
#include "gal_xy06_test.h"  
#include "gal_xys00a_test.h"  
#include "gal_xys00b_test.h" 
#include "gal_xys06a_test.h"

int
main
  (
  )
  
{

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_test_start ( "Precession, Nutation & Polar Motion", 0 ) ;
  
  gal_bi00_test   () ;
  gal_bp00_test   () ;  
  gal_bp06_test   () ;  
  gal_bpn2xy_test () ;  
  gal_c2i00a_test () ;  
  gal_c2i00b_test () ;  
  gal_c2i06a_test () ; 
  gal_c2ibpn_test () ;  
  gal_c2ixy_test  () ;  
  gal_c2ixys_test () ;  
  gal_c2t00a_test () ;  
  gal_c2t00b_test () ;  
  gal_c2t06a_test () ;  
  gal_c2tcio_test () ;  
  gal_c2teqx_test () ;  
  gal_c2tpe_test  () ;  
  gal_c2txy_test  () ;  
  gal_eo06a_test  () ;  
  gal_eors_test   () ;  
  gal_fad03_test  () ;  
  gal_fae03_test  () ;  
  gal_faf03_test  () ;  
  gal_faju03_test () ;  
  gal_fal03_test  () ; 
  gal_falp03_test () ;  
  gal_fama03_test () ;  
  gal_fame03_test () ;  
  gal_fane03_test () ;  
  gal_faom03_test () ; 
  gal_fapa03_test () ;  
  gal_fasa03_test () ;  
  gal_faur03_test () ; 
  gal_fave03_test () ;  
  gal_fw2m_test   () ;  
  gal_fw2xy_test  () ;  
  gal_num00a_test () ;  
  gal_num00b_test () ; 
  gal_num06a_test () ;  
  gal_numat_test  () ;  
  gal_nut00a_test () ;  
  gal_nut00b_test () ;  
  gal_nut06a_test () ;  
  gal_nut80_test  () ; 
  gal_nutm80_test () ;  
  gal_obl06_test  () ;  
  gal_obl80_test  () ;  
  gal_p06e_test   () ;  
  gal_pb06_test   () ;  
  gal_pfw06_test  () ;  
  gal_pmat00_test () ;  
  gal_pmat06_test () ;  
  gal_pmat76_test () ;  
  gal_pn00_test   () ;  
  gal_pn00a_test  () ;  
  gal_pn00b_test  () ;  
  gal_pn06_test   () ; 
  gal_pn06a_test  () ; 
  gal_pnm00a_test () ;  
  gal_pnm00b_test () ;  
  gal_pnm06a_test () ;  
  gal_pnm80_test  () ;  
  gal_pom00_test  () ;  
  gal_pr00_test   () ;  
  gal_prec76_test () ;  
  gal_s00_test    () ; 
  gal_s00a_test   () ;  
  gal_s00b_test   () ;  
  gal_s06_test    () ;  
  gal_s06a_test   () ;  
  gal_sp00_test   () ;  
  gal_xy06_test   () ;  
  gal_xys00a_test () ;  
  gal_xys00b_test () ; 
  gal_xys06a_test () ;
  
  return gal_test_stop () ;
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
