/*  
 *  - - - - - - - - - - - - - - - - - - -
 *   g a l _ e m d e t a i l s _ t e s t  
 *  - - - - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine tests the gal_emdetails routine
 *  
 *  Status: 
 *  
 *     Internal test routine  
 *  
 *  Called:  
 *  
 *     gal_emdetails                Get full details of Ellipsoid Model
 *     gal_vdv                      Verify double value
 *     gal_viv                      Verify integer value
 *     gal_vsv                      Verify string value
 *  
 *  This revision:  
 * 
 *     2009 January 6 
 *  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_emdetails_test.h"
#include "gal_emdetails.h"
#include "gal_test.h"
#include "gal_ellipsoids.h"
#include "gal_const.h"

void
gal_emdetails_test
  (
  ) 
{

  extern int gal_tfunc ;

  char name[40] ;
  
  int body ;
  
  double sma, inf ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Check Model Identifier Out of Range Conditions
 */
 
  gal_viv ( gal_emdetails (   -1, &body, name, &sma, &inf ) , 1, "gal_emdetails", "a 0" ) ;
  gal_viv ( gal_emdetails ( 1000, &body, name, &sma, &inf ) , 1, "gal_emdetails", "a 1" ) ;
  gal_vsv ( name, "", "gal_emdetails", "name 0" ) ;
  gal_viv ( gal_emdetails ( GAL_EMEA_INTL1909, &body, name, &sma, &inf ) , 0, "gal_emdetails", "a 1" ) ;
  gal_viv ( body, GAL_SSB_EA, "gal_emdetails", "body" ) ;
  gal_vsv ( name, "International 1909", "gal_emdetails", "name 1" ) ;

/*
 * Check parameters, these were transcribed separately from those in the
 * lookup table, so as to check for transcription errors.
 */
 
  gal_emdetails ( GAL_EMEA_AIRY1830, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6377563.396, 0.0, "gal_emdetails", "sma 0" ) ; 
  gal_vdv ( inf,  299.324964, 0.0, "gal_emdetails", "inf 0" ) ; 

  gal_emdetails ( GAL_EMEA_EVER1830, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6377276.345, 0.0, "gal_emdetails", "sma 1" ) ; 
  gal_vdv ( inf,    300.8017, 0.0, "gal_emdetails", "inf 1" ) ; 

  gal_emdetails ( GAL_EMEA_EVER1830BA, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6377301.243, 0.0, "gal_emdetails", "sma 2" ) ; 
  gal_vdv ( inf,    300.8017, 0.0, "gal_emdetails", "inf 2" ) ; 

  gal_emdetails ( GAL_EMEA_BESL1841, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6377397.155, 0.0, "gal_emdetails", "sma 3" ) ; 
  gal_vdv ( inf,  299.152813, 0.0, "gal_emdetails", "inf 3" ) ; 

  gal_emdetails ( GAL_EMEA_CL1866, &body, name, &sma, &inf ) ;
  gal_vdv ( sma,  6378206.4, 0.0, "gal_emdetails", "sma 4" ) ; 
  gal_vdv ( inf, 294.978698, 0.0, "gal_emdetails", "inf 4" ) ; 

  gal_emdetails ( GAL_EMEA_CL1880, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378249.145, 0.0, "gal_emdetails", "sma 5" ) ; 
  gal_vdv ( inf,     293.465, 0.0, "gal_emdetails", "inf 5" ) ; 

  gal_emdetails ( GAL_EMEA_CLA1880M, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378249.145, 0.0, "gal_emdetails", "sma 6" ) ; 
  gal_vdv ( inf,    293.4663, 0.0, "gal_emdetails", "inf 6" ) ; 

  gal_emdetails ( GAL_EMEA_HEL1906, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378200.0, 0.0, "gal_emdetails", "sma 7" ) ; 
  gal_vdv ( inf,     298.3, 0.0, "gal_emdetails", "inf 7" ) ; 

  gal_emdetails ( GAL_EMEA_INTL1909, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378388.0, 0.0, "gal_emdetails", "sma 8" ) ; 
  gal_vdv ( inf,     297.0, 0.0, "gal_emdetails", "inf 8" ) ; 

  gal_emdetails ( GAL_EMEA_KRSV, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378245.0, 0.0, "gal_emdetails", "sma 9" ) ; 
  gal_vdv ( inf,     298.3, 0.0, "gal_emdetails", "inf 9" ) ; 

  gal_emdetails ( GAL_EMEA_MERC1960, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378166.0, 0.0, "gal_emdetails", "sma 10" ) ; 
  gal_vdv ( inf,     298.3, 0.0, "gal_emdetails", "inf 10" ) ; 

  gal_emdetails ( GAL_EMEA_WGS1960, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378165.0, 0.0, "gal_emdetails", "sma 11" ) ; 
  gal_vdv ( inf,     298.3, 0.0, "gal_emdetails", "inf 11" ) ; 

  gal_emdetails ( GAL_EMEA_IAU1964, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378160.0, 0.0, "gal_emdetails", "sma 12" ) ; 
  gal_vdv ( inf,    298.25, 0.0, "gal_emdetails", "inf 12" ) ; 

  gal_emdetails ( GAL_EMEA_AUSNAT1965, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378160.0, 0.0, "gal_emdetails", "sma 13" ) ; 
  gal_vdv ( inf,    298.25, 0.0, "gal_emdetails", "inf 13" ) ; 

  gal_emdetails ( GAL_EMEA_WGS1966, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378145.0, 0.0, "gal_emdetails", "sma 14" ) ; 
  gal_vdv ( inf,    298.25, 0.0, "gal_emdetails", "inf 14" ) ; 

  gal_emdetails ( GAL_EMEA_MERC1968M, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378150.0, 0.0, "gal_emdetails", "sma 15" ) ; 
  gal_vdv ( inf,     298.3, 0.0, "gal_emdetails", "inf 15" ) ; 

  gal_emdetails ( GAL_EMEA_SA1969, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378160.0, 0.0, "gal_emdetails", "sma 16" ) ; 
  gal_vdv ( inf,    298.25, 0.0, "gal_emdetails", "inf 16" ) ; 

  gal_emdetails ( GAL_EMEA_GRS1967, &body, name, &sma, &inf ) ;
  gal_vdv ( sma,      6378160.0, 0.0, "gal_emdetails", "sma 17" ) ; 
  gal_vdv ( inf, 298.2471674273, 0.0, "gal_emdetails", "inf 17" ) ; 

  gal_emdetails ( GAL_EMEA_WGS1972, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378135.0, 0.0, "gal_emdetails", "sma 18" ) ; 
  gal_vdv ( inf,    298.26, 0.0, "gal_emdetails", "inf 18" ) ; 

  gal_emdetails ( GAL_EMEA_IAG1975, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378140.0, 0.0, "gal_emdetails", "sma 19" ) ; 
  gal_vdv ( inf,   298.256, 0.0, "gal_emdetails", "inf 19" ) ; 

  gal_emdetails ( GAL_EMEA_IAU1976, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378140.0, 0.0, "gal_emdetails", "sma 20" ) ; 
  gal_vdv ( inf,   298.257, 0.0, "gal_emdetails", "inf 20" ) ; 

  gal_emdetails ( GAL_EMEA_GRS1980, &body, name, &sma, &inf ) ;
  gal_vdv ( sma,     6378137.0, 0.0, "gal_emdetails", "sma 21" ) ; 
  gal_vdv ( inf, 298.257222101, 0.0, "gal_emdetails", "inf 21" ) ; 

  gal_emdetails ( GAL_EMEA_MERIT1983, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378137.0, 0.0, "gal_emdetails", "sma 22" ) ; 
  gal_vdv ( inf,   298.257, 0.0, "gal_emdetails", "inf 22" ) ; 

  gal_emdetails ( GAL_EMEA_WGS1984, &body, name, &sma, &inf ) ;
  gal_vdv ( sma,     6378137.0, 0.0, "gal_emdetails", "sma 23" ) ; 
  gal_vdv ( inf, 298.257223563, 0.0, "gal_emdetails", "inf 23" ) ; 

  gal_emdetails ( GAL_EMEA_IERS1989, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378136.0, 0.0, "gal_emdetails", "sma 24" ) ; 
  gal_vdv ( inf,   298.257, 0.0, "gal_emdetails", "inf 24" ) ; 

  gal_emdetails ( GAL_EMEA_DEL1800, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6375653.0, 0.0, "gal_emdetails", "sma 25" ) ; 
  gal_vdv ( inf,     334.0, 0.0, "gal_emdetails", "inf 25" ) ; 

  gal_emdetails ( GAL_EMEA_IERS2000, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378136.6, 0.0, "gal_emdetails", "sma 24" ) ; 
  gal_vdv ( inf, 298.25642, 0.0, "gal_emdetails", "inf 24" ) ; 

  gal_emdetails ( GAL_EMME_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 2439700.0, 0.0, "gal_emdetails", "sma 25" ) ; 
  gal_vdv ( inf,       0.0, 0.0, "gal_emdetails", "inf 25" ) ; 

  gal_emdetails ( GAL_EMVE_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6501900.0, 0.0, "gal_emdetails", "sma 26" ) ; 
  gal_vdv ( inf,       0.0, 0.0, "gal_emdetails", "inf 26" ) ; 

  gal_emdetails ( GAL_EMEA_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 6378140.0, 0.0, "gal_emdetails", "sma 27" ) ; 
  gal_vdv ( inf,   298.257, 0.0, "gal_emdetails", "inf 27" ) ; 

  gal_emdetails ( GAL_EMMA_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 3397000.0, 0.0, "gal_emdetails", "sma 28" ) ; 
  gal_vdv ( inf,   153.846, 0.0, "gal_emdetails", "inf 28" ) ; 

  gal_emdetails ( GAL_EMJU_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 71492000.0, 0.0, "gal_emdetails", "sma 29" ) ; 
  gal_vdv ( inf,    15.4154, 0.0, "gal_emdetails", "inf 29" ) ; 

  gal_emdetails ( GAL_EMSA_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 60268000.0, 0.0, "gal_emdetails", "sma 30" ) ; 
  gal_vdv ( inf,    10.2082, 0.0, "gal_emdetails", "inf 30" ) ; 

  gal_emdetails ( GAL_EMUR_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 25559000.0, 0.0, "gal_emdetails", "sma 31" ) ; 
  gal_vdv ( inf,     43.611, 0.0, "gal_emdetails", "inf 31" ) ; 

  gal_emdetails ( GAL_EMNE_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 24764000.0, 0.0, "gal_emdetails", "sma 32" ) ; 
  gal_vdv ( inf,    58.4795, 0.0, "gal_emdetails", "inf 32" ) ; 

  gal_emdetails ( GAL_EMPL_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 1151000.0, 0.0, "gal_emdetails", "sma 33" ) ; 
  gal_vdv ( inf,       0.0, 0.0, "gal_emdetails", "inf 33" ) ; 

  gal_emdetails ( GAL_EMPL_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma, 1151000.0, 0.0, "gal_emdetails", "sma 33" ) ; 
  gal_vdv ( inf,       0.0, 0.0, "gal_emdetails", "inf 33" ) ; 

  gal_emdetails ( GAL_EMSU_IAU1991, &body, name, &sma, &inf ) ;
  gal_vdv ( sma,    6.96e8, 0.0, "gal_emdetails", "sma 34" ) ; 
  gal_vdv ( inf,       0.0, 0.0, "gal_emdetails", "inf 34" ) ; 

  gal_tfunc++ ;
    
/*  
 * Finished.  
 */  

}
 
/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
