/*  
 *  - - - - - - - - - - - - - - - - -
 *   g a l _ g s u p v 0 0 _ t e s t  
 *  - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_gsupv00 routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_gsupv00  
 *     gal_viv  
 *     gal_vdv 
 *     gal_cal2jd
 *
 *  References:
 *
 *     Astronomical Almanac 1997
 *     Pages C20-C23 
 *  
 *  This Revision:
 *  
 *     2008 May 26  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_gsupv00_test.h"
#include "gal_gsupv00.h"
#include "gal_test.h"
#include "gal_cal2jd.h"
#include "gal_const.h"
  
void  
gal_gsupv00_test  
 (  
 ) 
 
{
  
  double pv[2][3], tt1, tt2 ;
  int j ;  
  
  extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  


  j = gal_cal2jd ( 1997, 4, 1, &tt1, &tt2 ) ; /* TT */
  
  gal_viv ( gal_gsupv00 ( tt1, tt2, pv ) , 0, "gal_gsupv00", "a 0" ) ;  
  
  gal_vdv ( pv[0][0], 0.9797435 * GAL_AU03, 1e+4, "gal_gsupv00", "pv[0][0] 0" ) ;  
  gal_vdv ( pv[0][1], 0.1804075 * GAL_AU03, 1e+5, "gal_gsupv00", "pv[0][1] 0" ) ;  
  gal_vdv ( pv[0][2], 0.0782229 * GAL_AU03, 1e+5, "gal_gsupv00", "pv[0][2] 0" ) ;  

  j = gal_cal2jd ( 1997, 11, 11, &tt1, &tt2 ) ; /* TT */
  
  gal_viv ( gal_gsupv00 ( tt1, tt2, pv ) , 0, "gal_gsup00", "a 1" ) ;  
  
  gal_vdv ( pv[0][0], -0.6538586 * GAL_AU03, 1e+4, "gal_gsupv00", "pv[0][0] 1" ) ;  
  gal_vdv ( pv[0][1], -0.6820633 * GAL_AU03, 1e+4, "gal_gsupv00", "pv[0][1] 1" ) ;  
  gal_vdv ( pv[0][2], -0.2957175 * GAL_AU03, 1e+4, "gal_gsupv00", "pv[0][2] 1" ) ;  

  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
