/*  
 *  - - - - - - - - - - - - - - - - - - - - - - - - - -
 *   g a l _ t e p h e m e r i d e s - ( m a i n . c )  
 *  - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  
 *  This program is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This program runs the test suite for the ephemerides sub-library
 *  
 *  Status: 
 *  
 *     Library test program  
 *  
 *  Returned:  
 *  
 *     gal_tephemerides i           0 is returned if all the tests pass, 
 *                                  1 is returned if any of the tests fail
 *  
 *  Called:  
 *  
 *     gal_test_start               Initialize and start the test run
 *     gal_test_stop                Stop the test run and output the statistics
 *     gal_epv00_test               gal_epv00 test routine  
 *     gal_plan94_test              gal_plan94 test routine
 *     gal_gsupv00_test             gal_gsupv00 test routine 
 *     gal_gmopv02_test             gal_gmopv02 test routine 
 *     gal_vsop87_test              gal_vsop87 test routine
 *     gal_hmepv87_test             gal_hmepv87 test routine  
 *     gal_hvepv87_test             gal_hvepv87 test routine  
 *     gal_heapv87_test             gal_heapv87 test routine  
 *     gal_hebpv87_test             gal_hebpv87 test routine  
 *     gal_hmapv87_test             gal_hmapv87 test routine  
 *     gal_hjupv87_test             gal_hjupv87 test routine  
 *     gal_hsapv87_test             gal_hsapv87 test routine  
 *     gal_hurpv87_test             gal_hurpv87 test routine  
 *     gal_hnepv87_test             gal_hnepv87 test routine  
 *     gal_hplpv87_test             gal_hplpv87 test routine  
 *     gal_bsupv87_test             gal_bsupv87 test routine  
 *     gal_bmepv87_test             gal_bmepv87 test routine  
 *     gal_bvepv87_test             gal_bvepv87 test routine  
 *     gal_beapv87_test             gal_beapv87 test routine  
 *     gal_bebpv87_test             gal_bebpv87 test routine  
 *     gal_bmapv87_test             gal_bmapv87 test routine  
 *     gal_bjupv87_test             gal_bjupv87 test routine  
 *     gal_bsapv87_test             gal_bsapv87 test routine  
 *     gal_burpv87_test             gal_burpv87 test routine  
 *     gal_bnepv87_test             gal_bnepv87 test routine  
 *     gal_bplpv87_test             gal_bplpv87 test routine  
 *  
 *  This revision:  
 * 
 *     2008 June 29 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdio.h>
#include "gal_pstrings.h"
#include "gal_test_common.h"
#include "gal_test.h"
#include "gal_epv00_test.h"
#include "gal_plan94_test.h"
#include "gal_gsupv00_test.h"
#include "gal_gmopv02_test.h"
#include "gal_vsop87_test.h"
#include "gal_hmepv87_test.h"
#include "gal_hvepv87_test.h"
#include "gal_heapv87_test.h"
#include "gal_hebpv87_test.h"
#include "gal_hmapv87_test.h"
#include "gal_hjupv87_test.h"
#include "gal_hsapv87_test.h"
#include "gal_hurpv87_test.h"
#include "gal_hnepv87_test.h"
#include "gal_hplpv87_test.h"
#include "gal_bsupv87_test.h"
#include "gal_bmepv87_test.h"
#include "gal_bvepv87_test.h"
#include "gal_beapv87_test.h"
#include "gal_bebpv87_test.h"
#include "gal_bmapv87_test.h"
#include "gal_bjupv87_test.h"
#include "gal_bsapv87_test.h"
#include "gal_burpv87_test.h"
#include "gal_bnepv87_test.h"
#include "gal_bplpv87_test.h"

/* #include "gal_extract_vsop87_tests.h" */

int
main
  (
  )
  
{

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_test_start ( "Ephemerides", 0 ) ;
  
  gal_epv00_test   () ;
  gal_plan94_test  () ;
  gal_gsupv00_test () ;
  gal_gmopv02_test () ;
  gal_vsop87_test  () ;
  gal_hmepv87_test () ;
  gal_hvepv87_test () ;
  gal_heapv87_test () ;
  gal_hebpv87_test () ;
  gal_hmapv87_test () ;
  gal_hjupv87_test () ;
  gal_hsapv87_test () ;
  gal_hurpv87_test () ;
  gal_hnepv87_test () ;
  gal_hplpv87_test () ;
  gal_bsupv87_test () ;
  gal_bmepv87_test () ;
  gal_bvepv87_test () ;
  gal_beapv87_test () ;
/* gal_bebpv87_test () ; */ /* <- In production this was tested using Earth instead of EMB */
  gal_bmapv87_test () ;
  gal_bjupv87_test () ;
  gal_bsapv87_test () ;
  gal_burpv87_test () ;
  gal_bnepv87_test () ;
  gal_bplpv87_test () ;
  
/*  gal_extract_vsop87_tests("/Users/Paul/Desktop/vsop87.chk","/Users/Paul/Desktop/vsop87x.c") ;
 */
  
  return gal_test_stop () ;
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
