/*  
 *  - - - - - - - - - - - - - - - - 
 *   g a l _ v s o p 8 7 _ t e s t  
 *  - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_vsop87 routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_heapv87  
 *     gal_viv  
 *     gal_vdv  
 *  
 *  This Revision:
 *  
 *     2008 June 28  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_vsop87_test.h"
#include "gal_test.h"
#include "gal_heapv87.h"
  
void  
gal_vsop87_test  
 ( 
 )
 
{

    double pvh[2][3] ;  
  
    extern int gal_tfunc ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/* 
  VSOP87A  EARTH       JD2451545.0  01/01/2000 12h TDB
 x   -.1771354586  au       y    .9672416237  au       z   -.0000039000  au
 x'  -.0172076240  au/d     y'  -.0031587881  au/d     z'   .0000001069  au/d

 VSOP87A  EARTH       JD2415020.0  31/12/1899 12h TDB
 x   -.1883079649  au       y    .9650688844  au       z    .0002150325  au
 x'  -.0171750350  au/d     y'  -.0033577553  au/d     z'  -.0000017927  au/d

 VSOP87A  EARTH       JD2378495.0  30/12/1799 12h TDB
 x   -.1993918002  au       y    .9627974368  au       z    .0004307602  au
 x'  -.0171333880  au/d     y'  -.0035564817  au/d     z'  -.0000024864  au/d

 VSOP87A  EARTH       JD2341970.0  29/12/1699 12h TDB
 x   -.2104654652  au       y    .9603579954  au       z    .0006472929  au
 x'  -.0170875581  au/d     y'  -.0037496415  au/d     z'  -.0000029043  au/d
*/ 
    gal_heapv87 ( 2451545.0, 0.0, 0, pvh ) ;  
    gal_vdv ( pvh[0][0], -.1771354586, 1e-10, "gal_vsop87", "pvh[0][0] 0" ) ;  
    gal_vdv ( pvh[0][1],  .9672416237, 1e-10, "gal_vsop87", "pvh[0][1] 0" ) ;  
    gal_vdv ( pvh[0][2], -.0000039000, 1e-10, "gal_vsop87", "pvh[0][2] 0" ) ;  
    gal_vdv ( pvh[1][0], -.0172076240, 1e-10, "gal_vsop87", "pvh[1][0] 0" ) ;  
    gal_vdv ( pvh[1][1], -.0031587881, 1e-10, "gal_vsop87", "pvh[1][1] 0" ) ;  
    gal_vdv ( pvh[1][2],  .0000001069, 1e-10, "gal_vsop87", "pvh[1][2] 0" ) ;  
    
    gal_heapv87 ( 2415020.0, 0.0,0,  pvh ) ;  
    gal_vdv ( pvh[0][0], -.1883079649, 1e-10, "gal_vsop87", "pvh[0][0] 1" ) ;  
    gal_vdv ( pvh[0][1],  .9650688844, 1e-10, "gal_vsop87", "pvh[0][1] 1" ) ;  
    gal_vdv ( pvh[0][2],  .0002150325, 1e-10, "gal_vsop87", "pvh[0][2] 1" ) ;  
    gal_vdv ( pvh[1][0], -.0171750350, 1e-10, "gal_vsop87", "pvh[1][0] 1" ) ;  
    gal_vdv ( pvh[1][1], -.0033577553, 1e-10, "gal_vsop87", "pvh[1][1] 1" ) ;  
    gal_vdv ( pvh[1][2], -.0000017927, 1e-10, "gal_vsop87", "pvh[1][2] 1" ) ; 
    
    gal_heapv87 ( 2400000.5, 53411.52501161,1, pvh ) ;  
    gal_vdv ( pvh[0][0], -0.7757238809297653, 1e-7, "gal_vsop87", "pvh[0][0] 2" ) ;  
    gal_vdv ( pvh[0][1], +0.5598052241363390, 1e-7, "gal_vsop87", "pvh[0][1] 2" ) ;  
    gal_vdv ( pvh[0][2], +0.2426998466481708, 1e-7, "gal_vsop87", "pvh[0][2] 2" ) ;  
    gal_vdv ( pvh[1][0], -0.0109189182414732, 1e-8, "gal_vsop87", "pvh[1][0] 2" ) ;  
    gal_vdv ( pvh[1][1], -0.0124718726844084, 1e-8, "gal_vsop87", "pvh[1][1] 2" ) ;  
    gal_vdv ( pvh[1][2], -0.0054075694180650, 1e-8, "gal_vsop87", "pvh[1][2] 2" ) ;  
 
    gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  
 
}    
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
