/*  
 *  - - - - - - - - - - - - - -  
 *   g a l _ a c c h _ t e s t  
 *  - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_acch routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_acch  
 *     gal_vdv 
 *     gal_gmcpy
 *     gal_gmfree 
 *     gal_rkf
 *     gal_rkfs45
 *     gal_cal2jd
 *     gal_cp
 *     gal_rxp
 *     gal_trxp
 *     gal_utc2tt
 *     gal_c2t06a
 *  
 *  This Revision:
 *  
 *     2008 June 15
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  

#include <stdio.h>  
#include "gal_acch_test.h"
#include "gal_acch.h"
#include "gal_test.h"
#include "gal_gmcpy.h"
#include "gal_gmfree.h"
#include "gal_odeint.h"
#include "gal_const.h"
#include "gal_cal2jd.h"
#include "gal_cp.h"
#include "gal_rxp.h"
#include "gal_trxp.h"
#include "gal_utc2tt.h"
#include "gal_c2t06a.h"
#include "gal_utc2ut1.h"


static void derivs
  (
    double x, 
    double y[6], 
    double dydx[6],
    int *derivsp
  ) 

{

  gal_derivsp_t *params = ( gal_derivsp_t * ) derivsp ;
  
  double itrf[3], rc2t[3][3], a[3] ;
  double utc1, utc2, xp, yp, tta, ttb, dut1, ut1a, ut1b ;
  int j ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
 
  j = gal_cal2jd ( 2003, 1, 4, &utc1, &utc2 ) ;
  
  utc2 += x / GAL_D2S ;
  
  gal_utc2tt ( utc1, utc2, &tta, &ttb ) ; 
  
  dut1 = -0.2904331 ;

  gal_utc2ut1 ( utc1, utc2, dut1, &ut1a, &ut1b ) ;
  
  xp   = -0.097550 * GAL_AS2R ; 
  yp   =  0.195456 * GAL_AS2R ;

  gal_cp ( &y[3], &dydx[0] ) ;
  
  gal_c2t06a ( tta, ttb, ut1a, ut1b, xp, yp, rc2t ) ;

  gal_rxp ( rc2t, &y[0], itrf ) ;
  
  gal_acch ( itrf, params->gm, params->max_degree, params->max_order, a ) ; 

  gal_trxp ( rc2t, a, &dydx[3] ) ;
  
/*  
 * Finished.  
 */  
                                        
} 

void  
gal_acch_test  
 (  
 ) 
 
{

  extern int gal_tfunc ;
  
  double pbf[3] = { 6525.919e3, 1710.416e3, 2508.886e3 } ;
  
  double a[3] ;
  
  gal_gm_t *gm ;

  extern gal_gm_t gal_gmjgm3 ;
  extern gal_gm_t gal_gmegm96 ;

  
  double y[6]  = { -20320831.70000,  7859549.80000, 4411786.10000,   1491.57130,  -2771.84800,   1649.56960 } ;
  double y2[6] = {   -605790.43080, -5870230.40700, 3493052.00400, -1568.251615, -3702.348353, -6479.484915 } ;
  
  gal_derivsp_t params ;
    
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
 
  gm = gal_gmcpy ( &gal_gmjgm3, 20, 20, 0 ) ;
  
  gal_acch ( pbf, gm, 4, 4, a ) ;
  
  gal_vdv ( a[0], -6.97931189287, 1e-6, "gal_acch", "a[0]" ) ;
  gal_vdv ( a[1], -1.82931487069, 1e-7, "gal_acch", "a[1]" ) ;
  gal_vdv ( a[2], -2.68999140120, 1e-7, "gal_acch", "a[2]" ) ;
  					
  gal_gmfree ( gm ) ;
  
  params.max_degree = 24 ;
  params.max_order  = 24 ;
  params.gm = gal_gmcpy ( &gal_gmegm96, params.max_degree, params.max_order, 0 ) ;
  
  gal_rkf ( y, 6, 0.0, 70.0 * 60.0, 1e-2, 10.0, 1e-4, derivs, gal_rkfs45, ( int * ) &params ) ;

  gal_vdv ( y[0], -4514392.77882, 1e-0, "gal_acch", "y[0]" ) ;
  gal_vdv ( y[1], -4925209.76760, 1e-1, "gal_acch", "y[1]" ) ;
  gal_vdv ( y[2],  6975841.71403, 1e-1, "gal_acch", "y[2]" ) ;
  gal_vdv ( y[3],     7096.10407, 1e-4, "gal_acch", "y[3]" ) ;
  gal_vdv ( y[4],    -2138.35063, 1e-5, "gal_acch", "y[4]" ) ;
  gal_vdv ( y[5],    -2088.23436, 1e-5, "gal_acch", "y[5]" ) ;

  gal_gmfree ( params.gm ) ;

  params.max_degree = 24 ;
  params.max_order  = 24 ;
  params.gm = gal_gmcpy ( &gal_gmegm96, params.max_degree, params.max_order, 0 ) ;
  
  gal_rkf ( y2, 6, 0.0, 70.0 * 60.0, 1e-2, 10.0, 1e-4, derivs, gal_rkfs45, ( int * ) &params ) ; 
  
/*  gal_rkf ( y2, 6, 0.0, 70.0 * 60.0, 1e-8, 10.0, 1e-12, derivs, gal_rkfcks45, ( int * ) &params ) ; */
/*  gal_rkf ( y2, 6, 0.0, 70.0 * 60.0, 1e-9, 10.0, 1e-12, derivs,   gal_rkfs56, ( int * ) &params ) ; */
/*  gal_rkf ( y2, 6, 0.0, 70.0 * 60.0, 1e-9, 10.0, 1e-12, derivs,   gal_rkfs67, ( int * ) &params ) ; */
/*  gal_rkf ( y2, 6, 0.0, 70.0 * 60.0, 1e-8, 10.0, 1e-12, derivs,   gal_rkfs78, ( int * ) &params ) ; */

  gal_vdv ( y2[0], 1435740.80988, 1e-1, "gal_acch", "y2[0]" ) ;
  gal_vdv ( y2[1], 3612638.93414, 1e-1, "gal_acch", "y2[1]" ) ;
  gal_vdv ( y2[2], 5648107.96335, 1e-1, "gal_acch", "y2[2]" ) ;
  gal_vdv ( y2[3],   -591.331078, 1e-4, "gal_acch", "y2[3]" ) ;
  gal_vdv ( y2[4],  -6337.085224, 1e-4, "gal_acch", "y2[4]" ) ;
  gal_vdv ( y2[5],   4194.258097, 1e-4, "gal_acch", "y2[5]" ) ;
                
  gal_gmfree ( params.gm ) ;
  
  gal_tfunc++ ; 
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */ 

