/*  
 *  - - - - - - - - - - - - - - -  
 *   g a l _ g m c p y _ t e s t  
 *  - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_gmcpy routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_gmcpy  
 *     gal_vdv  
 *     gal_viv  
 *     gal_vsv  
 *  
 *  This Revision:
 *  
 *     2008 March 23 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include <strings.h>
#include <stdio.h>
#include "gal_gm.h"
#include "gal_gmcpy_test.h"
#include "gal_gmcpy.h"
#include "gal_test.h"
#include "gal_const.h"
  
void  
gal_gmcpy_test  
 (  
 ) 
 
{

  extern int gal_tfunc ; 
  
  extern gal_gm_t gal_gmwgs72 ;
  
  gal_gm_t *gm ;
  
  int n, m ;
  
  double c1, s1, c2, s2 ;
  
  char c[30], s[30] ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gm = gal_gmcpy ( &gal_gmwgs72, 30, 30, GAL_NORMALIZED ) ;
  
  gal_viv ( gm->body,       GAL_SSB_EA,      "gal_gmcpy", "body"       ) ;
  gal_vdv ( gm->gm,         3.986008e+14, 0, "gal_gmcpy", "gm"         ) ;
  gal_vdv ( gm->sma,        6.378135e+06, 0, "gal_gmcpy", "sma"        ) ;
  gal_viv ( gm->max_degree, 30,              "gal_gmcpy", "max_degree" ) ;
  gal_viv ( gm->max_order,  30,              "gal_gmcpy", "max_order"  ) ;
  
  for ( n = 0; n <= 30; n++ ) {
    for ( m = 0; m <= n; m++ ) {
      sprintf ( c, "c %i %i", n, m ) ;
      sprintf ( s, "s %i %i", n, m ) ;
      if ( n > 28 || m > 27 ) {
        gal_stget ( n, m, gm, &c2, &s2 ) ;
        gal_vdv ( c2, 0.0, 0.0, "gal_gmcpy", c ) ;
        gal_vdv ( s2, 0.0, 0.0, "gal_gmcpy", s ) ;
      }
      else {
        gal_stget ( n, m, &gal_gmwgs72, &c1, &s1 ) ;
        gal_stget ( n, m, gm, &c2, &s2 ) ;
        gal_vdv ( c2, c1, 0.0, "gal_gmcpy", c ) ;
        gal_vdv ( s2, s1, 0.0, "gal_gmcpy", s ) ;
      }
    }
  }
  
  gal_vsv ( gm->name, "WGS-72", "gal_gmcpy", "name" ) ;
  
  gal_gmfree ( gm ) ;
  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

