/*  
 *  - - - - - - - - - - 
 *   g a l _ s t u n f   
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This function computes the spherical terms un-normalization factor.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *facexp     gal_facexp_t     Pointer to factorial exponent lookup table
 *     n                i           degree of terms  
 *     m                i           order of terms  
 *  
 *  Returned:  
 *  
 *     gal_stunf        d           un-normalization factor
 *  
 *  Called:  
 *  
 *     gal_factorial2               compute factorial x! / y! et al
 *  
 *  References:
 *  
 *     Fundamentals of Astrodynamics and Applications
 *     by David A. Vallado, Second Section, Second Pressing
 *     Pages 519-520
 *  
 *  This revision:  
 * 
 *     2008 June 14 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <math.h>
#include "gal_stunf.h"
#include "gal_factorial2.h"

double
gal_stunf
  (
    gal_facexp_t *facexp,
    const int n,
    const int m
  ) 
  
{

  long double f ;
    
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  if ( n < 2 ) {
    return 1.0 ;
  }
  else if ( m == 0 ) {
    return sqrt ( 2.0 * n + 1.0 ) ;
  }
  else {
    gal_factorial2 ( facexp, n-m, n+m, -1, &f ) ;
    return sqrt ( ( 4 * n + 2 ) * f ) ;
  }
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
