/*  
 *  - - - - - - - - - - - - - - - - - - - - - -
 *   g a l _ t g r a v i t y - ( m a i n . c )  
 *  - - - - - - - - - - - - - - - - - - - - - -
 *  
 *  This program is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This program runs the test suite for the gravity sub-library
 *  
 *  Status: 
 *  
 *     Library test program  
 *  
 *  Returned:  
 *  
 *     gal_tgravity     i           0 is returned if all the tests pass, 
 *                                  1 is returned if any of the tests fail
 *  Called:  
 *  
 *     gal_test_start               Initialize and start the test run
 *     gal_test_stop                Stop the test run and output the statistics
 *     gal_gmcpy_test               gal_gmcpy test routine
 *     gal_gmget_test               gal_gmget test routine
 *     gal_gmwgs72_test             gal_gmwgs72 test routine
 *     gal_gmwgs66_test             gal_gmwgs66 test routine
 *     gal_gmjgm3_test              gal_gmjgm3 test routine
 *     gal_gmegm96_test             gal_gmegm96 test routine 
 *     gal_gmmgnp120p_test          gal_gmmgnp120p test routine
 *     gal_gmmgnp180u_test          gal_gmmgnp180u test routine
 *     gal_gmglgm1_test             gal_gmglgm1 test routine
 *     gal_gmglgm2_test             gal_gmglgm2 test routine
 *     gal_gmgmm2b_test             gal_gmgmm2b test routine
 *     gal_gmmgm1025_test           gal_gmmgm1025 test routine
 *     gal_stget_test               gal_stget test routine 
 *     gal_stset_test               gal_stset test routine
 *     gal_stnf_test                gal_stnf test routine
 *     gal_stunf_test               gal_stunf test routine
 *     gal_acch_test                gal_acch test routine 
 *     gal_accpm_test               gal_accpm test routine 
 *     gal_tu_test                  gal_tu test routine
 *     gal_canpv_test               gal_canpv test routine
 *     gal_uncanpv_test             gal_uncanpv test routine
 *     gal_eaadhp_test              gal_eaadhp test routine
 *  
 *  This revision:  
 * 
 *     2009 January 4 
 *  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdio.h>
#include "gal_test_common.h"
#include "gal_test.h"
#include "gal_gmcpy_test.h"
#include "gal_gmget_test.h"
#include "gal_gmwgs72.h"
#include "gal_gmwgs72_test.h"
#include "gal_gmwgs66.h"
#include "gal_gmwgs66_test.h"
#include "gal_gmjgm3.h"
#include "gal_gmjgm3_test.h"
/* 
THE FOLLOWING TEST HAS BEEN EXCLUDED FROM THE STANDARD PACK 
DUE TO ITS EXCESSIVE SIZE AND COMPILE TIME
*/
/*
#include "gal_gmegm96.h"
#include "gal_gmegm96_test.h"
*/
#include "gal_gmmgnp120p.h"
#include "gal_gmmgnp120p_test.h"
/* 
THE FOLLOWING TEST HAS BEEN EXCLUDED FROM THE STANDARD PACK 
DUE TO ITS EXCESSIVE SIZE AND COMPILE TIME
*/
/*
#include "gal_gmmgnp180u.h"
#include "gal_gmmgnp180u_test.h"
*/
#include "gal_gmglgm1.h"
#include "gal_gmglgm1_test.h"
#include "gal_gmglgm2.h"
#include "gal_gmglgm2_test.h"
#include "gal_gmgmm2b.h"
#include "gal_gmgmm2b_test.h"
#include "gal_gmmgm1025.h"
#include "gal_gmmgm1025_test.h"
#include "gal_stget_test.h"
#include "gal_stset_test.h"
#include "gal_stnf_test.h"
#include "gal_stunf_test.h"
#include "gal_acch_test.h"
#include "gal_accpm_test.h"
#include "gal_tu_test.h"
#include "gal_canpv_test.h"
#include "gal_uncanpv_test.h"
#include "gal_eaadhp_test.h"

int
main
  (
  )
  
{

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  
  gal_test_start ( "Gravity", 0 ) ;
  
  gal_gmcpy_test      () ;
  gal_gmget_test      () ;
  gal_gmwgs72_test    () ;
  gal_gmwgs66_test    () ;
  gal_gmjgm3_test     () ;
/*
  gal_gmegm96_test    () ; 
*/
  gal_gmmgnp120p_test () ;
/*
  gal_gmmgnp180u_test () ;
*/
  gal_gmglgm1_test    () ;
  gal_gmglgm2_test    () ;
  gal_gmgmm2b_test    () ;
  gal_gmmgm1025_test  () ;
  gal_stget_test      () ;
  gal_stset_test      () ;
  gal_stnf_test       () ;
  gal_stunf_test      () ;
  gal_acch_test       () ;
  gal_accpm_test      () ;
  gal_tu_test         () ;
  gal_canpv_test      () ;
  gal_uncanpv_test    () ;
  gal_eaadhp_test     () ;

  return gal_test_stop () ;
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
