/*  
 *  - - - - - - - - - - - - - - - -  
 *   g a l _ k e p 3 p v _ t e s t  
 *  - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_kep2pv routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_kep2pv  
 *     gal_vdv  
 *  
 *  This Revision:
 *  
 *     2008 September 20 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_kep2pv_test.h"
#include "gal_kep2pv.h"
#include "gal_test.h"
#include "gal_const.h"
  
void  
gal_kep2pv_test  
 (  
 )  
  
{

  extern int gal_tfunc ;  

  const double gm = 3.986004415e+14 ;
  
  double pv[2][3] ;
    
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Vallado #2
 *          p km        a km          ecc         incl deg     raan deg    argp deg     nu deg       m deg      arglat         truelon        lonper
 * coes  11067.7983  36127.3376   0.832853398    87.8691262   227.89826    53.38493    92.33516     7.60474 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.832853398, 227.89826 * GAL_D2R, 53.38493 * GAL_D2R, 
  87.8691262 * GAL_D2R, 11067798.3, 92.33516 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;
  
  gal_vdv ( pv[0][0] , 6524834.000, 1e-0, "gal_kep2pv", "pv[0][0] 0" ) ;  
  gal_vdv ( pv[0][1] , 6862875.000, 1e-0, "gal_kep2pv", "pv[0][1] 0" ) ;  
  gal_vdv ( pv[0][2] , 6448296.000, 1e-0, "gal_kep2pv", "pv[0][2] 0" ) ;  
  gal_vdv ( pv[1][0] ,    4901.327, 1e-3, "gal_kep2pv", "pv[1][0] 0" ) ;  
  gal_vdv ( pv[1][1] ,    5533.756, 1e-3, "gal_kep2pv", "pv[1][1] 0" ) ;  
  gal_vdv ( pv[1][2] ,   -1976.341, 1e-3, "gal_kep2pv", "pv[1][2] 0" ) ;  

/*
 * Vallado #3
 *
 * coe test elliptical ----------------------------
 * start  7253.755711163 -6718.904276754 -5453.430870858 v     5.1467799360    3.5740223606    0.3012640175
 *          p km        a km          ecc         incl deg     raan deg    argp deg     nu deg      m deg        arglat         truelon       lonper
 * coes  12246.0230  12756.2739   0.199999991    29.9999997    30.00000   220.00001    64.99999    45.58117 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.199999991, 30.00000  * GAL_D2R, 220.00001 * GAL_D2R, 
  29.9999997 * GAL_D2R, 12246023.0, 64.99999 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] ,  7253755.7111630, 1e-0, "gal_kep2pv", "pv[0][0] 1" ) ;  
  gal_vdv ( pv[0][1] , -6718904.2767540, 1e-0, "gal_kep2pv", "pv[0][1] 1" ) ;  
  gal_vdv ( pv[0][2] , -5453430.8708580, 1e-0, "gal_kep2pv", "pv[0][2] 1" ) ;  
  gal_vdv ( pv[1][0] ,     5146.7799360, 1e-3, "gal_kep2pv", "pv[1][0] 1" ) ;  
  gal_vdv ( pv[1][1] ,     3574.0223606, 1e-3, "gal_kep2pv", "pv[1][1] 1" ) ;  
  gal_vdv ( pv[1][2] ,      301.2640175, 1e-3, "gal_kep2pv", "pv[1][2] 1" ) ;  

/*
 * Vallado #4
 *
 * coe test elliptical ----------------------------
 * start  6736.551306205 -5709.020679231  -525.369058131 v    -4.7282516696   -4.9753014767    1.1606611149
 *          p km        a km          ecc        incl deg     raan deg     argp deg      nu deg      m deg      arglat         truelon       lonper
 * coes   9471.4065   9567.0774   0.100000061   170.0000001   299.99999    24.99998   315.00001   322.68595 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.100000061, 299.99999  * GAL_D2R, 24.99998 * GAL_D2R, 
  170.0000001 * GAL_D2R, 9471406.5, 315.00001 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;
 
  gal_vdv ( pv[0][0] ,  6736551.3062050, 1e-1, "gal_kep2pv", "pv[0][0] 2" ) ;  
  gal_vdv ( pv[0][1] , -5709020.6792310, 1e-1, "gal_kep2pv", "pv[0][1] 2" ) ;  
  gal_vdv ( pv[0][2] ,  -525369.0581310, 1e-1, "gal_kep2pv", "pv[0][2] 2" ) ;  
  gal_vdv ( pv[1][0] ,    -4728.2516696, 1e-4, "gal_kep2pv", "pv[1][0] 2" ) ;  
  gal_vdv ( pv[1][1] ,    -4975.3014767, 1e-4, "gal_kep2pv", "pv[1][1] 2" ) ;  
  gal_vdv ( pv[1][2] ,     1160.6611149, 1e-4, "gal_kep2pv", "pv[1][2] 2" ) ;  
 
/*
 * Vallado #5
 *
 * coe test near circular inclined ----------------------------
 * start -2693.345022645  6428.433074941  4491.376922698 v    -3.9548475642   -4.2809668434    3.7556718640
 *          p km        a km          ecc         incl deg     raan deg     argp deg   nu deg       m deg        arglat        truelon        lonper
 * coes   8291.6435   8291.6435   0.000000190    50.0000018    80.00000    55.04346   349.95654   349.95654 57295727.94688 57295727.94688 57295727.94688
 */
 
  gal_kep2pv ( gm, 0.000000190, 80.00000  * GAL_D2R, 55.04346  * GAL_D2R, 
  50.0000018 * GAL_D2R, 8291643.5, 349.95654 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;
  
  gal_vdv ( pv[0][0] , -2693345.0226450, 1e-0, "gal_kep2pv", "pv[0][0] 3" ) ;  
  gal_vdv ( pv[0][1] ,  6428433.0749410, 1e-0, "gal_kep2pv", "pv[0][1] 3" ) ;  
  gal_vdv ( pv[0][2] ,  4491376.9226980, 1e-0, "gal_kep2pv", "pv[0][2] 3" ) ;  
  gal_vdv ( pv[1][0] ,    -3954.8475642, 1e-3, "gal_kep2pv", "pv[1][0] 3" ) ;  
  gal_vdv ( pv[1][1] ,    -4280.9668434, 1e-3, "gal_kep2pv", "pv[1][1] 3" ) ;  
  gal_vdv ( pv[1][2] ,     3755.6718640, 1e-3, "gal_kep2pv", "pv[1][2] 3" ) ;  

/*
 * Vallado #6
 * coe test near circular inclined ----------------------------
 * start -4662.010584046 -4333.718305450 -5313.742654607 v    -5.3156717595    0.2702069961    4.4433312061
 *           p km       a km          ecc        incl deg      raan deg    argp deg    nu deg       m deg        arglat        truelon       lonper
 * coes   8291.6430   8291.6430   0.000000190   115.0002009   200.00000   323.22048   351.77952   351.77953 57295727.94688 57295727.94688 57295727.94688
 */
 
  gal_kep2pv ( gm, 0.000000190, 200.00000 * GAL_D2R, 323.22048  * GAL_D2R, 
  115.0002009 * GAL_D2R, 8291643.0, 351.77952 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] , -4662010.5840460, 1e-1, "gal_kep2pv", "pv[0][0] 4" ) ;  
  gal_vdv ( pv[0][1] , -4333718.3054500, 1e-1, "gal_kep2pv", "pv[0][1] 4" ) ;  
  gal_vdv ( pv[0][2] , -5313742.6546070, 1e-1, "gal_kep2pv", "pv[0][2] 4" ) ;  
  gal_vdv ( pv[1][0] ,    -5315.6717595, 1e-2, "gal_kep2pv", "pv[1][0] 4" ) ;  
  gal_vdv ( pv[1][1] ,      270.2069961, 1e-2, "gal_kep2pv", "pv[1][1] 4" ) ;  
  gal_vdv ( pv[1][2] ,     4443.3312061, 1e-2, "gal_kep2pv", "pv[1][2] 4" ) ;  

/*
 * Vallado #7
 * coe test circular inclined ----------------------------
 * start -2693.345550101  6428.434253559  4491.377820504 v    -3.9548471225   -4.2809658538    3.7556710454
 *           p km        a km         ecc        incl deg      raan deg    argp deg        nu deg         m deg       arglat      truelon       lonper
 * coes   8291.6435   8291.6435   0.000000000    50.0000000    80.00000 57295727.94688 57295727.94688    45.00000    45.00000 57295727.94688 57295727.94688
 */
 
  gal_kep2pv ( gm, 0.000000000, 80.00000 * GAL_D2R, GAL_UNDEFINED, 
  50.0000000 * GAL_D2R, 8291643.5, GAL_UNDEFINED, GAL_UNDEFINED, 45.00000 * GAL_D2R, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] , -2693345.55010128000, 1e-8, "gal_kep2pv", "pv[0][0] 5" ) ;  
  gal_vdv ( pv[0][1] ,  6428434.25355863000, 1e-8, "gal_kep2pv", "pv[0][1] 5" ) ;  
  gal_vdv ( pv[0][2] ,  4491377.82050409000, 1e-8, "gal_kep2pv", "pv[0][2] 5" ) ;  
  gal_vdv ( pv[1][0] ,    -3954.84712246016, 1e-5, "gal_kep2pv", "pv[1][0] 5" ) ;  
  gal_vdv ( pv[1][1] ,    -4280.96585381370, 1e-5, "gal_kep2pv", "pv[1][1] 5" ) ;  
  gal_vdv ( pv[1][2] ,     3755.67104538731, 1e-5, "gal_kep2pv", "pv[1][2] 5" ) ;  

/* 
 * Vallado #8
 * coe test circular inclined ----------------------------
 * start -7079.688344834  3167.877188234 -2931.538673016 v     1.7760808033    6.2377093319    2.4513401795
 *           p km       a km          ecc        incl deg      raan deg     argp deg      nu deg          m deg      arglat       truelon       lonper
 * coes   8291.6435   8291.6435   0.000000000   150.0000000   115.00000 57295727.94688 57295727.94688   315.00000   315.00000 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.000000000, 115.00000 * GAL_D2R, GAL_UNDEFINED, 
  150.0000000 * GAL_D2R, 8291643.5, GAL_UNDEFINED, GAL_UNDEFINED, 315.00000 * GAL_D2R, GAL_UNDEFINED, pv ) ;
  
  gal_vdv ( pv[0][0] , -7079688.34483379000, 1e-8, "gal_kep2pv", "pv[0][0] 6" ) ;  
  gal_vdv ( pv[0][1] ,  3167877.18823353000, 1e-8, "gal_kep2pv", "pv[0][1] 6" ) ;  
  gal_vdv ( pv[0][2] , -2931538.67301568000, 1e-8, "gal_kep2pv", "pv[0][2] 6" ) ;  
  gal_vdv ( pv[1][0] ,     1776.08080328182, 1e-5, "gal_kep2pv", "pv[1][0] 6" ) ;  
  gal_vdv ( pv[1][1] ,     6237.70933190509, 1e-5, "gal_kep2pv", "pv[1][1] 6" ) ;  
  gal_vdv ( pv[1][2] ,     2451.34017949138, 1e-5, "gal_kep2pv", "pv[1][2] 6" ) ;  

/*
 * Vallado #9
 * coe test elliptical near equatorial ----------------------------
 * start 21648.610928074 -14058.772318870    -0.000359803 v     2.1637806072    3.3269434849    0.0000000416
 *          p km         a km         ecc         incl deg     raan deg    argp deg      nu deg      m deg        arglat       truelon       lonper
 * coes  26328.9547  26339.4905   0.020000000     0.0000009    20.00000   305.00000     2.00000     1.92120 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.020000000, 20.00000 * GAL_D2R, 305.00000 * GAL_D2R, 
  0.0000009 * GAL_D2R, 26328954.7, 2.00000 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] ,  21648610.92807390000, 1e-7, "gal_kep2pv", "pv[0][0] 7" ) ;  
  gal_vdv ( pv[0][1] , -14058772.31886980000, 1e-7, "gal_kep2pv", "pv[0][1] 7" ) ;  
  gal_vdv ( pv[0][2] ,        -0.35980290000, 1e-1, "gal_kep2pv", "pv[0][2] 7" ) ;  
  gal_vdv ( pv[1][0] ,      2163.78060719980, 1e-5, "gal_kep2pv", "pv[1][0] 7" ) ;  
  gal_vdv ( pv[1][1] ,      3326.94348486311, 1e-5, "gal_kep2pv", "pv[1][1] 7" ) ;  
  gal_vdv ( pv[1][2] ,         0.00004164788, 1e-5, "gal_kep2pv", "pv[1][2] 7" ) ;  

/*
 * Vallado #10
 * coe test elliptical near equatorial ----------------------------
 * start  7546.991448722 24685.103283436    -0.000359803 v     3.7960701605   -1.1577352048    0.0000000416
 *          p km        a km          ecc        incl deg      raan deg    argp deg      nu deg      m deg       arglat        truelon        lonper
 * coes  26328.9535  26339.4893   0.019999974   179.9999991    20.00000   305.00021     1.99979     1.92099 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.019999974, 20.00000 * GAL_D2R, 305.00021 * GAL_D2R, 
  179.9999991 * GAL_D2R, 26328953.5, 1.99979 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;
  
  gal_vdv ( pv[0][0] ,  7546991.44872220000, 1e+1, "gal_kep2pv", "pv[0][0] 8" ) ;  
  gal_vdv ( pv[0][1] , 24685103.28343560000, 1e+1, "gal_kep2pv", "pv[0][1] 8" ) ;  
  gal_vdv ( pv[0][2] ,       -0.35980290000, 1e+1, "gal_kep2pv", "pv[0][2] 8" ) ;  
  gal_vdv ( pv[1][0] ,     3796.07016047138, 1e-3, "gal_kep2pv", "pv[1][0] 8" ) ;  
  gal_vdv ( pv[1][1] ,    -1157.73520476223, 1e-3, "gal_kep2pv", "pv[1][1] 8" ) ;  
  gal_vdv ( pv[1][2] ,        0.00004164788, 1e-3, "gal_kep2pv", "pv[1][2] 8" ) ;  

/*
 * Vallado #11
 * coe test elliptical equatorial ----------------------------
 * start -22739.108659621 -22739.108659621     0.000000000 v     2.4851400419   -2.0200411207    0.0000000000
 *          p km        a km          ecc         incl deg     raan deg       argp deg       nu deg       m deg      arglat          truelon       lonper
 * coes  26328.9547  27425.9945   0.200000000     0.0000000 57295727.94688 57295727.94688   205.00000   216.17687 57295727.94688 57295727.94688    20.00000
 */

  gal_kep2pv ( gm, 0.200000000, GAL_UNDEFINED, GAL_UNDEFINED, 
  0.0000000 * GAL_D2R, 26328954.7, 205.00000 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, 20.00000 * GAL_D2R, pv ) ;

  gal_vdv ( pv[0][0] , -22739108.65962080000, 1e-7, "gal_kep2pv", "pv[0][0] 9" ) ;  
  gal_vdv ( pv[0][1] , -22739108.65962080000, 1e-7, "gal_kep2pv", "pv[0][1] 9" ) ;  
  gal_vdv ( pv[0][2] ,         0.00000000000, 1e-7, "gal_kep2pv", "pv[0][2] 9" ) ;  
  gal_vdv ( pv[1][0] ,      2485.14004188565, 1e-6, "gal_kep2pv", "pv[1][0] 9" ) ;  
  gal_vdv ( pv[1][1] ,     -2020.04112073465, 1e-6, "gal_kep2pv", "pv[1][1] 9" ) ;  
  gal_vdv ( pv[1][2] ,         0.00000000000, 1e-6, "gal_kep2pv", "pv[1][2] 9" ) ;  

/*
 * Vallado #12
 * coe test elliptical equatorial ----------------------------
 * start 28242.366282204  2470.886880840     0.000000000 v     0.6657521506   -3.6253302219    0.0000000000
 *          p km        a km          ecc        incl deg      raan deg      argp deg        nu deg       m deg      arglat          truelon       lonper
 * coes  27152.1143  27426.3781   0.100000000   180.0000000 57295727.94688 57295727.94688   115.00000   104.29062 57295727.94688 57295727.94688   240.00000
 */
 
  gal_kep2pv ( gm,0.100000000, GAL_UNDEFINED, GAL_UNDEFINED, 
  180.0000000 * GAL_D2R, 27152114.3, 115.00000 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, 240.00000 * GAL_D2R, pv ) ;

  gal_vdv ( pv[0][0] , 28242366.28220400000, 1e-7, "gal_kep2pv", "pv[0][0] 10" ) ;  
  gal_vdv ( pv[0][1] ,  2470886.88083970000, 1e-7, "gal_kep2pv", "pv[0][1] 10" ) ;  
  gal_vdv ( pv[0][2] ,        0.00000000000, 1e-7, "gal_kep2pv", "pv[0][2] 10" ) ;  
  gal_vdv ( pv[1][0] ,      665.75215057746, 1e-5, "gal_kep2pv", "pv[1][0] 10" ) ;  
  gal_vdv ( pv[1][1] ,    -3625.33022188304, 1e-5, "gal_kep2pv", "pv[1][1] 10" ) ;  
  gal_vdv ( pv[1][2] ,        0.00000000000, 1e-5, "gal_kep2pv", "pv[1][2] 10" ) ;  

/*
 * Vallado #13
 * coe test circular near equatorial ----------------------------
 * start -2547.369745493 14446.851725460     0.000000000 v    -5.1334515633   -0.9051660148    0.0000009098
 *          p km         a km         ecc         incl deg     raan deg     argp deg      nu deg           m deg       arglat     truelon       lonper
 * coes  14669.7177  14669.7177   0.000000000     0.0000100   100.00000 57295727.94688 57295727.94688     0.00000     0.00000 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.000000000, 100.00000 * GAL_D2R, GAL_UNDEFINED, 
  0.0000100 * GAL_D2R, 14669717.7, GAL_UNDEFINED, GAL_UNDEFINED, 0.00000, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] , -2547369.74549330000, 1e-7, "gal_kep2pv", "pv[0][0] 11" ) ;  
  gal_vdv ( pv[0][1] , 14446851.72546040000, 1e-7, "gal_kep2pv", "pv[0][1] 11" ) ;  
  gal_vdv ( pv[0][2] ,        0.00000000000, 1e-7, "gal_kep2pv", "pv[0][2] 11" ) ;  
  gal_vdv ( pv[1][0] ,    -5133.45156333487, 1e-5, "gal_kep2pv", "pv[1][0] 11" ) ;  
  gal_vdv ( pv[1][1] ,     -905.16601477599, 1e-5, "gal_kep2pv", "pv[1][1] 11" ) ;  
  gal_vdv ( pv[1][2] ,        0.00090977789, 1e-5, "gal_kep2pv", "pv[1][2] 11" ) ;  

/*
 * Vallado #14
 * coe test circular near equatorial ----------------------------
 * start  7334.858850000 -12704.348194546     0.000000000 v    -4.5142815431   -2.6063216641    0.0000009098
 *          p km        a km          ecc        incl deg     raan deg     argp deg        nu deg         m deg       arglat      truelon       lonper
 * coes  14669.7177  14669.7177   0.000000000   179.9999900   300.00000 57295727.94688 57295727.94688     0.00000     0.00000 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 0.000000000, 300.00000 * GAL_D2R, GAL_UNDEFINED, 
  179.9999900 * GAL_D2R, 14669717.7, GAL_UNDEFINED, GAL_UNDEFINED, 0.00000, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] ,   7334858.850000000000, 1e-7, "gal_kep2pv", "pv[0][0] 12" ) ;  
  gal_vdv ( pv[0][1] , -12704348.194546200000, 1e-7, "gal_kep2pv", "pv[0][1] 12" ) ;  
  gal_vdv ( pv[0][2] ,         0.000000000000, 1e-7, "gal_kep2pv", "pv[0][2] 12" ) ;  
  gal_vdv ( pv[1][0] ,     -4514.281543120467, 1e-5, "gal_kep2pv", "pv[1][0] 12" ) ;  
  gal_vdv ( pv[1][1] ,     -2606.321664118360, 1e-5, "gal_kep2pv", "pv[1][1] 12" ) ;  
  gal_vdv ( pv[1][2] ,         0.000909777890, 1e-5, "gal_kep2pv", "pv[1][2] 12" ) ;  

/*
 * Vallado #15
 * coe test circular equatorial ----------------------------
 * start  6199.690594601 13295.279385139     0.000000000 v    -4.7242592394    2.2029582625    0.0000000000
 *          p km        a km         ecc          incl deg     raan deg       argp deg        nu deg          m deg      arglat        truelon       lonper
 * coes  14669.7177  14669.7177   0.000000000     0.0000000 57295727.94688 57295727.94688 57295727.94688    65.00000 57295727.94688    65.00000 57295727.94688
 */

  gal_kep2pv ( gm, 0.000000000, GAL_UNDEFINED, GAL_UNDEFINED, 
  0.0000000 * GAL_D2R, 14669717.7, GAL_UNDEFINED, 65.00000 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] ,  6199690.59460080000, 1e-7, "gal_kep2pv", "pv[0][0] 13" ) ;  
  gal_vdv ( pv[0][1] , 13295279.38513940000, 1e-7, "gal_kep2pv", "pv[0][1] 13" ) ;  
  gal_vdv ( pv[0][2] ,        0.00000000000, 1e-7, "gal_kep2pv", "pv[0][2] 13" ) ;  
  gal_vdv ( pv[1][0] ,    -4724.25923942564, 1e-5, "gal_kep2pv", "pv[1][0] 13" ) ;  
  gal_vdv ( pv[1][1] ,     2202.95826245369, 1e-5, "gal_kep2pv", "pv[1][1] 13" ) ;  
  gal_vdv ( pv[1][2] ,        0.00000000000, 1e-5, "gal_kep2pv", "pv[1][2] 13" ) ;  

/*
 * Vallado #16
 * coe test circular equatorial ----------------------------
 * start  6199.690594601 -13295.279385139     0.000000000 v    -4.7242592394   -2.2029582625    0.0000000000
 *          p km        a km          ecc        incl deg      raan deg        argp deg       nu deg          m deg      arglat       truelon     lonper
 * coes  14669.7177  14669.7177   0.000000000   180.0000000 57295727.94688 57295727.94688 57295727.94688    65.00000 57295727.94688    65.00000 57295727.94688
 */

  gal_kep2pv ( gm, 0.000000000, GAL_UNDEFINED, GAL_UNDEFINED, 
  180.0000000 * GAL_D2R, 14669717.7, GAL_UNDEFINED, 65.00000 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0] ,   6199690.59460080000, 1e-7, "gal_kep2pv", "pv[0][0] 14" ) ;  
  gal_vdv ( pv[0][1] , -13295279.38513940000, 1e-7, "gal_kep2pv", "pv[0][1] 14" ) ;  
  gal_vdv ( pv[0][2] ,         0.00000000000, 1e-7, "gal_kep2pv", "pv[0][2] 14" ) ;  
  gal_vdv ( pv[1][0] ,     -4724.25923942564, 1e-5, "gal_kep2pv", "pv[1][0] 14" ) ;  
  gal_vdv ( pv[1][1] ,     -2202.95826245369, 1e-5, "gal_kep2pv", "pv[1][1] 14" ) ;  
  gal_vdv ( pv[1][2] ,         0.00000000000, 1e-5, "gal_kep2pv", "pv[1][2] 14" ) ;   

/*
 * Vallado #17
 * coe test parabolic ----------------------------
 * start  3773.375370893 -8221.009754418 -2384.366380699 v     9.0803778759   -0.6389504285   -1.5358015696
 *          p km          a km              ecc         incl deg     raan deg    argp deg      nu deg      m deg      arglat      truelon         lonper
 * coes  14031.9046 -21480206979.2030   1.000000327    15.0000008    35.00001   200.00000    59.99999     0.00000 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 1.000000327, 35.00001 * GAL_D2R, 200.00000 * GAL_D2R, 
  15.0000008 * GAL_D2R, 14031904.6, 59.99999 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0],  0.5916109 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][0] 15"  ) ;  
  gal_vdv ( pv[0][1], -1.2889359 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][1] 15"  ) ;  
  gal_vdv ( pv[0][2], -0.3738343 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][2] 15"  ) ;  
  gal_vdv ( pv[1][0],  1.1486347 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][0] 15"  ) ;  
  gal_vdv ( pv[1][1], -0.0808249 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][1] 15"  ) ;  
  gal_vdv ( pv[1][2], -0.1942733 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][2] 15"  ) ;  

/*
 * Vallado #18
 * coe test parabolic ----------------------------
 * start -6597.319126750 -3071.003443807  1106.940983879 v     1.0453091742    6.1545821004    8.3266083284
 *          p km           a km              ecc       incl deg     raan deg     argp deg      nu deg      m deg         arglat       truelon         lonper
 * coes  14031.9040 -23792471448.4876   1.000000295   120.0000012   210.00000    34.99999   335.00001 57295773.78350 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 1.000000295, 210.00000 * GAL_D2R, 34.99999 * GAL_D2R, 
  120.0000012 * GAL_D2R, 14031904.0, 335.00001 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0], -1.0343646 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][0] 16"  ) ;  
  gal_vdv ( pv[0][1], -0.4814891 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][1] 16"  ) ;  
  gal_vdv ( pv[0][2],  0.1735524 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][2] 16"  ) ;  
  gal_vdv ( pv[1][0],  0.1322278 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][0] 16"  ) ;  
  gal_vdv ( pv[1][1],  0.7785322 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][1] 16"  ) ;  
  gal_vdv ( pv[1][2],  1.0532856 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][2] 16"  ) ;  

/*
 * Vallado #19
 * coe test hyperbolic ---------------------------
 * start  5844.862878871  4468.361415334 -8871.748111235 v     1.3539552226    8.7245193998   -3.0122425354
 *          p km        a km          ecc        incl deg      raan deg    argp deg     nu deg      m deg       arglat        truelon        lonper
 * coes  15403.3960 -22323.7406   1.300000258    55.0000008    95.00000   215.00001    74.99999    12.10855 57295727.94688 57295727.94688 57295727.94688
 */

  gal_kep2pv ( gm, 1.300000258, 95.00000 * GAL_D2R, 215.00001 * GAL_D2R, 
  55.0000008 * GAL_D2R, 15403396.0, 74.99999 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0],  0.9163903 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][0] 17" ) ;  
  gal_vdv ( pv[0][1],  0.7005747 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][1] 17" ) ;  
  gal_vdv ( pv[0][2], -1.3909623 * 6378137.0,      1e-0, "gal_kep2pv", "pv[0][2] 17" ) ;  
  gal_vdv ( pv[1][0],  0.1712704 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][0] 17" ) ;  
  gal_vdv ( pv[1][1],  1.1036199 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][1] 17" ) ;  
  gal_vdv ( pv[1][2], -0.3810377 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][2] 17" ) ;  

/*
 * Vallado #20
 * coe test hyperbolic ---------------------------
 * start 78553.277524455 -45032.614967146 -24162.780497698 v    -4.6663202407    1.7115410213    1.2872616011
 *         p km        a km           ecc       incl deg     raan deg     argp deg     nu deg      m deg       arglat            truelon       lonper
 *coes  15404.4188 -22325.2342   1.300000123   165.0000006   235.00002    35.00001   230.00001 57295773.78350 57295727.94688 57295727.94688 57295727.94688
 */
/*
 *     gm             double        Gravitational parameter
 *     ecc              d           Eccentricity
 *     raan             d           Longitude of the ascending mode (radians) 
 *     argp             d           Argument of Pericentre (radians) 
 *     inc              d           Inclination (radians)
 *     p                d           Semi-Latus Rectum (m)
 *     v                d           True Anomaly (radians)
 *     truelon          d           True Longitude (radians)
 *     u                d           Argument of Latitude (radians)
 *     lonper           d           True Longitude of Periapsis (radians)
 */

  gal_kep2pv ( gm, 1.300000123 , 235.00002 * GAL_D2R, 35.00001 * GAL_D2R, 
  165.0000006 * GAL_D2R, 15404418.8, 230.00001 * GAL_D2R, GAL_UNDEFINED, GAL_UNDEFINED, GAL_UNDEFINED, pv ) ;

  gal_vdv ( pv[0][0], 12.3160223 * 6378137.0,      1e+2, "gal_kep2pv", "pv[0][0] 18" ) ;  
  gal_vdv ( pv[0][1], -7.0604653 * 6378137.0,      1e+2, "gal_kep2pv", "pv[0][1] 18" ) ;  
  gal_vdv ( pv[0][2], -3.7883759 * 6378137.0,      1e+2, "gal_kep2pv", "pv[0][2] 18" ) ;  
  gal_vdv ( pv[1][0], -0.5902725 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][0] 18" ) ;  
  gal_vdv ( pv[1][1],  0.2165037 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][1] 18" ) ;  
  gal_vdv ( pv[1][2],  0.1628339 * 7905.366149846, 1e-3, "gal_kep2pv", "pv[1][2] 18" ) ;  

  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

