/*  
 *  - - - - - - - - - - - - - - - -  
 *   g a l _ p v 2 k e p _ t e s t  
 *  - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_pv2kep routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_pv2kep  
 *     gal_vdv  
 *  
 *  This Revision:
 *  
 *     2008 September 14 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_pv2kep_test.h"
#include "gal_pv2kep.h"
#include "gal_test.h"
#include "gal_const.h"
#include <math.h>
  
void  
gal_pv2kep_test  
 (  
 ) 
 
{

  extern int gal_tfunc ;  

  const double gm = 3.986004415e+14 ;
  
  double pv[2][3] ;
  
  double sma, ecc, raan, argp, ma, inc, lonper , p, v, truelon, arglat ;
       
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Vallado #2
 *          p km        a km          ecc         incl deg     raan deg    argp deg     nu deg       m deg      arglat         truelon        lonper 
 * coes  11067.7983  36127.3376   0.832853398    87.8691262   227.89826    53.38493    92.33516     7.60474 57295727.94688 57295727.94688 57295727.94688
*/

  pv[0][0] = 6524834.000 ; 
  pv[0][1] = 6862875.000 ;
  pv[0][2] = 6448296.000 ;
  pv[1][0] =    4901.327 ;
  pv[1][1] =    5533.756 ;
  pv[1][2] =   -1976.341 ;
   
  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,             36127337.6,  1e-0, "gal_pv2kep", "sma 0"     ) ;  
  gal_vdv ( ecc,            0.832853398,  1e-8, "gal_pv2kep", "ecc 0"     ) ;  
  gal_vdv ( raan * GAL_R2D,   227.89826,  1e-6, "gal_pv2kep", "raan 0"    ) ;  
  gal_vdv ( argp * GAL_R2D,    53.38493,  1e-6, "gal_pv2kep", "argp 0"    ) ;  
  gal_vdv ( ma   * GAL_R2D,     7.60474,  1e-5, "gal_pv2kep", "ma 0"      ) ;  
  gal_vdv ( inc  * GAL_R2D,  87.8691262,  1e-7, "gal_pv2kep", "inc 0"     ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "lonper 0"      ) ;  
  gal_vdv ( p             ,  11067798.3,  1e-1, "gal_pv2kep", "p 0"       ) ;  
  gal_vdv ( v * GAL_R2D   ,    92.33516,  1e-5, "gal_pv2kep", "v 0"       ) ;  
  gal_vdv ( truelon       ,         GAL_UNDEFINED,  1e-11, "gal_pv2kep", "truelon 0" ) ;  
  gal_vdv ( arglat        ,         GAL_UNDEFINED,  1e-11, "gal_pv2kep", "arglat 0"  ) ;  

/*
 * Vallado #3
 *
 * coe test elliptical ----------------------------
 * start  7253.755711163 -6718.904276754 -5453.430870858 v     5.1467799360    3.5740223606    0.3012640175
 *          p km        a km          ecc         incl deg     raan deg    argp deg     nu deg      m deg        arglat         truelon       lonper 
 * coes  12246.0230  12756.2739   0.199999991    29.9999997    30.00000   220.00001    64.99999    45.58117 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] =  7253755.7111630 ; 
  pv[0][1] = -6718904.2767540 ;
  pv[0][2] = -5453430.8708580 ;
  pv[1][0] =     5146.7799360 ;
  pv[1][1] =     3574.0223606 ;
  pv[1][2] =     0301.2640175 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,             12756273.9, 1e-0, "gal_pv2kep", "sma 1"  ) ;  
  gal_vdv ( ecc,            0.199999991, 1e-8, "gal_pv2kep", "ecc 1"  ) ;  
  gal_vdv ( raan * GAL_R2D,    30.00000, 1e-5, "gal_pv2kep", "raan 1" ) ;  
  gal_vdv ( argp * GAL_R2D,   220.00001, 1e-5, "gal_pv2kep", "argp 1" ) ;  
  gal_vdv ( ma   * GAL_R2D,    45.58117, 1e-5, "gal_pv2kep", "ma 1"   ) ;  
  gal_vdv ( inc  * GAL_R2D,  29.9999997, 1e-7, "gal_pv2kep", "inc 1"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-8, "gal_pv2kep", "lonper 1"   ) ;  
  gal_vdv ( p             ,  12246023.0,  1e-1, "gal_pv2kep", "p 1"       ) ;  
  gal_vdv ( v * GAL_R2D   ,    64.99999,  1e-5, "gal_pv2kep", "v 1"       ) ;  
  gal_vdv ( truelon       , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "truelon 1" ) ;  
  gal_vdv ( arglat        , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "arglat 1"  ) ;  

/*
 * Vallado #4
 *
 * coe test elliptical ----------------------------
 * start  6736.551306205 -5709.020679231  -525.369058131 v    -4.7282516696   -4.9753014767    1.1606611149
 *          p km        a km          ecc        incl deg     raan deg     argp deg      nu deg      m deg      arglat         truelon       lonper 
 * coes   9471.4065   9567.0774   0.100000061   170.0000001   299.99999    24.99998   315.00001   322.68595 57295727.94688 57295727.94688 57295727.94688
 */
 
  pv[0][0] =  6736551.3062050 ; 
  pv[0][1] = -5709020.6792310 ;
  pv[0][2] =  -525369.0581310 ;
  pv[1][0] =    -4728.2516696 ;
  pv[1][1] =    -4975.3014767 ;
  pv[1][2] =     1160.6611149 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,              9567077.4, 1e-2, "gal_pv2kep", "sma 2"  ) ;  
  gal_vdv ( ecc,            0.100000061, 1e-9, "gal_pv2kep", "ecc 2"  ) ;  
  gal_vdv ( raan * GAL_R2D,   299.99999, 1e-5, "gal_pv2kep", "raan 2" ) ;  
  gal_vdv ( argp * GAL_R2D,    24.99998, 1e-5, "gal_pv2kep", "argp 2" ) ;  
  gal_vdv ( ma   * GAL_R2D,   322.68595, 1e-5, "gal_pv2kep", "ma 2"   ) ;  
  gal_vdv ( inc  * GAL_R2D, 170.0000001, 1e-7, "gal_pv2kep", "inc 2"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 2"   ) ;  
  gal_vdv ( p             ,   9471406.5,  1e-1, "gal_pv2kep", "p 2"       ) ;  
  gal_vdv ( v * GAL_R2D   ,   315.00001,  1e-5, "gal_pv2kep", "v 2"       ) ;  
  gal_vdv ( truelon       , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "truelon 2" ) ;  
  gal_vdv ( arglat        , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "arglat 2"  ) ;  

/*
 * Vallado #5
 *
 * coe test near circular inclined ----------------------------
 * start -2693.345022645  6428.433074941  4491.376922698 v    -3.9548475642   -4.2809668434    3.7556718640
 *          p km        a km          ecc         incl deg     raan deg     argp deg   nu deg       m deg        arglat        truelon        lonper 
 * coes   8291.6435   8291.6435   0.000000190    50.0000018    80.00000    55.04346   349.95654   349.95654 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] = -2693345.0226450 ; 
  pv[0][1] =  6428433.0749410 ;
  pv[0][2] =  4491376.9226980 ;
  pv[1][0] =    -3954.8475642 ;
  pv[1][1] =    -4280.9668434 ;
  pv[1][2] =     3755.6718640 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,              8291643.5, 1e-1, "gal_pv2kep", "sma 3"  ) ;  
  gal_vdv ( ecc,            0.000000190, 1e-8, "gal_pv2kep", "ecc 3"  ) ;  
  gal_vdv ( raan * GAL_R2D,    80.00000, 1e-5, "gal_pv2kep", "raan 3" ) ;  
  gal_vdv ( argp * GAL_R2D,    55.04346, 1e-1, "gal_pv2kep", "argp 3" ) ;  
  gal_vdv ( ma   * GAL_R2D,   349.95654, 1e-1, "gal_pv2kep", "ma 3"   ) ;  
  gal_vdv ( inc  * GAL_R2D,  50.0000018, 1e-7, "gal_pv2kep", "inc 3"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 3"   ) ;  
  gal_vdv ( p             ,   8291643.5,  1e-1, "gal_pv2kep", "p 3"       ) ;  
  gal_vdv ( v * GAL_R2D   ,   349.95654,  1e-1, "gal_pv2kep", "v 3"       ) ;  
  gal_vdv ( truelon       , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "truelon 3" ) ;  
  gal_vdv ( arglat        , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "arglat 3"  ) ;  

/*
 * Vallado #6
 * coe test near circular inclined ----------------------------
 * start -4662.010584046 -4333.718305450 -5313.742654607 v    -5.3156717595    0.2702069961    4.4433312061
 *           p km       a km          ecc        incl deg      raan deg    argp deg    nu deg       m deg        arglat        truelon       lonper 
 * coes   8291.6430   8291.6430   0.000000190   115.0002009   200.00000   323.22048   351.77952   351.77953 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] = -4662010.5840460 ; 
  pv[0][1] = -4333718.3054500 ;
  pv[0][2] = -5313742.6546070 ;
  pv[1][0] =    -5315.6717595 ;
  pv[1][1] =      270.2069961 ;
  pv[1][2] =     4443.3312061 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,              8291643.0, 1e-1, "gal_pv2kep", "sma 4"  ) ;  
  gal_vdv ( ecc,            0.000000190, 1e-8, "gal_pv2kep", "ecc 4"  ) ;  
  gal_vdv ( raan * GAL_R2D,   200.00000, 1e-5, "gal_pv2kep", "raan 4" ) ;  
  gal_vdv ( argp * GAL_R2D,   323.22048, 1e-1, "gal_pv2kep", "argp 4" ) ;  
  gal_vdv ( ma   * GAL_R2D,   351.77953, 1e-1, "gal_pv2kep", "ma 4"   ) ;  
  gal_vdv ( inc  * GAL_R2D, 115.0002009, 1e-7, "gal_pv2kep", "inc 4"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 4"   ) ;  
  gal_vdv ( p             ,   8291643.0,  1e-1, "gal_pv2kep", "p 4"       ) ;  
  gal_vdv ( v * GAL_R2D   ,   351.77952,  1e-1, "gal_pv2kep", "v 4"       ) ;  
  gal_vdv ( truelon       , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "truelon 4" ) ;  
  gal_vdv ( arglat        , GAL_UNDEFINED,  1e-11, "gal_pv2kep", "arglat 4"  ) ;  

/*
 * Vallado #7
 * coe test circular inclined ----------------------------
 * start -2693.345550101  6428.434253559  4491.377820504 v    -3.9548471225   -4.2809658538    3.7556710454
 *           p km        a km         ecc        incl deg      raan deg    argp deg        nu deg         m deg       arglat      truelon       lonper 
 * coes   8291.6435   8291.6435   0.000000000    50.0000000    80.00000 57295727.94688 57295727.94688    45.00000    45.00000 57295727.94688 57295727.94688
 */

  pv[0][0] = -2693345.55010128000 ; 
  pv[0][1] =  6428434.25355863000 ;
  pv[0][2] =  4491377.82050409000 ;
  pv[1][0] =    -3954.84712246016 ;
  pv[1][1] =    -4280.96585381370 ;
  pv[1][2] =     3755.67104538731 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,                8291643.5, 1e-2, "gal_pv2kep", "sma 5"  ) ;  
  gal_vdv ( ecc,              0.000000000, 1e-9, "gal_pv2kep", "ecc 5"  ) ;  
  gal_vdv ( raan * GAL_R2D,      80.00000, 1e-9, "gal_pv2kep", "raan 5" ) ;  
  gal_vdv ( argp ,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "argp 5" ) ;  
  gal_vdv ( ma   * GAL_R2D,      45.00000, 1e-9, "gal_pv2kep", "ma 5"   ) ;  
  gal_vdv ( inc  * GAL_R2D,    50.0000000, 1e-9, "gal_pv2kep", "inc 5"  ) ;  
  gal_vdv ( lonper            ,   GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 5"   ) ;  
  gal_vdv ( p             ,     8291643.0, 1e-0, "gal_pv2kep", "p 5"       ) ;  
  gal_vdv ( v     ,           GAL_UNDEFINED, 1e-5, "gal_pv2kep", "v 5"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 5" ) ;  
  gal_vdv ( arglat * GAL_R2D,    45.00000, 1e-11, "gal_pv2kep", "arglat 5"  ) ;  

/* 
 * Vallado #8
 * coe test circular inclined ----------------------------
 * start -7079.688344834  3167.877188234 -2931.538673016 v     1.7760808033    6.2377093319    2.4513401795
 *           p km       a km          ecc        incl deg      raan deg     argp deg      nu deg          m deg      arglat       truelon       lonper 
 * coes   8291.6435   8291.6435   0.000000000   150.0000000   115.00000 57295727.94688 57295727.94688   315.00000   315.00000 57295727.94688 57295727.94688
 */

  pv[0][0] = -7079688.34483379000 ; 
  pv[0][1] =  3167877.18823353000 ;
  pv[0][2] = -2931538.67301568000 ;
  pv[1][0] =     1776.08080328182 ;
  pv[1][1] =     6237.70933190509 ;
  pv[1][2] =     2451.34017949138 ;

 
  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,                8291643.5, 1e-2, "gal_pv2kep", "sma 6"  ) ;  
  gal_vdv ( ecc,              0.000000000, 1e-9, "gal_pv2kep", "ecc 6"  ) ;  
  gal_vdv ( raan * GAL_R2D,     115.00000, 1e-9, "gal_pv2kep", "raan 6" ) ;  
  gal_vdv ( argp ,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "argp 6" ) ;  
  gal_vdv ( ma   * GAL_R2D,     315.00000, 1e-9, "gal_pv2kep", "ma 6"   ) ;  
  gal_vdv ( inc  * GAL_R2D,   150.0000000, 1e-9, "gal_pv2kep", "inc 6"  ) ;  
  gal_vdv ( lonper            ,   GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 6"   ) ;  
  gal_vdv ( p             ,     8291643.5, 1e-1, "gal_pv2kep", "p 6"       ) ;  
  gal_vdv ( v     ,           GAL_UNDEFINED, 1e-5, "gal_pv2kep", "v 6"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 6" ) ;  
  gal_vdv ( arglat * GAL_R2D,   315.00000, 1e-11, "gal_pv2kep", "arglat 6"  ) ;  

/*
 * Vallado #9
 * coe test elliptical near equatorial ----------------------------
 * start 21648.610928074 -14058.772318870    -0.000359803 v     2.1637806072    3.3269434849    0.0000000416
 *          p km         a km         ecc         incl deg     raan deg    argp deg      nu deg      m deg        arglat       truelon       lonper 
 * coes  26328.9547  26339.4905   0.020000000     0.0000009    20.00000   305.00000     2.00000     1.92120 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] =  21648610.92807390000 ; 
  pv[0][1] = -14058772.31886980000 ;
  pv[0][2] =        -0.35980290000 ;
  pv[1][0] =      2163.78060719980 ;
  pv[1][1] =      3326.94348486311 ;
  pv[1][2] =         0.00004164788 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               26339490.5, 1e-1, "gal_pv2kep", "sma 7"  ) ;  
  gal_vdv ( ecc,              0.020000000, 1e-9, "gal_pv2kep", "ecc 7"  ) ;  
  gal_vdv ( raan * GAL_R2D,      20.00000, 1e-5, "gal_pv2kep", "raan 7" ) ;  
  gal_vdv ( argp * GAL_R2D,     305.00000, 1e-5, "gal_pv2kep", "argp 7" ) ;  
  gal_vdv ( ma   * GAL_R2D,       1.92120, 1e-6, "gal_pv2kep", "ma 7"   ) ;  
  gal_vdv ( inc  * GAL_R2D,     0.0000009, 1e-6, "gal_pv2kep", "inc 7"  ) ;  
  gal_vdv ( lonper            ,  GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 7"   ) ;  
  gal_vdv ( p             ,    26328954.7, 1e-1, "gal_pv2kep", "p 7"       ) ;  
  gal_vdv ( v * GAL_R2D   ,       2.00000, 1e-5, "gal_pv2kep", "v 7"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 7" ) ;  
  gal_vdv ( arglat ,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 7"  ) ;  

/*
 * Vallado #10
 * coe test elliptical near equatorial ----------------------------
 * start  7546.991448722 24685.103283436    -0.000359803 v     3.7960701605   -1.1577352048    0.0000000416
 *          p km        a km          ecc        incl deg      raan deg    argp deg      nu deg      m deg       arglat        truelon        lonper 
 * coes  26328.9535  26339.4893   0.019999974   179.9999991    20.00000   305.00021     1.99979     1.92099 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] =  7546991.44872220000 ; 
  pv[0][1] = 24685103.28343560000 ;
  pv[0][2] =       -0.35980290000 ;
  pv[1][0] =     3796.07016047138 ;
  pv[1][1] =    -1157.73520476223 ;
  pv[1][2] =        0.00004164788 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               26339489.3, 1e-1, "gal_pv2kep", "sma 8"  ) ;  
  gal_vdv ( ecc,              0.019999974, 1e-8, "gal_pv2kep", "ecc 8"  ) ;  
  gal_vdv ( raan * GAL_R2D,      20.00000, 1e-5, "gal_pv2kep", "raan 8" ) ;  
  gal_vdv ( argp * GAL_R2D,     305.00000, 1e-3, "gal_pv2kep", "argp 8" ) ;  
  gal_vdv ( ma   * GAL_R2D,       1.92099, 1e-5, "gal_pv2kep", "ma 8"   ) ;  
  gal_vdv ( inc  * GAL_R2D,   179.9999991, 1e-6, "gal_pv2kep", "inc 8"  ) ;  
  gal_vdv ( lonper            ,  GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 8"   ) ;  
  gal_vdv ( p             ,    26328953.5, 1e-1, "gal_pv2kep", "p 8"       ) ;  
  gal_vdv ( v * GAL_R2D   ,       1.99979, 1e-5, "gal_pv2kep", "v 8"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 8" ) ;  
  gal_vdv ( arglat  ,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 8"  ) ;  

/*
 * Vallado #11
 * coe test elliptical equatorial ----------------------------
 * start -22739.108659621 -22739.108659621     0.000000000 v     2.4851400419   -2.0200411207    0.0000000000
 *          p km        a km          ecc         incl deg     raan deg       argp deg       nu deg       m deg      arglat          truelon       lonper 
 * coes  26328.9547  27425.9945   0.200000000     0.0000000 57295727.94688 57295727.94688   205.00000   216.17687 57295727.94688 57295727.94688    20.00000
 */

  pv[0][0] = -22739108.65962080000 ; 
  pv[0][1] = -22739108.65962080000 ;
  pv[0][2] =         0.00000000000 ;
  pv[1][0] =      2485.14004188565 ;
  pv[1][1] =     -2020.04112073465 ;
  pv[1][2] =         0.00000000000 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               27425994.5, 1e-1, "gal_pv2kep", "sma 9"  ) ;  
  gal_vdv ( ecc,              0.200000000, 1e-8, "gal_pv2kep", "ecc 9"  ) ;  
  gal_vdv ( raan,                     GAL_UNDEFINED, 1e-5, "gal_pv2kep", "raan 9" ) ; 
  gal_vdv ( argp ,                    GAL_UNDEFINED, 1e-3, "gal_pv2kep", "argp 9" ) ; 
  gal_vdv ( ma   * GAL_R2D,     216.17687, 1e-5, "gal_pv2kep", "ma 9"   ) ;  
  gal_vdv ( inc  * GAL_R2D,     0.0000000, 1e-7, "gal_pv2kep", "inc 9"  ) ;  
  gal_vdv ( lonper * GAL_R2D           , 20.00000, 1e-6, "gal_pv2kep", "lonper 9"   ) ;  
  gal_vdv ( p             ,    26328954.7, 1e-1, "gal_pv2kep", "p 9"       ) ;  
  gal_vdv ( v * GAL_R2D   ,     205.00000, 1e-5, "gal_pv2kep", "v 9"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 9" ) ;  
  gal_vdv ( arglat ,                  GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 9"  ) ;  

/*
 * Vallado #12
 * coe test elliptical equatorial ----------------------------
 * start 28242.366282204  2470.886880840     0.000000000 v     0.6657521506   -3.6253302219    0.0000000000
 *          p km        a km          ecc        incl deg      raan deg      argp deg        nu deg       m deg      arglat          truelon       lonper 
 * coes  27152.1143  27426.3781   0.100000000   180.0000000 57295727.94688 57295727.94688   115.00000   104.29062 57295727.94688 57295727.94688   240.00000
 */

  pv[0][0] = 28242366.28220400000 ; 
  pv[0][1] =  2470886.88083970000 ;
  pv[0][2] =        0.00000000000 ;
  pv[1][0] =      665.75215057746 ;
  pv[1][1] =    -3625.33022188304 ;
  pv[1][2] =        0.00000000000 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               27426378.1, 1e-1, "gal_pv2kep", "sma 10"  ) ;  
  gal_vdv ( ecc,              0.100000000, 1e-8, "gal_pv2kep", "ecc 10"  ) ;  
  gal_vdv ( raan,           GAL_UNDEFINED, 1e-5, "gal_pv2kep", "raan 10" ) ;  
  gal_vdv ( argp,           GAL_UNDEFINED, 1e-3, "gal_pv2kep", "argp 10" ) ; 
  gal_vdv ( ma   * GAL_R2D,     104.29062, 1e-5, "gal_pv2kep", "ma 10"   ) ;  
  gal_vdv ( inc  * GAL_R2D,   180.0000000, 1e-7, "gal_pv2kep", "inc 10"  ) ;  
  gal_vdv ( lonper * GAL_R2D  , 240.00000, 1e-6, "gal_pv2kep", "lonper 10"   ) ;  
  gal_vdv ( p             ,    27152114.3, 1e-1, "gal_pv2kep", "p 10"       ) ;  
  gal_vdv ( v * GAL_R2D   ,     115.00000, 1e-5, "gal_pv2kep", "v 10"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 10" ) ;  
  gal_vdv ( arglat,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 10"  ) ;  

/*
 * Vallado #13
 * coe test circular near equatorial ----------------------------
 * start -2547.369745493 14446.851725460     0.000000000 v    -5.1334515633   -0.9051660148    0.0000009098
 *          p km         a km         ecc         incl deg     raan deg     argp deg      nu deg           m deg       arglat     truelon       lonper 
 * coes  14669.7177  14669.7177   0.000000000     0.0000100   100.00000 57295727.94688 57295727.94688     0.00000     0.00000 57295727.94688 57295727.94688
 */

  pv[0][0] = -2547369.74549330000 ; 
  pv[0][1] = 14446851.72546040000 ;
  pv[0][2] =        0.00000000000 ;
  pv[1][0] =    -5133.45156333487 ;
  pv[1][1] =     -905.16601477599 ;
  pv[1][2] =        0.00090977789 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               14669717.7, 1e-1, "gal_pv2kep", "sma 11"  ) ;  
  gal_vdv ( ecc,              0.000000000, 1e-9, "gal_pv2kep", "ecc 11"  ) ;  
  gal_vdv ( raan * GAL_R2D,     100.00000, 1e-5, "gal_pv2kep", "raan 11" ) ;  
  gal_vdv ( argp  ,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "argp 11" ) ;  
  gal_vdv ( ma   * GAL_R2D,       0.00000, 1e-5, "gal_pv2kep", "ma 11"   ) ;  
  gal_vdv ( inc  * GAL_R2D,     0.0000100, 1e-9, "gal_pv2kep", "inc 11"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 11"   ) ;  
  gal_vdv ( p             ,    14669717.7, 1e-1, "gal_pv2kep", "p 11"       ) ;  
  gal_vdv ( v     ,           GAL_UNDEFINED, 1e-5, "gal_pv2kep", "v 11"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 11" ) ;  
  gal_vdv ( arglat * GAL_R2D,         0.0, 1e-11, "gal_pv2kep", "arglat 11"  ) ;  

/*
 * Vallado #14
 * coe test circular near equatorial ----------------------------
 * start  7334.858850000 -12704.348194546     0.000000000 v    -4.5142815431   -2.6063216641    0.0000009098
 *          p km        a km          ecc        incl deg     raan deg     argp deg        nu deg         m deg       arglat      truelon       lonper 
 * coes  14669.7177  14669.7177   0.000000000   179.9999900   300.00000 57295727.94688 57295727.94688     0.00000     0.00000 57295727.94688 57295727.94688
 */
 
  pv[0][0] =   7334858.850000000000 ; 
  pv[0][1] = -12704348.194546200000 ;
  pv[0][2] =         0.000000000000 ;
  pv[1][0] =     -4514.281543120467 ;
  pv[1][1] =     -2606.321664118360 ;
  pv[1][2] =         0.000909777890 ;
  
  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               14669717.7, 1e-1, "gal_pv2kep", "sma 12"  ) ;  
  gal_vdv ( ecc,              0.000000000, 1e-9, "gal_pv2kep", "ecc 12"  ) ;  
  gal_vdv ( raan * GAL_R2D,     300.00000, 1e-5, "gal_pv2kep", "raan 12" ) ; 
  gal_vdv ( argp  ,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "argp 12" ) ;  
  gal_vdv ( ma   * GAL_R2D,       0.00000, 1e-5, "gal_pv2kep", "ma 12"   ) ;  
  gal_vdv ( inc  * GAL_R2D,   179.9999900, 1e-9, "gal_pv2kep", "inc 12"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 12"   ) ;  
  gal_vdv ( p             ,    14669717.7, 1e-1, "gal_pv2kep", "p 12"       ) ;  
  gal_vdv ( v     ,           GAL_UNDEFINED, 1e-5, "gal_pv2kep", "v 12"       ) ;  
  gal_vdv ( truelon       ,           GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 12" ) ;  
  gal_vdv ( arglat * GAL_R2D,         0.0, 1e-11, "gal_pv2kep", "arglat 12"  ) ;  

/*
 * Vallado #15
 * coe test circular equatorial ----------------------------
 * start  6199.690594601 13295.279385139     0.000000000 v    -4.7242592394    2.2029582625    0.0000000000
 *          p km        a km         ecc          incl deg     raan deg       argp deg        nu deg          m deg      arglat        truelon       lonper 
 * coes  14669.7177  14669.7177   0.000000000     0.0000000 57295727.94688 57295727.94688 57295727.94688    65.00000 57295727.94688    65.00000 57295727.94688
 */

  pv[0][0] =  6199690.59460080000 ; 
  pv[0][1] = 13295279.38513940000 ;
  pv[0][2] =        0.00000000000 ;
  pv[1][0] =    -4724.25923942564 ;
  pv[1][1] =     2202.95826245369 ;
  pv[1][2] =        0.00000000000 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               14669717.7, 1e-1, "gal_pv2kep", "sma 13"  ) ;  
  gal_vdv ( ecc,              0.000000000, 1e-9, "gal_pv2kep", "ecc 13"  ) ;  
  gal_vdv ( raan ,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "raan 13" ) ; 
  gal_vdv ( argp,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "argp 13" ) ;  
  gal_vdv ( ma   * GAL_R2D,      65.00000, 1e-10, "gal_pv2kep", "ma 13"   ) ;  
  gal_vdv ( inc  * GAL_R2D,     0.0000000, 1e-9, "gal_pv2kep", "inc 13"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 13"   ) ;  
  gal_vdv ( p             ,    14669717.7, 1e-1, "gal_pv2kep", "p 13"       ) ;  
  gal_vdv ( v    ,           GAL_UNDEFINED, 1e-5, "gal_pv2kep", "v 13"       ) ;  
  gal_vdv ( truelon * GAL_R2D,   65.00000, 1e-11, "gal_pv2kep", "truelon 13" ) ;  
  gal_vdv ( arglat  ,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 13"  ) ;  

/*
 * Vallado #16
 * coe test circular equatorial ----------------------------
 * start  6199.690594601 -13295.279385139     0.000000000 v    -4.7242592394   -2.2029582625    0.0000000000
 *          p km        a km          ecc        incl deg      raan deg        argp deg       nu deg          m deg      arglat       truelon     lonper 
 * coes  14669.7177  14669.7177   0.000000000   180.0000000 57295727.94688 57295727.94688 57295727.94688    65.00000 57295727.94688    65.00000 57295727.94688
 */
 
  pv[0][0] =   6199690.59460080000 ; 
  pv[0][1] = -13295279.38513940000 ;
  pv[0][2] =         0.00000000000 ;
  pv[1][0] =     -4724.25923942564 ;
  pv[1][1] =     -2202.95826245369 ;
  pv[1][2] =         0.00000000000 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               14669717.7, 1e-1, "gal_pv2kep", "sma 14"  ) ;  
  gal_vdv ( ecc,              0.000000000, 1e-9, "gal_pv2kep", "ecc 14"  ) ;  
  gal_vdv ( raan  ,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "raan 14" ) ; 
  gal_vdv ( argp  ,           GAL_UNDEFINED, 1e-9, "gal_pv2kep", "argp 14" ) ;  
  gal_vdv ( ma   * GAL_R2D,      65.00000, 1e-9, "gal_pv2kep", "ma 14"   ) ;  
  gal_vdv ( inc  * GAL_R2D,   180.0000000, 1e-9, "gal_pv2kep", "inc 14"  ) ;  
  gal_vdv ( lonper            , GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 14"   ) ;  
  gal_vdv ( p             ,    14669717.7, 1e-1, "gal_pv2kep", "p 14"       ) ;  
  gal_vdv ( v     ,           GAL_UNDEFINED, 1e-5, "gal_pv2kep", "v 14"       ) ;  
  gal_vdv ( truelon * GAL_R2D,   65.00000, 1e-11, "gal_pv2kep", "truelon 14" ) ;  
  gal_vdv ( arglat  ,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 14"  ) ;  

/*
 * Vallado #17
 * coe test parabolic ----------------------------
 * start  3773.375370893 -8221.009754418 -2384.366380699 v     9.0803778759   -0.6389504285   -1.5358015696
 *          p km          a km              ecc         incl deg     raan deg    argp deg      nu deg      m deg      arglat      truelon         lonper 
 * coes  14031.9046 -21480206979.2030   1.000000327    15.0000008    35.00001   200.00000    59.99999     0.00000 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] =  0.5916109 * 6378137.0 ; 
  pv[0][1] = -1.2889359 * 6378137.0 ;
  pv[0][2] = -0.3738343 * 6378137.0 ;
  pv[1][0] =  1.1486347 * 7905.366149846 ;
  pv[1][1] = -0.0808249 * 7905.366149846 ;
  pv[1][2] = -0.1942733 * 7905.366149846 ;
/*
  pv[0][0] =  3773375.3708930  ; 
  pv[0][1] = -8221009.7544180 ;
  pv[0][2] = -2384366.3806990 ;
  pv[1][0] =     9080.3778759 ;
  pv[1][1] =     -638.9504285 ;
  pv[1][2] =    -1535.8015696 ;
*/ 
  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,         -21480206979203.0, 1e+11, "gal_pv2kep", "sma 15"  ) ;  
  gal_vdv ( ecc,               1.000000327, 1e-8, "gal_pv2kep", "ecc 15"  ) ;  
  gal_vdv ( raan * GAL_R2D,       35.00001, 1e-5, "gal_pv2kep", "raan 15" ) ; 
  gal_vdv ( argp * GAL_R2D,      200.00000, 1e-5, "gal_pv2kep", "argp 15" ) ;  
  gal_vdv ( ma   * GAL_R2D,        0.00000, 1e-8, "gal_pv2kep", "ma 15"   ) ;  
  gal_vdv ( inc  * GAL_R2D,     15.0000008, 1e-6, "gal_pv2kep", "inc 15"  ) ;  
  gal_vdv ( lonper            ,  GAL_UNDEFINED, 1e-16, "gal_pv2kep", "lonper 15"   ) ;  
  gal_vdv ( p             ,    14031904.6, 1e-1, "gal_pv2kep", "p 15"       ) ;  
  gal_vdv ( v * GAL_R2D   ,      59.99999, 1e-5, "gal_pv2kep", "v 15"       ) ;  
  gal_vdv ( truelon  ,        GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 15" ) ;  
  gal_vdv ( arglat  ,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 15"  ) ;  

/*
 * Vallado #18
 * coe test parabolic ----------------------------
 * start -6597.319126750 -3071.003443807  1106.940983879 v     1.0453091742    6.1545821004    8.3266083284
 *          p km           a km              ecc       incl deg     raan deg     argp deg      nu deg      m deg         arglat       truelon         lonper 
 * coes  14031.9040 -23792471448.4876   1.000000295   120.0000012   210.00000    34.99999   335.00001 57295773.78350 57295727.94688 57295727.94688 57295727.94688
 */
 
  pv[0][0] = -1.0343646 * 6378137.0 ; 
  pv[0][1] = -0.4814891 * 6378137.0 ;
  pv[0][2] =  0.1735524 * 6378137.0 ;
  pv[1][0] =  0.1322278 * 7905.366149846 ;
  pv[1][1] =  0.7785322 * 7905.366149846 ;
  pv[1][2] =  1.0532856 * 7905.366149846 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,         -23792471448487.6, 1e+12, "gal_pv2kep", "sma 16"  ) ;  
  gal_vdv ( ecc,               1.000000295, 1e-8, "gal_pv2kep", "ecc 16"  ) ;  
  gal_vdv ( raan * GAL_R2D,      210.00000, 1e-5, "gal_pv2kep", "raan 16" ) ; 
  gal_vdv ( argp * GAL_R2D,       34.99999, 1e-5, "gal_pv2kep", "argp 16" ) ;  
  gal_vdv ( ma   ,            GAL_UNDEFINED, 1e-16, "gal_pv2kep", "ma 16"   ) ; 
  gal_vdv ( inc  * GAL_R2D,    120.0000012, 1e-6, "gal_pv2kep", "inc 16"  ) ;  
  gal_vdv ( lonper            ,  GAL_UNDEFINED, 1e-16, "gal_pv2kep", "lonper 16"   ) ; 
  gal_vdv ( p             ,    14031904.0, 1e-1, "gal_pv2kep", "p 16"       ) ;  
  gal_vdv ( v * GAL_R2D   ,     335.00001, 1e-5, "gal_pv2kep", "v 16"       ) ;  
  gal_vdv ( truelon  ,        GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 16" ) ;  
  gal_vdv ( arglat  ,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 16"  ) ;  

/*
 * Vallado #19
 * coe test hyperbolic ---------------------------
 * start  5844.862878871  4468.361415334 -8871.748111235 v     1.3539552226    8.7245193998   -3.0122425354
 *          p km        a km          ecc        incl deg      raan deg    argp deg     nu deg      m deg       arglat        truelon        lonper 
 * coes  15403.3960 -22323.7406   1.300000258    55.0000008    95.00000   215.00001    74.99999    12.10855 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] =  0.9163903 * 6378137.0 ; 
  pv[0][1] =  0.7005747 * 6378137.0 ;
  pv[0][2] = -1.3909623 * 6378137.0 ;
  pv[1][0] =  0.1712704 * 7905.366149846 ;
  pv[1][1] =  1.1036199 * 7905.366149846 ;
  pv[1][2] = -0.3810377 * 7905.366149846 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               -22323740.6, 1e+1, "gal_pv2kep", "sma 17"  ) ;  
  gal_vdv ( ecc,               1.300000258, 1e-9, "gal_pv2kep", "ecc 17"  ) ;  
  gal_vdv ( raan * GAL_R2D,       95.00000, 1e-6, "gal_pv2kep", "raan 17" ) ; 
  gal_vdv ( argp * GAL_R2D,      215.00001, 1e-5, "gal_pv2kep", "argp 17" ) ;  
  gal_vdv ( ma   * GAL_R2D,       12.10855, 1e-6, "gal_pv2kep", "ma 17"   ) ;  
  gal_vdv ( inc  * GAL_R2D,     55.0000008, 1e-7, "gal_pv2kep", "inc 17"  ) ;  
  gal_vdv ( lonper            ,  GAL_UNDEFINED, 1e-7, "gal_pv2kep", "lonper 17"   ) ; 
  gal_vdv ( p             ,    15403396.0, 1e-1, "gal_pv2kep", "p 17"       ) ;  
  gal_vdv ( v * GAL_R2D   ,     74.99999, 1e-5, "gal_pv2kep", "v 17"       ) ;  
  gal_vdv ( truelon  ,        GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 17" ) ;  
  gal_vdv ( arglat  ,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 17"  ) ;  

/*
 * Vallado #20
 * coe test hyperbolic ---------------------------
 * start 78553.277524455 -45032.614967146 -24162.780497698 v    -4.6663202407    1.7115410213    1.2872616011
 *         p km        a km           ecc       incl deg     raan deg     argp deg     nu deg      m deg       arglat            truelon       lonper 
 *coes  15404.4188 -22325.2342   1.300000123   165.0000006   235.00002    35.00001   230.00001 57295773.78350 57295727.94688 57295727.94688 57295727.94688
 */

  pv[0][0] = 12.3160223 * 6378137.0 ; 
  pv[0][1] = -7.0604653 * 6378137.0 ;
  pv[0][2] = -3.7883759 * 6378137.0 ;
  pv[1][0] = -0.5902725 * 7905.366149846 ;
  pv[1][1] =  0.2165037 * 7905.366149846 ;
  pv[1][2] =  0.1628339 * 7905.366149846 ;

  gal_pv2kep ( gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &arglat, &lonper  ) ;
   
  gal_vdv ( sma,               -22325234.2, 1e+1, "gal_pv2kep", "sma 18"  ) ;  
  gal_vdv ( ecc,               1.300000123, 1e-9, "gal_pv2kep", "ecc 18"  ) ;  
  gal_vdv ( raan * GAL_R2D,      235.00002, 1e-5, "gal_pv2kep", "raan 18" ) ; 
  gal_vdv ( argp * GAL_R2D,       35.00001, 1e-5, "gal_pv2kep", "argp 18" ) ;  
  gal_vdv ( ma ,           GAL_UNDEFINED, 1e-6, "gal_pv2kep", "ma 18"   ) ; 
  gal_vdv ( inc  * GAL_R2D,    165.0000006, 1e-7, "gal_pv2kep", "inc 18"  ) ;  
  gal_vdv ( lonper            ,GAL_UNDEFINED, 1e-9, "gal_pv2kep", "lonper 18"   ) ; 
  gal_vdv ( p             ,    15404418.8, 1e-1, "gal_pv2kep", "p 18"       ) ;  
  gal_vdv ( v * GAL_R2D   ,    230.00001, 1e-5, "gal_pv2kep", "v 18"       ) ;  
  gal_vdv ( truelon,        GAL_UNDEFINED, 1e-11, "gal_pv2kep", "truelon 18" ) ;  
  gal_vdv ( arglat,         GAL_UNDEFINED, 1e-11, "gal_pv2kep", "arglat 18"  ) ;  
                               
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

