/*  
 *  - - - - - - - - - - - - - - 
 *   g a l _ f a c t o r i a l  
 *  - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine computes the factorial n!.
 *  
 *  Status: 
 *  
 *     Math special function.  
 *  
 *  Given:  
 *
 *     n                i           Required factorial n >= 0
 *  
 *  Returned:  
 *  
 *     gal_factorial    d           n! if n >= 0, -1 otherwise
 *  
 *  This revision:  
 * 
 *     2008 June 14 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

long double
gal_factorial
  (
    int n 
  ) 
  
{

  long double f = 1.0 ;
  long double i ;
    
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  if ( n < 0 ) {
    f = -1.0 ;
  }
  else {
    for ( i = 1.0 ; i <= n ; i += 1.0 ) {
      f *= i ;
    }
  }
  
  return f ;
  
/*  
 * Finished.  
 */  

}
 
/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
