/*  
 *  - - - - - - - - - - - - - - - -  
 *   g a l _ r k f s 7 8 _ t e s t  
 *  - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_rkfs78 routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_rkfs78
 *     gal_rkf  
 *     gal_vdv  
 *  
 *  This Revision:
 *  
 *     2008 May 18 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  
  
#include "gal_rkfs78_test.h"
#include "gal_rkfs78.h"
#include "gal_rkf.h"
#include "gal_test.h"

static void derivs
  (
    double x, 
    double y[1], 
    double dydx[1],
    int *derivsp
  ) 

{

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
     
 dydx[0] = 0.25 * y[0] * ( 1.0 - y[0] / 20.0 ) ;

/*  
 * Finished.  
 */  
                                        
} 
  
void  
gal_rkfs78_test  
 (  
 ) 
 
{

  extern int gal_tfunc ;  

  double y[1] ;
  
  int i ;
    
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * This is a test routine for RKF
 *
 * SAMPLE RUN:                                                             
 *                                                                         
 * TEST 1                                                                  
 * Solve a scalar equation:                                                
 *                                                                         
 *  Y' = 0.25 * Y * ( 1 - Y / 20 )                                         
 *                                                                         
 *       T       Y_Exact                               
 *                                                                         
 *    0.00000    1.00000                           
 *    4.00000    2.50322                           
 *    8.00000    5.60009                             
 *   12.00000   10.27773                             
 *   16.00000   14.83683                             
 *   20.00000   17.73017  
 *
 * Reference:
 *
 * http://perso.orange.fr/jean-pierre.moreau/Pascal/trkf45_pas.txt
 *  
 */
 
  y[0] = 1.0 ;
  gal_rkf ( y, 1, 0.0, 4.0, 1e-6, 1e-6, 1e-12, derivs, gal_rkfs78, &i ) ;
  gal_vdv ( y[0] , 2.50322, 1e-7, "gal_rkfs78", "y 0" ) ; 
   
  gal_rkf ( y, 1, 4.0, 8.0, 1e-6, 1e-6, 1e-12, derivs, gal_rkfs78, &i ) ;
  gal_vdv ( y[0] , 5.60009, 1e-5, "gal_rkfs78", "y 1" ) ; 
   
  gal_rkf ( y, 1, 8.0, 12.0, 1e-6, 1e-6, 1e-12, derivs, gal_rkfs78, &i ) ;
  gal_vdv ( y[0] , 10.27773, 1e-5, "gal_rkfs78", "y 2" ) ;  
  
  gal_rkf ( y, 1, 12.0, 16.0, 1e-6, 1e-6, 1e-12, derivs, gal_rkfs78, &i ) ;
  gal_vdv ( y[0] , 14.83683, 1e-5, "gal_rkfs78", "y 3" ) ;  
  
  gal_rkf ( y, 1, 16.0, 20.0, 1e-6, 1e-6, 1e-12, derivs, gal_rkfs78, &i ) ;
  gal_vdv ( y[0] , 17.73017 , 1e-5, "gal_rkfs78", "y 4" ) ;  
  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

