/*  
 *  - - - - - - - - - - - 
 *   g a l _ d e l e t e 
 *  - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine deletes a sequence of characters of length l
 *     from the string s, starting at character position n.
 *  
 *  Status: 
 *  
 *     String manipulation routine  
 *  
 *  Given:  
 *
 *     *s              c[]          Target string
 *     n                i           Position to delete from 
 *     l                i           Number of characters to delete
 *  
 *  Returned:  
 *  
 *     *gal_delete      *c          Pointer to the start of the target string
 *  
 *  This revision:  
 * 
 *     2008 March 2 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <strings.h>
#include "gal_delete.h"

char *
gal_delete
  (
    char *s,
	int  n,
	int  l
  ) 
  
{

  int sl = strlen ( s ) ;
  int i ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */ 

  if ( n + l > sl ) {
    l = sl - n ;
  }  
  for ( i = n; i <= sl - l; i++ ) {
    s[i] = s[i+l] ; 
  }
  
  return s ;

/*  
 * Finished.  
 */  

}
 
/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
