/*  
 *  - - - - - - - - - -
 *   g a l _ t r i m r
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine copies s2 to s1, then deletes any trailing white-space 
 *     characters at the end of s1.  
 *  
 *  Status: 
 *  
 *     String manipulation routine  
 *  
 *  Given:  
 *
 *     *s1             c[]          Target string
 *     *s2             c[]          Source string 
 *  
 *  Returned:  
 *  
 *     *gal_trimr      *c           Pointer to the start of the target string
 *  
 *  Notes:  
 *
 *  1) The target string s1 must be at least the same length as the source 
 *     string s2.
 *
 *  Called:
 *
 *     gal_leftstr                  Copy left part of string
 *
 *  This revision:  
 * 
 *     2008 March 8 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <strings.h>
#include <ctype.h>
#include "gal_trimr.h"
#include "gal_leftstr.h"

char *
gal_trimr
  (
    char *s1,
	char *s2
  ) 
  
{
  
  int sl = strlen ( s2 ) - 1 ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */

  if ( sl < 0 ) {
  
    s1[0] = '\0' ;
  
  }
  else {
  
    for ( ; sl >= 0 && isspace ( s2[sl] ); sl-- ) ;
  
    gal_leftstr ( s1, s2, sl + 1 ) ;
	
  }
  
  return s1 ;
  
/*  
 * Finished.  
 */  

}
 
/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
