/*  
 *  - - - - - - - - - - - - - - - - - 
 *   g a l _ c 2 r a d e c _ t e s t  
 *  - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine tests the gal_gcrf2radec routine
 *  
 *  Status: 
 *  
 *     Internal test routine  
 *  
 *  Called:  
 *  
 *     gal_c2radec                  Convert Geocentric position & velocity to RA, Dec, Range
 *     gal_vdv                      Verify double value
 *
 *  Notes:
 *
 *  1) The test values come from Vallado Pages 262-263. It should be noted that the
 *     precision of the test values is not high. A better test should be found in
 *     due course.
 *  
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 262-263
 *
 *  This revision:  
 * 
 *     2008 May 4
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_c2radec_test.h"
#include "gal_c2radec.h"
#include "gal_test.h"
#include "gal_const.h"

void
gal_c2radec_test
  (
  ) 
  
{

  extern int gal_tfunc ;
  
  double ra, dec, range, radot, decdot, rangedot ;
  
  double gcrf[2][3] = { 
    { 1752246215000.0, -3759563433000.0, -1577568105000.0 } ,
    { -18324.0, 18332.0, 7777.0 } ,
  } ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_c2radec ( gcrf, &ra, &dec, &range, &radot, &decdot, &rangedot ) ;
    
  gal_vdv ( ra      , 294.9891458    * GAL_D2R, 1e-9, "gal_c2radec", "ra"       ) ;  
  gal_vdv ( dec     , -20.8234944    * GAL_D2R, 1e-9, "gal_c2radec", "dec"      ) ;  
  gal_vdv ( range   , 4437725220273.0 , 1e-00, "gal_c2radec", "range"    ) ;  
  gal_vdv ( radot   , -0.000000122447 * GAL_D2R, 1e-14, "gal_c2radec", "radot"    ) ;  
  gal_vdv ( decdot  , -0.000000017941 * GAL_D2R, 1e-14, "gal_c2radec", "decdot"   ) ;  
  gal_vdv ( rangedot, -25530.4729    , 1e-04, "gal_c2radec", "rangedot" ) ;  
  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
