/*  
 *  - - - - - - - - - - - - - - - - - -
 *   g a l _ c 2 t p v 0 0 b _ t e s t  
 *  - - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine tests the gal_c2tpv00b routine
 *  
 *  Status: 
 *  
 *     Internal test routine  
 *  
 *  Called:  
 *  
 *     gal_c2tpv00b                 Convert GCRF position & velocity to ITRF frame (IAU2000B)
 *     gal_vdv                      Verify double value
 *     gal_cal2jd                   Convert date to Julian Date
 *
 *  Notes:
 *
 *  1) The test values come from Vallado Pages 218-219. The answers in the book
 *     are incorrect, the values used below were derived from SOFA routines.
 *  
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 218-219
 *
 *  This revision:  
 * 
 *     2008 June 20
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_c2tpv00b_test.h"
#include "gal_c2tpv00b.h"
#include "gal_t2cpv00b.h"
#include "gal_test.h"
#include "gal_cal2jd.h"
#include "gal_const.h"

void
gal_c2tpv00b_test
  (
  ) 
  
{

  extern int gal_tfunc ;
  
  double utc1, utc2 ;
  
  double gcrf[2][3] = { 
    { 5102508.965708, 6123011.397234, 6378136.925304 } ,
    {   -4743.220155,     790.536503,    5533.755728 } ,
  } ;
  
  double itrf[2][3], gcrf2[2][3] ;
  
  int j ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  j = gal_cal2jd ( 2004, 4, 6, &utc1, &utc2 ) ;
  utc2 += 7.0 / GAL_D2H + 51.0 / GAL_D2M + 28.386009 / GAL_D2S ;
  
  gal_c2tpv00b ( gcrf, utc1, utc2, -0.4399619, 0.0015563, -0.140682 * GAL_AS2R, 0.333309 * GAL_AS2R, itrf ) ;

  gal_vdv ( itrf[0][0], -1033479.3843017062045, 1e-6, "gal_c2tpv00b", "itrf[0][0]") ;  
  gal_vdv ( itrf[0][1],  7901295.2767224105628, 1e-6, "gal_c2tpv00b", "itrf[0][1]") ;  
  gal_vdv ( itrf[0][2],  6380356.5939516147409, 1e-6, "gal_c2tpv00b", "itrf[0][2]") ;  
  gal_vdv ( itrf[1][0],    -3225.6365210688744, 1e-9, "gal_c2tpv00b", "itrf[1][0]") ;  
  gal_vdv ( itrf[1][1],    -2872.4514487597590, 1e-9, "gal_c2tpv00b", "itrf[1][1]") ;  
  gal_vdv ( itrf[1][2],     5531.9244456238090, 1e-9, "gal_c2tpv00b", "itrf[1][2]") ; 


  gal_t2cpv00b ( itrf, utc1, utc2, -0.4399619, 0.0015563, -0.140682 * GAL_AS2R, 0.333309 * GAL_AS2R, gcrf2 ) ;

  gal_vdv ( gcrf2[0][0], gcrf[0][0], 1e-8,  "gal_c2tpv00b-gal_t2cpv00b", "gcrf2[0][0]") ;  
  gal_vdv ( gcrf2[0][1], gcrf[0][1], 1e-8,  "gal_c2tpv00b-gal_t2cpv00b", "gcrf2[0][1]") ;  
  gal_vdv ( gcrf2[0][2], gcrf[0][2], 1e-9,  "gal_c2tpv00b-gal_t2cpv00b", "gcrf2[0][2]") ;  
  gal_vdv ( gcrf2[1][0], gcrf[1][0], 1e-11, "gal_c2tpv00b-gal_t2cpv00b", "gcrf2[1][0]") ;  
  gal_vdv ( gcrf2[1][1], gcrf[1][1], 1e-12, "gal_c2tpv00b-gal_t2cpv00b", "gcrf2[1][1]") ;  
  gal_vdv ( gcrf2[1][2], gcrf[1][2], 1e-12, "gal_c2tpv00b-gal_t2cpv00b", "gcrf2[1][2]") ; 

  gal_tfunc++ ;  
 
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
