/*  
 *  - - - - - - - - - - - -
 *   g a l _ i j k 2 p q w   
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine transforms a pv-vector from the IJK frame to the to PQW 
 *     frame.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     ijk           d[2][3]        pv-vector in IJK frame
 *     raan             d           Longitude of the ascending mode (radians)
 *     argp             d           Argument of Pericentre (radians)
 *     inc              d           Inclination (radians)
 *  
 *  Returned:
 *  
 *     pqw           d[2][3]        pv-vector in PQW frame
 *
 *  Called:
 *
 *     gal_pqw2ijkm                 Form PQW to IJK transformation matrix
 *     gal_trxpv                    Multiply transpose of r-matrix and pv-vector
 *  
 *  References:
 *
 *     Satellite Orbits
 *     Oliver Montenbruck, Eberhard Gill
 *     Springer 2005
 *     Chapter 2
 *
 *  This revision:
 *  
 *     2008 July 19   
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_ijk2pqw.h"
#include "gal_pqw2ijkm.h"
#include "gal_trxpv.h"
  
void  
gal_ijk2pqw  
 ( 
   double ijk[2][3],
   double raan,
   double argp,
   double inc,
   double pqw[2][3]
 ) 
 
{

  double pqw2ijk[3][3] ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_pqw2ijkm ( raan, argp, inc, pqw2ijk ) ;
  gal_trxpv ( pqw2ijk, ijk, pqw ) ;
  
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

