/*  
 *  - - - - - - - - - - - - - - - - - - 
 *   g a l _ l a t l o n 2 t _ t e s t  
 *  - - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine tests the gal_latlon2t routine
 *  
 *  Status: 
 *  
 *     Internal test routine  
 *  
 *  Called:  
 *  
 *     gal_latlon2t                 Convert latitude and longitude to ITRF position 
 *     gal_vdv                      Verify double value
 *
 *  Notes:
 *
 *  1) The test values come from Vallado Pages 177-178. It should be noted that the
 *     precision of the test values is not high. A better test should be found in
 *     due course.
 *  
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 177-178
 *
 *     Explantory Supplement to the Astronomical Supplement
 *     Seidelmann P. Kenneth 1992
 *     Pages 202-207
 *
 *  This revision:  
 * 
 *     2008 May 4
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_latlon2t_test.h"
#include "gal_latlon2t.h"
#include "gal_const.h"
#include "gal_test.h"

void
gal_latlon2t_test
  (
  ) 
  
{

  extern int gal_tfunc ;
    
  double itrf[3] ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_latlon2t ( 39.007 * GAL_D2R, -104.883 * GAL_D2R, 2186.3, 6378136.6, 298.25642, itrf ) ;
    
  gal_vdv ( itrf[0], -1275121.9, 1e-0, "gal_latlon2t", "lat 0"    ) ;  
  gal_vdv ( itrf[1], -4797989.0, 1e-0, "gal_latlon2t", "lon 0"    ) ;  
  gal_vdv ( itrf[2], 3994295.75, 1e-0, "gal_latlon2t", "height 0" ) ;  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
