/*  
 *  - - - - - - - - - - - - - - - - - - -
 *   g a l _ l a t l o n 2 t _ w g s 7 2 
 *  - - - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine creates a position vector in the ITRF reference
 *     frame from given geodetic latitude and longitude using
 *     WGS72 reference ellipsoid.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     lat                 d        Latitude ( radians )  
 *     lon                 d        Longitude ( radians ) 
 *     height              d        Height above the reference spheroid ( m ) 
 *  
 *  Returned:
 *
 *     itrf               d[3]      ITRF position vector ( km )
 *
 *  Called:
 *
 *     gal_latlon2t                 Convert latitude & longitude to ITRF position
 *  
 *  References:
 *
 *     Explantory Supplement to the Astronomical Supplement
 *     Seidelmann P. Kenneth 1992
 *     Pages 202-207
 *
 *     The Astronomical Almanac 1997
 *     Pages K11-K12
 *
 *  This revision:
 *  
 *     2008 May 4   
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_latlon2t_wgs72.h"
#include "gal_ellipsoids.h"
#include "gal_latlon2t.h"
  
void  
gal_latlon2t_wgs72  
 ( 
   double lat,
   double lon,
   double height,
   double itrf[3]
 ) 
 
{

  double sma, invf ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
  gal_emparams ( GAL_EMEA_WGS1972, &sma, &invf ) ;
  gal_latlon2t ( lat, lon, height, sma, invf, itrf ) ;
    
/*  
 * Finished.  
 */  

}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

