/*  
 *  - - - - - - - - - 
 *   g a l _ s e z m  
 *  - - - - - - - - - 
 *  
 *  Form SEZ transformation matrix  
 *  
 *  Description: 
 *  
 *     This routine forms the SEZ transformation matrix for specified
 *     latitude and longitude. 
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     lat                 d        Latitude ( radians )
 *     lon                 d        Longitude ( radians )
 *  
 *  Returned:
 *  
 *     sez              d[3][3]     SEZ matrix
 *  
 *  References:
 *
 *     Methods of Orbit Determination
 *     P. R. Escobal 1965
 *     Pages 405-406
 *
 *  This revision:
 *  
 *     2009 January 9   
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <math.h>
#include "gal_sezm.h"
  
void  
gal_sezm  
 ( 
   double latitude,
   double longitude,
   double sez[3][3]
 ) 
 
{

  double clat, slat, clon, slon ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  clat = cos ( latitude ) ;
  slat = sin ( latitude ) ;
  clon = cos ( longitude ) ;
  slon = sin ( longitude ) ;

  sez[0][0] = clon * slat  ;
  sez[0][1] = slon * slat ;
  sez[0][2] = -clat ;
  sez[1][0] = -slon ;
  sez[1][1] = clon ;
  sez[1][2] = 0.0 ;
  sez[2][0] = clon * clat ;
  sez[2][1] = slon * clat ;
  sez[2][2] = slat ;
  
/*  
 * Finished.  
 */
   
}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

