/*  
 *  - - - - - - - - - - - - - - - - 
 *   g a l _ t 2 a z e l _ t e s t  
 *  - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine tests the gal_t2azel routine
 *  
 *  Status: 
 *  
 *     Internal test routine  
 *  
 *  Called:  
 *  
 *     gal_t2azel                   Convert ITRF position to azimuth and elevation
 *     gal_vdv                      Verify double value
 *
 *  Notes:
 *
 *  1) The test values come from Vallado Pages 411-412. It should be noted that the
 *     precision of the test values is not high. A better test should be found in
 *     due course.
 *  
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 411-412
 *
 *  This revision:  
 * 
 *     2008 May 4
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_t2azel_test.h"
#include "gal_t2azel.h"
#include "gal_test.h"
#include "gal_const.h"
#include "gal_latlon2t.h"

void
gal_t2azel_test
  (
  ) 
  
{

  extern int gal_tfunc ;
  
  double az, el, range, rdot ;
  
  double itrf[2][3] = {
   { -1629680.32, -5257360.56, 3824243.88  },
   {    -2102.707,   -1664.813,   1484.966 },
   } ;
  
  double site[3] = { -1275121.9, -4797989.0, 3994295.75 } ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_t2azel ( itrf, site, 39.007 * GAL_D2R, -104.883 * GAL_D2R, &az, &el, &range, &rdot ) ;
    
  gal_vdv ( az   ,  205.6 * GAL_D2R, 1e-04, "gal_t2azel", "az"    ) ;  
  gal_vdv ( el   ,   30.7 * GAL_D2R, 1e-05, "gal_t2azel", "el"    ) ;  
  gal_vdv ( range,         604680.0, 1e+02, "gal_t2azel", "range" ) ;  
  gal_vdv ( rdot ,           2080.0, 1e-01, "gal_t2azel", "rdot"  ) ;  
  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
