/*  
 *  - - - - - - - - - - - - - - - - - -
 *   g a l _ t 2 c p v 0 6 a _ t e s t  
 *  - - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine tests the gal_t2cpv06a routine
 *  
 *  Status: 
 *  
 *     Internal test routine  
 *  
 *  Called:  
 *  
 *     gal_t2cpv06a                 Convert ITRF position & velocity to GCRF frame
 *     gal_vdv                      Verify double value
 *     gal_cal2jd                   Convert date to Julian Date
 *
 *  Notes:
 *
 *  1) The test values come from Vallado Pages 218-219. The answers in the book
 *     are incorrect, the values used below were derived from SOFA routines.
 *  
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 218-219
 *
 *  This revision:  
 * 
 *     2008 June 14
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_t2cpv06a_test.h"
#include "gal_t2cpv06a.h"
#include "gal_test.h"
#include "gal_const.h"
#include "gal_cal2jd.h"

void
gal_t2cpv06a_test
  (
  ) 
  
{

  extern int gal_tfunc ;
  
  double utc1, utc2 ;
  
  double itrf[2][3] = { 
    { -1033479.3830, 7901295.2754, 6380356.5958 } ,
    {  -3225.636520, -2872.451450,  5531.924446 } ,
  } ; 
  
  double gcrf[2][3] ;
  
  int j ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  j = gal_cal2jd ( 2004, 4, 6, &utc1, &utc2 ) ;
  utc2 += 7.0 / GAL_D2H + 51.0 / GAL_D2M + 28.386009 / GAL_D2S ;
  
  gal_t2cpv06a ( itrf, utc1, utc2, -0.4399619, 0.0015563, -0.140682 * GAL_AS2R, 0.333309 * GAL_AS2R, gcrf ) ;

  gal_vdv ( gcrf[0][0], 5102508.9657084063219, 1e-6, "gal_t2cpv06a", "gcrf[0][0]") ; 
  gal_vdv ( gcrf[0][1], 6123011.3972336093866, 1e-6, "gal_t2cpv06a", "gcrf[0][1]") ;  
  gal_vdv ( gcrf[0][2], 6378136.9253039420073, 1e-6, "gal_t2cpv06a", "gcrf[0][2]") ;  
  gal_vdv ( gcrf[1][0],   -4743.2201549739252, 1e-9, "gal_t2cpv06a", "gcrf[1][0]") ; 
  gal_vdv ( gcrf[1][1],     790.5365029739416, 1e-9, "gal_t2cpv06a", "gcrf[1][1]") ;  
  gal_vdv ( gcrf[1][2],    5533.7557282116574, 1e-9, "gal_t2cpv06a", "gcrf[1][2]") ; 
 
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
