/*  
 *  - - - - - - - - - - - - - - - - - - - 
 *   g a l _ t 2 l a t l o n f _ t e s t  
 *  - - - - - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine tests the gal_t2latlonf routine
 *  
 *  Status: 
 *  
 *     Internal test routine  
 *  
 *  Called:  
 *  
 *     gal_t2latonf                 Convert ITRF position to latitude and longitude
 *     gal_vdv                      Verify double value
 *
 *  Notes:
 *
 *  1) The test values come from Vallado Pages 177-178. It should be noted that the
 *     precision of the test values is not high. A better test should be found in
 *     due course.
 *  
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 177-178
 *
 *  This revision:  
 * 
 *     2008 May 3
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_t2latlonf_test.h"
#include "gal_t2latlonf.h"
#include "gal_test.h"
#include "gal_const.h"

void
gal_t2latlonf_test
  (
  ) 
  
{

  extern int gal_tfunc ;
  
  double lat, lon, height ;
  
/*  double itrf[3] = { 6524834.0, 6862875.0, 6448296.0 } ; */

  double itrf2[3] = { -1275121.9, -4797989.0, 3994295.75 } ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*    
  gal_t2latlonf ( itrf, 6378136.6, 298.25642, &lat, &lon, &height ) ;

  gal_vdv ( lat   , 34.352496 * GAL_D2R, 1e-6, "gal_t2latlonf", "lat 0"    ) ;  
  gal_vdv ( lon   ,  -72.5529 * GAL_D2R, 1e-4, "gal_t2latlonf", "lon 0"    ) ;  
  gal_vdv ( height,   5085.22, 1e-2, "gal_t2latlonf", "height 0" ) ;  
*/  
  gal_t2latlonf ( itrf2, 6378136.6, 298.25642, &lat, &lon, &height ) ;
    
  gal_vdv ( lat   ,   39.007 * GAL_D2R, 1e-6, "gal_t2latlonf", "lat 1"    ) ;  
  gal_vdv ( lon   , -104.883 * GAL_D2R, 1e-9, "gal_t2latlonf", "lon 1"    ) ;  
  gal_vdv ( height,   2186.3, 1e-1, "gal_t2latlonf", "height 1" ) ;  
  gal_tfunc++ ;  
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
