/*  
 *  - - - - - - - - - - - - - - - - - - 
 *   g a l _ t e s t _ c o m m o n . h  
 *  - - - - - - - - - - - - - - - - - - 
 *  
 *  This file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This file defines the external variables used by the GAL test system.
 *  
 *  Status: 
 *  
 *     Support file for the test system  
 *  
 *  Defines:  
 *
 *     gal_tpass        i           Count of the number of successful tests
 *                                  since the routine gal_test_start was last
 *                                  called
 *
 *     gal_tfail        i           Count of the number of tests that have
 *                                  failed since the routine gal_test_start
 *                                  was last called
 *
 *     gal_tfunc        i           Count of the number of routines that have
 *                                  been tested since the routine gal_test_start
 *                                  was last called
 *  
 *     gal_tverb        i           Set to 1 if both success and failure messages
 *                                  are to be reported by the test routines. Set 
 *                                  to 0 if failure messages only are to be 
 *                                  reported
 *
 *     gal_tlibn     c[256]         Name of the sub-library under test
 *  
 *  This revision:  
 * 
 *     2008 March 2 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_TEST_COMMON_H_  
#define _GAL_TEST_COMMON_H_ 1  
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

int gal_tpass ;
int gal_tfail ;
int gal_tfunc ;
int gal_tverb ;

#define GAL_MAXLIBNAME 256 

char gal_tlibn[GAL_MAXLIBNAME] ;

__END_DECLS  
  
#endif /* !_GAL_TEST_COMMON_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
