/*  
 *  - - - - - - - - - - - - - - - 
 *   g a l _ t e s t _ s t a r t 
 *  - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This starts a test run and resets the various statistics
 *  
 *  Status: 
 *  
 *     internal test routine.  
 *  
 *  Given:  
 *  
 *     *libname        c[]          Name of the sub-library under test.
 *
 *     verbose          i           Set to 1 if both success and failure
 *                                  messages are to be output by the test
 *                                  routines. Set to 0 if failure messages
 *                                  only are to be output.
 *  Notes:  
 *  
 *  1) The external variables gal_tpass, gal_tfail, and gal_tfunc are set
 *     to zero.
 *
 *  2) The external variable gal_tverb is set to the value of the parameter
 *     verbose.
 *
 *  3) The library name is copied to the external variable gal_tlibn to be
 *     used later by gal_test_stop.       
 *  
 *  This revision:  
 * 
 *     2008 March 2 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdio.h>
#include <strings.h>
#include "gal_test_start.h"
  
void
gal_test_start
  (
    char *libname,  
    int verbose
  ) 	  

{  
  
  extern int  gal_tpass ; 
  extern int  gal_tfail ;
  extern int  gal_tfunc ;  
  extern int  gal_tverb ;
  extern char gal_tlibn[] ; 
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
  strcpy ( gal_tlibn, libname ) ; 

  printf ("\n%s test started\n\n", gal_tlibn ) ;  
  
  gal_tpass = 0 ; 
  gal_tfail = 0 ;
  gal_tfunc = 0 ;
  gal_tverb = verbose ;
  
/*  
 * Finished.  
 */  
  
}  
 
/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
