/*  
 *  - - - - - - - - - - - - - - - 
 *   g a l _ t e s t _ s t a r t 
 *  - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This starts a test run and resets the various statistics
 *  
 *  Status: 
 *  
 *     internal test routine.  
 *  
 *  Given:  
 *
 *     *libname        c[]          Name of the sub-library under test.
 *
 *     verbose          i           Set to 1 if both success and failure
 *                                  messages are to be output by the test
 *                                  routines. Set to 0 if failure messages
 *                                  only are to be output.
 *  Notes:  
 *  
 *  1) The external variables gal_tpass, gal_tfail, and gal_tfunc are set
 *     to zero.
 *
 *  2) The external variable gal_tverb is set to the value of the parameter
 *     verbose.     
 *  
 *  3) The library name is copied to the external variable gal_tlibn to be
 *     used later by gal_test_stop.       
 *  
 *  This revision:  
 * 
 *     2008 March 2 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_TEST_START_H_  
#define _GAL_TEST_START_H_ 1  
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

void
gal_test_start
  (
    char *libname,
    int verbose
  ) ;	  
 
__END_DECLS  
  
#endif /* !_GAL_TEST_START_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
