/*  
 *  - - - - - - - -  
 *   g a l _ v d v  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine validates a double precision result.
 *  
 *  Status: 
 *  
 *     Internal test routine 
 *  
 *  Given:  
 *
 *     dval            d            Value computed by the routine under test  
 *     dvalok          d            Correct value  
 *     dtol            d            Tolerance
 *     *routine       c[]           Name of the routine under test  
 *     *test          c[]           Name of the individual test
 *  
 *  Notes:  
 *  
 *  1) The external variables gal_test_success and gal_test_failure are incremented
 *     depending upon the outcome of the test.
 *
 *  2) If the external variable gal_test_verbose is set to 1 then both test success
 *     and test failure messages are sent to the standard output. If set to 0 then
 *     only test failure messages are sent to the standard output.
 *  
 *  This revision:  
 * 
 *     2008 September 13 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <math.h>
#include <stdio.h>
#include "gal_vdv.h"
 
void   
gal_vdv  
  (  
    double dval,  
    double dvalok,
	double dtol,  
    char   *func,  
    char   *test 
  )  
  
{  
  
  extern int gal_tpass ; 
  extern int gal_tfail ;  
  extern int gal_tverb ; 
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  
  if ( ( dval == dvalok ) || ( fabs ( dval - dvalok ) <= dtol ) ) {
    gal_tpass++ ;  
    if ( gal_tverb == 1 ) {  
      printf ("Test %s %s passed.\n\n", func, test) ;  
    }  
  }  
  else {  
    gal_tfail++ ;  
    printf ("Test %s %s failed.\n", func, test) ;  
    printf ("Expected value: %30.19e\n", dvalok) ;  
    printf ("  Actual value: %30.19e\n", dval) ;  
    printf ("    Difference: %30.19e\n\n", dval-dvalok) ;  
  }  

/*  
 * Finished.  
 */  
  
}  
 
/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
