/*  
 *  - - - - - - - -  
 *   g a l _ p x p  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  p-vector outer (=vector=cross) product.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     a                  d[3]      first p-vector  
 *     b                  d[3]      second p-vector  
 *  
 *  Returned:
 *  
 *     axb                d[3]      a x b  
 *  
 *  This revision:
 *  
 *     2000 November 25 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_pxp.h"  
  
void  
gal_pxp  
 (  
    double a[3],  
    double b[3],  
    double axb[3]  
 )  
{  
  
    double xa, ya, za, xb, yb, zb ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    xa = a[0] ;  
    ya = a[1] ;  
    za = a[2] ;  
    xb = b[0] ;  
    yb = b[1] ;  
    zb = b[2] ;  
  
    axb[0] = ya * zb - za * yb ;  
    axb[1] = za * xb - xa * zb ;  
    axb[2] = xa * yb - ya * xb ;  
  
/*  
 *  Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
