/*  
 *  - - - - - - - -  
 *   g a l _ r x p  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Multiply a p-vector by an r-matrix.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     r                d[3][3]     r-matrix  
 *     p                  d[3]      p-vector  
 *  
 *  Returned:
 *  
 *     rp                 d[3]      r * p  
 *  
 *  Called:
 *  
 *     gal_cp             copy p-vector  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_rxp.h"  
#include "gal_cp.h"  
  
void  
gal_rxp  
 (  
    double r[3][3],  
    double p[3],  
    double rp[3]  
 )  
{  
  
    double w, wrp[3] ;  
  
    int i, j ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
/*  
 * Matrix r * vector p.  
 */  
  
    for ( j = 0; j < 3; j++ ) {  
        w = 0.0 ;  
        for ( i = 0; i < 3; i++ ) {  
            w += r[j][i] * p[i] ;  
        }  
        wrp[j] = w ;  
    }  
  
/*  
 * Return the result.  
 */  
  
    gal_cp ( wrp, rp ) ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
