/*  
 *  - - - - - - - -  
 *   g a l _ r x r  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Multiply two r-matrices.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     a                d[3][3]     first r-matrix  
 *     b                d[3][3]     second r-matrix  
 *  
 *  Returned:
 *  
 *     atb              d[3][3]     a * b  
 *  
 *  Called:
 *  
 *     gal_cr           copy r-matrix  
 *  
 *  This revision:
 *  
 *     2000 November 25 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_rxr.h"  
#include "gal_cr.h"  
  
void  
gal_rxr  
 (  
    double a[3][3],  
    double b[3][3],  
    double atb[3][3]  
 )  

{  
  
    int i, j, k ;  
  
    double w, wm[3][3] ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    for ( i = 0; i < 3; i++ ) {  
  
        for ( j = 0; j < 3; j++ ) {  
  
            w = 0.0 ;  
  
            for ( k = 0; k < 3; k++ ) {  
               w += a[i][k] * b[k][j] ;  
            }  
  
            wm[i][j] = w ;  
  
        }  
    }  
  
    gal_cr ( wm, atb ) ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
