/*  
 *  - - - - - - - -  
 *   g a l _ s 2 c  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Convert spherical coordinates to Cartesian.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     theta               d        longitude angle (radians)  
 *     phi                 d        latitude angle (radians)  
 *  
 *  Returned:
 *  
 *     c                  d[3]      direction cosines  
 *  
 *  This revision:
 *  
 *     2000 November 25 ( c version 2008 February 9 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <math.h>  
#include "gal_s2c.h"  
__BEGIN_DECLS  
  
void  
gal_s2c  
 (  
    double theta,  
    double phi,  
    double c[3]  
 )  
{  
  
    double cp ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    cp = cos ( phi ) ;  
    c[0] = cos ( theta ) * cp ;  
    c[1] = sin ( theta ) * cp ;  
    c[2] = sin ( phi )        ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
