/*  
 *  - - - - - - - - -  
 *   g a l _ s 2 p v  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Convert position/velocity from spherical to Cartesian coordinates.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *  
 *     theta               d        longitude angle (radians)  
 *     phi                 d        latitude angle (radians)  
 *     r                   d        radial distance  
 *     td                  d        rate of change of THETA  
 *     pd                  d        rate of change of PHI  
 *     rd                  d        rate of change of R  
 *  
 *  Returned:
 *  
 *     pv               d[2][3]     pv-vector  
 *  
 *  This revision:
 *  
 *     2000 November 25 ( c version 2008 February 9 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <math.h>  
#include "gal_s2pv.h"  
  
void  
gal_s2pv  
 (  
    double theta,  
    double phi,  
    double r,  
    double td,  
    double pd,  
    double rd,  
    double pv[2][3]  
 )  
{  
  
    double st, ct, sp, cp, rcp, x, y, rpd, w ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    st = sin ( theta ) ;  
    ct = cos ( theta ) ;  
    sp = sin ( phi ) ;  
    cp = cos ( phi ) ;  
    rcp = r * cp ;  
    x = rcp * ct ;  
    y = rcp * st ;  
    rpd = r * pd ;  
    w = rpd * sp - cp * rd ;  
  
    pv[0][0] = x ;  
    pv[0][1] = y ;  
    pv[0][2] = r * sp ;  
    pv[1][0] = - y * td - w * ct ;  
    pv[1][1] =   x * td - w * st ;  
    pv[1][2] = rpd * cp + sp * rd ;  
  
/*  
 *  Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
