/*  
 *  - - - - - - - - - -  
 *   g a l _ s 2 x p v  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Multiply a pv-vector by two scalars.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     s1                  d        scalar to multiply position component by  
 *     s2                  d        scalar to multiply velocity component by  
 *     pv               d[2][3]     pv-vector  
 *  
 *  Returned:
 *  
 *     spv              d[2][3]     pv-vector: p scaled by S1, v scaled by S2  
 *  
 *  Called:
 *  
 *     gal_sxp            multiply p-vector by scalar  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 February 9 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_s2xpv.h"  
#include "gal_sxp.h"  
  
void  
gal_s2xpv  
 (  
    double s1,  
    double s2,  
    double pv[2][3],  
    double spv[2][3]  
 )  
{  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
    gal_sxp ( s1, &pv[0][0], &spv[0][0] ) ;  
    gal_sxp ( s2, &pv[1][0], &spv[1][0] ) ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
