/*  
 *  - - - - - - - - -  
 *   g a l _ s e p s  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Angular separation between two sets of spherical coordinates.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     al                  d        first longitude (radians)  
 *     ap                  d        first latitude (radians)  
 *     bl                  d        second longitude (radians)  
 *     bp                  d        second latitude (radians)  
 *  
 *  Returned:
 *  
 *     gal_seps            d        angular separation (radians)  
 *  
 *  Called:
 *  
 *     gal_s2c             spherical coordinates to unit vector  
 *     gal_sepp            angular separation between two p-vectors  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_seps.h"  
#include "gal_s2c.h"  
#include "gal_sepp.h"  
  
double  
gal_seps  
 (  
    double al,  
    double ap,  
    double bl,  
    double bp  
 )  
{  
  
    double ac[3], bc[3] ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
/*  
 * Spherical to Cartesian.  
 */  
  
    gal_s2c ( al, ap, ac ) ;  
    gal_s2c ( bl, bp, bc ) ;  
  
/*  
 * Angle between the vectors.  
 */  
  
    return gal_sepp ( ac, bc ) ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
