/*  
 *  - - - - - - - - - -  
 *   g a l _ t r x p v  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Multiply a pv-vector by the transpose of an r-matrix.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     r                d[3][3]     r-matrix  
 *     pv               d[2][3]     pv-vector  
 *  
 *  Returned:
 *  
 *     trpv             d[2][3]     r * pv  
 *  
 *  Called:
 *  
 *     gal_tr           transpose r-matrix  
 *     gal_rxpv         product of r-matrix and pv-vector  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 February 9 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include "gal_trxpv.h"  
#include "gal_tr.h"  
#include "gal_rxpv.h"  
  
void  
gal_trxpv  
 (  
    double r[3][3],  
    double pv[2][3],  
    double trpv[2][3]  
 )  
{  
  
    double tr[3][3] ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
/*  
 * Transpose of matrix R.  
 */  
  
    gal_tr ( r, tr ) ;  
  
/*  
 * Matrix TR * vector PV -> vector TRPV.  
 */  
  
    gal_rxpv ( tr, pv, trpv ) ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
