/*  
 *  - - - - - - - - - - - - - -  
 *   g a l _ s g p 4 _ t e s t  
 *  - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     Test gal_sgp4 routine.  
 *  
 *  Status:  
 *  
 *     Internal test routine  
 *  
 *  Called:
 *  
 *     gal_sgp4  
 *     gal_vdv  
 *     gal_sgp4init 
 *     gal_tledec  
 *  
 *  This Revision:
 *  
 *     2008 May 4 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 */  

#include <strings.h>  
#include "gal_sgp4_test.h"
#include "gal_sgp4.h"
#include "gal_sgp4init.h"
#include "gal_tledec.h"
#include "gal_tle.h"
#include "gal_sgp4t.h"
#include "gal_gm.h"
#include "gal_const.h"
  
void  
gal_sgp4_test  
 (  
 ) 
 
{

  extern int gal_tfunc ; 
  
  char card1[70], card2[70] ;
  
  gal_tle_t tle ;
  
  gal_sgp4_t sgp4 ;
  
  extern gal_gm_t gal_gmwgs72 ;
  
  double pv[2][3] ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * TEME example  
 */  

  strcpy ( card1, "1 00005U 58002B   00179.78495062  .00000023  00000-0  28098-4 0  4753" ) ;  
  strcpy ( card2, "2 00005  34.2682 348.7242 1859667 331.7664  19.3264 10.82419157413667" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7022.46529266     , 1e+0, "gal_sgp4", "pv[0][0] 0 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1400.08296755    , 1e+0, "gal_sgp4", "pv[0][1] 0 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 0.03995155        , 1e+0, "gal_sgp4", "pv[0][2] 0 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.893841015       , 1e+0, "gal_sgp4", "pv[1][0] 0 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.405893759       , 1e+0, "gal_sgp4", "pv[1][1] 0 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.534807250       , 1e+0, "gal_sgp4", "pv[1][2] 0 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -7154.03120202    , 1e+0, "gal_sgp4", "pv[0][0] 0 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3783.17682504    , 1e+0, "gal_sgp4", "pv[0][1] 0 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3536.19412294    , 1e+0, "gal_sgp4", "pv[0][2] 0 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.741887409       , 1e+0, "gal_sgp4", "pv[1][0] 0 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.151817765      , 1e+0, "gal_sgp4", "pv[1][1] 0 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.093935425      , 1e+0, "gal_sgp4", "pv[1][2] 0 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -7134.59340119    , 1e+0, "gal_sgp4", "pv[0][0] 0 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6531.68641334     , 1e+0, "gal_sgp4", "pv[0][1] 0 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3260.27186483     , 1e+0, "gal_sgp4", "pv[0][2] 0 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -4.113793027      , 1e+0, "gal_sgp4", "pv[1][0] 0 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.911922039      , 1e+0, "gal_sgp4", "pv[1][1] 0 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.557327851      , 1e+0, "gal_sgp4", "pv[1][2] 0 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5568.53901181     , 1e+0, "gal_sgp4", "pv[0][0] 0 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4492.06992591     , 1e+0, "gal_sgp4", "pv[0][1] 0 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3863.87641983     , 1e+0, "gal_sgp4", "pv[0][2] 0 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -4.209106476      , 1e+0, "gal_sgp4", "pv[1][0] 0 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.159719888       , 1e+0, "gal_sgp4", "pv[1][1] 0 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.744852980       , 1e+0, "gal_sgp4", "pv[1][2] 0 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -938.55923943     , 1e+0, "gal_sgp4", "pv[0][0] 0 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6268.18748831    , 1e+0, "gal_sgp4", "pv[0][1] 0 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4294.02924751    , 1e+0, "gal_sgp4", "pv[0][2] 0 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 7.536105209       , 1e+0, "gal_sgp4", "pv[1][0] 0 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.427127707      , 1e+0, "gal_sgp4", "pv[1][1] 0 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.989878080       , 1e+0, "gal_sgp4", "pv[1][2] 0 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9680.56121728    , 1e+0, "gal_sgp4", "pv[0][0] 0 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2802.47771354     , 1e+0, "gal_sgp4", "pv[0][1] 0 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 124.10688038      , 1e+0, "gal_sgp4", "pv[0][2] 0 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.905874102      , 1e+0, "gal_sgp4", "pv[1][0] 0 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.659467970      , 1e+0, "gal_sgp4", "pv[1][1] 0 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.227347517      , 1e+0, "gal_sgp4", "pv[1][2] 0 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 190.19796988      , 1e+0, "gal_sgp4", "pv[0][0] 0 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 7746.96653614     , 1e+0, "gal_sgp4", "pv[0][1] 0 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5110.00675412     , 1e+0, "gal_sgp4", "pv[0][2] 0 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -6.112325142      , 1e+0, "gal_sgp4", "pv[1][0] 0 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.527008184       , 1e+0, "gal_sgp4", "pv[1][1] 0 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.139152358      , 1e+0, "gal_sgp4", "pv[1][2] 0 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5579.55640116     , 1e+0, "gal_sgp4", "pv[0][0] 0 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3995.61396789    , 1e+0, "gal_sgp4", "pv[0][1] 0 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1518.82108966    , 1e+0, "gal_sgp4", "pv[0][2] 0 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.767927483       , 1e+0, "gal_sgp4", "pv[1][0] 0 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.123185301       , 1e+0, "gal_sgp4", "pv[1][1] 0 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.276837355       , 1e+0, "gal_sgp4", "pv[1][2] 0 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8650.73082219    , 1e+0, "gal_sgp4", "pv[0][0] 0 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1914.93811525    , 1e+0, "gal_sgp4", "pv[0][1] 0 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3007.03603443    , 1e+0, "gal_sgp4", "pv[0][2] 0 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.067165127       , 1e+0, "gal_sgp4", "pv[1][0] 0 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.828384068      , 1e+0, "gal_sgp4", "pv[1][1] 0 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.515322836      , 1e+0, "gal_sgp4", "pv[1][2] 0 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5429.79204164    , 1e+0, "gal_sgp4", "pv[0][0] 0 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 7574.36493792     , 1e+0, "gal_sgp4", "pv[0][1] 0 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3747.39305236     , 1e+0, "gal_sgp4", "pv[0][2] 0 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -4.999442110      , 1e+0, "gal_sgp4", "pv[1][0] 0 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.800561422      , 1e+0, "gal_sgp4", "pv[1][1] 0 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.229392830      , 1e+0, "gal_sgp4", "pv[1][2] 0 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 6759.04583722     , 1e+0, "gal_sgp4", "pv[0][0] 0 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2001.58198220     , 1e+0, "gal_sgp4", "pv[0][1] 0 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2783.55192533     , 1e+0, "gal_sgp4", "pv[0][2] 0 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.180993947      , 1e+0, "gal_sgp4", "pv[1][0] 0 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.402085603       , 1e+0, "gal_sgp4", "pv[1][1] 0 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.644723952       , 1e+0, "gal_sgp4", "pv[1][2] 0 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3791.44531559    , 1e+0, "gal_sgp4", "pv[0][0] 0 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5712.95617894    , 1e+0, "gal_sgp4", "pv[0][1] 0 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4533.48630714    , 1e+0, "gal_sgp4", "pv[0][2] 0 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.668817493       , 1e+0, "gal_sgp4", "pv[1][0] 0 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.516382327      , 1e+0, "gal_sgp4", "pv[1][1] 0 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.082384354      , 1e+0, "gal_sgp4", "pv[1][2] 0 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 4320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9060.47373569    , 1e+0, "gal_sgp4", "pv[0][0] 0 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4658.70952502     , 1e+0, "gal_sgp4", "pv[0][1] 0 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 813.68673153      , 1e+0, "gal_sgp4", "pv[0][2] 0 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.232832783      , 1e+0, "gal_sgp4", "pv[1][0] 0 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.110453490      , 1e+0, "gal_sgp4", "pv[1][1] 0 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.157345433      , 1e+0, "gal_sgp4", "pv[1][2] 0 12" ) ;  

/*
 * fig show lyddane fix error with gsfc ver  
 */  

  strcpy ( card1, "1 04632U 70093B   04031.91070959 -.00000084  00000-0  10000-3 0  9955" ) ;  
  strcpy ( card2, "2 04632  11.4628 273.1101 1450506 207.6000 143.9350  1.20231981 44145" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2334.11450085     , 1e+0, "gal_sgp4", "pv[0][0] 1 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -41920.44035349   , 1e+0, "gal_sgp4", "pv[0][1] 1 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -0.03867437       , 1e+0, "gal_sgp4", "pv[0][2] 1 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.826321032       , 1e+0, "gal_sgp4", "pv[1][0] 1 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.065091664      , 1e+0, "gal_sgp4", "pv[1][1] 1 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.570936053       , 1e+0, "gal_sgp4", "pv[1][2] 1 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -5184.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -29020.02587128   , 1e+0, "gal_sgp4", "pv[0][0] 1 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 13819.84419063    , 1e+0, "gal_sgp4", "pv[0][1] 1 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5713.33679183    , 1e+0, "gal_sgp4", "pv[0][2] 1 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.768068390      , 1e+0, "gal_sgp4", "pv[1][0] 1 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.235371192      , 1e+0, "gal_sgp4", "pv[1][1] 1 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.395206135      , 1e+0, "gal_sgp4", "pv[1][2] 1 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -5064.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -32982.56870101   , 1e+0, "gal_sgp4", "pv[0][0] 1 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -11125.54996609   , 1e+0, "gal_sgp4", "pv[0][1] 1 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6803.28472771    , 1e+0, "gal_sgp4", "pv[0][2] 1 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.617446996       , 1e+0, "gal_sgp4", "pv[1][0] 1 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.379240041      , 1e+0, "gal_sgp4", "pv[1][1] 1 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.085954707       , 1e+0, "gal_sgp4", "pv[1][2] 1 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -4944.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -22097.68730513   , 1e+0, "gal_sgp4", "pv[0][0] 1 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -31583.13829284   , 1e+0, "gal_sgp4", "pv[0][1] 1 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4836.34329328    , 1e+0, "gal_sgp4", "pv[0][2] 1 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.230597499       , 1e+0, "gal_sgp4", "pv[1][0] 1 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.166594667      , 1e+0, "gal_sgp4", "pv[1][1] 1 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.426443070       , 1e+0, "gal_sgp4", "pv[1][2] 1 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -4896.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -15129.94694545   , 1e+0, "gal_sgp4", "pv[0][0] 1 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -36907.74526221   , 1e+0, "gal_sgp4", "pv[0][1] 1 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3487.56256701    , 1e+0, "gal_sgp4", "pv[0][2] 1 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.581167187       , 1e+0, "gal_sgp4", "pv[1][0] 1 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.524204737      , 1e+0, "gal_sgp4", "pv[1][1] 1 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.504805763       , 1e+0, "gal_sgp4", "pv[1][2] 1 4" ) ;  

/*
 * DELTA 1 DEB near earth normal drag equation  
 */  

/*
 * perigee = 377.26km, so moderate drag case  
 */  

  strcpy ( card1, "1 06251U 62025E   06176.82412014  .00008885  00000-0  12808-3 0  3985" ) ;  
  strcpy ( card2, "2 06251  58.0579  54.0425 0030035 139.1568 221.1854 15.56387291  6774" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3988.31022699     , 1e+0, "gal_sgp4", "pv[0][0] 2 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5498.96657235     , 1e+0, "gal_sgp4", "pv[0][1] 2 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 0.90055879        , 1e+0, "gal_sgp4", "pv[0][2] 2 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.290032738      , 1e+0, "gal_sgp4", "pv[1][0] 2 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.357652820       , 1e+0, "gal_sgp4", "pv[1][1] 2 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.496623475       , 1e+0, "gal_sgp4", "pv[1][2] 2 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3935.69800083    , 1e+0, "gal_sgp4", "pv[0][0] 2 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 409.10980837      , 1e+0, "gal_sgp4", "pv[0][1] 2 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5471.33577327     , 1e+0, "gal_sgp4", "pv[0][2] 2 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.374784183      , 1e+0, "gal_sgp4", "pv[1][0] 2 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.635211043      , 1e+0, "gal_sgp4", "pv[1][1] 2 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.942056221      , 1e+0, "gal_sgp4", "pv[1][2] 2 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1675.12766915    , 1e+0, "gal_sgp4", "pv[0][0] 2 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5683.30432352    , 1e+0, "gal_sgp4", "pv[0][1] 2 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3286.21510937    , 1e+0, "gal_sgp4", "pv[0][2] 2 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.282496925       , 1e+0, "gal_sgp4", "pv[1][0] 2 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.508674259       , 1e+0, "gal_sgp4", "pv[1][1] 2 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.354872978      , 1e+0, "gal_sgp4", "pv[1][2] 2 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4993.62642836     , 1e+0, "gal_sgp4", "pv[0][0] 2 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2890.54969900     , 1e+0, "gal_sgp4", "pv[0][1] 2 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3600.40145627    , 1e+0, "gal_sgp4", "pv[0][2] 2 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.347333429       , 1e+0, "gal_sgp4", "pv[1][0] 2 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.707031557       , 1e+0, "gal_sgp4", "pv[1][1] 2 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.070699638       , 1e+0, "gal_sgp4", "pv[1][2] 2 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1115.07959514    , 1e+0, "gal_sgp4", "pv[0][0] 2 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4015.11691491     , 1e+0, "gal_sgp4", "pv[0][1] 2 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5326.99727718     , 1e+0, "gal_sgp4", "pv[0][2] 2 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -5.524279443      , 1e+0, "gal_sgp4", "pv[1][0] 2 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.765738774      , 1e+0, "gal_sgp4", "pv[1][1] 2 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.402255961       , 1e+0, "gal_sgp4", "pv[1][2] 2 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4329.10008198    , 1e+0, "gal_sgp4", "pv[0][0] 2 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5176.70287935    , 1e+0, "gal_sgp4", "pv[0][1] 2 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 409.65313857      , 1e+0, "gal_sgp4", "pv[0][2] 2 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.858408303       , 1e+0, "gal_sgp4", "pv[1][0] 2 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.933091792      , 1e+0, "gal_sgp4", "pv[1][1] 2 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.509690397      , 1e+0, "gal_sgp4", "pv[1][2] 2 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3692.60030028     , 1e+0, "gal_sgp4", "pv[0][0] 2 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -976.24265255     , 1e+0, "gal_sgp4", "pv[0][1] 2 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5623.36447493    , 1e+0, "gal_sgp4", "pv[0][2] 2 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.897257243       , 1e+0, "gal_sgp4", "pv[1][0] 2 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.415554948       , 1e+0, "gal_sgp4", "pv[1][1] 2 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.429112190       , 1e+0, "gal_sgp4", "pv[1][2] 2 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2301.83510037     , 1e+0, "gal_sgp4", "pv[0][0] 2 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5723.92394553     , 1e+0, "gal_sgp4", "pv[0][1] 2 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2814.61514580     , 1e+0, "gal_sgp4", "pv[0][2] 2 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -5.110924966      , 1e+0, "gal_sgp4", "pv[1][0] 2 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.764510559      , 1e+0, "gal_sgp4", "pv[1][1] 2 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.662120145       , 1e+0, "gal_sgp4", "pv[1][2] 2 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4990.91637950    , 1e+0, "gal_sgp4", "pv[0][0] 2 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2303.42547880    , 1e+0, "gal_sgp4", "pv[0][1] 2 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3920.86335598     , 1e+0, "gal_sgp4", "pv[0][2] 2 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.993439372      , 1e+0, "gal_sgp4", "pv[1][0] 2 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.967458360      , 1e+0, "gal_sgp4", "pv[1][1] 2 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.759110856      , 1e+0, "gal_sgp4", "pv[1][2] 2 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 642.27769977      , 1e+0, "gal_sgp4", "pv[0][0] 2 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4332.89821901    , 1e+0, "gal_sgp4", "pv[0][1] 2 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5183.31523910    , 1e+0, "gal_sgp4", "pv[0][2] 2 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.720542579       , 1e+0, "gal_sgp4", "pv[1][0] 2 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.216573838       , 1e+0, "gal_sgp4", "pv[1][1] 2 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.846576139      , 1e+0, "gal_sgp4", "pv[1][2] 2 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4719.78335752     , 1e+0, "gal_sgp4", "pv[0][0] 2 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4798.06938996     , 1e+0, "gal_sgp4", "pv[0][1] 2 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -943.58851062     , 1e+0, "gal_sgp4", "pv[0][2] 2 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.294860662      , 1e+0, "gal_sgp4", "pv[1][0] 2 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.492499389       , 1e+0, "gal_sgp4", "pv[1][1] 2 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.408334723       , 1e+0, "gal_sgp4", "pv[1][2] 2 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3299.16993602    , 1e+0, "gal_sgp4", "pv[0][0] 2 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1576.83168320     , 1e+0, "gal_sgp4", "pv[0][1] 2 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5678.67840638     , 1e+0, "gal_sgp4", "pv[0][2] 2 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -4.460347074      , 1e+0, "gal_sgp4", "pv[1][0] 2 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.202025196      , 1e+0, "gal_sgp4", "pv[1][1] 2 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.885874586      , 1e+0, "gal_sgp4", "pv[1][2] 2 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2777.14682335    , 1e+0, "gal_sgp4", "pv[0][0] 2 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5663.16031708    , 1e+0, "gal_sgp4", "pv[0][1] 2 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2462.54889123    , 1e+0, "gal_sgp4", "pv[0][2] 2 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.915493146       , 1e+0, "gal_sgp4", "pv[1][0] 2 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.123328992       , 1e+0, "gal_sgp4", "pv[1][1] 2 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.896495091      , 1e+0, "gal_sgp4", "pv[1][2] 2 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4992.31573893     , 1e+0, "gal_sgp4", "pv[0][0] 2 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1716.62356770     , 1e+0, "gal_sgp4", "pv[0][1] 2 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4287.86065581    , 1e+0, "gal_sgp4", "pv[0][2] 2 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.640717189       , 1e+0, "gal_sgp4", "pv[1][0] 2 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.071570434       , 1e+0, "gal_sgp4", "pv[1][1] 2 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.338797931       , 1e+0, "gal_sgp4", "pv[1][2] 2 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8.22384755       , 1e+0, "gal_sgp4", "pv[0][0] 2 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4662.21521668     , 1e+0, "gal_sgp4", "pv[0][1] 2 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4905.66411857     , 1e+0, "gal_sgp4", "pv[0][2] 2 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -5.891011274      , 1e+0, "gal_sgp4", "pv[1][0] 2 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.593173872      , 1e+0, "gal_sgp4", "pv[1][1] 2 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.365100460       , 1e+0, "gal_sgp4", "pv[1][2] 2 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4966.20137963    , 1e+0, "gal_sgp4", "pv[0][0] 2 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4379.59155037    , 1e+0, "gal_sgp4", "pv[0][1] 2 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1349.33347502     , 1e+0, "gal_sgp4", "pv[0][2] 2 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.763172581       , 1e+0, "gal_sgp4", "pv[1][0] 2 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.981456387      , 1e+0, "gal_sgp4", "pv[1][1] 2 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.343279443      , 1e+0, "gal_sgp4", "pv[1][2] 2 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2954.49390331     , 1e+0, "gal_sgp4", "pv[0][0] 2 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2080.65984650    , 1e+0, "gal_sgp4", "pv[0][1] 2 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5754.75038057    , 1e+0, "gal_sgp4", "pv[0][2] 2 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.895893306       , 1e+0, "gal_sgp4", "pv[1][0] 2 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.858184322       , 1e+0, "gal_sgp4", "pv[1][1] 2 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.375474825       , 1e+0, "gal_sgp4", "pv[1][2] 2 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3363.28794321     , 1e+0, "gal_sgp4", "pv[0][0] 2 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5559.55841180     , 1e+0, "gal_sgp4", "pv[0][1] 2 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1956.05542266     , 1e+0, "gal_sgp4", "pv[0][2] 2 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -4.587378863      , 1e+0, "gal_sgp4", "pv[1][0] 2 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.591943403       , 1e+0, "gal_sgp4", "pv[1][1] 2 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.107838605       , 1e+0, "gal_sgp4", "pv[1][2] 2 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4856.66780070    , 1e+0, "gal_sgp4", "pv[0][0] 2 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1107.03450192    , 1e+0, "gal_sgp4", "pv[0][1] 2 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4557.21258241     , 1e+0, "gal_sgp4", "pv[0][2] 2 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.304158557      , 1e+0, "gal_sgp4", "pv[1][0] 2 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.186437070      , 1e+0, "gal_sgp4", "pv[1][1] 2 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.956549542      , 1e+0, "gal_sgp4", "pv[1][2] 2 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -497.84480071     , 1e+0, "gal_sgp4", "pv[0][0] 2 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4863.46005312    , 1e+0, "gal_sgp4", "pv[0][1] 2 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4700.81211217    , 1e+0, "gal_sgp4", "pv[0][2] 2 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.960065407       , 1e+0, "gal_sgp4", "pv[1][0] 2 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.996683369       , 1e+0, "gal_sgp4", "pv[1][1] 2 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.767123329      , 1e+0, "gal_sgp4", "pv[1][2] 2 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5241.61936096     , 1e+0, "gal_sgp4", "pv[0][0] 2 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3910.75960683     , 1e+0, "gal_sgp4", "pv[0][1] 2 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1857.93473952    , 1e+0, "gal_sgp4", "pv[0][2] 2 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.124834806      , 1e+0, "gal_sgp4", "pv[1][0] 2 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.406213160       , 1e+0, "gal_sgp4", "pv[1][1] 2 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.148161299       , 1e+0, "gal_sgp4", "pv[1][2] 2 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2451.38045953    , 1e+0, "gal_sgp4", "pv[0][0] 2 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2610.60463261     , 1e+0, "gal_sgp4", "pv[0][1] 2 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5729.79022069     , 1e+0, "gal_sgp4", "pv[0][2] 2 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -5.366560525      , 1e+0, "gal_sgp4", "pv[1][0] 2 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.500855666      , 1e+0, "gal_sgp4", "pv[1][1] 2 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.187958716       , 1e+0, "gal_sgp4", "pv[1][2] 2 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3791.87520638    , 1e+0, "gal_sgp4", "pv[0][0] 2 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5378.82851382    , 1e+0, "gal_sgp4", "pv[0][1] 2 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1575.82737930    , 1e+0, "gal_sgp4", "pv[0][2] 2 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.266273592       , 1e+0, "gal_sgp4", "pv[1][0] 2 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.199162551      , 1e+0, "gal_sgp4", "pv[1][1] 2 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.276154080      , 1e+0, "gal_sgp4", "pv[1][2] 2 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4730.53958356     , 1e+0, "gal_sgp4", "pv[0][0] 2 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 524.05006433      , 1e+0, "gal_sgp4", "pv[0][1] 2 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4857.29369725    , 1e+0, "gal_sgp4", "pv[0][2] 2 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.918056288       , 1e+0, "gal_sgp4", "pv[1][0] 2 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.135412849       , 1e+0, "gal_sgp4", "pv[1][1] 2 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.495115636       , 1e+0, "gal_sgp4", "pv[1][2] 2 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1159.27802897     , 1e+0, "gal_sgp4", "pv[0][0] 2 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5056.60175495     , 1e+0, "gal_sgp4", "pv[0][1] 2 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4353.49418579     , 1e+0, "gal_sgp4", "pv[0][2] 2 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -5.968060341      , 1e+0, "gal_sgp4", "pv[1][0] 2 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.314790406      , 1e+0, "gal_sgp4", "pv[1][1] 2 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.230722669       , 1e+0, "gal_sgp4", "pv[1][2] 2 24" ) ;  

/*
 * MOLNIYA 2-14 12h resonant ecc in 0.65 to 0.7 range  
 */  

  strcpy ( card1, "1 08195U 75081A   06176.33215444  .00000099  00000-0  11873-3 0   813" ) ;  
  strcpy ( card2, "2 08195  64.1586 279.0717 6877146 264.7651  20.2257  2.00491383225656" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2349.89483350     , 1e+0, "gal_sgp4", "pv[0][0] 3 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -14785.93811562   , 1e+0, "gal_sgp4", "pv[0][1] 3 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 0.02119378        , 1e+0, "gal_sgp4", "pv[0][2] 3 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.721488096       , 1e+0, "gal_sgp4", "pv[1][0] 3 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.256811655      , 1e+0, "gal_sgp4", "pv[1][1] 3 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.498416672       , 1e+0, "gal_sgp4", "pv[1][2] 3 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 15223.91713658    , 1e+0, "gal_sgp4", "pv[0][0] 3 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -17852.95881713   , 1e+0, "gal_sgp4", "pv[0][1] 3 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 25280.39558224    , 1e+0, "gal_sgp4", "pv[0][2] 3 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.079041732       , 1e+0, "gal_sgp4", "pv[1][0] 3 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.875187372       , 1e+0, "gal_sgp4", "pv[1][1] 3 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.485682813       , 1e+0, "gal_sgp4", "pv[1][2] 3 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19752.78050009    , 1e+0, "gal_sgp4", "pv[0][0] 3 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -8600.07130962    , 1e+0, "gal_sgp4", "pv[0][1] 3 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 37522.72921090    , 1e+0, "gal_sgp4", "pv[0][2] 3 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.238105279       , 1e+0, "gal_sgp4", "pv[1][0] 3 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.546110924       , 1e+0, "gal_sgp4", "pv[1][1] 3 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.986410447       , 1e+0, "gal_sgp4", "pv[1][2] 3 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19089.29762968    , 1e+0, "gal_sgp4", "pv[0][0] 3 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3107.89495018     , 1e+0, "gal_sgp4", "pv[0][1] 3 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39958.14661370    , 1e+0, "gal_sgp4", "pv[0][2] 3 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.410308034      , 1e+0, "gal_sgp4", "pv[1][0] 3 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.640332277       , 1e+0, "gal_sgp4", "pv[1][1] 3 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.306873818      , 1e+0, "gal_sgp4", "pv[1][2] 3 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13829.66070574    , 1e+0, "gal_sgp4", "pv[0][0] 3 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 13977.39999817    , 1e+0, "gal_sgp4", "pv[0][1] 3 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 32736.32082508    , 1e+0, "gal_sgp4", "pv[0][2] 3 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.065096849      , 1e+0, "gal_sgp4", "pv[1][0] 3 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.279983299       , 1e+0, "gal_sgp4", "pv[1][1] 3 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.760166075      , 1e+0, "gal_sgp4", "pv[1][2] 3 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3333.05838525     , 1e+0, "gal_sgp4", "pv[0][0] 3 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18395.31728674    , 1e+0, "gal_sgp4", "pv[0][1] 3 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12738.25031238    , 1e+0, "gal_sgp4", "pv[0][2] 3 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.882432221      , 1e+0, "gal_sgp4", "pv[1][0] 3 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.611623333      , 1e+0, "gal_sgp4", "pv[1][1] 3 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.039586549      , 1e+0, "gal_sgp4", "pv[1][2] 3 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2622.13222207     , 1e+0, "gal_sgp4", "pv[0][0] 3 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -15125.15464924   , 1e+0, "gal_sgp4", "pv[0][1] 3 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 474.51048398      , 1e+0, "gal_sgp4", "pv[0][2] 3 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.688287199       , 1e+0, "gal_sgp4", "pv[1][0] 3 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.078426664      , 1e+0, "gal_sgp4", "pv[1][1] 3 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.494979530       , 1e+0, "gal_sgp4", "pv[1][2] 3 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 15320.56770017    , 1e+0, "gal_sgp4", "pv[0][0] 3 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -17777.32564586   , 1e+0, "gal_sgp4", "pv[0][1] 3 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 25539.53198382    , 1e+0, "gal_sgp4", "pv[0][2] 3 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.064346229       , 1e+0, "gal_sgp4", "pv[1][0] 3 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.892184771       , 1e+0, "gal_sgp4", "pv[1][1] 3 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.459822414       , 1e+0, "gal_sgp4", "pv[1][2] 3 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19769.70267785    , 1e+0, "gal_sgp4", "pv[0][0] 3 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -8458.65104454    , 1e+0, "gal_sgp4", "pv[0][1] 3 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 37624.20130236    , 1e+0, "gal_sgp4", "pv[0][2] 3 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.229304396       , 1e+0, "gal_sgp4", "pv[1][0] 3 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.550363884       , 1e+0, "gal_sgp4", "pv[1][1] 3 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.966993056       , 1e+0, "gal_sgp4", "pv[1][2] 3 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19048.56201523    , 1e+0, "gal_sgp4", "pv[0][0] 3 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3260.43223119     , 1e+0, "gal_sgp4", "pv[0][1] 3 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39923.39143967    , 1e+0, "gal_sgp4", "pv[0][2] 3 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.418015536      , 1e+0, "gal_sgp4", "pv[1][0] 3 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.639346953       , 1e+0, "gal_sgp4", "pv[1][1] 3 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.326094840      , 1e+0, "gal_sgp4", "pv[1][2] 3 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13729.19205837    , 1e+0, "gal_sgp4", "pv[0][0] 3 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 14097.70014810    , 1e+0, "gal_sgp4", "pv[0][1] 3 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 32547.52799890    , 1e+0, "gal_sgp4", "pv[0][2] 3 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.074511043      , 1e+0, "gal_sgp4", "pv[1][0] 3 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.270505211       , 1e+0, "gal_sgp4", "pv[1][1] 3 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.785099927      , 1e+0, "gal_sgp4", "pv[1][2] 3 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3148.86165643     , 1e+0, "gal_sgp4", "pv[0][0] 3 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18323.19841703    , 1e+0, "gal_sgp4", "pv[0][1] 3 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12305.75195578    , 1e+0, "gal_sgp4", "pv[0][2] 3 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.895271701      , 1e+0, "gal_sgp4", "pv[1][0] 3 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.678343847      , 1e+0, "gal_sgp4", "pv[1][1] 3 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.086577951      , 1e+0, "gal_sgp4", "pv[1][2] 3 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2890.80638268     , 1e+0, "gal_sgp4", "pv[0][0] 3 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -15446.43952300   , 1e+0, "gal_sgp4", "pv[0][1] 3 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 948.77010176      , 1e+0, "gal_sgp4", "pv[0][2] 3 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.654407490       , 1e+0, "gal_sgp4", "pv[1][0] 3 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.909344895      , 1e+0, "gal_sgp4", "pv[1][1] 3 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.486437362       , 1e+0, "gal_sgp4", "pv[1][2] 3 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 15415.98410712    , 1e+0, "gal_sgp4", "pv[0][0] 3 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -17699.90714437   , 1e+0, "gal_sgp4", "pv[0][1] 3 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 25796.19644689    , 1e+0, "gal_sgp4", "pv[0][2] 3 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.049818334       , 1e+0, "gal_sgp4", "pv[1][0] 3 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.908822332       , 1e+0, "gal_sgp4", "pv[1][1] 3 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.434107329       , 1e+0, "gal_sgp4", "pv[1][2] 3 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19786.00618538    , 1e+0, "gal_sgp4", "pv[0][0] 3 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -8316.74570581    , 1e+0, "gal_sgp4", "pv[0][1] 3 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 37723.74539119    , 1e+0, "gal_sgp4", "pv[0][2] 3 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.220539813       , 1e+0, "gal_sgp4", "pv[1][0] 3 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.554518900       , 1e+0, "gal_sgp4", "pv[1][1] 3 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.947601047       , 1e+0, "gal_sgp4", "pv[1][2] 3 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19007.28688729    , 1e+0, "gal_sgp4", "pv[0][0] 3 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3412.85948715     , 1e+0, "gal_sgp4", "pv[0][1] 3 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39886.66579255    , 1e+0, "gal_sgp4", "pv[0][2] 3 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.425733568      , 1e+0, "gal_sgp4", "pv[1][0] 3 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.638276809       , 1e+0, "gal_sgp4", "pv[1][1] 3 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.345353807      , 1e+0, "gal_sgp4", "pv[1][2] 3 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13627.93015254    , 1e+0, "gal_sgp4", "pv[0][0] 3 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 14216.95401307    , 1e+0, "gal_sgp4", "pv[0][1] 3 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 32356.13706868    , 1e+0, "gal_sgp4", "pv[0][2] 3 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.083991976      , 1e+0, "gal_sgp4", "pv[1][0] 3 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.260802347       , 1e+0, "gal_sgp4", "pv[1][1] 3 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.810193903      , 1e+0, "gal_sgp4", "pv[1][2] 3 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2963.26486560     , 1e+0, "gal_sgp4", "pv[0][0] 3 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18243.85063641    , 1e+0, "gal_sgp4", "pv[0][1] 3 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 11868.25797486    , 1e+0, "gal_sgp4", "pv[0][2] 3 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.908015447      , 1e+0, "gal_sgp4", "pv[1][0] 3 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.747870342      , 1e+0, "gal_sgp4", "pv[1][1] 3 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.134004492      , 1e+0, "gal_sgp4", "pv[1][2] 3 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3155.85126036     , 1e+0, "gal_sgp4", "pv[0][0] 3 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -15750.70393364   , 1e+0, "gal_sgp4", "pv[0][1] 3 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1422.32496953     , 1e+0, "gal_sgp4", "pv[0][2] 3 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.620085624       , 1e+0, "gal_sgp4", "pv[1][0] 3 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.748990396      , 1e+0, "gal_sgp4", "pv[1][1] 3 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.473527039       , 1e+0, "gal_sgp4", "pv[1][2] 3 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 15510.15191770    , 1e+0, "gal_sgp4", "pv[0][0] 3 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -17620.71002219   , 1e+0, "gal_sgp4", "pv[0][1] 3 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 26050.43525345    , 1e+0, "gal_sgp4", "pv[0][2] 3 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.035454678       , 1e+0, "gal_sgp4", "pv[1][0] 3 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.925111006       , 1e+0, "gal_sgp4", "pv[1][1] 3 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.408534465       , 1e+0, "gal_sgp4", "pv[1][2] 3 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19801.67198812    , 1e+0, "gal_sgp4", "pv[0][0] 3 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -8174.33337167    , 1e+0, "gal_sgp4", "pv[0][1] 3 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 37821.38577439    , 1e+0, "gal_sgp4", "pv[0][2] 3 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.211812700       , 1e+0, "gal_sgp4", "pv[1][0] 3 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.558576937       , 1e+0, "gal_sgp4", "pv[1][1] 3 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.928231880       , 1e+0, "gal_sgp4", "pv[1][2] 3 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 18965.46529379    , 1e+0, "gal_sgp4", "pv[0][0] 3 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3565.19666242     , 1e+0, "gal_sgp4", "pv[0][1] 3 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39847.97510998    , 1e+0, "gal_sgp4", "pv[0][2] 3 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.433459945      , 1e+0, "gal_sgp4", "pv[1][0] 3 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.637120585       , 1e+0, "gal_sgp4", "pv[1][1] 3 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.364653213      , 1e+0, "gal_sgp4", "pv[1][2] 3 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13525.88227400    , 1e+0, "gal_sgp4", "pv[0][0] 3 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 14335.15978787    , 1e+0, "gal_sgp4", "pv[0][1] 3 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 32162.13236536    , 1e+0, "gal_sgp4", "pv[0][2] 3 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.093537945      , 1e+0, "gal_sgp4", "pv[1][0] 3 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.250868256       , 1e+0, "gal_sgp4", "pv[1][1] 3 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.835451681      , 1e+0, "gal_sgp4", "pv[1][2] 3 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2776.30574260     , 1e+0, "gal_sgp4", "pv[0][0] 3 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18156.98538451    , 1e+0, "gal_sgp4", "pv[0][1] 3 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 11425.73046481    , 1e+0, "gal_sgp4", "pv[0][2] 3 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.920632199      , 1e+0, "gal_sgp4", "pv[1][0] 3 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.820370733      , 1e+0, "gal_sgp4", "pv[1][1] 3 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.181839232      , 1e+0, "gal_sgp4", "pv[1][2] 3 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3417.20931587     , 1e+0, "gal_sgp4", "pv[0][0] 3 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -16038.79510665   , 1e+0, "gal_sgp4", "pv[0][1] 3 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1894.74934058     , 1e+0, "gal_sgp4", "pv[0][2] 3 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.585515864       , 1e+0, "gal_sgp4", "pv[1][0] 3 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.596818146      , 1e+0, "gal_sgp4", "pv[1][1] 3 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.456882556       , 1e+0, "gal_sgp4", "pv[1][2] 3 24" ) ;  

/*
 * MOLNIYA 1-36 fig 12h resonant ecc in 0.7 to 0.715 range  
 */  

  strcpy ( card1, "1 09880U 77021A   06176.56157475  .00000421  00000-0  10000-3 0  9814" ) ;  
  strcpy ( card2, "2 09880  64.5968 349.3786 7069051 270.0229  16.3320  2.00813614112380" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13020.06750784    , 1e+0, "gal_sgp4", "pv[0][0] 4 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2449.07193500    , 1e+0, "gal_sgp4", "pv[0][1] 4 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1.15896030        , 1e+0, "gal_sgp4", "pv[0][2] 4 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.247363935       , 1e+0, "gal_sgp4", "pv[1][0] 4 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.597178501       , 1e+0, "gal_sgp4", "pv[1][1] 4 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.956708611       , 1e+0, "gal_sgp4", "pv[1][2] 4 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19190.32482476    , 1e+0, "gal_sgp4", "pv[0][0] 4 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9249.01266902     , 1e+0, "gal_sgp4", "pv[0][1] 4 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 26596.71345328    , 1e+0, "gal_sgp4", "pv[0][2] 4 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.624960193      , 1e+0, "gal_sgp4", "pv[1][0] 4 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.324550562       , 1e+0, "gal_sgp4", "pv[1][1] 4 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.495697637       , 1e+0, "gal_sgp4", "pv[1][2] 4 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11332.67806218    , 1e+0, "gal_sgp4", "pv[0][0] 4 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 16517.99124008    , 1e+0, "gal_sgp4", "pv[0][1] 4 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 38569.78482991    , 1e+0, "gal_sgp4", "pv[0][2] 4 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.400974747      , 1e+0, "gal_sgp4", "pv[1][0] 4 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.710947006       , 1e+0, "gal_sgp4", "pv[1][1] 4 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.923935636       , 1e+0, "gal_sgp4", "pv[1][2] 4 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 328.74217398      , 1e+0, "gal_sgp4", "pv[0][0] 4 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19554.92047380    , 1e+0, "gal_sgp4", "pv[0][1] 4 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40558.26246145    , 1e+0, "gal_sgp4", "pv[0][2] 4 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.593281066      , 1e+0, "gal_sgp4", "pv[1][0] 4 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.126772913       , 1e+0, "gal_sgp4", "pv[1][1] 4 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.359627307      , 1e+0, "gal_sgp4", "pv[1][2] 4 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -10684.90590680   , 1e+0, "gal_sgp4", "pv[0][0] 4 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18057.15728839    , 1e+0, "gal_sgp4", "pv[0][1] 4 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 33158.75253886    , 1e+0, "gal_sgp4", "pv[0][2] 4 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.383205997      , 1e+0, "gal_sgp4", "pv[1][0] 4 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.582328999      , 1e+0, "gal_sgp4", "pv[1][1] 4 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.744412556      , 1e+0, "gal_sgp4", "pv[1][2] 4 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -17069.78000550   , 1e+0, "gal_sgp4", "pv[0][0] 4 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9944.86797897     , 1e+0, "gal_sgp4", "pv[0][1] 4 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 13885.91649059    , 1e+0, "gal_sgp4", "pv[0][2] 4 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.044133354       , 1e+0, "gal_sgp4", "pv[1][0] 4 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.853448464      , 1e+0, "gal_sgp4", "pv[1][1] 4 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.815303117      , 1e+0, "gal_sgp4", "pv[1][2] 4 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13725.09398980    , 1e+0, "gal_sgp4", "pv[0][0] 4 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2180.70877090    , 1e+0, "gal_sgp4", "pv[0][1] 4 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 863.29684523      , 1e+0, "gal_sgp4", "pv[0][2] 4 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.878478111       , 1e+0, "gal_sgp4", "pv[1][0] 4 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.656846496       , 1e+0, "gal_sgp4", "pv[1][1] 4 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.944867241       , 1e+0, "gal_sgp4", "pv[1][2] 4 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19089.63879226    , 1e+0, "gal_sgp4", "pv[0][0] 4 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9456.29670247     , 1e+0, "gal_sgp4", "pv[0][1] 4 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 27026.79562883    , 1e+0, "gal_sgp4", "pv[0][2] 4 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.656614299      , 1e+0, "gal_sgp4", "pv[1][0] 4 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.309112636       , 1e+0, "gal_sgp4", "pv[1][1] 4 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.449371941       , 1e+0, "gal_sgp4", "pv[1][2] 4 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11106.41248373    , 1e+0, "gal_sgp4", "pv[0][0] 4 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 16627.60874079    , 1e+0, "gal_sgp4", "pv[0][1] 4 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 38727.35140296    , 1e+0, "gal_sgp4", "pv[0][2] 4 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.409722680      , 1e+0, "gal_sgp4", "pv[1][0] 4 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.698582526       , 1e+0, "gal_sgp4", "pv[1][1] 4 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.891383535       , 1e+0, "gal_sgp4", "pv[1][2] 4 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 72.40958621       , 1e+0, "gal_sgp4", "pv[0][0] 4 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19575.08054144    , 1e+0, "gal_sgp4", "pv[0][1] 4 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40492.12544001    , 1e+0, "gal_sgp4", "pv[0][2] 4 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.593394604      , 1e+0, "gal_sgp4", "pv[1][0] 4 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.113655142       , 1e+0, "gal_sgp4", "pv[1][1] 4 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.390556063      , 1e+0, "gal_sgp4", "pv[1][2] 4 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -10905.89252576   , 1e+0, "gal_sgp4", "pv[0][0] 4 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 17965.41205111    , 1e+0, "gal_sgp4", "pv[0][1] 4 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 32850.07298244    , 1e+0, "gal_sgp4", "pv[0][2] 4 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.371396120      , 1e+0, "gal_sgp4", "pv[1][0] 4 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.601706604      , 1e+0, "gal_sgp4", "pv[1][1] 4 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.782817058      , 1e+0, "gal_sgp4", "pv[1][2] 4 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -17044.61207568   , 1e+0, "gal_sgp4", "pv[0][0] 4 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9635.48491849     , 1e+0, "gal_sgp4", "pv[0][1] 4 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 13212.59462953    , 1e+0, "gal_sgp4", "pv[0][2] 4 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.129244030       , 1e+0, "gal_sgp4", "pv[1][0] 4 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.903551430      , 1e+0, "gal_sgp4", "pv[1][1] 4 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.884569098      , 1e+0, "gal_sgp4", "pv[1][2] 4 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14369.90303735    , 1e+0, "gal_sgp4", "pv[0][0] 4 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1903.85601062    , 1e+0, "gal_sgp4", "pv[0][1] 4 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1722.15319853     , 1e+0, "gal_sgp4", "pv[0][2] 4 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.543393116       , 1e+0, "gal_sgp4", "pv[1][0] 4 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.701687176       , 1e+0, "gal_sgp4", "pv[1][1] 4 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.913881358       , 1e+0, "gal_sgp4", "pv[1][2] 4 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 18983.96210441    , 1e+0, "gal_sgp4", "pv[0][0] 4 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9661.12233804     , 1e+0, "gal_sgp4", "pv[0][1] 4 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 27448.99557732    , 1e+0, "gal_sgp4", "pv[0][2] 4 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.687189304      , 1e+0, "gal_sgp4", "pv[1][0] 4 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.293808870       , 1e+0, "gal_sgp4", "pv[1][1] 4 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.403630759       , 1e+0, "gal_sgp4", "pv[1][2] 4 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 10878.79336704    , 1e+0, "gal_sgp4", "pv[0][0] 4 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 16735.31433954    , 1e+0, "gal_sgp4", "pv[0][1] 4 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 38879.23434264    , 1e+0, "gal_sgp4", "pv[0][2] 4 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.418239666      , 1e+0, "gal_sgp4", "pv[1][0] 4 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.686235750       , 1e+0, "gal_sgp4", "pv[1][1] 4 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.858951848       , 1e+0, "gal_sgp4", "pv[1][2] 4 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -184.03743100     , 1e+0, "gal_sgp4", "pv[0][0] 4 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19593.09371709    , 1e+0, "gal_sgp4", "pv[0][1] 4 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40420.40606889    , 1e+0, "gal_sgp4", "pv[0][2] 4 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.593348925      , 1e+0, "gal_sgp4", "pv[1][0] 4 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.100448697       , 1e+0, "gal_sgp4", "pv[1][1] 4 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.421571993      , 1e+0, "gal_sgp4", "pv[1][2] 4 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -11125.12138631   , 1e+0, "gal_sgp4", "pv[0][0] 4 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 17870.19488928    , 1e+0, "gal_sgp4", "pv[0][1] 4 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 32534.21521208    , 1e+0, "gal_sgp4", "pv[0][2] 4 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.359116236      , 1e+0, "gal_sgp4", "pv[1][0] 4 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.621413776      , 1e+0, "gal_sgp4", "pv[1][1] 4 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.821629856      , 1e+0, "gal_sgp4", "pv[1][2] 4 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -17004.43272827   , 1e+0, "gal_sgp4", "pv[0][0] 4 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9316.53926351     , 1e+0, "gal_sgp4", "pv[0][1] 4 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12526.11883812    , 1e+0, "gal_sgp4", "pv[0][2] 4 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.220330736       , 1e+0, "gal_sgp4", "pv[1][0] 4 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.955594322      , 1e+0, "gal_sgp4", "pv[1][1] 4 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.955058575      , 1e+0, "gal_sgp4", "pv[1][2] 4 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14960.06492693    , 1e+0, "gal_sgp4", "pv[0][0] 4 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1620.68430805    , 1e+0, "gal_sgp4", "pv[0][1] 4 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2574.96359381     , 1e+0, "gal_sgp4", "pv[0][2] 4 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.238634028       , 1e+0, "gal_sgp4", "pv[1][0] 4 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.734723385       , 1e+0, "gal_sgp4", "pv[1][1] 4 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.868880331       , 1e+0, "gal_sgp4", "pv[1][2] 4 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 18873.46347257    , 1e+0, "gal_sgp4", "pv[0][0] 4 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9863.57004586     , 1e+0, "gal_sgp4", "pv[0][1] 4 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 27863.46574735    , 1e+0, "gal_sgp4", "pv[0][2] 4 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.716736981      , 1e+0, "gal_sgp4", "pv[1][0] 4 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.278632817       , 1e+0, "gal_sgp4", "pv[1][1] 4 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.358448535       , 1e+0, "gal_sgp4", "pv[1][2] 4 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 10649.86857581    , 1e+0, "gal_sgp4", "pv[0][0] 4 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 16841.14172669    , 1e+0, "gal_sgp4", "pv[0][1] 4 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39025.48035006    , 1e+0, "gal_sgp4", "pv[0][2] 4 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.426527152      , 1e+0, "gal_sgp4", "pv[1][0] 4 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.673901057       , 1e+0, "gal_sgp4", "pv[1][1] 4 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.826632332       , 1e+0, "gal_sgp4", "pv[1][2] 4 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -440.53459323     , 1e+0, "gal_sgp4", "pv[0][0] 4 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19608.95524423    , 1e+0, "gal_sgp4", "pv[0][1] 4 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40343.10675451    , 1e+0, "gal_sgp4", "pv[0][2] 4 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.593138597      , 1e+0, "gal_sgp4", "pv[1][0] 4 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.087147884       , 1e+0, "gal_sgp4", "pv[1][1] 4 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.452680559      , 1e+0, "gal_sgp4", "pv[1][2] 4 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -11342.45028909   , 1e+0, "gal_sgp4", "pv[0][0] 4 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 17771.44223942    , 1e+0, "gal_sgp4", "pv[0][1] 4 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 32211.12535721    , 1e+0, "gal_sgp4", "pv[0][2] 4 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.346344015      , 1e+0, "gal_sgp4", "pv[1][0] 4 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.641464291      , 1e+0, "gal_sgp4", "pv[1][1] 4 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.860864234      , 1e+0, "gal_sgp4", "pv[1][2] 4 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -16948.06005711   , 1e+0, "gal_sgp4", "pv[0][0] 4 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 8987.64254880     , 1e+0, "gal_sgp4", "pv[0][1] 4 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 11826.28284367    , 1e+0, "gal_sgp4", "pv[0][2] 4 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.318007297       , 1e+0, "gal_sgp4", "pv[1][0] 4 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.009693492      , 1e+0, "gal_sgp4", "pv[1][1] 4 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.026726648      , 1e+0, "gal_sgp4", "pv[1][2] 4 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 15500.53445068    , 1e+0, "gal_sgp4", "pv[0][0] 4 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1332.90981042    , 1e+0, "gal_sgp4", "pv[0][1] 4 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3419.72315308     , 1e+0, "gal_sgp4", "pv[0][2] 4 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.960917974       , 1e+0, "gal_sgp4", "pv[1][0] 4 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.758331634       , 1e+0, "gal_sgp4", "pv[1][1] 4 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.813698638       , 1e+0, "gal_sgp4", "pv[1][2] 4 24" ) ;  

/*
 * SMS 1 AKM show the integrator problem with gsfc ver  
 */  

  strcpy ( card1, "1 09998U 74033F   05148.79417928 -.00000112  00000-0  00000+0 0  4480" ) ;  
  strcpy ( card2, "2 09998   9.4958 313.1750 0270971 327.5225  30.8097  1.16186785 45878" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 25532.98947267    , 1e+0, "gal_sgp4", "pv[0][0] 5 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -27244.26327953   , 1e+0, "gal_sgp4", "pv[0][1] 5 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1.11572421       , 1e+0, "gal_sgp4", "pv[0][2] 5 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.410283885       , 1e+0, "gal_sgp4", "pv[1][0] 5 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.194175683       , 1e+0, "gal_sgp4", "pv[1][1] 5 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.545888526       , 1e+0, "gal_sgp4", "pv[1][2] 5 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -11362.18265118   , 1e+0, "gal_sgp4", "pv[0][0] 5 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -35117.55867813   , 1e+0, "gal_sgp4", "pv[0][1] 5 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5413.62537994    , 1e+0, "gal_sgp4", "pv[0][2] 5 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.137861261       , 1e+0, "gal_sgp4", "pv[1][0] 5 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.011678260      , 1e+0, "gal_sgp4", "pv[1][1] 5 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.267510059       , 1e+0, "gal_sgp4", "pv[1][2] 5 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1380.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 309.25349929      , 1e+0, "gal_sgp4", "pv[0][0] 5 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -36960.43090143   , 1e+0, "gal_sgp4", "pv[0][1] 5 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4198.48007670    , 1e+0, "gal_sgp4", "pv[0][2] 5 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.292429375       , 1e+0, "gal_sgp4", "pv[1][0] 5 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.002166046      , 1e+0, "gal_sgp4", "pv[1][1] 5 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.402111628       , 1e+0, "gal_sgp4", "pv[1][2] 5 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11949.04009077    , 1e+0, "gal_sgp4", "pv[0][0] 5 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -35127.37816804   , 1e+0, "gal_sgp4", "pv[0][1] 5 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2565.89806468    , 1e+0, "gal_sgp4", "pv[0][2] 5 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.119942784       , 1e+0, "gal_sgp4", "pv[1][0] 5 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.012096444       , 1e+0, "gal_sgp4", "pv[1][1] 5 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.497284100       , 1e+0, "gal_sgp4", "pv[1][2] 5 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1260.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 22400.45329336    , 1e+0, "gal_sgp4", "pv[0][0] 5 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -29798.63236321   , 1e+0, "gal_sgp4", "pv[0][1] 5 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -677.91515122     , 1e+0, "gal_sgp4", "pv[0][2] 5 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.638533344       , 1e+0, "gal_sgp4", "pv[1][0] 5 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.922477736       , 1e+0, "gal_sgp4", "pv[1][1] 5 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.542792913       , 1e+0, "gal_sgp4", "pv[1][2] 5 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 30640.84752458    , 1e+0, "gal_sgp4", "pv[0][0] 5 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -21525.02340201   , 1e+0, "gal_sgp4", "pv[0][1] 5 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1277.34808722     , 1e+0, "gal_sgp4", "pv[0][2] 5 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.903464941       , 1e+0, "gal_sgp4", "pv[1][0] 5 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.634294312       , 1e+0, "gal_sgp4", "pv[1][1] 5 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.534540934       , 1e+0, "gal_sgp4", "pv[1][2] 5 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1140.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 35899.56788035    , 1e+0, "gal_sgp4", "pv[0][0] 5 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -11152.71158138   , 1e+0, "gal_sgp4", "pv[0][1] 5 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3108.72535238     , 1e+0, "gal_sgp4", "pv[0][2] 5 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.997393045       , 1e+0, "gal_sgp4", "pv[1][0] 5 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.079858548       , 1e+0, "gal_sgp4", "pv[1][1] 5 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.474873291       , 1e+0, "gal_sgp4", "pv[1][2] 5 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 37732.45438600    , 1e+0, "gal_sgp4", "pv[0][0] 5 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 288.18821054      , 1e+0, "gal_sgp4", "pv[0][1] 5 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4643.87587495     , 1e+0, "gal_sgp4", "pv[0][2] 5 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.016652226       , 1e+0, "gal_sgp4", "pv[1][0] 5 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.225184410       , 1e+0, "gal_sgp4", "pv[1][1] 5 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.371669746       , 1e+0, "gal_sgp4", "pv[1][2] 5 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1020.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 36045.92961699    , 1e+0, "gal_sgp4", "pv[0][0] 5 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 11706.61816230    , 1e+0, "gal_sgp4", "pv[0][1] 5 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5746.32646574     , 1e+0, "gal_sgp4", "pv[0][2] 5 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.942409065      , 1e+0, "gal_sgp4", "pv[1][0] 5 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.069888941       , 1e+0, "gal_sgp4", "pv[1][1] 5 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.236662980       , 1e+0, "gal_sgp4", "pv[1][2] 5 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 31076.77273609    , 1e+0, "gal_sgp4", "pv[0][0] 5 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 22063.44379776    , 1e+0, "gal_sgp4", "pv[0][1] 5 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6325.93403705     , 1e+0, "gal_sgp4", "pv[0][2] 5 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.794027976      , 1e+0, "gal_sgp4", "pv[1][0] 5 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.642072476       , 1e+0, "gal_sgp4", "pv[1][1] 5 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.083556127       , 1e+0, "gal_sgp4", "pv[1][2] 5 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -900.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 23341.26015320    , 1e+0, "gal_sgp4", "pv[0][0] 5 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 30460.88002531    , 1e+0, "gal_sgp4", "pv[0][1] 5 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6342.91707895     , 1e+0, "gal_sgp4", "pv[0][2] 5 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.469409743      , 1e+0, "gal_sgp4", "pv[1][0] 5 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.990861658       , 1e+0, "gal_sgp4", "pv[1][1] 5 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.073612096      , 1e+0, "gal_sgp4", "pv[1][2] 5 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13568.39733054    , 1e+0, "gal_sgp4", "pv[0][0] 5 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 36204.45930900    , 1e+0, "gal_sgp4", "pv[0][1] 5 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5806.79548733     , 1e+0, "gal_sgp4", "pv[0][2] 5 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.919354203      , 1e+0, "gal_sgp4", "pv[1][0] 5 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.178920217       , 1e+0, "gal_sgp4", "pv[1][1] 5 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.221646814      , 1e+0, "gal_sgp4", "pv[1][2] 5 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -780.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2628.58762420     , 1e+0, "gal_sgp4", "pv[0][0] 5 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 38840.10855897    , 1e+0, "gal_sgp4", "pv[0][1] 5 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4771.91979854     , 1e+0, "gal_sgp4", "pv[0][2] 5 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.114400514      , 1e+0, "gal_sgp4", "pv[1][0] 5 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.276239109       , 1e+0, "gal_sgp4", "pv[1][1] 5 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.348926401      , 1e+0, "gal_sgp4", "pv[1][2] 5 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8535.81598158    , 1e+0, "gal_sgp4", "pv[0][0] 5 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 38171.79073851    , 1e+0, "gal_sgp4", "pv[0][1] 5 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3331.00311285     , 1e+0, "gal_sgp4", "pv[0][2] 5 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.043839958      , 1e+0, "gal_sgp4", "pv[1][0] 5 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.644462527      , 1e+0, "gal_sgp4", "pv[1][1] 5 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.445808894      , 1e+0, "gal_sgp4", "pv[1][2] 5 13" ) ;  

/*
 * Original STR3 SDP4 test  
 */  

  strcpy ( card1, "1 11801U          80230.29629788  .01431103  00000-0  14311-1      13" ) ;  
  strcpy ( card2, "2 11801  46.7916 230.4354 7318036  47.4722  10.4117  2.28537848    13" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7473.37102491     , 1e+0, "gal_sgp4", "pv[0][0] 6 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 428.94748312      , 1e+0, "gal_sgp4", "pv[0][1] 6 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5828.74846783     , 1e+0, "gal_sgp4", "pv[0][2] 6 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.107155391       , 1e+0, "gal_sgp4", "pv[1][0] 6 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.444680305       , 1e+0, "gal_sgp4", "pv[1][1] 6 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.186133297      , 1e+0, "gal_sgp4", "pv[1][2] 6 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3305.22148694    , 1e+0, "gal_sgp4", "pv[0][0] 6 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 32410.84323331    , 1e+0, "gal_sgp4", "pv[0][1] 6 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -24697.16974954   , 1e+0, "gal_sgp4", "pv[0][2] 6 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.301137319      , 1e+0, "gal_sgp4", "pv[1][0] 6 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.151315600      , 1e+0, "gal_sgp4", "pv[1][1] 6 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.283335823      , 1e+0, "gal_sgp4", "pv[1][2] 6 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14271.29083858    , 1e+0, "gal_sgp4", "pv[0][0] 6 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 24110.44309009    , 1e+0, "gal_sgp4", "pv[0][1] 6 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4725.76320143    , 1e+0, "gal_sgp4", "pv[0][2] 6 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.320504528      , 1e+0, "gal_sgp4", "pv[1][0] 6 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.679841539       , 1e+0, "gal_sgp4", "pv[1][1] 6 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.084054355      , 1e+0, "gal_sgp4", "pv[1][2] 6 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9990.05800009    , 1e+0, "gal_sgp4", "pv[0][0] 6 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 22717.34212448    , 1e+0, "gal_sgp4", "pv[0][1] 6 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -23616.88515553   , 1e+0, "gal_sgp4", "pv[0][2] 6 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.016674392      , 1e+0, "gal_sgp4", "pv[1][0] 6 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.290267981      , 1e+0, "gal_sgp4", "pv[1][1] 6 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.728923337       , 1e+0, "gal_sgp4", "pv[1][2] 6 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9787.87836256     , 1e+0, "gal_sgp4", "pv[0][0] 6 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 33753.32249667    , 1e+0, "gal_sgp4", "pv[0][1] 6 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -15030.79874625   , 1e+0, "gal_sgp4", "pv[0][2] 6 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.094251553      , 1e+0, "gal_sgp4", "pv[1][0] 6 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.923589906       , 1e+0, "gal_sgp4", "pv[1][1] 6 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.522311008      , 1e+0, "gal_sgp4", "pv[1][2] 6 4" ) ;  

/*
 * EUTELSAT 1-F1 (ECS1) fig lyddane choice in GSFC at 2080 min  
 */  

  strcpy ( card1, "1 14128U 83058A   06176.02844893 -.00000158  00000-0  10000-3 0  9627" ) ;  
  strcpy ( card2, "2 14128  11.4384  35.2134 0011562  26.4582 333.5652  0.98870114 46093" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 34747.57932696    , 1e+0, "gal_sgp4", "pv[0][0] 7 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 24502.37114079    , 1e+0, "gal_sgp4", "pv[0][1] 7 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1.32832986       , 1e+0, "gal_sgp4", "pv[0][2] 7 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.731642662      , 1e+0, "gal_sgp4", "pv[1][0] 7 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.452772615       , 1e+0, "gal_sgp4", "pv[1][1] 7 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.608510081       , 1e+0, "gal_sgp4", "pv[1][2] 7 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 18263.33439094    , 1e+0, "gal_sgp4", "pv[0][0] 7 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 38159.96004751    , 1e+0, "gal_sgp4", "pv[0][1] 7 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4186.18304085     , 1e+0, "gal_sgp4", "pv[0][2] 7 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.744396611      , 1e+0, "gal_sgp4", "pv[1][0] 7 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.255583260       , 1e+0, "gal_sgp4", "pv[1][1] 7 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.528558932       , 1e+0, "gal_sgp4", "pv[1][2] 7 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3023.38840703    , 1e+0, "gal_sgp4", "pv[0][0] 7 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 41783.13186459    , 1e+0, "gal_sgp4", "pv[0][1] 7 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 7273.03412906     , 1e+0, "gal_sgp4", "pv[0][2] 7 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.035574793      , 1e+0, "gal_sgp4", "pv[1][0] 7 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.271656544      , 1e+0, "gal_sgp4", "pv[1][1] 7 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.309645251       , 1e+0, "gal_sgp4", "pv[1][2] 7 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -23516.34391907   , 1e+0, "gal_sgp4", "pv[0][0] 7 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 34424.42065671    , 1e+0, "gal_sgp4", "pv[0][1] 7 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 8448.49867693     , 1e+0, "gal_sgp4", "pv[0][2] 7 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.529120477      , 1e+0, "gal_sgp4", "pv[1][0] 7 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.726186020      , 1e+0, "gal_sgp4", "pv[1][1] 7 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.009582303       , 1e+0, "gal_sgp4", "pv[1][2] 7 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -37837.46699511   , 1e+0, "gal_sgp4", "pv[0][0] 7 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18028.39727170    , 1e+0, "gal_sgp4", "pv[0][1] 7 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 7406.25540271     , 1e+0, "gal_sgp4", "pv[0][2] 7 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.360069525      , 1e+0, "gal_sgp4", "pv[1][0] 7 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.725794686      , 1e+0, "gal_sgp4", "pv[1][1] 7 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.292555349      , 1e+0, "gal_sgp4", "pv[1][2] 7 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -42243.58460661   , 1e+0, "gal_sgp4", "pv[0][0] 7 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3093.72887774    , 1e+0, "gal_sgp4", "pv[0][1] 7 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4422.91711801     , 1e+0, "gal_sgp4", "pv[0][2] 7 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.163110919       , 1e+0, "gal_sgp4", "pv[1][0] 7 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.009980598      , 1e+0, "gal_sgp4", "pv[1][1] 7 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.517584362      , 1e+0, "gal_sgp4", "pv[1][2] 7 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -35597.57919549   , 1e+0, "gal_sgp4", "pv[0][0] 7 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -23407.91145393   , 1e+0, "gal_sgp4", "pv[0][1] 7 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 282.09554383      , 1e+0, "gal_sgp4", "pv[0][2] 7 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.641405246       , 1e+0, "gal_sgp4", "pv[1][0] 7 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.506773678      , 1e+0, "gal_sgp4", "pv[1][1] 7 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.606963478      , 1e+0, "gal_sgp4", "pv[1][2] 7 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -19649.19834455   , 1e+0, "gal_sgp4", "pv[0][0] 7 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -37606.11623860   , 1e+0, "gal_sgp4", "pv[0][1] 7 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3932.71525948    , 1e+0, "gal_sgp4", "pv[0][2] 7 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.689647056       , 1e+0, "gal_sgp4", "pv[1][0] 7 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.349150016      , 1e+0, "gal_sgp4", "pv[1][1] 7 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.537710698      , 1e+0, "gal_sgp4", "pv[1][2] 7 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1431.30912160     , 1e+0, "gal_sgp4", "pv[0][0] 7 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -41982.04949668   , 1e+0, "gal_sgp4", "pv[0][1] 7 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7120.45467057    , 1e+0, "gal_sgp4", "pv[0][2] 7 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.035263353       , 1e+0, "gal_sgp4", "pv[1][0] 7 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.160882945       , 1e+0, "gal_sgp4", "pv[1][1] 7 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.327993994      , 1e+0, "gal_sgp4", "pv[1][2] 7 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 22136.97605384    , 1e+0, "gal_sgp4", "pv[0][0] 7 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -35388.19823762   , 1e+0, "gal_sgp4", "pv[0][1] 7 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -8447.62393401    , 1e+0, "gal_sgp4", "pv[0][2] 7 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.587624889       , 1e+0, "gal_sgp4", "pv[1][0] 7 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.630097136       , 1e+0, "gal_sgp4", "pv[1][1] 7 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.032349004      , 1e+0, "gal_sgp4", "pv[1][2] 7 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 37050.15790219    , 1e+0, "gal_sgp4", "pv[0][0] 7 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19537.23321425   , 1e+0, "gal_sgp4", "pv[0][1] 7 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7564.83463543    , 1e+0, "gal_sgp4", "pv[0][2] 7 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.461844494       , 1e+0, "gal_sgp4", "pv[1][0] 7 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.674654256       , 1e+0, "gal_sgp4", "pv[1][1] 7 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.272202191       , 1e+0, "gal_sgp4", "pv[1][2] 7 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 42253.81760945    , 1e+0, "gal_sgp4", "pv[0][0] 7 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1431.81867593     , 1e+0, "gal_sgp4", "pv[0][1] 7 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4699.87621174    , 1e+0, "gal_sgp4", "pv[0][2] 7 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.049247334      , 1e+0, "gal_sgp4", "pv[1][0] 7 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.019518960       , 1e+0, "gal_sgp4", "pv[1][1] 7 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.505890058       , 1e+0, "gal_sgp4", "pv[1][2] 7 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 36366.59147396    , 1e+0, "gal_sgp4", "pv[0][0] 7 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 22023.54245720    , 1e+0, "gal_sgp4", "pv[0][1] 7 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -601.47121821     , 1e+0, "gal_sgp4", "pv[0][2] 7 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.549681546      , 1e+0, "gal_sgp4", "pv[1][0] 7 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.571788981       , 1e+0, "gal_sgp4", "pv[1][1] 7 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.607057418       , 1e+0, "gal_sgp4", "pv[1][2] 7 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 20922.12287985    , 1e+0, "gal_sgp4", "pv[0][0] 7 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 36826.33975981    , 1e+0, "gal_sgp4", "pv[0][1] 7 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3654.91125886     , 1e+0, "gal_sgp4", "pv[0][2] 7 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.644070068      , 1e+0, "gal_sgp4", "pv[1][0] 7 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.447521216       , 1e+0, "gal_sgp4", "pv[1][1] 7 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.548722983       , 1e+0, "gal_sgp4", "pv[1][2] 7 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -23.77224182      , 1e+0, "gal_sgp4", "pv[0][0] 7 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 41945.51688402    , 1e+0, "gal_sgp4", "pv[0][1] 7 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6950.29891751     , 1e+0, "gal_sgp4", "pv[0][2] 7 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.043358385      , 1e+0, "gal_sgp4", "pv[1][0] 7 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.057417440      , 1e+0, "gal_sgp4", "pv[1][1] 7 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.346112094       , 1e+0, "gal_sgp4", "pv[1][2] 7 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -20964.17821076   , 1e+0, "gal_sgp4", "pv[0][0] 7 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 36039.06206172    , 1e+0, "gal_sgp4", "pv[0][1] 7 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 8418.91984963     , 1e+0, "gal_sgp4", "pv[0][2] 7 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.642795221      , 1e+0, "gal_sgp4", "pv[1][0] 7 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.546099886      , 1e+0, "gal_sgp4", "pv[1][1] 7 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.052725852       , 1e+0, "gal_sgp4", "pv[1][2] 7 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -36401.63863057   , 1e+0, "gal_sgp4", "pv[0][0] 7 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 20669.75286162    , 1e+0, "gal_sgp4", "pv[0][1] 7 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 7677.19769359     , 1e+0, "gal_sgp4", "pv[0][2] 7 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.549488154      , 1e+0, "gal_sgp4", "pv[1][0] 7 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.627052310      , 1e+0, "gal_sgp4", "pv[1][1] 7 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.254079652      , 1e+0, "gal_sgp4", "pv[1][2] 7 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -42298.30327543   , 1e+0, "gal_sgp4", "pv[0][0] 7 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -119.03351118     , 1e+0, "gal_sgp4", "pv[0][1] 7 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4922.96388841     , 1e+0, "gal_sgp4", "pv[0][2] 7 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.052232768      , 1e+0, "gal_sgp4", "pv[1][0] 7 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.018152669      , 1e+0, "gal_sgp4", "pv[1][1] 7 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.493827331      , 1e+0, "gal_sgp4", "pv[1][2] 7 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -37125.62383511   , 1e+0, "gal_sgp4", "pv[0][0] 7 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -20879.63058368   , 1e+0, "gal_sgp4", "pv[0][1] 7 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 879.86971348      , 1e+0, "gal_sgp4", "pv[0][2] 7 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.456499841       , 1e+0, "gal_sgp4", "pv[1][0] 7 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.619358421      , 1e+0, "gal_sgp4", "pv[1][1] 7 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.604081694      , 1e+0, "gal_sgp4", "pv[1][2] 7 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -22250.12320553   , 1e+0, "gal_sgp4", "pv[0][0] 7 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -36182.74736487   , 1e+0, "gal_sgp4", "pv[0][1] 7 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3393.15365183    , 1e+0, "gal_sgp4", "pv[0][2] 7 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.583161226       , 1e+0, "gal_sgp4", "pv[1][0] 7 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.536647628      , 1e+0, "gal_sgp4", "pv[1][1] 7 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.556404555      , 1e+0, "gal_sgp4", "pv[1][2] 7 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1563.06258654    , 1e+0, "gal_sgp4", "pv[0][0] 7 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -42035.43179159   , 1e+0, "gal_sgp4", "pv[0][1] 7 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6780.02161760    , 1e+0, "gal_sgp4", "pv[0][2] 7 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.034917506       , 1e+0, "gal_sgp4", "pv[1][0] 7 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.052702046      , 1e+0, "gal_sgp4", "pv[1][1] 7 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.363395654      , 1e+0, "gal_sgp4", "pv[1][2] 7 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19531.64069587    , 1e+0, "gal_sgp4", "pv[0][0] 7 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -36905.65470956   , 1e+0, "gal_sgp4", "pv[0][1] 7 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -8395.46892032    , 1e+0, "gal_sgp4", "pv[0][2] 7 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.693682199       , 1e+0, "gal_sgp4", "pv[1][0] 7 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.446079999       , 1e+0, "gal_sgp4", "pv[1][1] 7 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.075256054      , 1e+0, "gal_sgp4", "pv[1][2] 7 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 35516.53506142    , 1e+0, "gal_sgp4", "pv[0][0] 7 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22123.71916638   , 1e+0, "gal_sgp4", "pv[0][1] 7 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7815.04516935    , 1e+0, "gal_sgp4", "pv[0][2] 7 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.646882125       , 1e+0, "gal_sgp4", "pv[1][0] 7 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.568416058       , 1e+0, "gal_sgp4", "pv[1][1] 7 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.232985912       , 1e+0, "gal_sgp4", "pv[1][2] 7 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 42196.03535976    , 1e+0, "gal_sgp4", "pv[0][0] 7 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1547.32646751    , 1e+0, "gal_sgp4", "pv[0][1] 7 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5187.39401981    , 1e+0, "gal_sgp4", "pv[0][2] 7 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.166491841       , 1e+0, "gal_sgp4", "pv[1][0] 7 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.019211549       , 1e+0, "gal_sgp4", "pv[1][1] 7 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.480665780       , 1e+0, "gal_sgp4", "pv[1][2] 7 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 37802.25393045    , 1e+0, "gal_sgp4", "pv[0][0] 7 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19433.57330019    , 1e+0, "gal_sgp4", "pv[0][1] 7 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1198.66634226    , 1e+0, "gal_sgp4", "pv[0][2] 7 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.359930580      , 1e+0, "gal_sgp4", "pv[1][0] 7 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.677830903       , 1e+0, "gal_sgp4", "pv[1][1] 7 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.602507466       , 1e+0, "gal_sgp4", "pv[1][2] 7 24" ) ;  

/*
 * SL-6 R/B(2) Deep space, perigee = 82.48 (<98) for  
 */  

/*
 * s4 > 20 mod  
 */  

  strcpy ( card1, "1 16925U 86065D   06151.67415771  .02550794 -30915-6  18784-3 0  4486" ) ;  
  strcpy ( card2, "2 16925  62.0906 295.0239 5596327 245.1593  47.9690  4.88511875148616" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5559.11686836     , 1e+0, "gal_sgp4", "pv[0][0] 8 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -11941.04090781   , 1e+0, "gal_sgp4", "pv[0][1] 8 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -19.41235206      , 1e+0, "gal_sgp4", "pv[0][2] 8 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.392116762       , 1e+0, "gal_sgp4", "pv[1][0] 8 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.946985124      , 1e+0, "gal_sgp4", "pv[1][1] 8 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.250755852       , 1e+0, "gal_sgp4", "pv[1][2] 8 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 12339.83273749    , 1e+0, "gal_sgp4", "pv[0][0] 8 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2771.14447871    , 1e+0, "gal_sgp4", "pv[0][1] 8 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18904.57603433    , 1e+0, "gal_sgp4", "pv[0][2] 8 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.871247614      , 1e+0, "gal_sgp4", "pv[1][0] 8 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.600917693       , 1e+0, "gal_sgp4", "pv[1][1] 8 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.581560002       , 1e+0, "gal_sgp4", "pv[1][2] 8 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3385.00215658    , 1e+0, "gal_sgp4", "pv[0][0] 8 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 7538.13955729     , 1e+0, "gal_sgp4", "pv[0][1] 8 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 200.59008616      , 1e+0, "gal_sgp4", "pv[0][2] 8 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.023512865      , 1e+0, "gal_sgp4", "pv[1][0] 8 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.261808344      , 1e+0, "gal_sgp4", "pv[1][1] 8 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.856385787      , 1e+0, "gal_sgp4", "pv[1][2] 8 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 12805.22442200    , 1e+0, "gal_sgp4", "pv[0][0] 8 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -10258.94667177   , 1e+0, "gal_sgp4", "pv[0][1] 8 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 13780.16486738    , 1e+0, "gal_sgp4", "pv[0][2] 8 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.619279224       , 1e+0, "gal_sgp4", "pv[1][0] 8 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.821510542       , 1e+0, "gal_sgp4", "pv[1][1] 8 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.507365975       , 1e+0, "gal_sgp4", "pv[1][2] 8 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5682.46556318     , 1e+0, "gal_sgp4", "pv[0][0] 8 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 7199.30270473     , 1e+0, "gal_sgp4", "pv[0][1] 8 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 15437.67134070    , 1e+0, "gal_sgp4", "pv[0][2] 8 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.474365406      , 1e+0, "gal_sgp4", "pv[1][0] 8 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.087897336       , 1e+0, "gal_sgp4", "pv[1][1] 8 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.583767460      , 1e+0, "gal_sgp4", "pv[1][2] 8 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7628.94243982     , 1e+0, "gal_sgp4", "pv[0][0] 8 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -12852.72097492   , 1e+0, "gal_sgp4", "pv[0][1] 8 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2902.87208981     , 1e+0, "gal_sgp4", "pv[0][2] 8 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.748131081       , 1e+0, "gal_sgp4", "pv[1][0] 8 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.740084579      , 1e+0, "gal_sgp4", "pv[1][1] 8 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.125307943       , 1e+0, "gal_sgp4", "pv[1][2] 8 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11531.64866625    , 1e+0, "gal_sgp4", "pv[0][0] 8 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -858.27542736     , 1e+0, "gal_sgp4", "pv[0][1] 8 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 19086.85993771    , 1e+0, "gal_sgp4", "pv[0][2] 8 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.170071901      , 1e+0, "gal_sgp4", "pv[1][0] 8 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.660311986       , 1e+0, "gal_sgp4", "pv[1][1] 8 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.096005705       , 1e+0, "gal_sgp4", "pv[1][2] 8 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3866.98069515    , 1e+0, "gal_sgp4", "pv[0][0] 8 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2603.73442786     , 1e+0, "gal_sgp4", "pv[0][1] 8 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4577.36484577    , 1e+0, "gal_sgp4", "pv[0][2] 8 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.157257298       , 1e+0, "gal_sgp4", "pv[1][0] 8 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -8.453281164      , 1e+0, "gal_sgp4", "pv[1][1] 8 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.683959407      , 1e+0, "gal_sgp4", "pv[1][2] 8 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13054.77732721    , 1e+0, "gal_sgp4", "pv[0][0] 8 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -8707.92757730    , 1e+0, "gal_sgp4", "pv[0][1] 8 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 15537.63259903    , 1e+0, "gal_sgp4", "pv[0][2] 8 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.229846748       , 1e+0, "gal_sgp4", "pv[1][0] 8 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.119467054       , 1e+0, "gal_sgp4", "pv[1][1] 8 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.063396852       , 1e+0, "gal_sgp4", "pv[1][2] 8 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3496.91064652     , 1e+0, "gal_sgp4", "pv[0][0] 8 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 8712.83919778     , 1e+0, "gal_sgp4", "pv[0][1] 8 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12845.81838327    , 1e+0, "gal_sgp4", "pv[0][2] 8 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.782184997      , 1e+0, "gal_sgp4", "pv[1][0] 8 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.552950644       , 1e+0, "gal_sgp4", "pv[1][1] 8 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.554436131      , 1e+0, "gal_sgp4", "pv[1][2] 8 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9593.07424729     , 1e+0, "gal_sgp4", "pv[0][0] 8 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -13023.75963608   , 1e+0, "gal_sgp4", "pv[0][1] 8 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6250.46484931     , 1e+0, "gal_sgp4", "pv[0][2] 8 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.072666376       , 1e+0, "gal_sgp4", "pv[1][0] 8 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.278735334       , 1e+0, "gal_sgp4", "pv[1][1] 8 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.778111073       , 1e+0, "gal_sgp4", "pv[1][2] 8 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 10284.79205084    , 1e+0, "gal_sgp4", "pv[0][0] 8 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1487.89914169     , 1e+0, "gal_sgp4", "pv[0][1] 8 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18824.37381327    , 1e+0, "gal_sgp4", "pv[0][2] 8 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.530335053      , 1e+0, "gal_sgp4", "pv[1][0] 8 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.663107730       , 1e+0, "gal_sgp4", "pv[1][1] 8 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.542205966      , 1e+0, "gal_sgp4", "pv[1][2] 8 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -984.62035146     , 1e+0, "gal_sgp4", "pv[0][0] 8 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5187.03480813    , 1e+0, "gal_sgp4", "pv[0][1] 8 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5745.59594144    , 1e+0, "gal_sgp4", "pv[0][2] 8 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.340271916       , 1e+0, "gal_sgp4", "pv[1][0] 8 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.266811354      , 1e+0, "gal_sgp4", "pv[1][1] 8 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.777668888       , 1e+0, "gal_sgp4", "pv[1][2] 8 12" ) ;  

/*
 * SL-12 R/B Shows Lyddane choice at 1860 and 4700 min  
 */  

  strcpy ( card1, "1 20413U 83020D   05363.79166667  .00000000  00000-0  00000+0 0  7041" ) ;  
  strcpy ( card2, "2 20413  12.3514 187.4253 7864447 196.3027 356.5478  0.24690082  7978" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 25123.29290741    , 1e+0, "gal_sgp4", "pv[0][0] 9 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -13225.49966286   , 1e+0, "gal_sgp4", "pv[0][1] 9 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3249.40351869     , 1e+0, "gal_sgp4", "pv[0][2] 9 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.488683419       , 1e+0, "gal_sgp4", "pv[1][0] 9 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.797897593       , 1e+0, "gal_sgp4", "pv[1][1] 9 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.961119693      , 1e+0, "gal_sgp4", "pv[1][2] 9 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -151669.05280515  , 1e+0, "gal_sgp4", "pv[0][0] 9 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5645.20454550    , 1e+0, "gal_sgp4", "pv[0][1] 9 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2198.51592118    , 1e+0, "gal_sgp4", "pv[0][2] 9 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.869182889      , 1e+0, "gal_sgp4", "pv[1][0] 9 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.870759872      , 1e+0, "gal_sgp4", "pv[1][1] 9 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.156508219       , 1e+0, "gal_sgp4", "pv[1][2] 9 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -157497.71657495  , 1e+0, "gal_sgp4", "pv[0][0] 9 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -11884.99595074   , 1e+0, "gal_sgp4", "pv[0][1] 9 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1061.44439402    , 1e+0, "gal_sgp4", "pv[0][2] 9 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.749657961      , 1e+0, "gal_sgp4", "pv[1][0] 9 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.864016715      , 1e+0, "gal_sgp4", "pv[1][1] 9 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.157766101       , 1e+0, "gal_sgp4", "pv[1][2] 9 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -162498.32255577  , 1e+0, "gal_sgp4", "pv[0][0] 9 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -18062.99733167   , 1e+0, "gal_sgp4", "pv[0][1] 9 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 81.00915253       , 1e+0, "gal_sgp4", "pv[0][2] 9 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.638980378      , 1e+0, "gal_sgp4", "pv[1][0] 9 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.853687105      , 1e+0, "gal_sgp4", "pv[1][1] 9 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.158098992       , 1e+0, "gal_sgp4", "pv[1][2] 9 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -166728.76010920  , 1e+0, "gal_sgp4", "pv[0][0] 9 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -24155.99648299   , 1e+0, "gal_sgp4", "pv[0][1] 9 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1222.84128677     , 1e+0, "gal_sgp4", "pv[0][2] 9 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.535600687      , 1e+0, "gal_sgp4", "pv[1][0] 9 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.840455444      , 1e+0, "gal_sgp4", "pv[1][1] 9 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.157680857       , 1e+0, "gal_sgp4", "pv[1][2] 9 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -169935.81924592  , 1e+0, "gal_sgp4", "pv[0][0] 9 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -31767.29787964   , 1e+0, "gal_sgp4", "pv[0][1] 9 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2749.01540345     , 1e+0, "gal_sgp4", "pv[0][2] 9 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.430050431      , 1e+0, "gal_sgp4", "pv[1][0] 9 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.828904183      , 1e+0, "gal_sgp4", "pv[1][1] 9 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.157812340       , 1e+0, "gal_sgp4", "pv[1][2] 9 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -172703.07831815  , 1e+0, "gal_sgp4", "pv[0][0] 9 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -37662.95639336   , 1e+0, "gal_sgp4", "pv[0][1] 9 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3883.60052579     , 1e+0, "gal_sgp4", "pv[0][2] 9 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.338004891      , 1e+0, "gal_sgp4", "pv[1][0] 9 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.810277487      , 1e+0, "gal_sgp4", "pv[1][1] 9 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.156020035       , 1e+0, "gal_sgp4", "pv[1][2] 9 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -174823.19337404  , 1e+0, "gal_sgp4", "pv[0][0] 9 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -43417.55605219   , 1e+0, "gal_sgp4", "pv[0][1] 9 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5003.26312809     , 1e+0, "gal_sgp4", "pv[0][2] 9 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.250258622      , 1e+0, "gal_sgp4", "pv[1][0] 9 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.789828672      , 1e+0, "gal_sgp4", "pv[1][1] 9 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.153764903       , 1e+0, "gal_sgp4", "pv[1][2] 9 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -176324.63925775  , 1e+0, "gal_sgp4", "pv[0][0] 9 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -49018.51958648   , 1e+0, "gal_sgp4", "pv[0][1] 9 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6104.85025002     , 1e+0, "gal_sgp4", "pv[0][2] 9 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.166136613      , 1e+0, "gal_sgp4", "pv[1][0] 9 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.767706262      , 1e+0, "gal_sgp4", "pv[1][1] 9 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.151092242       , 1e+0, "gal_sgp4", "pv[1][2] 9 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -177231.42142458  , 1e+0, "gal_sgp4", "pv[0][0] 9 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -54454.12699497   , 1e+0, "gal_sgp4", "pv[0][1] 9 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 7185.48661607     , 1e+0, "gal_sgp4", "pv[0][2] 9 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.085067854      , 1e+0, "gal_sgp4", "pv[1][0] 9 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.744001567      , 1e+0, "gal_sgp4", "pv[1][1] 9 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.148033403       , 1e+0, "gal_sgp4", "pv[1][2] 9 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -177563.73583232  , 1e+0, "gal_sgp4", "pv[0][0] 9 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -59713.14859144   , 1e+0, "gal_sgp4", "pv[0][1] 9 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 8242.48472591     , 1e+0, "gal_sgp4", "pv[0][2] 9 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.006561730      , 1e+0, "gal_sgp4", "pv[1][0] 9 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.718760309      , 1e+0, "gal_sgp4", "pv[1][1] 9 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.144608676       , 1e+0, "gal_sgp4", "pv[1][2] 9 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -177338.48026483  , 1e+0, "gal_sgp4", "pv[0][0] 9 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -64784.54644698   , 1e+0, "gal_sgp4", "pv[0][1] 9 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 9273.27220003     , 1e+0, "gal_sgp4", "pv[0][2] 9 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.069809946       , 1e+0, "gal_sgp4", "pv[1][0] 9 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.691990238      , 1e+0, "gal_sgp4", "pv[1][1] 9 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.140829236       , 1e+0, "gal_sgp4", "pv[1][2] 9 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -176569.65151461  , 1e+0, "gal_sgp4", "pv[0][0] 9 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -69657.21976255   , 1e+0, "gal_sgp4", "pv[0][1] 9 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 10275.33063459    , 1e+0, "gal_sgp4", "pv[0][2] 9 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.144426878       , 1e+0, "gal_sgp4", "pv[1][0] 9 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.663665876      , 1e+0, "gal_sgp4", "pv[1][1] 9 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.136698419       , 1e+0, "gal_sgp4", "pv[1][2] 9 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -175268.65299073  , 1e+0, "gal_sgp4", "pv[0][0] 9 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -74319.77625463   , 1e+0, "gal_sgp4", "pv[0][1] 9 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 11246.14177160    , 1e+0, "gal_sgp4", "pv[0][2] 9 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.217631370       , 1e+0, "gal_sgp4", "pv[1][0] 9 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.633731091      , 1e+0, "gal_sgp4", "pv[1][1] 9 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.132212491       , 1e+0, "gal_sgp4", "pv[1][2] 9 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3000.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -173444.53039609  , 1e+0, "gal_sgp4", "pv[0][0] 9 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -78760.31560396   , 1e+0, "gal_sgp4", "pv[0][1] 9 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12183.13775212    , 1e+0, "gal_sgp4", "pv[0][2] 9 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.289737325       , 1e+0, "gal_sgp4", "pv[1][0] 9 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.602099929      , 1e+0, "gal_sgp4", "pv[1][1] 9 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.127361017       , 1e+0, "gal_sgp4", "pv[1][2] 9 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -171104.14813653  , 1e+0, "gal_sgp4", "pv[0][0] 9 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -82966.21323591   , 1e+0, "gal_sgp4", "pv[0][1] 9 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 13083.65278381    , 1e+0, "gal_sgp4", "pv[0][2] 9 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.361037779       , 1e+0, "gal_sgp4", "pv[1][0] 9 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.568655903      , 1e+0, "gal_sgp4", "pv[1][1] 9 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.122126889       , 1e+0, "gal_sgp4", "pv[1][2] 9 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -168252.31543803  , 1e+0, "gal_sgp4", "pv[0][0] 9 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -86923.89363433   , 1e+0, "gal_sgp4", "pv[0][1] 9 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 13944.87382716    , 1e+0, "gal_sgp4", "pv[0][2] 9 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.431811396       , 1e+0, "gal_sgp4", "pv[1][0] 9 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.533249797      , 1e+0, "gal_sgp4", "pv[1][1] 9 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.116486022       , 1e+0, "gal_sgp4", "pv[1][2] 9 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -164891.86832887  , 1e+0, "gal_sgp4", "pv[0][0] 9 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -90618.58225954   , 1e+0, "gal_sgp4", "pv[0][1] 9 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 14763.78794247    , 1e+0, "gal_sgp4", "pv[0][2] 9 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.502328269       , 1e+0, "gal_sgp4", "pv[1][0] 9 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.495695896      , 1e+0, "gal_sgp4", "pv[1][1] 9 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.110406725       , 1e+0, "gal_sgp4", "pv[1][2] 9 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -161023.71139825  , 1e+0, "gal_sgp4", "pv[0][0] 9 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -94034.02398835   , 1e+0, "gal_sgp4", "pv[0][1] 9 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 15537.12375729    , 1e+0, "gal_sgp4", "pv[0][2] 9 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.572855321       , 1e+0, "gal_sgp4", "pv[1][0] 9 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.455766412      , 1e+0, "gal_sgp4", "pv[1][1] 9 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.103848688       , 1e+0, "gal_sgp4", "pv[1][2] 9 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -156646.82136726  , 1e+0, "gal_sgp4", "pv[0][0] 9 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -97152.15370791   , 1e+0, "gal_sgp4", "pv[0][1] 9 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 16261.28409305    , 1e+0, "gal_sgp4", "pv[0][2] 9 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.643661538       , 1e+0, "gal_sgp4", "pv[1][0] 9 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.413183688      , 1e+0, "gal_sgp4", "pv[1][1] 9 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.096761524       , 1e+0, "gal_sgp4", "pv[1][2] 9 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -151758.21285737  , 1e+0, "gal_sgp4", "pv[0][0] 9 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -99952.70098346   , 1e+0, "gal_sgp4", "pv[0][1] 9 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 16932.26607548    , 1e+0, "gal_sgp4", "pv[0][2] 9 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.715023254       , 1e+0, "gal_sgp4", "pv[1][0] 9 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.367609561      , 1e+0, "gal_sgp4", "pv[1][1] 9 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.089082727       , 1e+0, "gal_sgp4", "pv[1][2] 9 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -146352.86521283  , 1e+0, "gal_sgp4", "pv[0][0] 9 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -102412.70506284  , 1e+0, "gal_sgp4", "pv[0][1] 9 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 17545.56394158    , 1e+0, "gal_sgp4", "pv[0][2] 9 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.787229695       , 1e+0, "gal_sgp4", "pv[1][0] 9 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.318630913      , 1e+0, "gal_sgp4", "pv[1][1] 9 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.080734873       , 1e+0, "gal_sgp4", "pv[1][2] 9 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 3960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -140423.60777444  , 1e+0, "gal_sgp4", "pv[0][0] 9 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -104505.90799734  , 1e+0, "gal_sgp4", "pv[0][1] 9 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18096.04807097    , 1e+0, "gal_sgp4", "pv[0][2] 9 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.860588979       , 1e+0, "gal_sgp4", "pv[1][0] 9 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.265739987      , 1e+0, "gal_sgp4", "pv[1][1] 9 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.071621768       , 1e+0, "gal_sgp4", "pv[1][2] 9 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 4080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -133960.95961851  , 1e+0, "gal_sgp4", "pv[0][0] 9 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -106201.98091318  , 1e+0, "gal_sgp4", "pv[0][1] 9 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18577.81121953    , 1e+0, "gal_sgp4", "pv[0][2] 9 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.935434758       , 1e+0, "gal_sgp4", "pv[1][0] 9 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.208307307      , 1e+0, "gal_sgp4", "pv[1][1] 9 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.061623110       , 1e+0, "gal_sgp4", "pv[1][2] 9 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 4200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -126952.91860010  , 1e+0, "gal_sgp4", "pv[0][0] 9 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -107465.51906186  , 1e+0, "gal_sgp4", "pv[0][1] 9 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18983.96903112    , 1e+0, "gal_sgp4", "pv[0][2] 9 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.012133628       , 1e+0, "gal_sgp4", "pv[1][0] 9 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.145543878      , 1e+0, "gal_sgp4", "pv[1][1] 9 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.050587007       , 1e+0, "gal_sgp4", "pv[1][2] 9 24" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 4320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -119384.69396454  , 1e+0, "gal_sgp4", "pv[0][0] 9 25" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -108254.71115372  , 1e+0, "gal_sgp4", "pv[0][1] 9 25" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 19306.39581892    , 1e+0, "gal_sgp4", "pv[0][2] 9 25" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.091093313       , 1e+0, "gal_sgp4", "pv[1][0] 9 25" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.076447479      , 1e+0, "gal_sgp4", "pv[1][1] 9 25" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.038319282       , 1e+0, "gal_sgp4", "pv[1][2] 9 25" ) ;  

/*
 * MOLNIYA 1-83 12h resonant, ecc > 0.715 (negative BSTAR)  
 */  

  strcpy ( card1, "1 21897U 92011A   06176.02341244 -.00001273  00000-0 -13525-3 0  3044" ) ;  
  strcpy ( card2, "2 21897  62.1749 198.0096 7421690 253.0462  20.1561  2.01269994104880" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -14464.72135182   , 1e+0, "gal_sgp4", "pv[0][0] 10 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4699.19517587    , 1e+0, "gal_sgp4", "pv[0][1] 10 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 0.06681686        , 1e+0, "gal_sgp4", "pv[0][2] 10 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.249312013      , 1e+0, "gal_sgp4", "pv[1][0] 10 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.281032707      , 1e+0, "gal_sgp4", "pv[1][1] 10 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.007046940       , 1e+0, "gal_sgp4", "pv[1][2] 10 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -19410.46286123   , 1e+0, "gal_sgp4", "pv[0][0] 10 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19143.03318969   , 1e+0, "gal_sgp4", "pv[0][1] 10 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 23114.05522619    , 1e+0, "gal_sgp4", "pv[0][2] 10 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.508602237       , 1e+0, "gal_sgp4", "pv[1][0] 10 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.156882269      , 1e+0, "gal_sgp4", "pv[1][1] 10 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.379923455       , 1e+0, "gal_sgp4", "pv[1][2] 10 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12686.06129708   , 1e+0, "gal_sgp4", "pv[0][0] 10 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -23853.75335645   , 1e+0, "gal_sgp4", "pv[0][1] 10 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 35529.81733588    , 1e+0, "gal_sgp4", "pv[0][2] 10 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.231633829       , 1e+0, "gal_sgp4", "pv[1][0] 10 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.221718202      , 1e+0, "gal_sgp4", "pv[1][1] 10 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.118440291       , 1e+0, "gal_sgp4", "pv[1][2] 10 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2775.46649359    , 1e+0, "gal_sgp4", "pv[0][0] 10 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22839.64574119   , 1e+0, "gal_sgp4", "pv[0][1] 10 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39494.64689967    , 1e+0, "gal_sgp4", "pv[0][2] 10 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.468963405       , 1e+0, "gal_sgp4", "pv[1][0] 10 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.489481769       , 1e+0, "gal_sgp4", "pv[1][1] 10 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.023972788      , 1e+0, "gal_sgp4", "pv[1][2] 10 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7679.87883570     , 1e+0, "gal_sgp4", "pv[0][0] 10 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -16780.50760106   , 1e+0, "gal_sgp4", "pv[0][1] 10 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 34686.21815555    , 1e+0, "gal_sgp4", "pv[0][2] 10 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.364171080       , 1e+0, "gal_sgp4", "pv[1][0] 10 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.211183897       , 1e+0, "gal_sgp4", "pv[1][1] 10 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.385151371      , 1e+0, "gal_sgp4", "pv[1][2] 10 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14552.40023028    , 1e+0, "gal_sgp4", "pv[0][0] 10 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4819.50121461    , 1e+0, "gal_sgp4", "pv[0][1] 10 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 17154.70672449    , 1e+0, "gal_sgp4", "pv[0][2] 10 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.109201591       , 1e+0, "gal_sgp4", "pv[1][0] 10 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.176124494       , 1e+0, "gal_sgp4", "pv[1][1] 10 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.854856805      , 1e+0, "gal_sgp4", "pv[1][2] 10 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -15302.38845375   , 1e+0, "gal_sgp4", "pv[0][0] 10 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5556.43440300    , 1e+0, "gal_sgp4", "pv[0][1] 10 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1095.95088753     , 1e+0, "gal_sgp4", "pv[0][2] 10 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.838224312      , 1e+0, "gal_sgp4", "pv[1][0] 10 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.134231137      , 1e+0, "gal_sgp4", "pv[1][1] 10 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.992596326       , 1e+0, "gal_sgp4", "pv[1][2] 10 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -19289.20066748   , 1e+0, "gal_sgp4", "pv[0][0] 10 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19427.04851118   , 1e+0, "gal_sgp4", "pv[0][1] 10 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 23759.45685636    , 1e+0, "gal_sgp4", "pv[0][2] 10 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.552495087       , 1e+0, "gal_sgp4", "pv[1][0] 10 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.112499437      , 1e+0, "gal_sgp4", "pv[1][1] 10 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.325112654       , 1e+0, "gal_sgp4", "pv[1][2] 10 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12376.21976437   , 1e+0, "gal_sgp4", "pv[0][0] 10 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -23893.38020018   , 1e+0, "gal_sgp4", "pv[0][1] 10 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 35831.33691892    , 1e+0, "gal_sgp4", "pv[0][2] 10 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.246701529       , 1e+0, "gal_sgp4", "pv[1][0] 10 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.194294048      , 1e+0, "gal_sgp4", "pv[1][1] 10 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.074867282       , 1e+0, "gal_sgp4", "pv[1][2] 10 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2400.55677665    , 1e+0, "gal_sgp4", "pv[0][0] 10 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22698.62264640   , 1e+0, "gal_sgp4", "pv[0][1] 10 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39482.75964390    , 1e+0, "gal_sgp4", "pv[0][2] 10 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.472582922       , 1e+0, "gal_sgp4", "pv[1][0] 10 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.513555654       , 1e+0, "gal_sgp4", "pv[1][1] 10 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.069306561      , 1e+0, "gal_sgp4", "pv[1][2] 10 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8031.66819252     , 1e+0, "gal_sgp4", "pv[0][0] 10 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -16455.77592085   , 1e+0, "gal_sgp4", "pv[0][1] 10 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 34298.94391742    , 1e+0, "gal_sgp4", "pv[0][2] 10 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.351357426       , 1e+0, "gal_sgp4", "pv[1][0] 10 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.239633234       , 1e+0, "gal_sgp4", "pv[1][1] 10 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.448195324      , 1e+0, "gal_sgp4", "pv[1][2] 10 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14559.48780372    , 1e+0, "gal_sgp4", "pv[0][0] 10 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4238.43773813    , 1e+0, "gal_sgp4", "pv[0][1] 10 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 16079.23154704    , 1e+0, "gal_sgp4", "pv[0][2] 10 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.026409655      , 1e+0, "gal_sgp4", "pv[1][0] 10 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.218938770       , 1e+0, "gal_sgp4", "pv[1][1] 10 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.012628896      , 1e+0, "gal_sgp4", "pv[1][2] 10 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -16036.04980660   , 1e+0, "gal_sgp4", "pv[0][0] 10 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6372.51406468    , 1e+0, "gal_sgp4", "pv[0][1] 10 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2183.44834232     , 1e+0, "gal_sgp4", "pv[0][2] 10 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.485113443      , 1e+0, "gal_sgp4", "pv[1][0] 10 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.994994355      , 1e+0, "gal_sgp4", "pv[1][1] 10 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.955891272       , 1e+0, "gal_sgp4", "pv[1][2] 10 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -19156.71583814   , 1e+0, "gal_sgp4", "pv[0][0] 10 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19698.89059957   , 1e+0, "gal_sgp4", "pv[0][1] 10 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 24389.29473934    , 1e+0, "gal_sgp4", "pv[0][2] 10 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.594278133       , 1e+0, "gal_sgp4", "pv[1][0] 10 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.069418599      , 1e+0, "gal_sgp4", "pv[1][1] 10 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.271152044       , 1e+0, "gal_sgp4", "pv[1][2] 10 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12062.72925552   , 1e+0, "gal_sgp4", "pv[0][0] 10 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -23925.82362911   , 1e+0, "gal_sgp4", "pv[0][1] 10 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 36120.66680667    , 1e+0, "gal_sgp4", "pv[0][2] 10 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.261238798       , 1e+0, "gal_sgp4", "pv[1][0] 10 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.167201856      , 1e+0, "gal_sgp4", "pv[1][1] 10 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.031478939       , 1e+0, "gal_sgp4", "pv[1][2] 10 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2024.96136966    , 1e+0, "gal_sgp4", "pv[0][0] 10 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22551.56626703   , 1e+0, "gal_sgp4", "pv[0][1] 10 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39458.50085787    , 1e+0, "gal_sgp4", "pv[0][2] 10 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.475816889       , 1e+0, "gal_sgp4", "pv[1][0] 10 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.537615764       , 1e+0, "gal_sgp4", "pv[1][1] 10 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.114887472      , 1e+0, "gal_sgp4", "pv[1][2] 10 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8379.80916204     , 1e+0, "gal_sgp4", "pv[0][0] 10 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -16123.95878459   , 1e+0, "gal_sgp4", "pv[0][1] 10 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 33894.75123231    , 1e+0, "gal_sgp4", "pv[0][2] 10 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.337468254       , 1e+0, "gal_sgp4", "pv[1][0] 10 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.268432783       , 1e+0, "gal_sgp4", "pv[1][1] 10 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.512473301      , 1e+0, "gal_sgp4", "pv[1][2] 10 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14527.86748873    , 1e+0, "gal_sgp4", "pv[0][0] 10 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3646.33817120    , 1e+0, "gal_sgp4", "pv[0][1] 10 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 14960.74306518    , 1e+0, "gal_sgp4", "pv[0][2] 10 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.180035839      , 1e+0, "gal_sgp4", "pv[1][0] 10 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.261273515       , 1e+0, "gal_sgp4", "pv[1][1] 10 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.179355590      , 1e+0, "gal_sgp4", "pv[1][2] 10 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -16680.12147335   , 1e+0, "gal_sgp4", "pv[0][0] 10 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -7149.80800425    , 1e+0, "gal_sgp4", "pv[0][1] 10 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3257.64227208     , 1e+0, "gal_sgp4", "pv[0][2] 10 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.178897351      , 1e+0, "gal_sgp4", "pv[1][0] 10 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.863927095      , 1e+0, "gal_sgp4", "pv[1][1] 10 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.904876943       , 1e+0, "gal_sgp4", "pv[1][2] 10 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -19013.58793448   , 1e+0, "gal_sgp4", "pv[0][0] 10 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19958.93766022   , 1e+0, "gal_sgp4", "pv[0][1] 10 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 25003.81778666    , 1e+0, "gal_sgp4", "pv[0][2] 10 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.634100431       , 1e+0, "gal_sgp4", "pv[1][0] 10 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.027559823      , 1e+0, "gal_sgp4", "pv[1][1] 10 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.218002685       , 1e+0, "gal_sgp4", "pv[1][2] 10 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -11745.76155818   , 1e+0, "gal_sgp4", "pv[0][0] 10 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -23951.19438627   , 1e+0, "gal_sgp4", "pv[0][1] 10 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 36397.87676581    , 1e+0, "gal_sgp4", "pv[0][2] 10 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.275261813       , 1e+0, "gal_sgp4", "pv[1][0] 10 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.140425132      , 1e+0, "gal_sgp4", "pv[1][1] 10 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.988259441       , 1e+0, "gal_sgp4", "pv[1][2] 10 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1648.81945070    , 1e+0, "gal_sgp4", "pv[0][0] 10 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22398.50594576   , 1e+0, "gal_sgp4", "pv[0][1] 10 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39421.83273890    , 1e+0, "gal_sgp4", "pv[0][2] 10 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.478660174       , 1e+0, "gal_sgp4", "pv[1][0] 10 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.561671519       , 1e+0, "gal_sgp4", "pv[1][1] 10 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.160733093      , 1e+0, "gal_sgp4", "pv[1][2] 10 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8723.97652795     , 1e+0, "gal_sgp4", "pv[0][0] 10 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -15784.99406275   , 1e+0, "gal_sgp4", "pv[0][1] 10 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 33473.35215527    , 1e+0, "gal_sgp4", "pv[0][2] 10 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.322433593       , 1e+0, "gal_sgp4", "pv[1][0] 10 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.297602497       , 1e+0, "gal_sgp4", "pv[1][1] 10 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.578055493      , 1e+0, "gal_sgp4", "pv[1][2] 10 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14452.25571587    , 1e+0, "gal_sgp4", "pv[0][0] 10 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3043.42332645    , 1e+0, "gal_sgp4", "pv[0][1] 10 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 13796.84870805    , 1e+0, "gal_sgp4", "pv[0][2] 10 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.355190169      , 1e+0, "gal_sgp4", "pv[1][0] 10 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.302485443       , 1e+0, "gal_sgp4", "pv[1][1] 10 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.355767077      , 1e+0, "gal_sgp4", "pv[1][2] 10 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -17246.31075678   , 1e+0, "gal_sgp4", "pv[0][0] 10 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -7890.72601508    , 1e+0, "gal_sgp4", "pv[0][1] 10 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4315.39410307     , 1e+0, "gal_sgp4", "pv[0][2] 10 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.910968458      , 1e+0, "gal_sgp4", "pv[1][0] 10 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.740945672      , 1e+0, "gal_sgp4", "pv[1][1] 10 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.844722726       , 1e+0, "gal_sgp4", "pv[1][2] 10 24" ) ;  

/*
 * SL-6 R/B(2) last tle given, decayed 2006-04-04, day 94  
 */  

  strcpy ( card1, "1 22312U 93002D   06094.46235912  .99999999  81888-5  49949-3 0  3953" ) ;  
  strcpy ( card2, "2 22312  62.1486  77.4698 0308723 267.9229  88.7392 15.95744531 98783" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1442.10132912     , 1e+0, "gal_sgp4", "pv[0][0] 11 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6510.23625449     , 1e+0, "gal_sgp4", "pv[0][1] 11 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 8.83145885        , 1e+0, "gal_sgp4", "pv[0][2] 11 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.475714837      , 1e+0, "gal_sgp4", "pv[1][0] 11 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.997262768       , 1e+0, "gal_sgp4", "pv[1][1] 11 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.835860345       , 1e+0, "gal_sgp4", "pv[1][2] 11 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 54.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 306.10478453      , 1e+0, "gal_sgp4", "pv[0][0] 11 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5816.45655525    , 1e+0, "gal_sgp4", "pv[0][1] 11 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2979.55846068    , 1e+0, "gal_sgp4", "pv[0][2] 11 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.950663855       , 1e+0, "gal_sgp4", "pv[1][0] 11 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.415332543       , 1e+0, "gal_sgp4", "pv[1][1] 11 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.879974329      , 1e+0, "gal_sgp4", "pv[1][2] 11 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 74.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3282.82085464     , 1e+0, "gal_sgp4", "pv[0][0] 11 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2077.46972905     , 1e+0, "gal_sgp4", "pv[0][1] 11 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5189.17988770    , 1e+0, "gal_sgp4", "pv[0][2] 11 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.097342701       , 1e+0, "gal_sgp4", "pv[1][0] 11 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 7.375135692       , 1e+0, "gal_sgp4", "pv[1][1] 11 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.900196702       , 1e+0, "gal_sgp4", "pv[1][2] 11 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 94.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 530.82729176      , 1e+0, "gal_sgp4", "pv[0][0] 11 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6426.20790003     , 1e+0, "gal_sgp4", "pv[0][1] 11 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1712.37076793     , 1e+0, "gal_sgp4", "pv[0][2] 11 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.837120395      , 1e+0, "gal_sgp4", "pv[1][0] 11 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.252430637      , 1e+0, "gal_sgp4", "pv[1][1] 11 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.561602577       , 1e+0, "gal_sgp4", "pv[1][2] 11 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 114.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3191.69170212    , 1e+0, "gal_sgp4", "pv[0][0] 11 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 170.27219912      , 1e+0, "gal_sgp4", "pv[0][1] 11 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5956.29807775     , 1e+0, "gal_sgp4", "pv[0][2] 11 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.394956872      , 1e+0, "gal_sgp4", "pv[1][0] 11 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.438073471      , 1e+0, "gal_sgp4", "pv[1][1] 11 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.557553115      , 1e+0, "gal_sgp4", "pv[1][2] 11 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 134.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1818.99222465    , 1e+0, "gal_sgp4", "pv[0][0] 11 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6322.45146616    , 1e+0, "gal_sgp4", "pv[0][1] 11 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 681.95247154      , 1e+0, "gal_sgp4", "pv[0][2] 11 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.349795173       , 1e+0, "gal_sgp4", "pv[1][0] 11 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.530140265      , 1e+0, "gal_sgp4", "pv[1][1] 11 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.831522765      , 1e+0, "gal_sgp4", "pv[1][2] 11 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 154.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2515.66448634     , 1e+0, "gal_sgp4", "pv[0][0] 11 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2158.83091224    , 1e+0, "gal_sgp4", "pv[0][1] 11 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5552.13320544    , 1e+0, "gal_sgp4", "pv[0][2] 11 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.571979660       , 1e+0, "gal_sgp4", "pv[1][0] 11 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 7.311930509       , 1e+0, "gal_sgp4", "pv[1][1] 11 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.639865620      , 1e+0, "gal_sgp4", "pv[1][2] 11 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 174.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2414.52833210     , 1e+0, "gal_sgp4", "pv[0][0] 11 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5749.10150922     , 1e+0, "gal_sgp4", "pv[0][1] 11 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1998.59693165    , 1e+0, "gal_sgp4", "pv[0][2] 11 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.681032960      , 1e+0, "gal_sgp4", "pv[1][0] 11 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.527589301       , 1e+0, "gal_sgp4", "pv[1][1] 11 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.452951429       , 1e+0, "gal_sgp4", "pv[1][2] 11 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 194.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1877.98944331    , 1e+0, "gal_sgp4", "pv[0][0] 11 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3862.27848302     , 1e+0, "gal_sgp4", "pv[0][1] 11 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5112.48435863     , 1e+0, "gal_sgp4", "pv[0][2] 11 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.261489804      , 1e+0, "gal_sgp4", "pv[1][0] 11 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.026859137      , 1e+0, "gal_sgp4", "pv[1][1] 11 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.433254768       , 1e+0, "gal_sgp4", "pv[1][2] 11 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 214.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3117.36584395    , 1e+0, "gal_sgp4", "pv[0][0] 11 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4419.74773864    , 1e+0, "gal_sgp4", "pv[0][1] 11 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3840.85960912     , 1e+0, "gal_sgp4", "pv[0][2] 11 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.545479182       , 1e+0, "gal_sgp4", "pv[1][0] 11 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.475416581      , 1e+0, "gal_sgp4", "pv[1][1] 11 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.207913748      , 1e+0, "gal_sgp4", "pv[1][2] 11 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 234.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 815.32034678      , 1e+0, "gal_sgp4", "pv[0][0] 11 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5231.67692249    , 1e+0, "gal_sgp4", "pv[0][1] 11 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3760.04690354    , 1e+0, "gal_sgp4", "pv[0][2] 11 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.870864200       , 1e+0, "gal_sgp4", "pv[1][0] 11 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.455588552       , 1e+0, "gal_sgp4", "pv[1][1] 11 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.211082191      , 1e+0, "gal_sgp4", "pv[1][2] 11 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 254.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3269.54341810     , 1e+0, "gal_sgp4", "pv[0][0] 11 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3029.00081083     , 1e+0, "gal_sgp4", "pv[0][1] 11 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4704.67969713    , 1e+0, "gal_sgp4", "pv[0][2] 11 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.526711345      , 1e+0, "gal_sgp4", "pv[1][0] 11 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.812157950       , 1e+0, "gal_sgp4", "pv[1][1] 11 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.929825087       , 1e+0, "gal_sgp4", "pv[1][2] 11 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 274.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -10.18099756      , 1e+0, "gal_sgp4", "pv[0][0] 11 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6026.23341453     , 1e+0, "gal_sgp4", "pv[0][1] 11 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2643.50518407     , 1e+0, "gal_sgp4", "pv[0][2] 11 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.953623254      , 1e+0, "gal_sgp4", "pv[1][0] 11 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.616070012      , 1e+0, "gal_sgp4", "pv[1][1] 11 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.145637500       , 1e+0, "gal_sgp4", "pv[1][2] 11 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 294.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3320.58819584    , 1e+0, "gal_sgp4", "pv[0][0] 11 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1248.42679945    , 1e+0, "gal_sgp4", "pv[0][1] 11 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5563.06017927     , 1e+0, "gal_sgp4", "pv[0][2] 11 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.637046974      , 1e+0, "gal_sgp4", "pv[1][0] 11 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.417786044      , 1e+0, "gal_sgp4", "pv[1][1] 11 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.076120187      , 1e+0, "gal_sgp4", "pv[1][2] 11 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 314.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1025.48974616    , 1e+0, "gal_sgp4", "pv[0][0] 11 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6366.98945782    , 1e+0, "gal_sgp4", "pv[0][1] 11 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -911.23559153     , 1e+0, "gal_sgp4", "pv[0][2] 11 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.811771909       , 1e+0, "gal_sgp4", "pv[1][0] 11 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.438071490       , 1e+0, "gal_sgp4", "pv[1][1] 11 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.829260617      , 1e+0, "gal_sgp4", "pv[1][2] 11 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 334.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3003.75996128     , 1e+0, "gal_sgp4", "pv[0][0] 11 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -413.85708003     , 1e+0, "gal_sgp4", "pv[0][1] 11 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5706.15591435    , 1e+0, "gal_sgp4", "pv[0][2] 11 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.674350083       , 1e+0, "gal_sgp4", "pv[1][0] 11 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 7.694169068       , 1e+0, "gal_sgp4", "pv[1][1] 11 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.316915204       , 1e+0, "gal_sgp4", "pv[1][2] 11 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 354.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1731.42816980     , 1e+0, "gal_sgp4", "pv[0][0] 11 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6258.27676925     , 1e+0, "gal_sgp4", "pv[0][1] 11 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -409.32527982     , 1e+0, "gal_sgp4", "pv[0][2] 11 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.400497806      , 1e+0, "gal_sgp4", "pv[1][0] 11 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.447945424       , 1e+0, "gal_sgp4", "pv[1][1] 11 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.904010052       , 1e+0, "gal_sgp4", "pv[1][2] 11 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 374.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2582.52111460    , 1e+0, "gal_sgp4", "pv[0][0] 11 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2024.19020680     , 1e+0, "gal_sgp4", "pv[0][1] 11 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5647.55650268     , 1e+0, "gal_sgp4", "pv[0][2] 11 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.530348121      , 1e+0, "gal_sgp4", "pv[1][0] 11 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.221719393      , 1e+0, "gal_sgp4", "pv[1][1] 11 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.438141553       , 1e+0, "gal_sgp4", "pv[1][2] 11 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 394.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2440.56848578    , 1e+0, "gal_sgp4", "pv[0][0] 11 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5702.77311877    , 1e+0, "gal_sgp4", "pv[0][1] 11 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1934.81094689     , 1e+0, "gal_sgp4", "pv[0][2] 11 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.731792947       , 1e+0, "gal_sgp4", "pv[1][0] 11 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.350576075      , 1e+0, "gal_sgp4", "pv[1][1] 11 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.527773339      , 1e+0, "gal_sgp4", "pv[1][2] 11 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 414.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1951.22934391     , 1e+0, "gal_sgp4", "pv[0][0] 11 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3423.59443045    , 1e+0, "gal_sgp4", "pv[0][1] 11 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5121.67808201    , 1e+0, "gal_sgp4", "pv[0][2] 11 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.249039133       , 1e+0, "gal_sgp4", "pv[1][0] 11 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.465974362       , 1e+0, "gal_sgp4", "pv[1][1] 11 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.069806659      , 1e+0, "gal_sgp4", "pv[1][2] 11 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 434.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2886.50939356     , 1e+0, "gal_sgp4", "pv[0][0] 11 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4888.68626216     , 1e+0, "gal_sgp4", "pv[0][1] 11 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3096.29885989    , 1e+0, "gal_sgp4", "pv[0][2] 11 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.973162139      , 1e+0, "gal_sgp4", "pv[1][0] 11 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.877039020       , 1e+0, "gal_sgp4", "pv[1][1] 11 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.832414910       , 1e+0, "gal_sgp4", "pv[1][2] 11 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 454.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1276.55532182    , 1e+0, "gal_sgp4", "pv[0][0] 11 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4553.26898463     , 1e+0, "gal_sgp4", "pv[0][1] 11 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4406.19787375     , 1e+0, "gal_sgp4", "pv[0][2] 11 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.715146421      , 1e+0, "gal_sgp4", "pv[1][0] 11 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.320176914      , 1e+0, "gal_sgp4", "pv[1][1] 11 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.418210777       , 1e+0, "gal_sgp4", "pv[1][2] 11 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 474.20286720 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3181.54698042    , 1e+0, "gal_sgp4", "pv[0][0] 11 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3831.29976506    , 1e+0, "gal_sgp4", "pv[0][1] 11 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4096.80242787     , 1e+0, "gal_sgp4", "pv[0][2] 11 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.114159970       , 1e+0, "gal_sgp4", "pv[1][0] 11 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.104773578      , 1e+0, "gal_sgp4", "pv[1][1] 11 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.829967400      , 1e+0, "gal_sgp4", "pv[1][2] 11 22" ) ;  

/*
 * SL-6 R/B(2) 12h resonant ecc in the > 0.715 range  
 */  

  strcpy ( card1, "1 22674U 93035D   06176.55909107  .00002121  00000-0  29868-3 0  6569" ) ;  
  strcpy ( card2, "2 22674  63.5035 354.4452 7541712 253.3264  18.7754  1.96679808 93877" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14712.22023280    , 1e+0, "gal_sgp4", "pv[0][0] 12 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1443.81061850    , 1e+0, "gal_sgp4", "pv[0][1] 12 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 0.83497888        , 1e+0, "gal_sgp4", "pv[0][2] 12 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.418965470       , 1e+0, "gal_sgp4", "pv[1][0] 12 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.629592098       , 1e+0, "gal_sgp4", "pv[1][1] 12 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.115531802       , 1e+0, "gal_sgp4", "pv[1][2] 12 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 25418.88807860    , 1e+0, "gal_sgp4", "pv[0][0] 12 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9342.60307989     , 1e+0, "gal_sgp4", "pv[0][1] 12 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 23611.46690798    , 1e+0, "gal_sgp4", "pv[0][2] 12 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.051284086       , 1e+0, "gal_sgp4", "pv[1][0] 12 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.213127306       , 1e+0, "gal_sgp4", "pv[1][1] 12 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.429004159       , 1e+0, "gal_sgp4", "pv[1][2] 12 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 21619.59550749    , 1e+0, "gal_sgp4", "pv[0][0] 12 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 16125.24978864    , 1e+0, "gal_sgp4", "pv[0][1] 12 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 36396.79365831    , 1e+0, "gal_sgp4", "pv[0][2] 12 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.963604380      , 1e+0, "gal_sgp4", "pv[1][0] 12 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.685454965       , 1e+0, "gal_sgp4", "pv[1][1] 12 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.177181937       , 1e+0, "gal_sgp4", "pv[1][2] 12 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 12721.50543331    , 1e+0, "gal_sgp4", "pv[0][0] 12 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19258.96193362    , 1e+0, "gal_sgp4", "pv[0][1] 12 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40898.47648359    , 1e+0, "gal_sgp4", "pv[0][2] 12 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.457448565      , 1e+0, "gal_sgp4", "pv[1][0] 12 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.179955469       , 1e+0, "gal_sgp4", "pv[1][1] 12 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.071502601       , 1e+0, "gal_sgp4", "pv[1][2] 12 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1272.80760054     , 1e+0, "gal_sgp4", "pv[0][0] 12 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18458.41971897    , 1e+0, "gal_sgp4", "pv[0][1] 12 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 37044.74742696    , 1e+0, "gal_sgp4", "pv[0][2] 12 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.674863386      , 1e+0, "gal_sgp4", "pv[1][0] 12 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.436454983      , 1e+0, "gal_sgp4", "pv[1][1] 12 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.201040990      , 1e+0, "gal_sgp4", "pv[1][2] 12 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -10058.43188619   , 1e+0, "gal_sgp4", "pv[0][0] 12 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 11906.60764454    , 1e+0, "gal_sgp4", "pv[0][1] 12 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 21739.62097733    , 1e+0, "gal_sgp4", "pv[0][2] 12 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.245829683      , 1e+0, "gal_sgp4", "pv[1][0] 12 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.543789125      , 1e+0, "gal_sgp4", "pv[1][1] 12 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.324449221      , 1e+0, "gal_sgp4", "pv[1][2] 12 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 10924.40116466    , 1e+0, "gal_sgp4", "pv[0][0] 12 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2571.92414170    , 1e+0, "gal_sgp4", "pv[0][1] 12 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2956.34856294    , 1e+0, "gal_sgp4", "pv[0][2] 12 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.071727751       , 1e+0, "gal_sgp4", "pv[1][0] 12 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.349579102       , 1e+0, "gal_sgp4", "pv[1][1] 12 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.898430260       , 1e+0, "gal_sgp4", "pv[1][2] 12 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 25332.14851525    , 1e+0, "gal_sgp4", "pv[0][0] 12 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 8398.91099924     , 1e+0, "gal_sgp4", "pv[0][1] 12 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 21783.90654357    , 1e+0, "gal_sgp4", "pv[0][2] 12 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.222320754       , 1e+0, "gal_sgp4", "pv[1][0] 12 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.272214306       , 1e+0, "gal_sgp4", "pv[1][1] 12 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.580527192       , 1e+0, "gal_sgp4", "pv[1][2] 12 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 22317.71926039    , 1e+0, "gal_sgp4", "pv[0][0] 12 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15574.82086129    , 1e+0, "gal_sgp4", "pv[0][1] 12 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 35495.77144092    , 1e+0, "gal_sgp4", "pv[0][2] 12 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.892750056      , 1e+0, "gal_sgp4", "pv[1][0] 12 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.737383381       , 1e+0, "gal_sgp4", "pv[1][1] 12 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.291738834       , 1e+0, "gal_sgp4", "pv[1][2] 12 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13795.68675885    , 1e+0, "gal_sgp4", "pv[0][0] 12 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19088.83051008    , 1e+0, "gal_sgp4", "pv[0][1] 12 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40803.69584385    , 1e+0, "gal_sgp4", "pv[0][2] 12 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.420277669      , 1e+0, "gal_sgp4", "pv[1][0] 12 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.235599456       , 1e+0, "gal_sgp4", "pv[1][1] 12 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.185517056       , 1e+0, "gal_sgp4", "pv[1][2] 12 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2515.17145049     , 1e+0, "gal_sgp4", "pv[0][0] 12 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18746.63776282    , 1e+0, "gal_sgp4", "pv[0][1] 12 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 37864.58088636    , 1e+0, "gal_sgp4", "pv[0][2] 12 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.668016053      , 1e+0, "gal_sgp4", "pv[1][0] 12 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.360431458      , 1e+0, "gal_sgp4", "pv[1][1] 12 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.052854596      , 1e+0, "gal_sgp4", "pv[1][2] 12 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9084.48602106    , 1e+0, "gal_sgp4", "pv[0][0] 12 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 12982.62608646    , 1e+0, "gal_sgp4", "pv[0][1] 12 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 24045.63900249    , 1e+0, "gal_sgp4", "pv[0][2] 12 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.378032363      , 1e+0, "gal_sgp4", "pv[1][0] 12 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.373184736      , 1e+0, "gal_sgp4", "pv[1][1] 12 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.013963835      , 1e+0, "gal_sgp4", "pv[1][2] 12 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5647.00909495     , 1e+0, "gal_sgp4", "pv[0][0] 12 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3293.90518693    , 1e+0, "gal_sgp4", "pv[0][1] 12 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5425.85235063    , 1e+0, "gal_sgp4", "pv[0][2] 12 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 8.507977176       , 1e+0, "gal_sgp4", "pv[1][0] 12 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.414560797       , 1e+0, "gal_sgp4", "pv[1][1] 12 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.543322806       , 1e+0, "gal_sgp4", "pv[1][2] 12 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 25111.63372210    , 1e+0, "gal_sgp4", "pv[0][0] 12 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 7412.55109488     , 1e+0, "gal_sgp4", "pv[0][1] 12 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 19844.25781729    , 1e+0, "gal_sgp4", "pv[0][2] 12 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.416496290       , 1e+0, "gal_sgp4", "pv[1][0] 12 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.332106006       , 1e+0, "gal_sgp4", "pv[1][1] 12 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.739301737       , 1e+0, "gal_sgp4", "pv[1][2] 12 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 22961.47461641    , 1e+0, "gal_sgp4", "pv[0][0] 12 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 14985.74459578    , 1e+0, "gal_sgp4", "pv[0][1] 12 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 34511.09257381    , 1e+0, "gal_sgp4", "pv[0][2] 12 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.816711048      , 1e+0, "gal_sgp4", "pv[1][0] 12 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.789391108       , 1e+0, "gal_sgp4", "pv[1][1] 12 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.407901804       , 1e+0, "gal_sgp4", "pv[1][2] 12 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14841.15301459    , 1e+0, "gal_sgp4", "pv[0][0] 12 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18876.91439870    , 1e+0, "gal_sgp4", "pv[0][1] 12 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40626.25901619    , 1e+0, "gal_sgp4", "pv[0][2] 12 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.380403341      , 1e+0, "gal_sgp4", "pv[1][0] 12 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.290228810       , 1e+0, "gal_sgp4", "pv[1][1] 12 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.298258120       , 1e+0, "gal_sgp4", "pv[1][2] 12 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3750.70174081     , 1e+0, "gal_sgp4", "pv[0][0] 12 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18978.57939698    , 1e+0, "gal_sgp4", "pv[0][1] 12 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 38578.11783220    , 1e+0, "gal_sgp4", "pv[0][2] 12 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.656939412      , 1e+0, "gal_sgp4", "pv[1][0] 12 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.287930881      , 1e+0, "gal_sgp4", "pv[1][1] 12 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.910825599      , 1e+0, "gal_sgp4", "pv[1][2] 12 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8027.30219489    , 1e+0, "gal_sgp4", "pv[0][0] 12 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 13939.54436955    , 1e+0, "gal_sgp4", "pv[0][1] 12 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 26136.49045637    , 1e+0, "gal_sgp4", "pv[0][2] 12 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.474476061      , 1e+0, "gal_sgp4", "pv[1][0] 12 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.222693624      , 1e+0, "gal_sgp4", "pv[1][1] 12 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.737178731      , 1e+0, "gal_sgp4", "pv[1][2] 12 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1296.95657092    , 1e+0, "gal_sgp4", "pv[0][0] 12 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2813.69369768    , 1e+0, "gal_sgp4", "pv[0][1] 12 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5871.09587258    , 1e+0, "gal_sgp4", "pv[0][2] 12 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 9.881929371       , 1e+0, "gal_sgp4", "pv[1][0] 12 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.978467207      , 1e+0, "gal_sgp4", "pv[1][1] 12 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.922261005      , 1e+0, "gal_sgp4", "pv[1][2] 12 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 24738.60364819    , 1e+0, "gal_sgp4", "pv[0][0] 12 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6383.41644019     , 1e+0, "gal_sgp4", "pv[0][1] 12 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 17787.27631900    , 1e+0, "gal_sgp4", "pv[0][2] 12 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.639556952       , 1e+0, "gal_sgp4", "pv[1][0] 12 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.392554379       , 1e+0, "gal_sgp4", "pv[1][1] 12 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.906206324       , 1e+0, "gal_sgp4", "pv[1][2] 12 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 23546.85388669    , 1e+0, "gal_sgp4", "pv[0][0] 12 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 14358.15602832    , 1e+0, "gal_sgp4", "pv[0][1] 12 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 33441.67679479    , 1e+0, "gal_sgp4", "pv[0][2] 12 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.734895006      , 1e+0, "gal_sgp4", "pv[1][0] 12 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.841564851       , 1e+0, "gal_sgp4", "pv[1][1] 12 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.526009909       , 1e+0, "gal_sgp4", "pv[1][2] 12 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 15855.87696303    , 1e+0, "gal_sgp4", "pv[0][0] 12 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18624.05633582    , 1e+0, "gal_sgp4", "pv[0][1] 12 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 40367.13420574    , 1e+0, "gal_sgp4", "pv[0][2] 12 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.337753546      , 1e+0, "gal_sgp4", "pv[1][0] 12 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.343969522       , 1e+0, "gal_sgp4", "pv[1][1] 12 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.410018472       , 1e+0, "gal_sgp4", "pv[1][2] 12 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4976.44933591     , 1e+0, "gal_sgp4", "pv[0][0] 12 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19156.75504042    , 1e+0, "gal_sgp4", "pv[0][1] 12 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 39189.68603184    , 1e+0, "gal_sgp4", "pv[0][2] 12 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.642084365      , 1e+0, "gal_sgp4", "pv[1][0] 12 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.218525096      , 1e+0, "gal_sgp4", "pv[1][1] 12 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.774148204      , 1e+0, "gal_sgp4", "pv[1][2] 12 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -6909.20746210    , 1e+0, "gal_sgp4", "pv[0][0] 12 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 14790.44707042    , 1e+0, "gal_sgp4", "pv[0][1] 12 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 28034.46732222    , 1e+0, "gal_sgp4", "pv[0][2] 12 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.545152610      , 1e+0, "gal_sgp4", "pv[1][0] 12 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.088119523      , 1e+0, "gal_sgp4", "pv[1][1] 12 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.487447214      , 1e+0, "gal_sgp4", "pv[1][2] 12 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -7331.65006707    , 1e+0, "gal_sgp4", "pv[0][0] 12 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -604.17323419     , 1e+0, "gal_sgp4", "pv[0][1] 12 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2723.51014575    , 1e+0, "gal_sgp4", "pv[0][2] 12 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.168997265       , 1e+0, "gal_sgp4", "pv[1][0] 12 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.634011554      , 1e+0, "gal_sgp4", "pv[1][1] 12 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.963531682      , 1e+0, "gal_sgp4", "pv[1][2] 12 24" ) ;  

/*
 * ARIANE 44L+ R/B Lyddane bug at <= 70 min for atan2(),  
 */  

/*
 * no quadrant fix  
 */  

  strcpy ( card1, "1 23177U 94040C   06175.45752052  .00000386  00000-0  76590-3 0    95" ) ;  
  strcpy ( card2, "2 23177   7.0496 179.8238 7258491 296.0482   8.3061  2.25906668 97438" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8801.60046706    , 1e+0, "gal_sgp4", "pv[0][0] 13 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -0.03357557       , 1e+0, "gal_sgp4", "pv[0][1] 13 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -0.44522743       , 1e+0, "gal_sgp4", "pv[0][2] 13 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.835279101      , 1e+0, "gal_sgp4", "pv[1][0] 13 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.662552175      , 1e+0, "gal_sgp4", "pv[1][1] 13 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.944561323       , 1e+0, "gal_sgp4", "pv[1][2] 13 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1684.34352858    , 1e+0, "gal_sgp4", "pv[0][0] 13 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -31555.95196340   , 1e+0, "gal_sgp4", "pv[0][1] 13 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3888.99944319     , 1e+0, "gal_sgp4", "pv[0][2] 13 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.023055719       , 1e+0, "gal_sgp4", "pv[1][0] 13 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.151306405      , 1e+0, "gal_sgp4", "pv[1][1] 13 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.265065778       , 1e+0, "gal_sgp4", "pv[1][2] 13 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 12325.51410155    , 1e+0, "gal_sgp4", "pv[0][0] 13 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -38982.15046244   , 1e+0, "gal_sgp4", "pv[0][1] 13 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4802.88832275     , 1e+0, "gal_sgp4", "pv[0][2] 13 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.763224157       , 1e+0, "gal_sgp4", "pv[1][0] 13 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.102514446      , 1e+0, "gal_sgp4", "pv[1][1] 13 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.012397139       , 1e+0, "gal_sgp4", "pv[1][2] 13 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 22773.66831936    , 1e+0, "gal_sgp4", "pv[0][0] 13 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -34348.02176606   , 1e+0, "gal_sgp4", "pv[0][1] 13 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4228.77407391     , 1e+0, "gal_sgp4", "pv[0][2] 13 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.067616787       , 1e+0, "gal_sgp4", "pv[1][0] 13 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.352427865       , 1e+0, "gal_sgp4", "pv[1][1] 13 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.166956367      , 1e+0, "gal_sgp4", "pv[1][2] 13 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 26194.40441089    , 1e+0, "gal_sgp4", "pv[0][0] 13 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19482.94203672   , 1e+0, "gal_sgp4", "pv[0][1] 13 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2393.84774063     , 1e+0, "gal_sgp4", "pv[0][2] 13 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.313732186      , 1e+0, "gal_sgp4", "pv[1][0] 13 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.808771328       , 1e+0, "gal_sgp4", "pv[1][1] 13 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.346204118      , 1e+0, "gal_sgp4", "pv[1][2] 13 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8893.50573448     , 1e+0, "gal_sgp4", "pv[0][0] 13 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5763.38890561     , 1e+0, "gal_sgp4", "pv[0][1] 13 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -713.69884164     , 1e+0, "gal_sgp4", "pv[0][2] 13 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -7.037399220      , 1e+0, "gal_sgp4", "pv[1][0] 13 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.022613131       , 1e+0, "gal_sgp4", "pv[1][1] 13 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.370272416      , 1e+0, "gal_sgp4", "pv[1][2] 13 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -6028.75686537    , 1e+0, "gal_sgp4", "pv[0][0] 13 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -25648.99913786   , 1e+0, "gal_sgp4", "pv[0][1] 13 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3164.37107274     , 1e+0, "gal_sgp4", "pv[0][2] 13 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.883159288       , 1e+0, "gal_sgp4", "pv[1][0] 13 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.177051976      , 1e+0, "gal_sgp4", "pv[1][1] 13 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.390793162       , 1e+0, "gal_sgp4", "pv[1][2] 13 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8313.57299056     , 1e+0, "gal_sgp4", "pv[0][0] 13 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -38146.45710922   , 1e+0, "gal_sgp4", "pv[0][1] 13 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4697.80777535     , 1e+0, "gal_sgp4", "pv[0][2] 13 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.905002133       , 1e+0, "gal_sgp4", "pv[1][0] 13 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.625883074      , 1e+0, "gal_sgp4", "pv[1][1] 13 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.076098187       , 1e+0, "gal_sgp4", "pv[1][2] 13 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 20181.29108622    , 1e+0, "gal_sgp4", "pv[0][0] 13 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -36842.60674073   , 1e+0, "gal_sgp4", "pv[0][1] 13 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4529.12568218     , 1e+0, "gal_sgp4", "pv[0][2] 13 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.326244476       , 1e+0, "gal_sgp4", "pv[1][0] 13 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.921916487       , 1e+0, "gal_sgp4", "pv[1][1] 13 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.114527455      , 1e+0, "gal_sgp4", "pv[1][2] 13 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 26302.61794569    , 1e+0, "gal_sgp4", "pv[0][0] 13 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -25173.39539436   , 1e+0, "gal_sgp4", "pv[0][1] 13 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3084.65309986     , 1e+0, "gal_sgp4", "pv[0][2] 13 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.245398835       , 1e+0, "gal_sgp4", "pv[1][0] 13 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.329974347       , 1e+0, "gal_sgp4", "pv[1][1] 13 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.287495880      , 1e+0, "gal_sgp4", "pv[1][2] 13 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19365.07045602    , 1e+0, "gal_sgp4", "pv[0][0] 13 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2700.00490122    , 1e+0, "gal_sgp4", "pv[0][1] 13 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 317.42727417      , 1e+0, "gal_sgp4", "pv[0][2] 13 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.009733018      , 1e+0, "gal_sgp4", "pv[1][0] 13 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.902496058       , 1e+0, "gal_sgp4", "pv[1][1] 13 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.478928582      , 1e+0, "gal_sgp4", "pv[1][2] 13 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9667.81878780    , 1e+0, "gal_sgp4", "pv[0][0] 13 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -16930.19112642   , 1e+0, "gal_sgp4", "pv[0][1] 13 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2095.87469034     , 1e+0, "gal_sgp4", "pv[0][2] 13 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.279288285       , 1e+0, "gal_sgp4", "pv[1][0] 13 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.736005905      , 1e+0, "gal_sgp4", "pv[1][1] 13 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.582878255       , 1e+0, "gal_sgp4", "pv[1][2] 13 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4021.31438583     , 1e+0, "gal_sgp4", "pv[0][0] 13 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -36066.09209609   , 1e+0, "gal_sgp4", "pv[0][1] 13 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4442.91587411     , 1e+0, "gal_sgp4", "pv[0][2] 13 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.007322354       , 1e+0, "gal_sgp4", "pv[1][0] 13 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.227461376      , 1e+0, "gal_sgp4", "pv[1][1] 13 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.149383897       , 1e+0, "gal_sgp4", "pv[1][2] 13 12" ) ;  

/*
 * WIND STR3 Kepler failes past about 200 min  
 */  

  strcpy ( card1, "1 23333U 94071A   94305.49999999 -.00172956  26967-3  10000-3 0    15" ) ;  
  strcpy ( card2, "2 23333  28.7490   2.3720 9728298  30.4360   1.3500  0.07309491    70" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9301.24542292    , 1e+0, "gal_sgp4", "pv[0][0] 14 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3326.10200382     , 1e+0, "gal_sgp4", "pv[0][1] 14 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2318.36441127     , 1e+0, "gal_sgp4", "pv[0][2] 14 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -8.729303005      , 1e+0, "gal_sgp4", "pv[1][0] 14 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.828225037      , 1e+0, "gal_sgp4", "pv[1][1] 14 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.122314827      , 1e+0, "gal_sgp4", "pv[1][2] 14 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -44672.91239680   , 1e+0, "gal_sgp4", "pv[0][0] 14 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6213.11996581    , 1e+0, "gal_sgp4", "pv[0][1] 14 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1738.80131727    , 1e+0, "gal_sgp4", "pv[0][2] 14 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.719475070      , 1e+0, "gal_sgp4", "pv[1][0] 14 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.336673022      , 1e+0, "gal_sgp4", "pv[1][1] 14 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.621888261      , 1e+0, "gal_sgp4", "pv[1][2] 14 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -67053.08885388   , 1e+0, "gal_sgp4", "pv[0][0] 14 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -14994.69685946   , 1e+0, "gal_sgp4", "pv[0][1] 14 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5897.99072793    , 1e+0, "gal_sgp4", "pv[0][2] 14 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.860576613      , 1e+0, "gal_sgp4", "pv[1][0] 14 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.183771565      , 1e+0, "gal_sgp4", "pv[1][1] 14 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.568473909      , 1e+0, "gal_sgp4", "pv[1][2] 14 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -85227.84253168   , 1e+0, "gal_sgp4", "pv[0][0] 14 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22897.08484471   , 1e+0, "gal_sgp4", "pv[0][1] 14 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -9722.59184564    , 1e+0, "gal_sgp4", "pv[0][2] 14 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.426469823      , 1e+0, "gal_sgp4", "pv[1][0] 14 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.078592475      , 1e+0, "gal_sgp4", "pv[1][1] 14 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.525341431      , 1e+0, "gal_sgp4", "pv[1][2] 14 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -100986.00419136  , 1e+0, "gal_sgp4", "pv[0][0] 14 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -30171.19698695   , 1e+0, "gal_sgp4", "pv[0][1] 14 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -13283.77044765   , 1e+0, "gal_sgp4", "pv[0][2] 14 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.147108978      , 1e+0, "gal_sgp4", "pv[1][0] 14 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.000530827      , 1e+0, "gal_sgp4", "pv[1][1] 14 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.491587582      , 1e+0, "gal_sgp4", "pv[1][2] 14 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -115093.00686387  , 1e+0, "gal_sgp4", "pv[0][0] 14 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -36962.56316477   , 1e+0, "gal_sgp4", "pv[0][1] 14 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -16634.15682929   , 1e+0, "gal_sgp4", "pv[0][2] 14 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.945446188      , 1e+0, "gal_sgp4", "pv[1][0] 14 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.938947736      , 1e+0, "gal_sgp4", "pv[1][1] 14 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.464199202      , 1e+0, "gal_sgp4", "pv[1][2] 14 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -127965.80064891  , 1e+0, "gal_sgp4", "pv[0][0] 14 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -43363.32967165   , 1e+0, "gal_sgp4", "pv[0][1] 14 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -19809.90480432   , 1e+0, "gal_sgp4", "pv[0][2] 14 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.789652016      , 1e+0, "gal_sgp4", "pv[1][0] 14 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.888278463      , 1e+0, "gal_sgp4", "pv[1][1] 14 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.441254468      , 1e+0, "gal_sgp4", "pv[1][2] 14 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -139863.28332207  , 1e+0, "gal_sgp4", "pv[0][0] 14 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -49436.45704153   , 1e+0, "gal_sgp4", "pv[0][1] 14 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -22836.80438139   , 1e+0, "gal_sgp4", "pv[0][2] 14 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.663762568      , 1e+0, "gal_sgp4", "pv[1][0] 14 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.845315913      , 1e+0, "gal_sgp4", "pv[1][1] 14 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.421548627      , 1e+0, "gal_sgp4", "pv[1][2] 14 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -150960.22978259  , 1e+0, "gal_sgp4", "pv[0][0] 14 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -55227.45413896   , 1e+0, "gal_sgp4", "pv[0][1] 14 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -25734.01408879   , 1e+0, "gal_sgp4", "pv[0][2] 14 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.558730986      , 1e+0, "gal_sgp4", "pv[1][0] 14 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.808061065      , 1e+0, "gal_sgp4", "pv[1][1] 14 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.404293846      , 1e+0, "gal_sgp4", "pv[1][2] 14 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -161381.71414630  , 1e+0, "gal_sgp4", "pv[0][0] 14 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -60770.64040903   , 1e+0, "gal_sgp4", "pv[0][1] 14 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -28516.26290017   , 1e+0, "gal_sgp4", "pv[0][2] 14 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.468977174      , 1e+0, "gal_sgp4", "pv[1][0] 14 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.775190459      , 1e+0, "gal_sgp4", "pv[1][1] 14 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.388951810      , 1e+0, "gal_sgp4", "pv[1][2] 14 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -171221.18736947  , 1e+0, "gal_sgp4", "pv[0][0] 14 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -66092.76474442   , 1e+0, "gal_sgp4", "pv[0][1] 14 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -31195.19847387   , 1e+0, "gal_sgp4", "pv[0][2] 14 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.390837596      , 1e+0, "gal_sgp4", "pv[1][0] 14 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.745785633      , 1e+0, "gal_sgp4", "pv[1][1] 14 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.375140398      , 1e+0, "gal_sgp4", "pv[1][2] 14 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -180550.82888746  , 1e+0, "gal_sgp4", "pv[0][0] 14 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -71215.23290630   , 1e+0, "gal_sgp4", "pv[0][1] 14 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -33780.24938270   , 1e+0, "gal_sgp4", "pv[0][2] 14 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.321788672      , 1e+0, "gal_sgp4", "pv[1][0] 14 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.719184752      , 1e+0, "gal_sgp4", "pv[1][1] 14 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.362579495      , 1e+0, "gal_sgp4", "pv[1][2] 14 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -189427.87533074  , 1e+0, "gal_sgp4", "pv[0][0] 14 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -76155.54943344   , 1e+0, "gal_sgp4", "pv[0][1] 14 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -36279.19882816   , 1e+0, "gal_sgp4", "pv[0][2] 14 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.260024473      , 1e+0, "gal_sgp4", "pv[1][0] 14 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.694896053      , 1e+0, "gal_sgp4", "pv[1][1] 14 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.351058133      , 1e+0, "gal_sgp4", "pv[1][2] 14 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -197898.69401409  , 1e+0, "gal_sgp4", "pv[0][0] 14 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -80928.29015181   , 1e+0, "gal_sgp4", "pv[0][1] 14 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -38698.57972447   , 1e+0, "gal_sgp4", "pv[0][2] 14 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.204211888      , 1e+0, "gal_sgp4", "pv[1][0] 14 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.672544709      , 1e+0, "gal_sgp4", "pv[1][1] 14 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.340413731      , 1e+0, "gal_sgp4", "pv[1][2] 14 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -200638.82986236  , 1e+0, "gal_sgp4", "pv[0][0] 14 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -82484.14969882   , 1e+0, "gal_sgp4", "pv[0][1] 14 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -39488.34331447   , 1e+0, "gal_sgp4", "pv[0][2] 14 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.186748462      , 1e+0, "gal_sgp4", "pv[1][0] 14 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.665472422      , 1e+0, "gal_sgp4", "pv[1][1] 14 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.337037582      , 1e+0, "gal_sgp4", "pv[1][2] 14 14" ) ;  

/*
 * ARIANE 42P+3 R/B fig Lyddane bug at > 280.5 min for AcTan()  
 */  

  strcpy ( card1, "1 23599U 95029B   06171.76535463  .00085586  12891-6  12956-2 0  2905" ) ;  
  strcpy ( card2, "2 23599   6.9327   0.2849 5782022 274.4436  25.2425  4.47796565123555" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9892.63794341     , 1e+0, "gal_sgp4", "pv[0][0] 15 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 35.76144969       , 1e+0, "gal_sgp4", "pv[0][1] 15 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1.08228838       , 1e+0, "gal_sgp4", "pv[0][2] 15 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.556643237       , 1e+0, "gal_sgp4", "pv[1][0] 15 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.456009375       , 1e+0, "gal_sgp4", "pv[1][1] 15 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.783610890       , 1e+0, "gal_sgp4", "pv[1][2] 15 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 20.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11931.95642997    , 1e+0, "gal_sgp4", "pv[0][0] 15 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 7340.74973750     , 1e+0, "gal_sgp4", "pv[0][1] 15 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 886.46365987      , 1e+0, "gal_sgp4", "pv[0][2] 15 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.308329116       , 1e+0, "gal_sgp4", "pv[1][0] 15 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.532328972       , 1e+0, "gal_sgp4", "pv[1][1] 15 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.672887281       , 1e+0, "gal_sgp4", "pv[1][2] 15 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 40.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11321.71039205    , 1e+0, "gal_sgp4", "pv[0][0] 15 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 13222.84749156    , 1e+0, "gal_sgp4", "pv[0][1] 15 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1602.40119049     , 1e+0, "gal_sgp4", "pv[0][2] 15 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.151973982      , 1e+0, "gal_sgp4", "pv[1][0] 15 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.285810871       , 1e+0, "gal_sgp4", "pv[1][1] 15 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.521919425       , 1e+0, "gal_sgp4", "pv[1][2] 15 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 60.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9438.29395675     , 1e+0, "gal_sgp4", "pv[0][0] 15 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 17688.05450261    , 1e+0, "gal_sgp4", "pv[0][1] 15 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2146.59293402     , 1e+0, "gal_sgp4", "pv[0][2] 15 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.907904054      , 1e+0, "gal_sgp4", "pv[1][0] 15 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.179955046       , 1e+0, "gal_sgp4", "pv[1][1] 15 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.387692479       , 1e+0, "gal_sgp4", "pv[1][2] 15 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 80.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 6872.08634639     , 1e+0, "gal_sgp4", "pv[0][0] 15 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 20910.11016811    , 1e+0, "gal_sgp4", "pv[0][1] 15 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2539.79945034     , 1e+0, "gal_sgp4", "pv[0][2] 15 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.323995367      , 1e+0, "gal_sgp4", "pv[1][0] 15 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.207398462       , 1e+0, "gal_sgp4", "pv[1][1] 15 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.269506121       , 1e+0, "gal_sgp4", "pv[1][2] 15 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 100.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3933.37509798     , 1e+0, "gal_sgp4", "pv[0][0] 15 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 23024.07662542    , 1e+0, "gal_sgp4", "pv[0][1] 15 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2798.25966746     , 1e+0, "gal_sgp4", "pv[0][2] 15 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.542860616      , 1e+0, "gal_sgp4", "pv[1][0] 15 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.327134966       , 1e+0, "gal_sgp4", "pv[1][1] 15 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.162450076       , 1e+0, "gal_sgp4", "pv[1][2] 15 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 816.64091546      , 1e+0, "gal_sgp4", "pv[0][0] 15 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 24118.98675475    , 1e+0, "gal_sgp4", "pv[0][1] 15 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2932.69459428     , 1e+0, "gal_sgp4", "pv[0][2] 15 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.626838010      , 1e+0, "gal_sgp4", "pv[1][0] 15 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.504502763       , 1e+0, "gal_sgp4", "pv[1][1] 15 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.062344306       , 1e+0, "gal_sgp4", "pv[1][2] 15 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 140.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2334.41705804    , 1e+0, "gal_sgp4", "pv[0][0] 15 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 24246.86096326    , 1e+0, "gal_sgp4", "pv[0][1] 15 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2949.36448841     , 1e+0, "gal_sgp4", "pv[0][2] 15 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.602259646      , 1e+0, "gal_sgp4", "pv[1][0] 15 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.288058266      , 1e+0, "gal_sgp4", "pv[1][1] 15 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.034145135      , 1e+0, "gal_sgp4", "pv[1][2] 15 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5394.31798039    , 1e+0, "gal_sgp4", "pv[0][0] 15 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 23429.42716149    , 1e+0, "gal_sgp4", "pv[0][1] 15 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2850.86832586     , 1e+0, "gal_sgp4", "pv[0][2] 15 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.474434068      , 1e+0, "gal_sgp4", "pv[1][0] 15 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.074055982      , 1e+0, "gal_sgp4", "pv[1][1] 15 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.129868366      , 1e+0, "gal_sgp4", "pv[1][2] 15 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 180.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8233.35130237    , 1e+0, "gal_sgp4", "pv[0][0] 15 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 21661.24480883    , 1e+0, "gal_sgp4", "pv[0][1] 15 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2636.51456118     , 1e+0, "gal_sgp4", "pv[0][2] 15 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.230845533      , 1e+0, "gal_sgp4", "pv[1][0] 15 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.875742344      , 1e+0, "gal_sgp4", "pv[1][1] 15 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.227528603      , 1e+0, "gal_sgp4", "pv[1][2] 15 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -10693.96497348   , 1e+0, "gal_sgp4", "pv[0][0] 15 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18909.88168891    , 1e+0, "gal_sgp4", "pv[0][1] 15 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2302.33707548     , 1e+0, "gal_sgp4", "pv[0][2] 15 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.835912433      , 1e+0, "gal_sgp4", "pv[1][0] 15 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.716169865      , 1e+0, "gal_sgp4", "pv[1][1] 15 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.329931880      , 1e+0, "gal_sgp4", "pv[1][2] 15 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 220.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12553.89669904   , 1e+0, "gal_sgp4", "pv[0][0] 15 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15114.63990716    , 1e+0, "gal_sgp4", "pv[0][1] 15 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1840.93573231     , 1e+0, "gal_sgp4", "pv[0][2] 15 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.212478879      , 1e+0, "gal_sgp4", "pv[1][0] 15 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.619036996      , 1e+0, "gal_sgp4", "pv[1][1] 15 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.439970633      , 1e+0, "gal_sgp4", "pv[1][2] 15 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -13450.20591864   , 1e+0, "gal_sgp4", "pv[0][0] 15 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 10190.57904289    , 1e+0, "gal_sgp4", "pv[0][1] 15 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1241.95958736     , 1e+0, "gal_sgp4", "pv[0][2] 15 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.189082511      , 1e+0, "gal_sgp4", "pv[1][0] 15 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.596701971      , 1e+0, "gal_sgp4", "pv[1][1] 15 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.559173899      , 1e+0, "gal_sgp4", "pv[1][2] 15 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 260.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12686.60437121   , 1e+0, "gal_sgp4", "pv[0][0] 15 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4079.31106161     , 1e+0, "gal_sgp4", "pv[0][1] 15 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 498.27078614      , 1e+0, "gal_sgp4", "pv[0][2] 15 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.664498211       , 1e+0, "gal_sgp4", "pv[1][0] 15 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.559889865      , 1e+0, "gal_sgp4", "pv[1][1] 15 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.676747779      , 1e+0, "gal_sgp4", "pv[1][2] 15 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8672.55867753    , 1e+0, "gal_sgp4", "pv[0][0] 15 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2827.56823315    , 1e+0, "gal_sgp4", "pv[0][1] 15 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -342.59644716     , 1e+0, "gal_sgp4", "pv[0][2] 15 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.515079852       , 1e+0, "gal_sgp4", "pv[1][0] 15 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.551222962      , 1e+0, "gal_sgp4", "pv[1][1] 15 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.676360044      , 1e+0, "gal_sgp4", "pv[1][2] 15 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 300.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1153.31498060     , 1e+0, "gal_sgp4", "pv[0][0] 15 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6411.98692060    , 1e+0, "gal_sgp4", "pv[0][1] 15 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -779.87288941     , 1e+0, "gal_sgp4", "pv[0][2] 15 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 9.689818102       , 1e+0, "gal_sgp4", "pv[1][0] 15 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.388598425       , 1e+0, "gal_sgp4", "pv[1][1] 15 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.167868798       , 1e+0, "gal_sgp4", "pv[1][2] 15 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9542.79201056     , 1e+0, "gal_sgp4", "pv[0][0] 15 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -533.71253081     , 1e+0, "gal_sgp4", "pv[0][1] 15 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -65.73165428      , 1e+0, "gal_sgp4", "pv[0][2] 15 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.926947087       , 1e+0, "gal_sgp4", "pv[1][0] 15 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.459583539       , 1e+0, "gal_sgp4", "pv[1][1] 15 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.785686755       , 1e+0, "gal_sgp4", "pv[1][2] 15 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 340.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11868.80960100    , 1e+0, "gal_sgp4", "pv[0][0] 15 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6861.59590848     , 1e+0, "gal_sgp4", "pv[0][1] 15 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 833.72780602      , 1e+0, "gal_sgp4", "pv[0][2] 15 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.452957852       , 1e+0, "gal_sgp4", "pv[1][0] 15 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.632811328       , 1e+0, "gal_sgp4", "pv[1][1] 15 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.685262323       , 1e+0, "gal_sgp4", "pv[1][2] 15 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11376.23941678    , 1e+0, "gal_sgp4", "pv[0][0] 15 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 12858.97121366    , 1e+0, "gal_sgp4", "pv[0][1] 15 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1563.40660172     , 1e+0, "gal_sgp4", "pv[0][2] 15 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.087665695      , 1e+0, "gal_sgp4", "pv[1][0] 15 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.374693347       , 1e+0, "gal_sgp4", "pv[1][1] 15 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.532207051       , 1e+0, "gal_sgp4", "pv[1][2] 15 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 380.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9547.70300782     , 1e+0, "gal_sgp4", "pv[0][0] 15 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 17421.48570758    , 1e+0, "gal_sgp4", "pv[0][1] 15 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2118.56907515     , 1e+0, "gal_sgp4", "pv[0][2] 15 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.876540262      , 1e+0, "gal_sgp4", "pv[1][0] 15 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.253891728       , 1e+0, "gal_sgp4", "pv[1][1] 15 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.395810243       , 1e+0, "gal_sgp4", "pv[1][2] 15 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7008.51470263     , 1e+0, "gal_sgp4", "pv[0][0] 15 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 20725.47471227    , 1e+0, "gal_sgp4", "pv[0][1] 15 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2520.56064289     , 1e+0, "gal_sgp4", "pv[0][2] 15 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.308703599      , 1e+0, "gal_sgp4", "pv[1][0] 15 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.270724438       , 1e+0, "gal_sgp4", "pv[1][1] 15 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.276138613       , 1e+0, "gal_sgp4", "pv[1][2] 15 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 420.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4083.18551180     , 1e+0, "gal_sgp4", "pv[0][0] 15 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 22910.88306802    , 1e+0, "gal_sgp4", "pv[0][1] 15 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2786.35642660     , 1e+0, "gal_sgp4", "pv[0][2] 15 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.536610941      , 1e+0, "gal_sgp4", "pv[1][0] 15 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.383768875       , 1e+0, "gal_sgp4", "pv[1][1] 15 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.168165414       , 1e+0, "gal_sgp4", "pv[1][2] 15 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 970.13107533      , 1e+0, "gal_sgp4", "pv[0][0] 15 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 24071.19896282    , 1e+0, "gal_sgp4", "pv[0][1] 15 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2927.30875440     , 1e+0, "gal_sgp4", "pv[0][2] 15 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.626673095      , 1e+0, "gal_sgp4", "pv[1][0] 15 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.557274717       , 1e+0, "gal_sgp4", "pv[1][1] 15 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.067549303       , 1e+0, "gal_sgp4", "pv[1][2] 15 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 460.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2183.75499348    , 1e+0, "gal_sgp4", "pv[0][0] 15 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 24261.30188126    , 1e+0, "gal_sgp4", "pv[0][1] 15 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2950.09189560     , 1e+0, "gal_sgp4", "pv[0][2] 15 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.607082241      , 1e+0, "gal_sgp4", "pv[1][0] 15 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.236785937      , 1e+0, "gal_sgp4", "pv[1][1] 15 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.029112844      , 1e+0, "gal_sgp4", "pv[1][2] 15 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5252.49066783    , 1e+0, "gal_sgp4", "pv[0][0] 15 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 23505.58108388    , 1e+0, "gal_sgp4", "pv[0][1] 15 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2857.68628654     , 1e+0, "gal_sgp4", "pv[0][2] 15 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.484465059      , 1e+0, "gal_sgp4", "pv[1][0] 15 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.022158411      , 1e+0, "gal_sgp4", "pv[1][1] 15 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.124702643      , 1e+0, "gal_sgp4", "pv[1][2] 15 24" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 500.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8107.41437587    , 1e+0, "gal_sgp4", "pv[0][0] 15 25" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 21801.13395060    , 1e+0, "gal_sgp4", "pv[0][1] 15 25" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2649.76852683     , 1e+0, "gal_sgp4", "pv[0][2] 15 25" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.247669530      , 1e+0, "gal_sgp4", "pv[1][0] 15 25" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.821071275      , 1e+0, "gal_sgp4", "pv[1][1] 15 25" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.221914939      , 1e+0, "gal_sgp4", "pv[1][2] 15 25" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -10594.01813094   , 1e+0, "gal_sgp4", "pv[0][0] 15 26" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19118.22269010    , 1e+0, "gal_sgp4", "pv[0][1] 15 26" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2322.77197767     , 1e+0, "gal_sgp4", "pv[0][2] 15 26" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.863224062      , 1e+0, "gal_sgp4", "pv[1][0] 15 26" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.656353699      , 1e+0, "gal_sgp4", "pv[1][1] 15 26" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.323512642      , 1e+0, "gal_sgp4", "pv[1][2] 15 26" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 540.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12496.70758499   , 1e+0, "gal_sgp4", "pv[0][0] 15 27" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15399.13096351    , 1e+0, "gal_sgp4", "pv[0][1] 15 27" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1869.75958053     , 1e+0, "gal_sgp4", "pv[0][2] 15 27" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.258272118      , 1e+0, "gal_sgp4", "pv[1][0] 15 27" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.551534022      , 1e+0, "gal_sgp4", "pv[1][1] 15 27" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.432332913      , 1e+0, "gal_sgp4", "pv[1][2] 15 27" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -13467.50382653   , 1e+0, "gal_sgp4", "pv[0][0] 15 28" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 10561.43040038    , 1e+0, "gal_sgp4", "pv[0][1] 15 28" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1280.84842178     , 1e+0, "gal_sgp4", "pv[0][2] 15 28" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.272050695      , 1e+0, "gal_sgp4", "pv[1][0] 15 28" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.520503543      , 1e+0, "gal_sgp4", "pv[1][1] 15 28" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.550014833      , 1e+0, "gal_sgp4", "pv[1][2] 15 28" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 580.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12848.00717497   , 1e+0, "gal_sgp4", "pv[0][0] 15 29" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4541.72432009     , 1e+0, "gal_sgp4", "pv[0][1] 15 29" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 548.59976478      , 1e+0, "gal_sgp4", "pv[0][2] 15 29" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.493938056       , 1e+0, "gal_sgp4", "pv[1][0] 15 29" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.489644146      , 1e+0, "gal_sgp4", "pv[1][1] 15 29" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.667479244      , 1e+0, "gal_sgp4", "pv[1][2] 15 29" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9152.79920397    , 1e+0, "gal_sgp4", "pv[0][0] 15 30" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2343.88902799    , 1e+0, "gal_sgp4", "pv[0][1] 15 30" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -287.93741332     , 1e+0, "gal_sgp4", "pv[0][2] 15 30" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.127695273       , 1e+0, "gal_sgp4", "pv[1][0] 15 30" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.650584983      , 1e+0, "gal_sgp4", "pv[1][1] 15 30" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.686013644      , 1e+0, "gal_sgp4", "pv[1][2] 15 30" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 620.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 280.12478642      , 1e+0, "gal_sgp4", "pv[0][0] 15 31" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6500.11368508    , 1e+0, "gal_sgp4", "pv[0][1] 15 31" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -790.36236302     , 1e+0, "gal_sgp4", "pv[0][2] 15 31" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 9.779642904       , 1e+0, "gal_sgp4", "pv[1][0] 15 31" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.581430120       , 1e+0, "gal_sgp4", "pv[1][1] 15 31" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.074124421       , 1e+0, "gal_sgp4", "pv[1][2] 15 31" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9166.21406115     , 1e+0, "gal_sgp4", "pv[0][0] 15 32" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1093.48756223    , 1e+0, "gal_sgp4", "pv[0][1] 15 32" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -129.53833135     , 1e+0, "gal_sgp4", "pv[0][2] 15 32" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.316926785       , 1e+0, "gal_sgp4", "pv[1][0] 15 32" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.438465969       , 1e+0, "gal_sgp4", "pv[1][1] 15 32" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.785095966       , 1e+0, "gal_sgp4", "pv[1][2] 15 32" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 660.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11794.74563870    , 1e+0, "gal_sgp4", "pv[0][0] 15 33" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6381.74484842     , 1e+0, "gal_sgp4", "pv[0][1] 15 33" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 780.82775971      , 1e+0, "gal_sgp4", "pv[0][2] 15 33" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.604642523       , 1e+0, "gal_sgp4", "pv[1][0] 15 33" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.731705440       , 1e+0, "gal_sgp4", "pv[1][1] 15 33" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.697571522       , 1e+0, "gal_sgp4", "pv[1][2] 15 33" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 11424.80363789    , 1e+0, "gal_sgp4", "pv[0][0] 15 34" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 12493.80833338    , 1e+0, "gal_sgp4", "pv[0][1] 15 34" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1524.27683836     , 1e+0, "gal_sgp4", "pv[0][2] 15 34" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.021148661      , 1e+0, "gal_sgp4", "pv[1][0] 15 34" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.463489406       , 1e+0, "gal_sgp4", "pv[1][1] 15 34" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.542537702       , 1e+0, "gal_sgp4", "pv[1][2] 15 34" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 700.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9652.78920084     , 1e+0, "gal_sgp4", "pv[0][0] 15 35" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 17153.46470428    , 1e+0, "gal_sgp4", "pv[0][1] 15 35" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2090.43413681     , 1e+0, "gal_sgp4", "pv[0][2] 15 35" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.844382696      , 1e+0, "gal_sgp4", "pv[1][0] 15 35" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.327595388       , 1e+0, "gal_sgp4", "pv[1][1] 15 35" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.403924198       , 1e+0, "gal_sgp4", "pv[1][2] 15 35" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7141.24742526     , 1e+0, "gal_sgp4", "pv[0][0] 15 36" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 20538.97115158    , 1e+0, "gal_sgp4", "pv[0][1] 15 36" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2501.18059966     , 1e+0, "gal_sgp4", "pv[0][2] 15 36" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.293079623      , 1e+0, "gal_sgp4", "pv[1][0] 15 36" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.333598993       , 1e+0, "gal_sgp4", "pv[1][1] 15 36" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.282727441       , 1e+0, "gal_sgp4", "pv[1][2] 15 36" ) ;  

/*
 * ITALSAT 2 24h resonant GEO, inclination > 3 deg  
 */  

  strcpy ( card1, "1 24208U 96044A   06177.04061740 -.00000094  00000-0  10000-3 0  1600" ) ;  
  strcpy ( card2, "2 24208   3.8536  80.0121 0026640 311.0977  48.3000  1.00778054 36119" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7534.10987189     , 1e+0, "gal_sgp4", "pv[0][0] 16 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 41266.39266843    , 1e+0, "gal_sgp4", "pv[0][1] 16 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -0.10801028       , 1e+0, "gal_sgp4", "pv[0][2] 16 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.027168008      , 1e+0, "gal_sgp4", "pv[1][0] 16 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.558848996       , 1e+0, "gal_sgp4", "pv[1][1] 16 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.207982755       , 1e+0, "gal_sgp4", "pv[1][2] 16 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -14289.19940414   , 1e+0, "gal_sgp4", "pv[0][0] 16 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 39469.05530051    , 1e+0, "gal_sgp4", "pv[0][1] 16 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1428.62838591     , 1e+0, "gal_sgp4", "pv[0][2] 16 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.893205245      , 1e+0, "gal_sgp4", "pv[1][0] 16 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.045447840      , 1e+0, "gal_sgp4", "pv[1][1] 16 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.179634249       , 1e+0, "gal_sgp4", "pv[1][2] 16 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -32222.92014955   , 1e+0, "gal_sgp4", "pv[0][0] 16 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 26916.25425799    , 1e+0, "gal_sgp4", "pv[0][1] 16 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2468.59996594     , 1e+0, "gal_sgp4", "pv[0][2] 16 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.973007929      , 1e+0, "gal_sgp4", "pv[1][0] 16 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.359335071      , 1e+0, "gal_sgp4", "pv[1][1] 16 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.102539376       , 1e+0, "gal_sgp4", "pv[1][2] 16 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -41413.95109398   , 1e+0, "gal_sgp4", "pv[0][0] 16 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 7055.51656639     , 1e+0, "gal_sgp4", "pv[0][1] 16 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2838.90906671     , 1e+0, "gal_sgp4", "pv[0][2] 16 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.521665080      , 1e+0, "gal_sgp4", "pv[1][0] 16 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.029172207      , 1e+0, "gal_sgp4", "pv[1][1] 16 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.002066843      , 1e+0, "gal_sgp4", "pv[1][2] 16 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -39402.72251896   , 1e+0, "gal_sgp4", "pv[0][0] 16 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -14716.42475223   , 1e+0, "gal_sgp4", "pv[0][1] 16 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2441.32678358     , 1e+0, "gal_sgp4", "pv[0][2] 16 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.066928187       , 1e+0, "gal_sgp4", "pv[1][0] 16 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.878714619      , 1e+0, "gal_sgp4", "pv[1][1] 16 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.105865729      , 1e+0, "gal_sgp4", "pv[1][2] 16 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -26751.08889828   , 1e+0, "gal_sgp4", "pv[0][0] 16 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -32515.13982431   , 1e+0, "gal_sgp4", "pv[0][1] 16 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1384.38865570     , 1e+0, "gal_sgp4", "pv[0][2] 16 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.366228869       , 1e+0, "gal_sgp4", "pv[1][0] 16 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.951032799      , 1e+0, "gal_sgp4", "pv[1][1] 16 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.181018498      , 1e+0, "gal_sgp4", "pv[1][2] 16 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -6874.77975542    , 1e+0, "gal_sgp4", "pv[0][0] 16 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -41530.38329422   , 1e+0, "gal_sgp4", "pv[0][1] 16 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -46.60245459      , 1e+0, "gal_sgp4", "pv[0][2] 16 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.027415087       , 1e+0, "gal_sgp4", "pv[1][0] 16 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.494671177      , 1e+0, "gal_sgp4", "pv[1][1] 16 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.207337260      , 1e+0, "gal_sgp4", "pv[1][2] 16 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 14859.52039042    , 1e+0, "gal_sgp4", "pv[0][0] 16 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -39302.58907247   , 1e+0, "gal_sgp4", "pv[0][1] 16 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1465.02482524    , 1e+0, "gal_sgp4", "pv[0][2] 16 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.869609883       , 1e+0, "gal_sgp4", "pv[1][0] 16 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.100123969       , 1e+0, "gal_sgp4", "pv[1][1] 16 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.177514425      , 1e+0, "gal_sgp4", "pv[1][2] 16 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 32553.14863770    , 1e+0, "gal_sgp4", "pv[0][0] 16 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -26398.88401807   , 1e+0, "gal_sgp4", "pv[0][1] 16 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2485.45866002    , 1e+0, "gal_sgp4", "pv[0][2] 16 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.930064459       , 1e+0, "gal_sgp4", "pv[1][0] 16 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.401574539       , 1e+0, "gal_sgp4", "pv[1][1] 16 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.099250520      , 1e+0, "gal_sgp4", "pv[1][2] 16 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 41365.67576837    , 1e+0, "gal_sgp4", "pv[0][0] 16 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6298.09965811    , 1e+0, "gal_sgp4", "pv[0][1] 16 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2828.05254033    , 1e+0, "gal_sgp4", "pv[0][2] 16 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.459741276       , 1e+0, "gal_sgp4", "pv[1][0] 16 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.051680214       , 1e+0, "gal_sgp4", "pv[1][1] 16 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.006431872       , 1e+0, "gal_sgp4", "pv[1][2] 16 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 38858.83295070    , 1e+0, "gal_sgp4", "pv[0][0] 16 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15523.39314924    , 1e+0, "gal_sgp4", "pv[0][1] 16 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2396.86850752    , 1e+0, "gal_sgp4", "pv[0][2] 16 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.140211488      , 1e+0, "gal_sgp4", "pv[1][0] 16 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.867567143       , 1e+0, "gal_sgp4", "pv[1][1] 16 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.110637217       , 1e+0, "gal_sgp4", "pv[1][2] 16 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 25701.46068162    , 1e+0, "gal_sgp4", "pv[0][0] 16 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 33089.42617648    , 1e+0, "gal_sgp4", "pv[0][1] 16 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1308.68556638    , 1e+0, "gal_sgp4", "pv[0][2] 16 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.428713821      , 1e+0, "gal_sgp4", "pv[1][0] 16 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.897381431       , 1e+0, "gal_sgp4", "pv[1][1] 16 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.184605907       , 1e+0, "gal_sgp4", "pv[1][2] 16 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5501.08137100     , 1e+0, "gal_sgp4", "pv[0][0] 16 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 41590.27784405    , 1e+0, "gal_sgp4", "pv[0][1] 16 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 138.32522930      , 1e+0, "gal_sgp4", "pv[0][2] 16 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.050691874      , 1e+0, "gal_sgp4", "pv[1][0] 16 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.409203052       , 1e+0, "gal_sgp4", "pv[1][1] 16 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.207958133       , 1e+0, "gal_sgp4", "pv[1][2] 16 12" ) ;  

/*
 * AMC-4 fig low incl, show incl shift with  
 */  

/*
 * gsfc version from 240 to 1440 min  
 */  

  strcpy ( card1, "1 25954U 99060A   04039.68057285 -.00000108  00000-0  00000-0 0  6847" ) ;  
  strcpy ( card2, "2 25954   0.0004 243.8136 0001765  15.5294  22.7134  1.00271289 15615" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8827.15660472     , 1e+0, "gal_sgp4", "pv[0][0] 17 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -41223.00971237   , 1e+0, "gal_sgp4", "pv[0][1] 17 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3.63482963        , 1e+0, "gal_sgp4", "pv[0][2] 17 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.007087319       , 1e+0, "gal_sgp4", "pv[1][0] 17 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.643701323       , 1e+0, "gal_sgp4", "pv[1][1] 17 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000941663       , 1e+0, "gal_sgp4", "pv[1][2] 17 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8118.18519221     , 1e+0, "gal_sgp4", "pv[0][0] 17 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -41368.40537378   , 1e+0, "gal_sgp4", "pv[0][1] 17 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4.11046687        , 1e+0, "gal_sgp4", "pv[0][2] 17 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.017696741       , 1e+0, "gal_sgp4", "pv[1][0] 17 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.591994297       , 1e+0, "gal_sgp4", "pv[1][1] 17 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000933016       , 1e+0, "gal_sgp4", "pv[1][2] 17 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 27766.34015328    , 1e+0, "gal_sgp4", "pv[0][0] 17 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -31724.97000557   , 1e+0, "gal_sgp4", "pv[0][1] 17 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 9.93297846        , 1e+0, "gal_sgp4", "pv[0][2] 17 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.314236153       , 1e+0, "gal_sgp4", "pv[1][0] 17 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.024903193       , 1e+0, "gal_sgp4", "pv[1][1] 17 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000660861       , 1e+0, "gal_sgp4", "pv[1][2] 17 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 39932.57237973    , 1e+0, "gal_sgp4", "pv[0][0] 17 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -13532.60040454   , 1e+0, "gal_sgp4", "pv[0][1] 17 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 13.12958252       , 1e+0, "gal_sgp4", "pv[0][2] 17 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.987382819       , 1e+0, "gal_sgp4", "pv[1][0] 17 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.911942843       , 1e+0, "gal_sgp4", "pv[1][1] 17 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000213298       , 1e+0, "gal_sgp4", "pv[1][2] 17 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 41341.01365441    , 1e+0, "gal_sgp4", "pv[0][0] 17 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 8305.71681955     , 1e+0, "gal_sgp4", "pv[0][1] 17 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12.84988501       , 1e+0, "gal_sgp4", "pv[0][2] 17 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.605098224      , 1e+0, "gal_sgp4", "pv[1][0] 17 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.014378268       , 1e+0, "gal_sgp4", "pv[1][1] 17 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000291034      , 1e+0, "gal_sgp4", "pv[1][2] 17 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 31614.99210558    , 1e+0, "gal_sgp4", "pv[0][0] 17 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 27907.29155353    , 1e+0, "gal_sgp4", "pv[0][1] 17 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 9.16618797        , 1e+0, "gal_sgp4", "pv[0][2] 17 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.034243523      , 1e+0, "gal_sgp4", "pv[1][0] 17 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.305014102       , 1e+0, "gal_sgp4", "pv[1][1] 17 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000718418      , 1e+0, "gal_sgp4", "pv[1][2] 17 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 13375.75227587    , 1e+0, "gal_sgp4", "pv[0][0] 17 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 39994.27017651    , 1e+0, "gal_sgp4", "pv[0][1] 17 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3.05416854        , 1e+0, "gal_sgp4", "pv[0][2] 17 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.915424366      , 1e+0, "gal_sgp4", "pv[1][0] 17 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.975119874       , 1e+0, "gal_sgp4", "pv[1][1] 17 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000955576      , 1e+0, "gal_sgp4", "pv[1][2] 17 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8464.89963309    , 1e+0, "gal_sgp4", "pv[0][0] 17 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 41312.93549892    , 1e+0, "gal_sgp4", "pv[0][1] 17 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3.86622919       , 1e+0, "gal_sgp4", "pv[0][2] 17 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.011600615      , 1e+0, "gal_sgp4", "pv[1][0] 17 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.617275050      , 1e+0, "gal_sgp4", "pv[1][1] 17 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000939664      , 1e+0, "gal_sgp4", "pv[1][2] 17 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -28026.23406158   , 1e+0, "gal_sgp4", "pv[0][0] 17 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 31507.89995661    , 1e+0, "gal_sgp4", "pv[0][1] 17 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -9.76047869       , 1e+0, "gal_sgp4", "pv[0][2] 17 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.296840160      , 1e+0, "gal_sgp4", "pv[1][0] 17 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.043607595      , 1e+0, "gal_sgp4", "pv[1][1] 17 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000674889      , 1e+0, "gal_sgp4", "pv[1][2] 17 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -40040.01314363   , 1e+0, "gal_sgp4", "pv[0][0] 17 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 13218.00579413    , 1e+0, "gal_sgp4", "pv[0][1] 17 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -13.06594832      , 1e+0, "gal_sgp4", "pv[0][2] 17 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.963328772      , 1e+0, "gal_sgp4", "pv[1][0] 17 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.919827983      , 1e+0, "gal_sgp4", "pv[1][1] 17 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000231414      , 1e+0, "gal_sgp4", "pv[1][2] 17 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -41268.43291976   , 1e+0, "gal_sgp4", "pv[0][0] 17 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -8632.06859693    , 1e+0, "gal_sgp4", "pv[0][1] 17 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -12.90661266      , 1e+0, "gal_sgp4", "pv[0][2] 17 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.630042315       , 1e+0, "gal_sgp4", "pv[1][0] 17 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.009677376      , 1e+0, "gal_sgp4", "pv[1][1] 17 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000273163       , 1e+0, "gal_sgp4", "pv[1][2] 17 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -31377.85317015   , 1e+0, "gal_sgp4", "pv[0][0] 17 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -28156.13970334   , 1e+0, "gal_sgp4", "pv[0][1] 17 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -9.32605530       , 1e+0, "gal_sgp4", "pv[0][2] 17 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.054021717       , 1e+0, "gal_sgp4", "pv[1][0] 17 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.288554158      , 1e+0, "gal_sgp4", "pv[1][1] 17 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000704959       , 1e+0, "gal_sgp4", "pv[1][2] 17 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + -120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -13031.41552688   , 1e+0, "gal_sgp4", "pv[0][0] 17 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -40092.33381029   , 1e+0, "gal_sgp4", "pv[0][1] 17 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3.27636660       , 1e+0, "gal_sgp4", "pv[0][2] 17 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.924657466       , 1e+0, "gal_sgp4", "pv[1][0] 17 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.950541167      , 1e+0, "gal_sgp4", "pv[1][1] 17 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000949381       , 1e+0, "gal_sgp4", "pv[1][2] 17 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 8827.15660472     , 1e+0, "gal_sgp4", "pv[0][0] 17 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -41223.00971237   , 1e+0, "gal_sgp4", "pv[0][1] 17 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3.63482963        , 1e+0, "gal_sgp4", "pv[0][2] 17 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.007087319       , 1e+0, "gal_sgp4", "pv[1][0] 17 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.643701323       , 1e+0, "gal_sgp4", "pv[1][1] 17 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000941663       , 1e+0, "gal_sgp4", "pv[1][2] 17 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 28306.85426674    , 1e+0, "gal_sgp4", "pv[0][0] 17 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -31243.80147394   , 1e+0, "gal_sgp4", "pv[0][1] 17 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 9.57216891        , 1e+0, "gal_sgp4", "pv[0][2] 17 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.279137743       , 1e+0, "gal_sgp4", "pv[1][0] 17 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.064316875       , 1e+0, "gal_sgp4", "pv[1][1] 17 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000684127       , 1e+0, "gal_sgp4", "pv[1][2] 17 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 40159.05128805    , 1e+0, "gal_sgp4", "pv[0][0] 17 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -12845.39151157   , 1e+0, "gal_sgp4", "pv[0][1] 17 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12.96086316       , 1e+0, "gal_sgp4", "pv[0][2] 17 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.937265422       , 1e+0, "gal_sgp4", "pv[1][0] 17 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.928448287       , 1e+0, "gal_sgp4", "pv[1][1] 17 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000245505       , 1e+0, "gal_sgp4", "pv[1][2] 17 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 41192.55903455    , 1e+0, "gal_sgp4", "pv[0][0] 17 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 9013.79606759     , 1e+0, "gal_sgp4", "pv[0][1] 17 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 12.90495666       , 1e+0, "gal_sgp4", "pv[0][2] 17 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.656727442      , 1e+0, "gal_sgp4", "pv[1][0] 17 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.003543458       , 1e+0, "gal_sgp4", "pv[1][1] 17 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000257479      , 1e+0, "gal_sgp4", "pv[1][2] 17 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 31131.69755798    , 1e+0, "gal_sgp4", "pv[0][0] 17 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 28445.55681731    , 1e+0, "gal_sgp4", "pv[0][1] 17 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 9.42419238        , 1e+0, "gal_sgp4", "pv[0][2] 17 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.073484842      , 1e+0, "gal_sgp4", "pv[1][0] 17 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.269770851       , 1e+0, "gal_sgp4", "pv[1][1] 17 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000691233      , 1e+0, "gal_sgp4", "pv[1][2] 17 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 12687.81846530    , 1e+0, "gal_sgp4", "pv[0][0] 17 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 40217.83324639    , 1e+0, "gal_sgp4", "pv[0][1] 17 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3.44726249        , 1e+0, "gal_sgp4", "pv[0][2] 17 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.931721827      , 1e+0, "gal_sgp4", "pv[1][0] 17 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.924962230       , 1e+0, "gal_sgp4", "pv[1][1] 17 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000940766      , 1e+0, "gal_sgp4", "pv[1][2] 17 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9172.23500245    , 1e+0, "gal_sgp4", "pv[0][0] 17 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 41161.63475527    , 1e+0, "gal_sgp4", "pv[0][1] 17 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3.43575757       , 1e+0, "gal_sgp4", "pv[0][2] 17 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.000571486      , 1e+0, "gal_sgp4", "pv[1][0] 17 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.668847508      , 1e+0, "gal_sgp4", "pv[1][1] 17 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000940101      , 1e+0, "gal_sgp4", "pv[1][2] 17 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -28562.51093192   , 1e+0, "gal_sgp4", "pv[0][0] 17 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 31022.45987587    , 1e+0, "gal_sgp4", "pv[0][1] 17 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -9.39562161       , 1e+0, "gal_sgp4", "pv[0][2] 17 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.261449202      , 1e+0, "gal_sgp4", "pv[1][0] 17 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.082713897      , 1e+0, "gal_sgp4", "pv[1][1] 17 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000689669      , 1e+0, "gal_sgp4", "pv[1][2] 17 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -40260.77504549   , 1e+0, "gal_sgp4", "pv[0][0] 17 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 12529.11484344    , 1e+0, "gal_sgp4", "pv[0][1] 17 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -12.84915105      , 1e+0, "gal_sgp4", "pv[0][2] 17 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.913097031      , 1e+0, "gal_sgp4", "pv[1][0] 17 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.935933528      , 1e+0, "gal_sgp4", "pv[1][1] 17 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000256181      , 1e+0, "gal_sgp4", "pv[1][2] 17 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -41114.14376538   , 1e+0, "gal_sgp4", "pv[0][0] 17 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -9338.87194483    , 1e+0, "gal_sgp4", "pv[0][1] 17 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -12.87952404      , 1e+0, "gal_sgp4", "pv[0][2] 17 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.681588815       , 1e+0, "gal_sgp4", "pv[1][0] 17 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.998432565      , 1e+0, "gal_sgp4", "pv[1][1] 17 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000245006       , 1e+0, "gal_sgp4", "pv[1][2] 17 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -30890.01512240   , 1e+0, "gal_sgp4", "pv[0][0] 17 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -28690.40750792   , 1e+0, "gal_sgp4", "pv[0][1] 17 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -9.48037212       , 1e+0, "gal_sgp4", "pv[0][2] 17 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.092989805       , 1e+0, "gal_sgp4", "pv[1][0] 17 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.252978152      , 1e+0, "gal_sgp4", "pv[1][1] 17 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000680459       , 1e+0, "gal_sgp4", "pv[1][2] 17 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -12341.46194020   , 1e+0, "gal_sgp4", "pv[0][0] 17 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -40310.06316386   , 1e+0, "gal_sgp4", "pv[0][1] 17 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3.55833201       , 1e+0, "gal_sgp4", "pv[0][2] 17 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.940537098       , 1e+0, "gal_sgp4", "pv[1][0] 17 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.900219523      , 1e+0, "gal_sgp4", "pv[1][1] 17 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000934170       , 1e+0, "gal_sgp4", "pv[1][2] 17 24" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9533.27750818     , 1e+0, "gal_sgp4", "pv[0][0] 17 25" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -41065.52390214   , 1e+0, "gal_sgp4", "pv[0][1] 17 25" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3.30756482        , 1e+0, "gal_sgp4", "pv[0][2] 17 25" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.995596171       , 1e+0, "gal_sgp4", "pv[1][0] 17 25" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.695200236       , 1e+0, "gal_sgp4", "pv[1][1] 17 25" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000938525       , 1e+0, "gal_sgp4", "pv[1][2] 17 25" ) ;  

/*
 * INTELSAT 902 negative incl at 9313 min then  
 */  

/*
 * 270 deg Lyddane bug at 37606 min  
 */  

  strcpy ( card1, "1 26900U 01039A   06106.74503247  .00000045  00000-0  10000-3 0  8290" ) ;  
  strcpy ( card2, "2 26900   0.0164 266.5378 0003319  86.1794 182.2590  1.00273847 16981" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -42014.83795787   , 1e+0, "gal_sgp4", "pv[0][0] 18 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3702.34357772     , 1e+0, "gal_sgp4", "pv[0][1] 18 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -26.67500257      , 1e+0, "gal_sgp4", "pv[0][2] 18 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.269775247      , 1e+0, "gal_sgp4", "pv[1][0] 18 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.061854393      , 1e+0, "gal_sgp4", "pv[1][1] 18 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000336726       , 1e+0, "gal_sgp4", "pv[1][2] 18 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 9300.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 40968.68133298    , 1e+0, "gal_sgp4", "pv[0][0] 18 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -9905.99156086    , 1e+0, "gal_sgp4", "pv[0][1] 18 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 11.84946837       , 1e+0, "gal_sgp4", "pv[0][2] 18 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.722756848       , 1e+0, "gal_sgp4", "pv[1][0] 18 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.989645389       , 1e+0, "gal_sgp4", "pv[1][1] 18 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000161261      , 1e+0, "gal_sgp4", "pv[1][2] 18 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 9360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 42135.66858481    , 1e+0, "gal_sgp4", "pv[0][0] 18 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1072.99195618     , 1e+0, "gal_sgp4", "pv[0][1] 18 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 10.83481752       , 1e+0, "gal_sgp4", "pv[0][2] 18 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.078150602      , 1e+0, "gal_sgp4", "pv[1][0] 18 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.074772455       , 1e+0, "gal_sgp4", "pv[1][1] 18 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000380063      , 1e+0, "gal_sgp4", "pv[1][2] 18 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 9400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 41304.75156132    , 1e+0, "gal_sgp4", "pv[0][0] 18 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 8398.27742944     , 1e+0, "gal_sgp4", "pv[0][1] 18 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 9.74006214        , 1e+0, "gal_sgp4", "pv[0][2] 18 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.612515135      , 1e+0, "gal_sgp4", "pv[1][0] 18 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.014117469       , 1e+0, "gal_sgp4", "pv[1][1] 18 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000511575      , 1e+0, "gal_sgp4", "pv[1][2] 18 3" ) ;  

/*
 * COSMOS 1024 DEB 12h resonant ecc in 0.5 to 0.65 range  
 */  

  strcpy ( card1, "1 26975U 78066F   06174.85818871  .00000620  00000-0  10000-3 0  6809" ) ;  
  strcpy ( card2, "2 26975  68.4714 236.1303 5602877 123.7484 302.5767  2.05657553 67521" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -14506.92313768   , 1e+0, "gal_sgp4", "pv[0][0] 19 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -21613.56043281   , 1e+0, "gal_sgp4", "pv[0][1] 19 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 10.05018894       , 1e+0, "gal_sgp4", "pv[0][2] 19 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.212943308       , 1e+0, "gal_sgp4", "pv[1][0] 19 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.159970892       , 1e+0, "gal_sgp4", "pv[1][1] 19 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.020600202       , 1e+0, "gal_sgp4", "pv[1][2] 19 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7309.62197950     , 1e+0, "gal_sgp4", "pv[0][0] 19 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6076.00713664     , 1e+0, "gal_sgp4", "pv[0][1] 19 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6800.08705263     , 1e+0, "gal_sgp4", "pv[0][2] 19 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.300543383       , 1e+0, "gal_sgp4", "pv[1][0] 19 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.322579615       , 1e+0, "gal_sgp4", "pv[1][1] 19 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.788746312      , 1e+0, "gal_sgp4", "pv[1][2] 19 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3882.62933791    , 1e+0, "gal_sgp4", "pv[0][0] 19 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 11960.00543452    , 1e+0, "gal_sgp4", "pv[0][1] 19 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -25088.14383845   , 1e+0, "gal_sgp4", "pv[0][2] 19 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.146773699      , 1e+0, "gal_sgp4", "pv[1][0] 19 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.372461491      , 1e+0, "gal_sgp4", "pv[1][1] 19 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.579382089      , 1e+0, "gal_sgp4", "pv[1][2] 19 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -16785.45507465   , 1e+0, "gal_sgp4", "pv[0][0] 19 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -734.79159704     , 1e+0, "gal_sgp4", "pv[0][1] 19 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -34300.57085853   , 1e+0, "gal_sgp4", "pv[0][2] 19 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.386528125      , 1e+0, "gal_sgp4", "pv[1][0] 19 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.907762641      , 1e+0, "gal_sgp4", "pv[1][1] 19 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.220949641      , 1e+0, "gal_sgp4", "pv[1][2] 19 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -23524.16689356   , 1e+0, "gal_sgp4", "pv[0][0] 19 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -13629.45124622   , 1e+0, "gal_sgp4", "pv[0][1] 19 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -30246.27899200   , 1e+0, "gal_sgp4", "pv[0][2] 19 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.462846784      , 1e+0, "gal_sgp4", "pv[1][0] 19 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.586139830      , 1e+0, "gal_sgp4", "pv[1][1] 19 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.269293624       , 1e+0, "gal_sgp4", "pv[1][2] 19 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -22890.23597092   , 1e+0, "gal_sgp4", "pv[0][0] 19 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22209.35900155   , 1e+0, "gal_sgp4", "pv[0][1] 19 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -16769.91946116   , 1e+0, "gal_sgp4", "pv[0][2] 19 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.704351342       , 1e+0, "gal_sgp4", "pv[1][0] 19 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.671112594      , 1e+0, "gal_sgp4", "pv[1][1] 19 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.432433851       , 1e+0, "gal_sgp4", "pv[1][2] 19 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -11646.39698980   , 1e+0, "gal_sgp4", "pv[0][0] 19 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19855.44222106   , 1e+0, "gal_sgp4", "pv[0][1] 19 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3574.00109607     , 1e+0, "gal_sgp4", "pv[0][2] 19 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.626712727       , 1e+0, "gal_sgp4", "pv[1][0] 19 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.815887329       , 1e+0, "gal_sgp4", "pv[1][1] 19 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.960883901       , 1e+0, "gal_sgp4", "pv[1][2] 19 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7665.76124241     , 1e+0, "gal_sgp4", "pv[0][0] 19 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 11159.78946577    , 1e+0, "gal_sgp4", "pv[0][1] 19 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 345.93813117      , 1e+0, "gal_sgp4", "pv[0][2] 19 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.584818007      , 1e+0, "gal_sgp4", "pv[1][0] 19 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.193514161       , 1e+0, "gal_sgp4", "pv[1][1] 19 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.750338922      , 1e+0, "gal_sgp4", "pv[1][2] 19 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -6369.35388112    , 1e+0, "gal_sgp4", "pv[0][0] 19 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 10204.80073022    , 1e+0, "gal_sgp4", "pv[0][1] 19 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -27844.52150384   , 1e+0, "gal_sgp4", "pv[0][2] 19 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.050573276      , 1e+0, "gal_sgp4", "pv[1][0] 19 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.582940542      , 1e+0, "gal_sgp4", "pv[1][1] 19 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.076075232      , 1e+0, "gal_sgp4", "pv[1][2] 19 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -18345.64763145   , 1e+0, "gal_sgp4", "pv[0][0] 19 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2977.76684430    , 1e+0, "gal_sgp4", "pv[0][1] 19 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -34394.90760612   , 1e+0, "gal_sgp4", "pv[0][2] 19 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.243589864      , 1e+0, "gal_sgp4", "pv[1][0] 19 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.892050757      , 1e+0, "gal_sgp4", "pv[1][1] 19 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.060372061       , 1e+0, "gal_sgp4", "pv[1][2] 19 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -23979.74839255   , 1e+0, "gal_sgp4", "pv[0][0] 19 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -15436.44139571   , 1e+0, "gal_sgp4", "pv[0][1] 19 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -28616.50540218   , 1e+0, "gal_sgp4", "pv[0][2] 19 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.294973425      , 1e+0, "gal_sgp4", "pv[1][0] 19 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.482987916      , 1e+0, "gal_sgp4", "pv[1][1] 19 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.478255628       , 1e+0, "gal_sgp4", "pv[1][2] 19 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -21921.97167880   , 1e+0, "gal_sgp4", "pv[0][0] 19 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22852.45147658   , 1e+0, "gal_sgp4", "pv[0][1] 19 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -13784.85308485   , 1e+0, "gal_sgp4", "pv[0][2] 19 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.945455629       , 1e+0, "gal_sgp4", "pv[1][0] 19 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.428940995      , 1e+0, "gal_sgp4", "pv[1][1] 19 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.596964378       , 1e+0, "gal_sgp4", "pv[1][2] 19 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8266.43821031    , 1e+0, "gal_sgp4", "pv[0][0] 19 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -17210.74590112   , 1e+0, "gal_sgp4", "pv[0][1] 19 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6967.95546070     , 1e+0, "gal_sgp4", "pv[0][2] 19 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.082244069       , 1e+0, "gal_sgp4", "pv[1][0] 19 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.665881872       , 1e+0, "gal_sgp4", "pv[1][1] 19 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.712555075       , 1e+0, "gal_sgp4", "pv[1][2] 19 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 6286.85464535     , 1e+0, "gal_sgp4", "pv[0][0] 19 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 13809.56328971    , 1e+0, "gal_sgp4", "pv[0][1] 19 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6321.60663781    , 1e+0, "gal_sgp4", "pv[0][2] 19 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.615964016      , 1e+0, "gal_sgp4", "pv[1][0] 19 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.383135377       , 1e+0, "gal_sgp4", "pv[1][1] 19 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.358719132      , 1e+0, "gal_sgp4", "pv[1][2] 19 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -8730.87526788    , 1e+0, "gal_sgp4", "pv[0][0] 19 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 8244.63344365     , 1e+0, "gal_sgp4", "pv[0][1] 19 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -30039.92372791   , 1e+0, "gal_sgp4", "pv[0][2] 19 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.935622871      , 1e+0, "gal_sgp4", "pv[1][0] 19 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.724162072      , 1e+0, "gal_sgp4", "pv[1][1] 19 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.631224738      , 1e+0, "gal_sgp4", "pv[1][2] 19 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -19735.81883249   , 1e+0, "gal_sgp4", "pv[0][0] 19 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5191.76593007    , 1e+0, "gal_sgp4", "pv[0][1] 19 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -34166.14974143   , 1e+0, "gal_sgp4", "pv[0][2] 19 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.097835530      , 1e+0, "gal_sgp4", "pv[1][0] 19 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.860148418      , 1e+0, "gal_sgp4", "pv[1][1] 19 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.324401050       , 1e+0, "gal_sgp4", "pv[1][2] 19 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -24232.73847703   , 1e+0, "gal_sgp4", "pv[0][0] 19 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -17112.08243255   , 1e+0, "gal_sgp4", "pv[0][1] 19 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -26742.88893252   , 1e+0, "gal_sgp4", "pv[0][2] 19 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.119786184      , 1e+0, "gal_sgp4", "pv[1][0] 19 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.364365317      , 1e+0, "gal_sgp4", "pv[1][1] 19 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.680220468       , 1e+0, "gal_sgp4", "pv[1][2] 19 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -20654.45640708   , 1e+0, "gal_sgp4", "pv[0][0] 19 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -23184.54386047   , 1e+0, "gal_sgp4", "pv[0][1] 19 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -10611.55144716   , 1e+0, "gal_sgp4", "pv[0][2] 19 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.209238113       , 1e+0, "gal_sgp4", "pv[1][0] 19 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.144169639      , 1e+0, "gal_sgp4", "pv[1][1] 19 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.748054938       , 1e+0, "gal_sgp4", "pv[1][2] 19 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4337.15988957    , 1e+0, "gal_sgp4", "pv[0][0] 19 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -13410.46817244   , 1e+0, "gal_sgp4", "pv[0][1] 19 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 9870.45949215     , 1e+0, "gal_sgp4", "pv[0][2] 19 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.532753095       , 1e+0, "gal_sgp4", "pv[1][0] 19 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.772236461       , 1e+0, "gal_sgp4", "pv[1][1] 19 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.088424247       , 1e+0, "gal_sgp4", "pv[1][2] 19 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4074.62263523     , 1e+0, "gal_sgp4", "pv[0][0] 19 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 14698.07548285    , 1e+0, "gal_sgp4", "pv[0][1] 19 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -12248.65327973   , 1e+0, "gal_sgp4", "pv[0][2] 19 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.053824693      , 1e+0, "gal_sgp4", "pv[1][0] 19 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.203325817       , 1e+0, "gal_sgp4", "pv[1][1] 19 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.607867718      , 1e+0, "gal_sgp4", "pv[1][2] 19 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -10950.23438984   , 1e+0, "gal_sgp4", "pv[0][0] 19 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6148.66879447     , 1e+0, "gal_sgp4", "pv[0][1] 19 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -31736.65532865   , 1e+0, "gal_sgp4", "pv[0][2] 19 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.809875605      , 1e+0, "gal_sgp4", "pv[1][0] 19 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.816179062      , 1e+0, "gal_sgp4", "pv[1][1] 19 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.233364913      , 1e+0, "gal_sgp4", "pv[1][2] 19 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -20952.40702045   , 1e+0, "gal_sgp4", "pv[0][0] 19 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -7358.71507895    , 1e+0, "gal_sgp4", "pv[0][1] 19 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -33633.06643074   , 1e+0, "gal_sgp4", "pv[0][2] 19 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.948973031      , 1e+0, "gal_sgp4", "pv[1][0] 19 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.813594137      , 1e+0, "gal_sgp4", "pv[1][1] 19 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.573893078       , 1e+0, "gal_sgp4", "pv[1][2] 19 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -24273.48944134   , 1e+0, "gal_sgp4", "pv[0][0] 19 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -18637.15546906   , 1e+0, "gal_sgp4", "pv[0][1] 19 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -24633.27702390   , 1e+0, "gal_sgp4", "pv[0][2] 19 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.064161440       , 1e+0, "gal_sgp4", "pv[1][0] 19 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.228537560      , 1e+0, "gal_sgp4", "pv[1][1] 19 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.875728935       , 1e+0, "gal_sgp4", "pv[1][2] 19 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -19057.55468077   , 1e+0, "gal_sgp4", "pv[0][0] 19 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -23148.29322082   , 1e+0, "gal_sgp4", "pv[0][1] 19 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7269.38614178    , 1e+0, "gal_sgp4", "pv[0][2] 19 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.500802809       , 1e+0, "gal_sgp4", "pv[1][0] 19 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.195383037       , 1e+0, "gal_sgp4", "pv[1][1] 19 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.879031237       , 1e+0, "gal_sgp4", "pv[1][2] 19 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 43.69305308       , 1e+0, "gal_sgp4", "pv[0][0] 19 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -8145.90299207    , 1e+0, "gal_sgp4", "pv[0][1] 19 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 11634.57079913    , 1e+0, "gal_sgp4", "pv[0][2] 19 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.780661682       , 1e+0, "gal_sgp4", "pv[1][0] 19 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.105315423       , 1e+0, "gal_sgp4", "pv[1][1] 19 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.714401345       , 1e+0, "gal_sgp4", "pv[1][2] 19 24" ) ;  

/*
 * CBERS 2 Near Earth, ecc = 8.84E-5 (< 1.0e-4)  
 */  

/*
 * drop certain normal drag terms  
 */  

  strcpy ( card1, "1 28057U 03049A   06177.78615833  .00000060  00000-0  35940-4 0  1836" ) ;  
  strcpy ( card2, "2 28057  98.4283 247.6961 0000884  88.1964 271.9322 14.35478080140550" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2715.28237486    , 1e+0, "gal_sgp4", "pv[0][0] 20 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6619.26436889    , 1e+0, "gal_sgp4", "pv[0][1] 20 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -0.01341443       , 1e+0, "gal_sgp4", "pv[0][2] 20 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.008587273      , 1e+0, "gal_sgp4", "pv[1][0] 20 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.422782003       , 1e+0, "gal_sgp4", "pv[1][1] 20 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.385272942       , 1e+0, "gal_sgp4", "pv[1][2] 20 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1816.87920942    , 1e+0, "gal_sgp4", "pv[0][0] 20 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1835.78762132    , 1e+0, "gal_sgp4", "pv[0][1] 20 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6661.07926465     , 1e+0, "gal_sgp4", "pv[0][2] 20 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.325140071       , 1e+0, "gal_sgp4", "pv[1][0] 20 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.655669329       , 1e+0, "gal_sgp4", "pv[1][1] 20 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.463394512       , 1e+0, "gal_sgp4", "pv[1][2] 20 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1483.17364291     , 1e+0, "gal_sgp4", "pv[0][0] 20 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5395.21248786     , 1e+0, "gal_sgp4", "pv[0][1] 20 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4448.65907172     , 1e+0, "gal_sgp4", "pv[0][2] 20 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.560540387       , 1e+0, "gal_sgp4", "pv[1][0] 20 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.039025766       , 1e+0, "gal_sgp4", "pv[1][1] 20 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.736648561      , 1e+0, "gal_sgp4", "pv[1][2] 20 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2801.25607157     , 1e+0, "gal_sgp4", "pv[0][0] 20 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5455.03931333     , 1e+0, "gal_sgp4", "pv[0][1] 20 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3692.12865695    , 1e+0, "gal_sgp4", "pv[0][2] 20 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.595095864      , 1e+0, "gal_sgp4", "pv[1][0] 20 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.951923117      , 1e+0, "gal_sgp4", "pv[1][1] 20 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.298799125      , 1e+0, "gal_sgp4", "pv[1][2] 20 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 411.09332812      , 1e+0, "gal_sgp4", "pv[0][0] 20 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1728.99769152    , 1e+0, "gal_sgp4", "pv[0][1] 20 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6935.45548810    , 1e+0, "gal_sgp4", "pv[0][2] 20 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.935970964      , 1e+0, "gal_sgp4", "pv[1][0] 20 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.684085058      , 1e+0, "gal_sgp4", "pv[1][1] 20 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.492800886       , 1e+0, "gal_sgp4", "pv[1][2] 20 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2506.52558454    , 1e+0, "gal_sgp4", "pv[0][0] 20 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6628.98655094    , 1e+0, "gal_sgp4", "pv[0][1] 20 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -988.07784497     , 1e+0, "gal_sgp4", "pv[0][2] 20 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.390577189      , 1e+0, "gal_sgp4", "pv[1][0] 20 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.556164143      , 1e+0, "gal_sgp4", "pv[1][1] 20 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.312736468       , 1e+0, "gal_sgp4", "pv[1][2] 20 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2090.79884266    , 1e+0, "gal_sgp4", "pv[0][0] 20 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2723.22832193    , 1e+0, "gal_sgp4", "pv[0][1] 20 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6266.13356576     , 1e+0, "gal_sgp4", "pv[0][2] 20 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.992640665       , 1e+0, "gal_sgp4", "pv[1][0] 20 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.337529519       , 1e+0, "gal_sgp4", "pv[1][1] 20 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.411803080       , 1e+0, "gal_sgp4", "pv[1][2] 20 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1091.80560222     , 1e+0, "gal_sgp4", "pv[0][0] 20 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4809.88229503     , 1e+0, "gal_sgp4", "pv[0][1] 20 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5172.42897894     , 1e+0, "gal_sgp4", "pv[0][2] 20 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.717483546       , 1e+0, "gal_sgp4", "pv[1][0] 20 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.805518977       , 1e+0, "gal_sgp4", "pv[1][1] 20 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.030019896      , 1e+0, "gal_sgp4", "pv[1][2] 20 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2811.14062300     , 1e+0, "gal_sgp4", "pv[0][0] 20 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5950.65707171     , 1e+0, "gal_sgp4", "pv[0][1] 20 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2813.23705389    , 1e+0, "gal_sgp4", "pv[0][2] 20 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.159662742      , 1e+0, "gal_sgp4", "pv[1][0] 20 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.121215491      , 1e+0, "gal_sgp4", "pv[1][1] 20 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.775341949      , 1e+0, "gal_sgp4", "pv[1][2] 20 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 805.72698304      , 1e+0, "gal_sgp4", "pv[0][0] 20 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -812.16627907     , 1e+0, "gal_sgp4", "pv[0][1] 20 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7067.58483968    , 1e+0, "gal_sgp4", "pv[0][2] 20 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.798936020      , 1e+0, "gal_sgp4", "pv[1][0] 20 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.889265977      , 1e+0, "gal_sgp4", "pv[1][1] 20 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.472770873       , 1e+0, "gal_sgp4", "pv[1][2] 20 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2249.59837532    , 1e+0, "gal_sgp4", "pv[0][0] 20 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6505.84890714    , 1e+0, "gal_sgp4", "pv[0][1] 20 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1956.72365062    , 1e+0, "gal_sgp4", "pv[0][2] 20 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.731234729      , 1e+0, "gal_sgp4", "pv[1][0] 20 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.528750230      , 1e+0, "gal_sgp4", "pv[1][1] 20 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.096660885       , 1e+0, "gal_sgp4", "pv[1][2] 20 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2311.57375797    , 1e+0, "gal_sgp4", "pv[0][0] 20 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3560.99112891    , 1e+0, "gal_sgp4", "pv[0][1] 20 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5748.16749600     , 1e+0, "gal_sgp4", "pv[0][2] 20 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.626569751       , 1e+0, "gal_sgp4", "pv[1][0] 20 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.890482233       , 1e+0, "gal_sgp4", "pv[1][1] 20 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.293545048       , 1e+0, "gal_sgp4", "pv[1][2] 20 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 688.16056594      , 1e+0, "gal_sgp4", "pv[0][0] 20 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4124.87618964     , 1e+0, "gal_sgp4", "pv[0][1] 20 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5794.55994449     , 1e+0, "gal_sgp4", "pv[0][2] 20 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.810973665       , 1e+0, "gal_sgp4", "pv[1][0] 20 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.479585563       , 1e+0, "gal_sgp4", "pv[1][1] 20 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.224866316      , 1e+0, "gal_sgp4", "pv[1][2] 20 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1560.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2759.94088230     , 1e+0, "gal_sgp4", "pv[0][0] 20 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6329.87271798     , 1e+0, "gal_sgp4", "pv[0][1] 20 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1879.19518331    , 1e+0, "gal_sgp4", "pv[0][2] 20 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.266930672       , 1e+0, "gal_sgp4", "pv[1][0] 20 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.222670878      , 1e+0, "gal_sgp4", "pv[1][1] 20 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.119390567      , 1e+0, "gal_sgp4", "pv[1][2] 20 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1680.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1171.50677137     , 1e+0, "gal_sgp4", "pv[0][0] 20 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 125.82053748      , 1e+0, "gal_sgp4", "pv[0][1] 20 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7061.96626202    , 1e+0, "gal_sgp4", "pv[0][2] 20 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.605687852      , 1e+0, "gal_sgp4", "pv[1][0] 20 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.958489749      , 1e+0, "gal_sgp4", "pv[1][1] 20 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.556333225      , 1e+0, "gal_sgp4", "pv[1][2] 20 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1800.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1951.43708472    , 1e+0, "gal_sgp4", "pv[0][0] 20 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6251.71945820    , 1e+0, "gal_sgp4", "pv[0][1] 20 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2886.95472355    , 1e+0, "gal_sgp4", "pv[0][2] 20 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.024131483      , 1e+0, "gal_sgp4", "pv[1][0] 20 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.475214272      , 1e+0, "gal_sgp4", "pv[1][1] 20 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.741537478       , 1e+0, "gal_sgp4", "pv[1][2] 20 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1920.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2475.70722288    , 1e+0, "gal_sgp4", "pv[0][0] 20 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4331.90569958    , 1e+0, "gal_sgp4", "pv[0][1] 20 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5117.31234924     , 1e+0, "gal_sgp4", "pv[0][2] 20 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.235823539       , 1e+0, "gal_sgp4", "pv[1][0] 20 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.322743371       , 1e+0, "gal_sgp4", "pv[1][1] 20 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.091281211       , 1e+0, "gal_sgp4", "pv[1][2] 20 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2040.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 281.46097847      , 1e+0, "gal_sgp4", "pv[0][0] 20 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3353.51057102     , 1e+0, "gal_sgp4", "pv[0][1] 20 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6302.87900650     , 1e+0, "gal_sgp4", "pv[0][2] 20 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.840647273       , 1e+0, "gal_sgp4", "pv[1][0] 20 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.047222485       , 1e+0, "gal_sgp4", "pv[1][1] 20 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.337085992      , 1e+0, "gal_sgp4", "pv[1][2] 20 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2650.33118860     , 1e+0, "gal_sgp4", "pv[0][0] 20 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6584.33434851     , 1e+0, "gal_sgp4", "pv[0][1] 20 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -908.29027134     , 1e+0, "gal_sgp4", "pv[0][2] 20 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.675457235       , 1e+0, "gal_sgp4", "pv[1][0] 20 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.274044972      , 1e+0, "gal_sgp4", "pv[1][1] 20 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.323921567      , 1e+0, "gal_sgp4", "pv[1][2] 20 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1501.17226597     , 1e+0, "gal_sgp4", "pv[0][0] 20 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1066.31132756     , 1e+0, "gal_sgp4", "pv[0][1] 20 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6918.71472952    , 1e+0, "gal_sgp4", "pv[0][2] 20 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.361891904      , 1e+0, "gal_sgp4", "pv[1][0] 20 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.889669974      , 1e+0, "gal_sgp4", "pv[1][1] 20 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.574718619      , 1e+0, "gal_sgp4", "pv[1][2] 20 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1619.73468334    , 1e+0, "gal_sgp4", "pv[0][0] 20 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5871.14051991    , 1e+0, "gal_sgp4", "pv[0][1] 20 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3760.56587071    , 1e+0, "gal_sgp4", "pv[0][2] 20 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.264093975      , 1e+0, "gal_sgp4", "pv[1][0] 20 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.376316601      , 1e+0, "gal_sgp4", "pv[1][1] 20 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.254622256       , 1e+0, "gal_sgp4", "pv[1][2] 20 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2520.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2581.04202505    , 1e+0, "gal_sgp4", "pv[0][0] 20 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5020.05572531    , 1e+0, "gal_sgp4", "pv[0][1] 20 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4385.92329047     , 1e+0, "gal_sgp4", "pv[0][2] 20 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.829668458       , 1e+0, "gal_sgp4", "pv[1][0] 20 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.645048038       , 1e+0, "gal_sgp4", "pv[1][1] 20 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.789262667       , 1e+0, "gal_sgp4", "pv[1][2] 20 21" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2640.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -119.22080628     , 1e+0, "gal_sgp4", "pv[0][0] 20 22" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2510.90620488     , 1e+0, "gal_sgp4", "pv[0][1] 20 22" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6687.45615459     , 1e+0, "gal_sgp4", "pv[0][2] 20 22" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.807575712       , 1e+0, "gal_sgp4", "pv[1][0] 20 22" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.496549689       , 1e+0, "gal_sgp4", "pv[1][1] 20 22" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.384136661      , 1e+0, "gal_sgp4", "pv[1][2] 20 22" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2760.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2486.23806726     , 1e+0, "gal_sgp4", "pv[0][0] 20 23" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6708.18210028     , 1e+0, "gal_sgp4", "pv[0][1] 20 23" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 80.43349581       , 1e+0, "gal_sgp4", "pv[0][2] 20 23" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.057274905       , 1e+0, "gal_sgp4", "pv[1][0] 20 23" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.294294027      , 1e+0, "gal_sgp4", "pv[1][1] 20 23" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.384689123      , 1e+0, "gal_sgp4", "pv[1][2] 20 23" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 2880.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1788.42334580     , 1e+0, "gal_sgp4", "pv[0][0] 20 24" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1990.50530957     , 1e+0, "gal_sgp4", "pv[0][1] 20 24" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6640.59337725    , 1e+0, "gal_sgp4", "pv[0][2] 20 24" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.074169091      , 1e+0, "gal_sgp4", "pv[1][0] 20 24" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.683381288      , 1e+0, "gal_sgp4", "pv[1][1] 20 24" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.562777776      , 1e+0, "gal_sgp4", "pv[1][2] 20 24" ) ;  

/*
 * NAVSTAR 53 (USA 175) 12h non-resonant GPS (ecc < 0.5 ecc)  
 */  

  strcpy ( card1, "1 28129U 03058A   06175.57071136 -.00000104  00000-0  10000-3 0   459" ) ;  
  strcpy ( card2, "2 28129  54.7298 324.8098 0048506 266.2640  93.1663  2.00562768 18443" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 21707.46412351    , 1e+0, "gal_sgp4", "pv[0][0] 21 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -15318.61752390   , 1e+0, "gal_sgp4", "pv[0][1] 21 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 0.13551152        , 1e+0, "gal_sgp4", "pv[0][2] 21 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.304029214       , 1e+0, "gal_sgp4", "pv[1][0] 21 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.816904974       , 1e+0, "gal_sgp4", "pv[1][1] 21 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.161919976       , 1e+0, "gal_sgp4", "pv[1][2] 21 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 18616.75971861    , 1e+0, "gal_sgp4", "pv[0][0] 21 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3166.15177043     , 1e+0, "gal_sgp4", "pv[0][1] 21 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18833.41523210    , 1e+0, "gal_sgp4", "pv[0][2] 21 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.076122016      , 1e+0, "gal_sgp4", "pv[1][0] 21 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.838457575       , 1e+0, "gal_sgp4", "pv[1][1] 21 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.586210535       , 1e+0, "gal_sgp4", "pv[1][2] 21 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3006.50596328    , 1e+0, "gal_sgp4", "pv[0][0] 21 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18522.20742011    , 1e+0, "gal_sgp4", "pv[0][1] 21 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18941.84078154    , 1e+0, "gal_sgp4", "pv[0][2] 21 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.375452789      , 1e+0, "gal_sgp4", "pv[1][0] 21 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.032680773       , 1e+0, "gal_sgp4", "pv[1][1] 21 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.559324534      , 1e+0, "gal_sgp4", "pv[1][2] 21 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -21607.02086957   , 1e+0, "gal_sgp4", "pv[0][0] 21 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15432.59962630    , 1e+0, "gal_sgp4", "pv[0][1] 21 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 206.62470309      , 1e+0, "gal_sgp4", "pv[0][2] 21 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.306049851      , 1e+0, "gal_sgp4", "pv[1][0] 21 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.817011568      , 1e+0, "gal_sgp4", "pv[1][1] 21 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.163725018      , 1e+0, "gal_sgp4", "pv[1][2] 21 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -18453.06134549   , 1e+0, "gal_sgp4", "pv[0][0] 21 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3150.83256134    , 1e+0, "gal_sgp4", "pv[0][1] 21 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -18685.83030936   , 1e+0, "gal_sgp4", "pv[0][2] 21 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.106017925       , 1e+0, "gal_sgp4", "pv[1][0] 21 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.860236337      , 1e+0, "gal_sgp4", "pv[1][1] 21 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.586151870      , 1e+0, "gal_sgp4", "pv[1][2] 21 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3425.11742384     , 1e+0, "gal_sgp4", "pv[0][0] 21 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -18514.73232706   , 1e+0, "gal_sgp4", "pv[0][1] 21 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -18588.67200557   , 1e+0, "gal_sgp4", "pv[0][2] 21 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.394666340       , 1e+0, "gal_sgp4", "pv[1][0] 21 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.003072030      , 1e+0, "gal_sgp4", "pv[1][1] 21 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.610061295       , 1e+0, "gal_sgp4", "pv[1][2] 21 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 21858.23838148    , 1e+0, "gal_sgp4", "pv[0][0] 21 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -15101.51661554   , 1e+0, "gal_sgp4", "pv[0][1] 21 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 387.34517048      , 1e+0, "gal_sgp4", "pv[0][2] 21 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.247973967       , 1e+0, "gal_sgp4", "pv[1][0] 21 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.856017403       , 1e+0, "gal_sgp4", "pv[1][1] 21 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.161439948       , 1e+0, "gal_sgp4", "pv[1][2] 21 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 18360.69935796    , 1e+0, "gal_sgp4", "pv[0][0] 21 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3506.55256762     , 1e+0, "gal_sgp4", "pv[0][1] 21 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 19024.81678979    , 1e+0, "gal_sgp4", "pv[0][2] 21 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.122684184      , 1e+0, "gal_sgp4", "pv[1][0] 21 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.830618605       , 1e+0, "gal_sgp4", "pv[1][1] 21 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.537510677       , 1e+0, "gal_sgp4", "pv[1][2] 21 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3412.84765409    , 1e+0, "gal_sgp4", "pv[0][0] 21 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18646.85269710    , 1e+0, "gal_sgp4", "pv[0][1] 21 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 18748.00359987    , 1e+0, "gal_sgp4", "pv[0][2] 21 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.366815728      , 1e+0, "gal_sgp4", "pv[1][0] 21 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.986039922       , 1e+0, "gal_sgp4", "pv[1][1] 21 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.607874972      , 1e+0, "gal_sgp4", "pv[1][2] 21 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -21758.08331586   , 1e+0, "gal_sgp4", "pv[0][0] 21 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15215.44829478    , 1e+0, "gal_sgp4", "pv[0][1] 21 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -180.82181406     , 1e+0, "gal_sgp4", "pv[0][2] 21 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.250144680      , 1e+0, "gal_sgp4", "pv[1][0] 21 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.856490448      , 1e+0, "gal_sgp4", "pv[1][1] 21 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.163774870      , 1e+0, "gal_sgp4", "pv[1][2] 21 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -18193.41290284   , 1e+0, "gal_sgp4", "pv[0][0] 21 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3493.85876912    , 1e+0, "gal_sgp4", "pv[0][1] 21 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -18877.14757717   , 1e+0, "gal_sgp4", "pv[0][2] 21 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.153326942       , 1e+0, "gal_sgp4", "pv[1][0] 21 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.852221264      , 1e+0, "gal_sgp4", "pv[1][1] 21 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.536617760      , 1e+0, "gal_sgp4", "pv[1][2] 21 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 3833.57386848     , 1e+0, "gal_sgp4", "pv[0][0] 21 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -18635.77026711   , 1e+0, "gal_sgp4", "pv[0][1] 21 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -18388.68722885   , 1e+0, "gal_sgp4", "pv[0][2] 21 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.384748179       , 1e+0, "gal_sgp4", "pv[1][0] 21 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.955363841      , 1e+0, "gal_sgp4", "pv[1][1] 21 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.658785020       , 1e+0, "gal_sgp4", "pv[1][2] 21 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 22002.20074562    , 1e+0, "gal_sgp4", "pv[0][0] 21 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -14879.72595593   , 1e+0, "gal_sgp4", "pv[0][1] 21 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 774.32827099      , 1e+0, "gal_sgp4", "pv[0][2] 21 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.191573619       , 1e+0, "gal_sgp4", "pv[1][0] 21 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.894561165       , 1e+0, "gal_sgp4", "pv[1][1] 21 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.159953047       , 1e+0, "gal_sgp4", "pv[1][2] 21 12" ) ;  

/*
 * COSMOS 2405 Near Earth, perigee = 127.20 (< 156) s4 mod  
 */  

  strcpy ( card1, "1 28350U 04020A   06167.21788666  .16154492  76267-5  18678-3 0  8894" ) ;  
  strcpy ( card2, "2 28350  64.9977 345.6130 0024870 260.7578  99.9590 16.47856722116490" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 6333.08123128     , 1e+0, "gal_sgp4", "pv[0][0] 22 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1580.82852326    , 1e+0, "gal_sgp4", "pv[0][1] 22 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 90.69355720       , 1e+0, "gal_sgp4", "pv[0][2] 22 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.714634423       , 1e+0, "gal_sgp4", "pv[1][0] 22 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.224246550       , 1e+0, "gal_sgp4", "pv[1][1] 22 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.083128132       , 1e+0, "gal_sgp4", "pv[1][2] 22 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3990.93845855    , 1e+0, "gal_sgp4", "pv[0][0] 22 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3052.98341907     , 1e+0, "gal_sgp4", "pv[0][1] 22 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4155.32700629     , 1e+0, "gal_sgp4", "pv[0][2] 22 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -5.909006188      , 1e+0, "gal_sgp4", "pv[1][0] 22 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.876307966      , 1e+0, "gal_sgp4", "pv[1][1] 22 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.039131404      , 1e+0, "gal_sgp4", "pv[1][2] 22 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -603.55232010     , 1e+0, "gal_sgp4", "pv[0][0] 22 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2685.13474569    , 1e+0, "gal_sgp4", "pv[0][1] 22 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5891.70274282    , 1e+0, "gal_sgp4", "pv[0][2] 22 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 7.572519907       , 1e+0, "gal_sgp4", "pv[1][0] 22 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.975656726      , 1e+0, "gal_sgp4", "pv[1][1] 22 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.121722605       , 1e+0, "gal_sgp4", "pv[1][2] 22 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4788.22345627     , 1e+0, "gal_sgp4", "pv[0][0] 22 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 782.56169214      , 1e+0, "gal_sgp4", "pv[0][1] 22 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4335.14284621     , 1e+0, "gal_sgp4", "pv[0][2] 22 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -4.954509026      , 1e+0, "gal_sgp4", "pv[1][0] 22 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.683346464       , 1e+0, "gal_sgp4", "pv[1][1] 22 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.804645839       , 1e+0, "gal_sgp4", "pv[1][2] 22 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -6291.84601644    , 1e+0, "gal_sgp4", "pv[0][0] 22 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1547.82790772     , 1e+0, "gal_sgp4", "pv[0][1] 22 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -453.67116498     , 1e+0, "gal_sgp4", "pv[0][2] 22 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.308625588      , 1e+0, "gal_sgp4", "pv[1][0] 22 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.341538574      , 1e+0, "gal_sgp4", "pv[1][1] 22 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.082659115      , 1e+0, "gal_sgp4", "pv[1][2] 22 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4480.74573428     , 1e+0, "gal_sgp4", "pv[0][0] 22 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3028.55200374    , 1e+0, "gal_sgp4", "pv[0][1] 22 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3586.94343641    , 1e+0, "gal_sgp4", "pv[0][2] 22 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.320920857       , 1e+0, "gal_sgp4", "pv[1][0] 22 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.199736275       , 1e+0, "gal_sgp4", "pv[1][1] 22 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.626350481       , 1e+0, "gal_sgp4", "pv[1][2] 22 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -446.42460916     , 1e+0, "gal_sgp4", "pv[0][0] 22 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2932.28872588     , 1e+0, "gal_sgp4", "pv[0][1] 22 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5759.19389757     , 1e+0, "gal_sgp4", "pv[0][2] 22 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -7.561000245      , 1e+0, "gal_sgp4", "pv[1][0] 22 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.550975493       , 1e+0, "gal_sgp4", "pv[1][1] 22 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.374970885      , 1e+0, "gal_sgp4", "pv[1][2] 22 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3713.79581831    , 1e+0, "gal_sgp4", "pv[0][0] 22 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1382.66125130    , 1e+0, "gal_sgp4", "pv[0][1] 22 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5122.45131136    , 1e+0, "gal_sgp4", "pv[0][2] 22 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.090931626       , 1e+0, "gal_sgp4", "pv[1][0] 22 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.512629733      , 1e+0, "gal_sgp4", "pv[1][1] 22 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.467571746      , 1e+0, "gal_sgp4", "pv[1][2] 22 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 6058.32017522     , 1e+0, "gal_sgp4", "pv[0][0] 22 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -827.47406722     , 1e+0, "gal_sgp4", "pv[0][1] 22 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2104.04678651     , 1e+0, "gal_sgp4", "pv[0][2] 22 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.798403024      , 1e+0, "gal_sgp4", "pv[1][0] 22 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.787067272       , 1e+0, "gal_sgp4", "pv[1][1] 22 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.641439744       , 1e+0, "gal_sgp4", "pv[1][2] 22 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5631.73659006    , 1e+0, "gal_sgp4", "pv[0][0] 22 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2623.70953644     , 1e+0, "gal_sgp4", "pv[0][1] 22 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1766.49125084     , 1e+0, "gal_sgp4", "pv[0][2] 22 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.216401578      , 1e+0, "gal_sgp4", "pv[1][0] 22 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.309140959      , 1e+0, "gal_sgp4", "pv[1][1] 22 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.788609120      , 1e+0, "gal_sgp4", "pv[1][2] 22 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2776.84991560     , 1e+0, "gal_sgp4", "pv[0][0] 22 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3255.36941953    , 1e+0, "gal_sgp4", "pv[0][1] 22 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4837.19667790    , 1e+0, "gal_sgp4", "pv[0][2] 22 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.748135564       , 1e+0, "gal_sgp4", "pv[1][0] 22 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.193044825      , 1e+0, "gal_sgp4", "pv[1][1] 22 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.005718698       , 1e+0, "gal_sgp4", "pv[1][2] 22 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1148.04430837     , 1e+0, "gal_sgp4", "pv[0][0] 22 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2486.07343386     , 1e+0, "gal_sgp4", "pv[0][1] 22 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5826.34075913     , 1e+0, "gal_sgp4", "pv[0][2] 22 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -7.420162295      , 1e+0, "gal_sgp4", "pv[1][0] 22 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.589456382       , 1e+0, "gal_sgp4", "pv[1][1] 22 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.356350006       , 1e+0, "gal_sgp4", "pv[1][2] 22 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4527.90871828    , 1e+0, "gal_sgp4", "pv[0][0] 22 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -723.29199041     , 1e+0, "gal_sgp4", "pv[0][1] 22 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4527.44608319    , 1e+0, "gal_sgp4", "pv[0][2] 22 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 5.121674217       , 1e+0, "gal_sgp4", "pv[1][0] 22 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.909895427      , 1e+0, "gal_sgp4", "pv[1][1] 22 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.500218556      , 1e+0, "gal_sgp4", "pv[1][2] 22 12" ) ;  

/*
 * H-2 R/B Deep space, perigee = 135.75 (<156) s4 mod  
 */  

  strcpy ( card1, "1 28623U 05006B   06177.81079184  .00637644  69054-6  96390-3 0  6000" ) ;  
  strcpy ( card2, "2 28623  28.5200 114.9834 6249053 170.2550 212.8965  3.79477162 12753" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -11665.70902324   , 1e+0, "gal_sgp4", "pv[0][0] 23 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 24943.61433357    , 1e+0, "gal_sgp4", "pv[0][1] 23 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 25.80543633       , 1e+0, "gal_sgp4", "pv[0][2] 23 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.596228621      , 1e+0, "gal_sgp4", "pv[1][0] 23 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.476127961      , 1e+0, "gal_sgp4", "pv[1][1] 23 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.126059754       , 1e+0, "gal_sgp4", "pv[1][2] 23 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -11645.35454950   , 1e+0, "gal_sgp4", "pv[0][0] 23 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 979.37668356      , 1e+0, "gal_sgp4", "pv[0][1] 23 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5517.89500058     , 1e+0, "gal_sgp4", "pv[0][2] 23 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.407743502       , 1e+0, "gal_sgp4", "pv[1][0] 23 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.183094988      , 1e+0, "gal_sgp4", "pv[1][1] 23 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.492983277      , 1e+0, "gal_sgp4", "pv[1][2] 23 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5619.19252274     , 1e+0, "gal_sgp4", "pv[0][0] 23 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 19651.44862280    , 1e+0, "gal_sgp4", "pv[0][1] 23 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7261.38496765    , 1e+0, "gal_sgp4", "pv[0][2] 23 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.013634213      , 1e+0, "gal_sgp4", "pv[1][0] 23 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.106842861       , 1e+0, "gal_sgp4", "pv[1][1] 23 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.284235517       , 1e+0, "gal_sgp4", "pv[1][2] 23 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -9708.68629714    , 1e+0, "gal_sgp4", "pv[0][0] 23 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 26306.14553149    , 1e+0, "gal_sgp4", "pv[0][1] 23 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1204.29478856    , 1e+0, "gal_sgp4", "pv[0][2] 23 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.824164290      , 1e+0, "gal_sgp4", "pv[1][0] 23 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.931909596      , 1e+0, "gal_sgp4", "pv[1][1] 23 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.113419052       , 1e+0, "gal_sgp4", "pv[1][2] 23 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -14394.03162892   , 1e+0, "gal_sgp4", "pv[0][0] 23 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6659.30765074     , 1e+0, "gal_sgp4", "pv[0][1] 23 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5593.38345858     , 1e+0, "gal_sgp4", "pv[0][2] 23 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.556522911       , 1e+0, "gal_sgp4", "pv[1][0] 23 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.681657614      , 1e+0, "gal_sgp4", "pv[1][1] 23 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.296912248       , 1e+0, "gal_sgp4", "pv[1][2] 23 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 7712.09476270     , 1e+0, "gal_sgp4", "pv[0][0] 23 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15565.72627434    , 1e+0, "gal_sgp4", "pv[0][1] 23 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -7342.40465571    , 1e+0, "gal_sgp4", "pv[0][2] 23 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.646800364      , 1e+0, "gal_sgp4", "pv[1][0] 23 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.070313571       , 1e+0, "gal_sgp4", "pv[1][1] 23 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.109483081      , 1e+0, "gal_sgp4", "pv[1][2] 23 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -7558.36739603    , 1e+0, "gal_sgp4", "pv[0][0] 23 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 27035.11367962    , 1e+0, "gal_sgp4", "pv[0][1] 23 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2385.12054184    , 1e+0, "gal_sgp4", "pv[0][2] 23 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.999583791      , 1e+0, "gal_sgp4", "pv[1][0] 23 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.393409283      , 1e+0, "gal_sgp4", "pv[1][1] 23 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.078093515       , 1e+0, "gal_sgp4", "pv[1][2] 23 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -15495.61862220   , 1e+0, "gal_sgp4", "pv[0][0] 23 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 11550.15897828    , 1e+0, "gal_sgp4", "pv[0][1] 23 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5053.83178121     , 1e+0, "gal_sgp4", "pv[0][2] 23 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.469277336       , 1e+0, "gal_sgp4", "pv[1][0] 23 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.029761073      , 1e+0, "gal_sgp4", "pv[1][1] 23 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.679054742       , 1e+0, "gal_sgp4", "pv[1][2] 23 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9167.02568222     , 1e+0, "gal_sgp4", "pv[0][0] 23 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 10363.65204210    , 1e+0, "gal_sgp4", "pv[0][1] 23 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6871.52576042    , 1e+0, "gal_sgp4", "pv[0][2] 23 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.881621027      , 1e+0, "gal_sgp4", "pv[1][0] 23 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.223361510       , 1e+0, "gal_sgp4", "pv[1][1] 23 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.740696297      , 1e+0, "gal_sgp4", "pv[1][2] 23 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5275.80272094    , 1e+0, "gal_sgp4", "pv[0][0] 23 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 27151.78486008    , 1e+0, "gal_sgp4", "pv[0][1] 23 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3494.50687216    , 1e+0, "gal_sgp4", "pv[0][2] 23 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.129609388      , 1e+0, "gal_sgp4", "pv[1][0] 23 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.150196480       , 1e+0, "gal_sgp4", "pv[1][1] 23 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.021038089       , 1e+0, "gal_sgp4", "pv[1][2] 23 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -15601.37656145   , 1e+0, "gal_sgp4", "pv[0][0] 23 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 15641.29379850    , 1e+0, "gal_sgp4", "pv[0][1] 23 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4217.03266850     , 1e+0, "gal_sgp4", "pv[0][2] 23 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.249183123      , 1e+0, "gal_sgp4", "pv[1][0] 23 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.405238557      , 1e+0, "gal_sgp4", "pv[1][1] 23 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.888214503       , 1e+0, "gal_sgp4", "pv[1][2] 23 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 9301.05872300     , 1e+0, "gal_sgp4", "pv[0][0] 23 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3883.15265574     , 1e+0, "gal_sgp4", "pv[0][1] 23 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5477.86477017    , 1e+0, "gal_sgp4", "pv[0][2] 23 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.871447821       , 1e+0, "gal_sgp4", "pv[1][0] 23 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.493677331       , 1e+0, "gal_sgp4", "pv[1][1] 23 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.885545282      , 1e+0, "gal_sgp4", "pv[1][2] 23 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2914.31065828    , 1e+0, "gal_sgp4", "pv[0][0] 23 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 26665.20392758    , 1e+0, "gal_sgp4", "pv[0][1] 23 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4511.09814335    , 1e+0, "gal_sgp4", "pv[0][2] 23 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.216261909      , 1e+0, "gal_sgp4", "pv[1][0] 23 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.710067769       , 1e+0, "gal_sgp4", "pv[1][1] 23 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.940691824       , 1e+0, "gal_sgp4", "pv[1][2] 23 12" ) ;  

/*
 * XM-3 24h resonant geo, incl < 3 deg goes  
 */  

/*
 * negative around 1130 min  
 */  

  strcpy ( card1, "1 28626U 05008A   06176.46683397 -.00000205  00000-0  10000-3 0  2190" ) ;  
  strcpy ( card2, "2 28626   0.0019 286.9433 0000335  13.7918  55.6504  1.00270176  4891" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 42080.71852213    , 1e+0, "gal_sgp4", "pv[0][0] 24 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2646.86387436    , 1e+0, "gal_sgp4", "pv[0][1] 24 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 0.81851294        , 1e+0, "gal_sgp4", "pv[0][2] 24 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.193105177       , 1e+0, "gal_sgp4", "pv[1][0] 24 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.068688251       , 1e+0, "gal_sgp4", "pv[1][1] 24 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000438449       , 1e+0, "gal_sgp4", "pv[1][2] 24 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 37740.00085593    , 1e+0, "gal_sgp4", "pv[0][0] 24 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 18802.76872802    , 1e+0, "gal_sgp4", "pv[0][1] 24 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3.45512584        , 1e+0, "gal_sgp4", "pv[0][2] 24 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.371035206      , 1e+0, "gal_sgp4", "pv[1][0] 24 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.752105932       , 1e+0, "gal_sgp4", "pv[1][1] 24 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000336883       , 1e+0, "gal_sgp4", "pv[1][2] 24 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 23232.82515008    , 1e+0, "gal_sgp4", "pv[0][0] 24 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 35187.33981802    , 1e+0, "gal_sgp4", "pv[0][1] 24 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4.98927428        , 1e+0, "gal_sgp4", "pv[0][2] 24 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.565776620      , 1e+0, "gal_sgp4", "pv[1][0] 24 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.694193132       , 1e+0, "gal_sgp4", "pv[1][1] 24 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000163365       , 1e+0, "gal_sgp4", "pv[1][2] 24 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2467.44290178     , 1e+0, "gal_sgp4", "pv[0][0] 24 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 42093.60909959    , 1e+0, "gal_sgp4", "pv[0][1] 24 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5.15062987        , 1e+0, "gal_sgp4", "pv[0][2] 24 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.069341800      , 1e+0, "gal_sgp4", "pv[1][0] 24 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.179976276       , 1e+0, "gal_sgp4", "pv[1][1] 24 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000031739      , 1e+0, "gal_sgp4", "pv[1][2] 24 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -18962.59052991   , 1e+0, "gal_sgp4", "pv[0][0] 24 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 37661.66243819    , 1e+0, "gal_sgp4", "pv[0][1] 24 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4.04433258        , 1e+0, "gal_sgp4", "pv[0][2] 24 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.746151982      , 1e+0, "gal_sgp4", "pv[1][0] 24 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.382675777      , 1e+0, "gal_sgp4", "pv[1][1] 24 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000197633      , 1e+0, "gal_sgp4", "pv[1][2] 24 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -35285.00095313   , 1e+0, "gal_sgp4", "pv[0][0] 24 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 23085.44402778    , 1e+0, "gal_sgp4", "pv[0][1] 24 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2.08711880        , 1e+0, "gal_sgp4", "pv[0][2] 24 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.683277908      , 1e+0, "gal_sgp4", "pv[1][0] 24 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.572893625      , 1e+0, "gal_sgp4", "pv[1][1] 24 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000296282      , 1e+0, "gal_sgp4", "pv[1][2] 24 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -42103.20138132   , 1e+0, "gal_sgp4", "pv[0][0] 24 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2291.06228893     , 1e+0, "gal_sgp4", "pv[0][1] 24 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -0.13274964       , 1e+0, "gal_sgp4", "pv[0][2] 24 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.166974816      , 1e+0, "gal_sgp4", "pv[1][0] 24 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.070104560      , 1e+0, "gal_sgp4", "pv[1][1] 24 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000311007      , 1e+0, "gal_sgp4", "pv[1][2] 24 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -37580.31858370   , 1e+0, "gal_sgp4", "pv[0][0] 24 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -19120.40485693   , 1e+0, "gal_sgp4", "pv[0][1] 24 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2.02755702       , 1e+0, "gal_sgp4", "pv[0][2] 24 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.394367848       , 1e+0, "gal_sgp4", "pv[1][0] 24 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.740341612      , 1e+0, "gal_sgp4", "pv[1][1] 24 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000248591      , 1e+0, "gal_sgp4", "pv[1][2] 24 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -22934.20761876   , 1e+0, "gal_sgp4", "pv[0][0] 24 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -35381.23870806   , 1e+0, "gal_sgp4", "pv[0][1] 24 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3.16495932       , 1e+0, "gal_sgp4", "pv[0][2] 24 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.580167539       , 1e+0, "gal_sgp4", "pv[1][0] 24 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.672360951      , 1e+0, "gal_sgp4", "pv[1][1] 24 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000134907      , 1e+0, "gal_sgp4", "pv[1][2] 24 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2109.90332389    , 1e+0, "gal_sgp4", "pv[0][0] 24 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -42110.71508198   , 1e+0, "gal_sgp4", "pv[0][1] 24 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3.36507889       , 1e+0, "gal_sgp4", "pv[0][2] 24 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 3.070935369       , 1e+0, "gal_sgp4", "pv[1][0] 24 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.153808390      , 1e+0, "gal_sgp4", "pv[1][1] 24 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.000005855      , 1e+0, "gal_sgp4", "pv[1][2] 24 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 19282.77774728    , 1e+0, "gal_sgp4", "pv[0][0] 24 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -37495.59250598   , 1e+0, "gal_sgp4", "pv[0][1] 24 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2.71861462       , 1e+0, "gal_sgp4", "pv[0][2] 24 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.734400524       , 1e+0, "gal_sgp4", "pv[1][0] 24 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.406220933       , 1e+0, "gal_sgp4", "pv[1][1] 24 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000103486       , 1e+0, "gal_sgp4", "pv[1][2] 24 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 35480.60990600    , 1e+0, "gal_sgp4", "pv[0][0] 24 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -22779.03375285   , 1e+0, "gal_sgp4", "pv[0][1] 24 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1.52841859       , 1e+0, "gal_sgp4", "pv[0][2] 24 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.661210676       , 1e+0, "gal_sgp4", "pv[1][0] 24 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.587414593       , 1e+0, "gal_sgp4", "pv[1][1] 24 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000168300       , 1e+0, "gal_sgp4", "pv[1][2] 24 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 42119.96263499    , 1e+0, "gal_sgp4", "pv[0][0] 24 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1925.77567263    , 1e+0, "gal_sgp4", "pv[0][1] 24 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -0.19827433       , 1e+0, "gal_sgp4", "pv[0][2] 24 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.140521206       , 1e+0, "gal_sgp4", "pv[1][0] 24 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.071541613       , 1e+0, "gal_sgp4", "pv[1][1] 24 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.000179561       , 1e+0, "gal_sgp4", "pv[1][2] 24 12" ) ;  

/*
 * MINOTAUR R/B Sub-orbital case - Decayed 2005-11-29  
 */  

/*
 * (perigee = -51km), lost in 50 minutes  
 */  

  strcpy ( card1, "1 28872U 05037B   05333.02012661  .25992681  00000-0  24476-3 0  1534" ) ;  
  strcpy ( card2, "2 28872  96.4736 157.9986 0303955 244.0492 110.6523 16.46015938 10708" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -6131.82730456    , 1e+0, "gal_sgp4", "pv[0][0] 25 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2446.52815528     , 1e+0, "gal_sgp4", "pv[0][1] 25 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -253.64211033     , 1e+0, "gal_sgp4", "pv[0][2] 25 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.144920228      , 1e+0, "gal_sgp4", "pv[1][0] 25 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.995100963       , 1e+0, "gal_sgp4", "pv[1][1] 25 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.658645067       , 1e+0, "gal_sgp4", "pv[1][2] 25 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 5.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5799.24256134    , 1e+0, "gal_sgp4", "pv[0][0] 25 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2589.14811119     , 1e+0, "gal_sgp4", "pv[0][1] 25 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2011.54515100     , 1e+0, "gal_sgp4", "pv[0][2] 25 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.325207364       , 1e+0, "gal_sgp4", "pv[1][0] 25 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.047125672      , 1e+0, "gal_sgp4", "pv[1][1] 25 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.296234071       , 1e+0, "gal_sgp4", "pv[1][2] 25 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 10.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4769.05061967    , 1e+0, "gal_sgp4", "pv[0][0] 25 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2420.46580562     , 1e+0, "gal_sgp4", "pv[0][1] 25 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4035.30855837     , 1e+0, "gal_sgp4", "pv[0][2] 25 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.464585796       , 1e+0, "gal_sgp4", "pv[1][0] 25 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.060923209      , 1e+0, "gal_sgp4", "pv[1][1] 25 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.070907874       , 1e+0, "gal_sgp4", "pv[1][2] 25 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 15.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3175.45157340    , 1e+0, "gal_sgp4", "pv[0][0] 25 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1965.98738086     , 1e+0, "gal_sgp4", "pv[0][1] 25 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5582.12569607     , 1e+0, "gal_sgp4", "pv[0][2] 25 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.049639376       , 1e+0, "gal_sgp4", "pv[1][0] 25 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.935777558      , 1e+0, "gal_sgp4", "pv[1][1] 25 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.148607019       , 1e+0, "gal_sgp4", "pv[1][2] 25 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 20.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -1210.19024802    , 1e+0, "gal_sgp4", "pv[0][0] 25 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1281.54541294     , 1e+0, "gal_sgp4", "pv[0][1] 25 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6474.68172772     , 1e+0, "gal_sgp4", "pv[0][2] 25 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.920746273       , 1e+0, "gal_sgp4", "pv[1][0] 25 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.580517337      , 1e+0, "gal_sgp4", "pv[1][1] 25 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.748783868       , 1e+0, "gal_sgp4", "pv[1][2] 25 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 25.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 896.73799533      , 1e+0, "gal_sgp4", "pv[0][0] 25 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 447.12357305      , 1e+0, "gal_sgp4", "pv[0][1] 25 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6607.22400507     , 1e+0, "gal_sgp4", "pv[0][2] 25 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.983396282       , 1e+0, "gal_sgp4", "pv[1][0] 25 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.925846168      , 1e+0, "gal_sgp4", "pv[1][1] 25 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.872655207      , 1e+0, "gal_sgp4", "pv[1][2] 25 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 30.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2896.99663534     , 1e+0, "gal_sgp4", "pv[0][0] 25 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -440.04738594     , 1e+0, "gal_sgp4", "pv[0][1] 25 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5954.92675486     , 1e+0, "gal_sgp4", "pv[0][2] 25 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.211488246       , 1e+0, "gal_sgp4", "pv[1][0] 25 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.926949815      , 1e+0, "gal_sgp4", "pv[1][1] 25 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.433959806      , 1e+0, "gal_sgp4", "pv[1][2] 25 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 35.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4545.78970167     , 1e+0, "gal_sgp4", "pv[0][0] 25 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1273.55952872    , 1e+0, "gal_sgp4", "pv[0][1] 25 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4580.16512984     , 1e+0, "gal_sgp4", "pv[0][2] 25 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.656984233       , 1e+0, "gal_sgp4", "pv[1][0] 25 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.568711513      , 1e+0, "gal_sgp4", "pv[1][1] 25 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.638510954      , 1e+0, "gal_sgp4", "pv[1][2] 25 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 40.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5627.43299371     , 1e+0, "gal_sgp4", "pv[0][0] 25 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1947.94282469    , 1e+0, "gal_sgp4", "pv[0][1] 25 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2634.16714930     , 1e+0, "gal_sgp4", "pv[0][2] 25 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.464141047       , 1e+0, "gal_sgp4", "pv[1][0] 25 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -1.873985161      , 1e+0, "gal_sgp4", "pv[1][1] 25 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.195743032      , 1e+0, "gal_sgp4", "pv[1][2] 25 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 45.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5984.72318534     , 1e+0, "gal_sgp4", "pv[0][0] 25 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2371.37691609    , 1e+0, "gal_sgp4", "pv[0][1] 25 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 349.87996209      , 1e+0, "gal_sgp4", "pv[0][2] 25 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.121276950      , 1e+0, "gal_sgp4", "pv[1][0] 25 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.911981546      , 1e+0, "gal_sgp4", "pv[1][1] 25 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.859613894      , 1e+0, "gal_sgp4", "pv[1][2] 25 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 50.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5548.43325922     , 1e+0, "gal_sgp4", "pv[0][0] 25 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2480.16469245    , 1e+0, "gal_sgp4", "pv[0][1] 25 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1979.24314527    , 1e+0, "gal_sgp4", "pv[0][2] 25 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.763269534      , 1e+0, "gal_sgp4", "pv[1][0] 25 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.199691915       , 1e+0, "gal_sgp4", "pv[1][1] 25 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.482796996      , 1e+0, "gal_sgp4", "pv[1][2] 25 10" ) ;  

/*
 * SL-14 DEB Last stage of decay - lost in under 420 min  
 */  

  strcpy ( card1, "1 29141U 85108AA  06170.26783845  .99999999  00000-0  13519-0 0   718" ) ;  
  strcpy ( card2, "2 29141  82.4288 273.4882 0015848 277.2124  83.9133 15.93343074  6828" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 423.99295524      , 1e+0, "gal_sgp4", "pv[0][0] 26 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6658.12256149    , 1e+0, "gal_sgp4", "pv[0][1] 26 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 136.13040356      , 1e+0, "gal_sgp4", "pv[0][2] 26 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.006373613       , 1e+0, "gal_sgp4", "pv[1][0] 26 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.217309983       , 1e+0, "gal_sgp4", "pv[1][1] 26 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.662587892       , 1e+0, "gal_sgp4", "pv[1][2] 26 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 20.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 931.80883587      , 1e+0, "gal_sgp4", "pv[0][0] 26 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1017.17852239    , 1e+0, "gal_sgp4", "pv[0][1] 26 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6529.19244527     , 1e+0, "gal_sgp4", "pv[0][2] 26 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.298847918      , 1e+0, "gal_sgp4", "pv[1][0] 26 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 7.613891977       , 1e+0, "gal_sgp4", "pv[1][1] 26 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.226399480       , 1e+0, "gal_sgp4", "pv[1][2] 26 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 40.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -83.44906141      , 1e+0, "gal_sgp4", "pv[0][0] 26 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6286.20208453     , 1e+0, "gal_sgp4", "pv[0][1] 26 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 2223.49837161     , 1e+0, "gal_sgp4", "pv[0][2] 26 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.113515974      , 1e+0, "gal_sgp4", "pv[1][0] 26 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.530970283       , 1e+0, "gal_sgp4", "pv[1][1] 26 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.219445568      , 1e+0, "gal_sgp4", "pv[1][2] 26 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 60.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -958.57681221     , 1e+0, "gal_sgp4", "pv[0][0] 26 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3259.26005348     , 1e+0, "gal_sgp4", "pv[0][1] 26 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5722.63732467    , 1e+0, "gal_sgp4", "pv[0][2] 26 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.101225813      , 1e+0, "gal_sgp4", "pv[1][0] 26 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.735338321      , 1e+0, "gal_sgp4", "pv[1][1] 26 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.804851872      , 1e+0, "gal_sgp4", "pv[1][2] 26 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 80.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -255.25619985     , 1e+0, "gal_sgp4", "pv[0][0] 26 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5132.59762974    , 1e+0, "gal_sgp4", "pv[0][1] 26 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4221.27233118    , 1e+0, "gal_sgp4", "pv[0][2] 26 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.077709303       , 1e+0, "gal_sgp4", "pv[1][0] 26 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.905938824      , 1e+0, "gal_sgp4", "pv[1][1] 26 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.892521264       , 1e+0, "gal_sgp4", "pv[1][2] 26 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 100.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 867.44295097      , 1e+0, "gal_sgp4", "pv[0][0] 26 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5038.40402933    , 1e+0, "gal_sgp4", "pv[0][1] 26 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4256.73810533     , 1e+0, "gal_sgp4", "pv[0][2] 26 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.479447535       , 1e+0, "gal_sgp4", "pv[1][0] 26 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.032326446       , 1e+0, "gal_sgp4", "pv[1][1] 26 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.857126248       , 1e+0, "gal_sgp4", "pv[1][2] 26 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 559.16882013      , 1e+0, "gal_sgp4", "pv[0][0] 26 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3376.30587937     , 1e+0, "gal_sgp4", "pv[0][1] 26 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5699.22017391     , 1e+0, "gal_sgp4", "pv[0][2] 26 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.906749328      , 1e+0, "gal_sgp4", "pv[1][0] 26 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.646149867       , 1e+0, "gal_sgp4", "pv[1][1] 26 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.852331832      , 1e+0, "gal_sgp4", "pv[1][2] 26 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 140.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -669.85184205     , 1e+0, "gal_sgp4", "pv[0][0] 26 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6196.00229484     , 1e+0, "gal_sgp4", "pv[0][1] 26 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2281.95741770    , 1e+0, "gal_sgp4", "pv[0][2] 26 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.795804092      , 1e+0, "gal_sgp4", "pv[1][0] 26 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -2.752114827      , 1e+0, "gal_sgp4", "pv[1][1] 26 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.202478520      , 1e+0, "gal_sgp4", "pv[1][2] 26 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 160.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -784.20708019     , 1e+0, "gal_sgp4", "pv[0][0] 26 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1278.53125553    , 1e+0, "gal_sgp4", "pv[0][1] 26 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6449.19892596    , 1e+0, "gal_sgp4", "pv[0][2] 26 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.636702380       , 1e+0, "gal_sgp4", "pv[1][0] 26 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.595425203      , 1e+0, "gal_sgp4", "pv[1][1] 26 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.431090802       , 1e+0, "gal_sgp4", "pv[1][2] 26 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 180.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 406.15811659      , 1e+0, "gal_sgp4", "pv[0][0] 26 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6607.03115799    , 1e+0, "gal_sgp4", "pv[0][1] 26 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 148.33021477      , 1e+0, "gal_sgp4", "pv[0][2] 26 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.009818575       , 1e+0, "gal_sgp4", "pv[1][0] 26 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.231843765       , 1e+0, "gal_sgp4", "pv[1][1] 26 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.692047844       , 1e+0, "gal_sgp4", "pv[1][2] 26 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 916.34911813      , 1e+0, "gal_sgp4", "pv[0][0] 26 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -884.08649248     , 1e+0, "gal_sgp4", "pv[0][1] 26 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6491.09810362     , 1e+0, "gal_sgp4", "pv[0][2] 26 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.302163049      , 1e+0, "gal_sgp4", "pv[1][0] 26 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 7.669887109       , 1e+0, "gal_sgp4", "pv[1][1] 26 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.084336909       , 1e+0, "gal_sgp4", "pv[1][2] 26 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 220.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -104.02490970     , 1e+0, "gal_sgp4", "pv[0][0] 26 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6304.31821405     , 1e+0, "gal_sgp4", "pv[0][1] 26 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1960.08739882     , 1e+0, "gal_sgp4", "pv[0][2] 26 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.108873823      , 1e+0, "gal_sgp4", "pv[1][0] 26 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.259522809       , 1e+0, "gal_sgp4", "pv[1][1] 26 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.351147710      , 1e+0, "gal_sgp4", "pv[1][2] 26 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -944.61642849     , 1e+0, "gal_sgp4", "pv[0][0] 26 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2872.17248379     , 1e+0, "gal_sgp4", "pv[0][1] 26 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5846.94103362    , 1e+0, "gal_sgp4", "pv[0][2] 26 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.051117686      , 1e+0, "gal_sgp4", "pv[1][0] 26 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.989747076      , 1e+0, "gal_sgp4", "pv[1][1] 26 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.413102600      , 1e+0, "gal_sgp4", "pv[1][2] 26 12" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 260.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -187.16569888     , 1e+0, "gal_sgp4", "pv[0][0] 26 13" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5404.86163467    , 1e+0, "gal_sgp4", "pv[0][1] 26 13" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3731.97057618    , 1e+0, "gal_sgp4", "pv[0][2] 26 13" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.094696706       , 1e+0, "gal_sgp4", "pv[1][0] 26 13" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.412110995      , 1e+0, "gal_sgp4", "pv[1][1] 26 13" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.326060952       , 1e+0, "gal_sgp4", "pv[1][2] 26 13" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 280.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 884.59720467      , 1e+0, "gal_sgp4", "pv[0][0] 26 14" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4465.74516163    , 1e+0, "gal_sgp4", "pv[0][1] 26 14" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4725.83632696     , 1e+0, "gal_sgp4", "pv[0][2] 26 14" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.380656028       , 1e+0, "gal_sgp4", "pv[1][0] 26 14" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.691554046       , 1e+0, "gal_sgp4", "pv[1][1] 26 14" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.303910983       , 1e+0, "gal_sgp4", "pv[1][2] 26 14" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 300.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 446.40767236      , 1e+0, "gal_sgp4", "pv[0][0] 26 15" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4086.66839620     , 1e+0, "gal_sgp4", "pv[0][1] 26 15" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5093.05596650     , 1e+0, "gal_sgp4", "pv[0][2] 26 15" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.982424447      , 1e+0, "gal_sgp4", "pv[1][0] 26 15" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.072965199       , 1e+0, "gal_sgp4", "pv[1][1] 26 15" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -4.791630682      , 1e+0, "gal_sgp4", "pv[1][2] 26 15" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -752.24467495     , 1e+0, "gal_sgp4", "pv[0][0] 26 16" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5588.35473301     , 1e+0, "gal_sgp4", "pv[0][1] 26 16" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3275.04092573    , 1e+0, "gal_sgp4", "pv[0][2] 26 16" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.661161370      , 1e+0, "gal_sgp4", "pv[1][0] 26 16" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -4.016290740      , 1e+0, "gal_sgp4", "pv[1][1] 26 16" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.676898026      , 1e+0, "gal_sgp4", "pv[1][2] 26 16" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 340.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -643.72872525     , 1e+0, "gal_sgp4", "pv[0][0] 26 17" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2585.02528560    , 1e+0, "gal_sgp4", "pv[0][1] 26 17" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5923.01306608    , 1e+0, "gal_sgp4", "pv[0][2] 26 17" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.807922142       , 1e+0, "gal_sgp4", "pv[1][0] 26 17" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.171597814      , 1e+0, "gal_sgp4", "pv[1][1] 26 17" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.041115058       , 1e+0, "gal_sgp4", "pv[1][2] 26 17" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 584.40295819      , 1e+0, "gal_sgp4", "pv[0][0] 26 18" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6202.35605817    , 1e+0, "gal_sgp4", "pv[0][1] 26 18" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1781.00536019     , 1e+0, "gal_sgp4", "pv[0][2] 26 18" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.869250450       , 1e+0, "gal_sgp4", "pv[1][0] 26 18" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.226927514       , 1e+0, "gal_sgp4", "pv[1][1] 26 18" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 7.471676765       , 1e+0, "gal_sgp4", "pv[1][2] 26 18" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 380.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 779.59211765      , 1e+0, "gal_sgp4", "pv[0][0] 26 19" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1100.73728301     , 1e+0, "gal_sgp4", "pv[0][1] 26 19" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 6311.59529480     , 1e+0, "gal_sgp4", "pv[0][2] 26 19" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.599552305      , 1e+0, "gal_sgp4", "pv[1][0] 26 19" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 7.721032522       , 1e+0, "gal_sgp4", "pv[1][1] 26 19" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -1.275153027      , 1e+0, "gal_sgp4", "pv[1][2] 26 19" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 400.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -403.03155588     , 1e+0, "gal_sgp4", "pv[0][0] 26 20" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 6399.18000837     , 1e+0, "gal_sgp4", "pv[0][1] 26 20" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -364.12735875     , 1e+0, "gal_sgp4", "pv[0][2] 26 20" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -1.008861924      , 1e+0, "gal_sgp4", "pv[1][0] 26 20" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.516636615      , 1e+0, "gal_sgp4", "pv[1][1] 26 20" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.799812287      , 1e+0, "gal_sgp4", "pv[1][2] 26 20" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 420.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -852.93910071     , 1e+0, "gal_sgp4", "pv[0][0] 26 21" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 192.65232023      , 1e+0, "gal_sgp4", "pv[0][1] 26 21" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6322.47054784    , 1e+0, "gal_sgp4", "pv[0][2] 26 21" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.396006194       , 1e+0, "gal_sgp4", "pv[1][0] 26 21" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -7.882964919      , 1e+0, "gal_sgp4", "pv[1][1] 26 21" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.289331517      , 1e+0, "gal_sgp4", "pv[1][2] 26 21" ) ;  

/*
 * SL-12 DEB Near Earth, perigee = 212.24 < 220  
 */  

/*
 * simplified drag eq  
 */  

  strcpy ( card1, "1 29238U 06022G   06177.28732010  .00766286  10823-4  13334-2 0   101" ) ;  
  strcpy ( card2, "2 29238  51.5595 213.7903 0202579  95.2503 267.9010 15.73823839  1061" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5566.59512819    , 1e+0, "gal_sgp4", "pv[0][0] 27 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3789.75991159    , 1e+0, "gal_sgp4", "pv[0][1] 27 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 67.60382245       , 1e+0, "gal_sgp4", "pv[0][2] 27 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.873759367       , 1e+0, "gal_sgp4", "pv[1][0] 27 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.825340523      , 1e+0, "gal_sgp4", "pv[1][1] 27 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 6.023253926       , 1e+0, "gal_sgp4", "pv[1][2] 27 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4474.27915495     , 1e+0, "gal_sgp4", "pv[0][0] 27 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -1447.72286142    , 1e+0, "gal_sgp4", "pv[0][1] 27 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4619.83927235     , 1e+0, "gal_sgp4", "pv[0][2] 27 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 4.712595822       , 1e+0, "gal_sgp4", "pv[1][0] 27 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.668306153       , 1e+0, "gal_sgp4", "pv[1][1] 27 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -2.701606741      , 1e+0, "gal_sgp4", "pv[1][2] 27 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1922.17712474     , 1e+0, "gal_sgp4", "pv[0][0] 27 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 5113.01138342     , 1e+0, "gal_sgp4", "pv[0][1] 27 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4087.08470203    , 1e+0, "gal_sgp4", "pv[0][2] 27 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -6.490769651      , 1e+0, "gal_sgp4", "pv[1][0] 27 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.522350158      , 1e+0, "gal_sgp4", "pv[1][1] 27 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -3.896001154      , 1e+0, "gal_sgp4", "pv[1][2] 27 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -6157.93546882    , 1e+0, "gal_sgp4", "pv[0][0] 27 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -2094.70798790    , 1e+0, "gal_sgp4", "pv[0][1] 27 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -1941.63730960    , 1e+0, "gal_sgp4", "pv[0][2] 27 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 0.149900661       , 1e+0, "gal_sgp4", "pv[1][0] 27 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.175192523      , 1e+0, "gal_sgp4", "pv[1][1] 27 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.604262034       , 1e+0, "gal_sgp4", "pv[1][2] 27 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2482.64052411     , 1e+0, "gal_sgp4", "pv[0][0] 27 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -3268.45944555    , 1e+0, "gal_sgp4", "pv[0][1] 27 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5146.38006190     , 1e+0, "gal_sgp4", "pv[0][2] 27 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.501814698       , 1e+0, "gal_sgp4", "pv[1][0] 27 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 4.402848754       , 1e+0, "gal_sgp4", "pv[1][1] 27 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -0.350943511      , 1e+0, "gal_sgp4", "pv[1][2] 27 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 4036.26455287     , 1e+0, "gal_sgp4", "pv[0][0] 27 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 4827.43347201     , 1e+0, "gal_sgp4", "pv[0][1] 27 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -2507.99063955    , 1e+0, "gal_sgp4", "pv[0][2] 27 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -5.184409515      , 1e+0, "gal_sgp4", "pv[1][0] 27 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.772280695       , 1e+0, "gal_sgp4", "pv[1][1] 27 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.331390168      , 1e+0, "gal_sgp4", "pv[1][2] 27 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -5776.81371622    , 1e+0, "gal_sgp4", "pv[0][0] 27 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -118.64155319     , 1e+0, "gal_sgp4", "pv[0][1] 27 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -3641.22052418    , 1e+0, "gal_sgp4", "pv[0][2] 27 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -2.539917207      , 1e+0, "gal_sgp4", "pv[1][0] 27 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.622701582      , 1e+0, "gal_sgp4", "pv[1][1] 27 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.403125405       , 1e+0, "gal_sgp4", "pv[1][2] 27 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 67.98699487       , 1e+0, "gal_sgp4", "pv[0][0] 27 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4456.49213473    , 1e+0, "gal_sgp4", "pv[0][1] 27 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4863.71794283     , 1e+0, "gal_sgp4", "pv[0][2] 27 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 7.183809420       , 1e+0, "gal_sgp4", "pv[1][0] 27 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 2.418917791       , 1e+0, "gal_sgp4", "pv[1][1] 27 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.015642495       , 1e+0, "gal_sgp4", "pv[1][2] 27 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 5520.62207038     , 1e+0, "gal_sgp4", "pv[0][0] 27 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3782.38203554     , 1e+0, "gal_sgp4", "pv[0][1] 27 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -596.73193161     , 1e+0, "gal_sgp4", "pv[0][2] 27 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.027966069      , 1e+0, "gal_sgp4", "pv[1][0] 27 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 3.754152525       , 1e+0, "gal_sgp4", "pv[1][1] 27 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -6.013506363      , 1e+0, "gal_sgp4", "pv[1][2] 27 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -4528.05104455    , 1e+0, "gal_sgp4", "pv[0][0] 27 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 1808.46273329     , 1e+0, "gal_sgp4", "pv[0][1] 27 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -4816.99727762    , 1e+0, "gal_sgp4", "pv[0][2] 27 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -4.808419763      , 1e+0, "gal_sgp4", "pv[1][0] 27 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.185789345      , 1e+0, "gal_sgp4", "pv[1][1] 27 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.642104494       , 1e+0, "gal_sgp4", "pv[1][2] 27 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2356.61468078    , 1e+0, "gal_sgp4", "pv[0][0] 27 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -4852.51202272    , 1e+0, "gal_sgp4", "pv[0][1] 27 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 3856.53816184     , 1e+0, "gal_sgp4", "pv[0][2] 27 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 6.688446735       , 1e+0, "gal_sgp4", "pv[1][0] 27 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.118520958       , 1e+0, "gal_sgp4", "pv[1][1] 27 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.021854210       , 1e+0, "gal_sgp4", "pv[1][2] 27 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 6149.65800134     , 1e+0, "gal_sgp4", "pv[0][0] 27 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2173.59423261     , 1e+0, "gal_sgp4", "pv[0][1] 27 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1369.29488732     , 1e+0, "gal_sgp4", "pv[0][2] 27 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -0.345832777      , 1e+0, "gal_sgp4", "pv[1][0] 27 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.109857861       , 1e+0, "gal_sgp4", "pv[1][1] 27 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -5.842951828      , 1e+0, "gal_sgp4", "pv[1][2] 27 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2629.55011449    , 1e+0, "gal_sgp4", "pv[0][0] 27 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3400.98040158     , 1e+0, "gal_sgp4", "pv[0][1] 27 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5344.38217129    , 1e+0, "gal_sgp4", "pv[0][2] 27 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -6.368548448      , 1e+0, "gal_sgp4", "pv[1][0] 27 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -3.998963509      , 1e+0, "gal_sgp4", "pv[1][1] 27 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 0.577253064       , 1e+0, "gal_sgp4", "pv[1][2] 27 12" ) ;  

/*
 * Original STR3 SGP4 test  
 */  

  strcpy ( card1, "1 88888U          80275.98708465  .00073094  13844-3  66816-4 0    87" ) ;  
  strcpy ( card2, "2 88888  72.8435 115.9689 0086731  52.6988 110.5714 16.05824518  1058" ) ;  

  gal_tledec ( card1, card2, &tle ) ; 

  gal_sgp4init ( &gal_gmwgs72, &tle, &sgp4 ) ;  

  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 0.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2328.96975262     , 1e+0, "gal_sgp4", "pv[0][0] 28 0" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -5995.22051338    , 1e+0, "gal_sgp4", "pv[0][1] 28 0" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1719.97297192     , 1e+0, "gal_sgp4", "pv[0][2] 28 0" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.912073281       , 1e+0, "gal_sgp4", "pv[1][0] 28 0" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.983417956      , 1e+0, "gal_sgp4", "pv[1][1] 28 0" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.090816210      , 1e+0, "gal_sgp4", "pv[1][2] 28 0" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 120.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 1020.69234558     , 1e+0, "gal_sgp4", "pv[0][0] 28 1" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2286.56260634     , 1e+0, "gal_sgp4", "pv[0][1] 28 1" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6191.55565927    , 1e+0, "gal_sgp4", "pv[0][2] 28 1" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.746543902      , 1e+0, "gal_sgp4", "pv[1][0] 28 1" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.467532721       , 1e+0, "gal_sgp4", "pv[1][1] 28 1" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 1.827985678       , 1e+0, "gal_sgp4", "pv[1][2] 28 1" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 240.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3226.54349155    , 1e+0, "gal_sgp4", "pv[0][0] 28 2" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3503.70977525     , 1e+0, "gal_sgp4", "pv[0][1] 28 2" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4532.80979343     , 1e+0, "gal_sgp4", "pv[0][2] 28 2" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.000992116       , 1e+0, "gal_sgp4", "pv[1][0] 28 2" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -5.788042888      , 1e+0, "gal_sgp4", "pv[1][1] 28 2" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 5.162585826       , 1e+0, "gal_sgp4", "pv[1][2] 28 2" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 360.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2456.10706533     , 1e+0, "gal_sgp4", "pv[0][0] 28 3" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6071.93855503    , 1e+0, "gal_sgp4", "pv[0][1] 28 3" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 1222.89768554     , 1e+0, "gal_sgp4", "pv[0][2] 28 3" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.679390040       , 1e+0, "gal_sgp4", "pv[1][0] 28 3" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -0.448290811      , 1e+0, "gal_sgp4", "pv[1][1] 28 3" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.228792155      , 1e+0, "gal_sgp4", "pv[1][2] 28 3" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 480.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 787.16457349      , 1e+0, "gal_sgp4", "pv[0][0] 28 4" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2719.91800946     , 1e+0, "gal_sgp4", "pv[0][1] 28 4" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -6043.86662024    , 1e+0, "gal_sgp4", "pv[0][2] 28 4" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.759883839      , 1e+0, "gal_sgp4", "pv[1][0] 28 4" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.277439314       , 1e+0, "gal_sgp4", "pv[1][1] 28 4" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.397897864       , 1e+0, "gal_sgp4", "pv[1][2] 28 4" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 600.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -3110.97648029    , 1e+0, "gal_sgp4", "pv[0][0] 28 5" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3121.73026235     , 1e+0, "gal_sgp4", "pv[0][1] 28 5" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 4878.15217035     , 1e+0, "gal_sgp4", "pv[0][2] 28 5" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.244916056       , 1e+0, "gal_sgp4", "pv[1][0] 28 5" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.124880425      , 1e+0, "gal_sgp4", "pv[1][1] 28 5" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.700576353       , 1e+0, "gal_sgp4", "pv[1][2] 28 5" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 720.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2567.56229695     , 1e+0, "gal_sgp4", "pv[0][0] 28 6" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6112.50383922    , 1e+0, "gal_sgp4", "pv[0][1] 28 6" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 713.96374435      , 1e+0, "gal_sgp4", "pv[0][2] 28 6" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.440245751       , 1e+0, "gal_sgp4", "pv[1][0] 28 6" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.098109002       , 1e+0, "gal_sgp4", "pv[1][1] 28 6" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.319959258      , 1e+0, "gal_sgp4", "pv[1][2] 28 6" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 840.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 556.05661780      , 1e+0, "gal_sgp4", "pv[0][0] 28 7" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3144.52288201     , 1e+0, "gal_sgp4", "pv[0][1] 28 7" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5855.34636178    , 1e+0, "gal_sgp4", "pv[0][2] 28 7" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.754660143      , 1e+0, "gal_sgp4", "pv[1][0] 28 7" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 6.044752775       , 1e+0, "gal_sgp4", "pv[1][1] 28 7" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 2.957941672       , 1e+0, "gal_sgp4", "pv[1][2] 28 7" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 960.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2982.47940539    , 1e+0, "gal_sgp4", "pv[0][0] 28 8" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2712.61663711     , 1e+0, "gal_sgp4", "pv[0][1] 28 8" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5192.32330472     , 1e+0, "gal_sgp4", "pv[0][2] 28 8" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.475566773       , 1e+0, "gal_sgp4", "pv[1][0] 28 8" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.427737014      , 1e+0, "gal_sgp4", "pv[1][1] 28 8" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 4.202420227       , 1e+0, "gal_sgp4", "pv[1][2] 28 8" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1080.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2663.08964352     , 1e+0, "gal_sgp4", "pv[0][0] 28 9" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6115.48290885    , 1e+0, "gal_sgp4", "pv[0][1] 28 9" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 196.40072866      , 1e+0, "gal_sgp4", "pv[0][2] 28 9" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 2.196121564       , 1e+0, "gal_sgp4", "pv[1][0] 28 9" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 0.652415093       , 1e+0, "gal_sgp4", "pv[1][1] 28 9" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.362824152      , 1e+0, "gal_sgp4", "pv[1][2] 28 9" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1200.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 328.54999674      , 1e+0, "gal_sgp4", "pv[0][0] 28 10" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 3557.09490552     , 1e+0, "gal_sgp4", "pv[0][1] 28 10" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -5626.21427211    , 1e+0, "gal_sgp4", "pv[0][2] 28 10" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * -3.731193288      , 1e+0, "gal_sgp4", "pv[1][0] 28 10" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 5.769341172       , 1e+0, "gal_sgp4", "pv[1][1] 28 10" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.504058731       , 1e+0, "gal_sgp4", "pv[1][2] 28 10" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1320.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * -2842.06876757    , 1e+0, "gal_sgp4", "pv[0][0] 28 11" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * 2278.42343492     , 1e+0, "gal_sgp4", "pv[0][1] 28 11" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * 5472.33437150     , 1e+0, "gal_sgp4", "pv[0][2] 28 11" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.691852635       , 1e+0, "gal_sgp4", "pv[1][0] 28 11" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * -6.693216335      , 1e+0, "gal_sgp4", "pv[1][1] 28 11" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * 3.671022712       , 1e+0, "gal_sgp4", "pv[1][2] 28 11" ) ;  
  gal_sgp4 ( &sgp4, sgp4.jdepoch1, sgp4.jdepoch2 + 1440.00000000 / 1440.0 , pv ) ; 
  gal_vdv ( pv[0][0], GAL_KM2M * 2742.55398832     , 1e+0, "gal_sgp4", "pv[0][0] 28 12" ) ;  
  gal_vdv ( pv[0][1], GAL_KM2M * -6079.67009123    , 1e+0, "gal_sgp4", "pv[0][1] 28 12" ) ;  
  gal_vdv ( pv[0][2], GAL_KM2M * -326.39012649     , 1e+0, "gal_sgp4", "pv[0][2] 28 12" ) ;  
  gal_vdv ( pv[1][0], GAL_KM2M * 1.948497651       , 1e+0, "gal_sgp4", "pv[1][0] 28 12" ) ;  
  gal_vdv ( pv[1][1], GAL_KM2M * 1.211072678       , 1e+0, "gal_sgp4", "pv[1][1] 28 12" ) ;  
  gal_vdv ( pv[1][2], GAL_KM2M * -7.356193131      , 1e+0, "gal_sgp4", "pv[1][2] 28 12" ) ;  

/*
 *   
 */  
  
  gal_tfunc++ ;  

/*  
 * Finished.  
 */  
 
}

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  

